C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE LU_decompose (M)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes an LU factorization of M.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     M: on entry, an invertible matrix. On exit, an LU factorization
C     of M.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of 'chemical' arrays.

      INCLUDE 'PARACHEM.INC'

      DOUBLE PRECISION M(Nesp,Nesp)
      DOUBLE PRECISION temp



C     Upper part.
      M(2, 35) = M(2, 35) / M(2, 2)

C     Upper part.
      temp = M(3, 2) * M(2, 35)
      M(3, 35) = ( M(3, 35) - temp ) / M(3, 3)

C     Upper part.
      M(4, 35) = M(4, 35) / M(4, 4)

C     Upper part.
      M(5, 35) = M(5, 35) / M(5, 5)

C     Upper part.
      M(6, 16) = M(6, 16) / M(6, 6)
C     Upper part.
      M(6, 26) = M(6, 26) / M(6, 6)

C     Upper part.
      M(7, 30) = M(7, 30) / M(7, 7)
C     Upper part.
      M(7, 34) = M(7, 34) / M(7, 7)

C     Upper part.
      M(8, 33) = M(8, 33) / M(8, 8)
C     Upper part.
      temp = M(8, 4) * M(4, 35)
      temp = temp + M(8, 5) * M(5, 35)
      M(8, 35) = ( M(8, 35) - temp ) / M(8, 8)

C     Upper part.
      M(9, 29) = M(9, 29) / M(9, 9)
C     Upper part.
      temp = M(9, 8) * M(8, 33)
      M(9, 33) = ( M(9, 33) - temp ) / M(9, 9)
C     Upper part.
      temp = M(9, 4) * M(4, 35)
      temp = temp + M(9, 5) * M(5, 35)
      temp = temp + M(9, 8) * M(8, 35)
      M(9, 35) = ( M(9, 35) - temp ) / M(9, 9)

C     Upper part.
      M(10, 16) = M(10, 16) / M(10, 10)
C     Upper part.
      M(10, 29) = M(10, 29) / M(10, 10)
C     Upper part.
      M(10, 34) = M(10, 34) / M(10, 10)

C     Upper part.
      M(11, 26) = M(11, 26) / M(11, 11)
C     Upper part.
      temp = M(11, 9) * M(9, 29)
      M(11, 29) = ( M(11, 29) - temp ) / M(11, 11)
C     Upper part.
      temp = M(11, 8) * M(8, 33)
      temp = temp + M(11, 9) * M(9, 33)
      M(11, 33) = ( M(11, 33) - temp ) / M(11, 11)
C     Upper part.
      temp = M(11, 8) * M(8, 35)
      temp = temp + M(11, 9) * M(9, 35)
      M(11, 35) = ( M(11, 35) - temp ) / M(11, 11)

C     Upper part.
      M(12, 20) = M(12, 20) / M(12, 12)
C     Upper part.
      temp = M(12, 11) * M(11, 26)
      M(12, 26) = ( M(12, 26) - temp ) / M(12, 12)
C     Upper part.
      temp = M(12, 11) * M(11, 29)
      M(12, 29) = ( M(12, 29) - temp ) / M(12, 12)
C     Upper part.
      temp = M(12, 11) * M(11, 33)
      M(12, 33) = ( M(12, 33) - temp ) / M(12, 12)
C     Upper part.
      temp = M(12, 5) * M(5, 35)
      temp = temp + M(12, 11) * M(11, 35)
      M(12, 35) = ( M(12, 35) - temp ) / M(12, 12)

C     Upper part.
      M(13, 34) = M(13, 34) / M(13, 13)
C     Upper part.
      M(13, 35) = M(13, 35) / M(13, 13)
C     Upper part.
      M(13, 36) = M(13, 36) / M(13, 13)

C     Upper part.
      M(14, 22) = M(14, 22) / M(14, 14)
C     Upper part.
      M(14, 34) = M(14, 34) / M(14, 14)
C     Upper part.
      M(14, 35) = M(14, 35) / M(14, 14)

C     Upper part.
      M(15, 16) = M(15, 16) / M(15, 15)
C     Upper part.
      M(15, 35) = M(15, 35) / M(15, 15)
C     Upper part.
      M(15, 36) = M(15, 36) / M(15, 15)

C     Lower part.
      temp = M(16, 6) * M(6, 16)
      temp = temp + M(16, 10) * M(10, 16)
      M(16, 16) = M(16, 16) - temp
C     Lower part.
      temp = M(24, 10) * M(10, 16)
      M(24, 16) = M(24, 16) - temp
C     Lower part.
      temp = M(27, 6) * M(6, 16)
      M(27, 16) = M(27, 16) - temp
C     Lower part.
      temp = M(29, 10) * M(10, 16)
      M(29, 16) = M(29, 16) - temp
C     Lower part.
      temp = M(34, 10) * M(10, 16)
      M(34, 16) = M(34, 16) - temp
C     Lower part.
      temp = M(35, 6) * M(6, 16)
      temp = temp + M(35, 15) * M(15, 16)
      M(35, 16) = M(35, 16) - temp
C     Lower part.
      temp = M(36, 15) * M(15, 16)
      M(36, 16) = M(36, 16) - temp
C     Upper part.
      temp = M(16, 6) * M(6, 26)
      M(16, 26) = ( M(16, 26) - temp ) / M(16, 16)
C     Upper part.
      temp = M(16, 10) * M(10, 29)
      M(16, 29) = ( M(16, 29) - temp ) / M(16, 16)
C     Upper part.
      M(16, 33) = M(16, 33) / M(16, 16)
C     Upper part.
      temp = M(16, 10) * M(10, 34)
      M(16, 34) = ( M(16, 34) - temp ) / M(16, 16)
C     Upper part.
      M(16, 36) = M(16, 36) / M(16, 16)

C     Upper part.
      temp = M(17, 16) * M(16, 26)
      M(17, 26) = ( M(17, 26) - temp ) / M(17, 17)
C     Upper part.
      temp = M(17, 16) * M(16, 29)
      M(17, 29) = ( M(17, 29) - temp ) / M(17, 17)
C     Upper part.
      temp = M(17, 16) * M(16, 33)
      M(17, 33) = ( M(17, 33) - temp ) / M(17, 17)
C     Upper part.
      temp = M(17, 16) * M(16, 34)
      M(17, 34) = ( M(17, 34) - temp ) / M(17, 17)
C     Upper part.
      M(17, 35) = M(17, 35) / M(17, 17)
C     Upper part.
      temp = M(17, 16) * M(16, 36)
      M(17, 36) = ( M(17, 36) - temp ) / M(17, 17)

C     Upper part.
      temp = M(18, 9) * M(9, 29)
      M(18, 29) = ( M(18, 29) - temp ) / M(18, 18)
C     Upper part.
      temp = M(18, 9) * M(9, 33)
      M(18, 33) = ( M(18, 33) - temp ) / M(18, 18)
C     Upper part.
      M(18, 34) = M(18, 34) / M(18, 18)
C     Upper part.
      temp = M(18, 9) * M(9, 35)
      M(18, 35) = ( M(18, 35) - temp ) / M(18, 18)

C     Upper part.
      M(19, 20) = M(19, 20) / M(19, 19)
C     Upper part.
      M(19, 26) = M(19, 26) / M(19, 19)
C     Upper part.
      M(19, 27) = M(19, 27) / M(19, 19)
C     Upper part.
      M(19, 35) = M(19, 35) / M(19, 19)

C     Lower part.
      temp = M(23, 19) * M(19, 20)
      M(23, 20) = M(23, 20) - temp
C     Lower part.
      temp = M(26, 19) * M(19, 20)
      M(26, 20) = M(26, 20) - temp
C     Lower part.
      temp = M(27, 19) * M(19, 20)
      M(27, 20) = M(27, 20) - temp
C     Lower part.
      temp = M(28, 12) * M(12, 20)
      temp = temp + M(28, 19) * M(19, 20)
      M(28, 20) = M(28, 20) - temp
C     Lower part.
      temp = M(30, 12) * M(12, 20)
      M(30, 20) = M(30, 20) - temp
C     Lower part.
      temp = M(31, 19) * M(19, 20)
      M(31, 20) = M(31, 20) - temp
C     Lower part.
      temp = M(32, 12) * M(12, 20)
      temp = temp + M(32, 19) * M(19, 20)
      M(32, 20) = M(32, 20) - temp
C     Lower part.
      temp = M(35, 12) * M(12, 20)
      temp = temp + M(35, 19) * M(19, 20)
      M(35, 20) = M(35, 20) - temp
C     Lower part.
      temp = M(36, 12) * M(12, 20)
      temp = temp + M(36, 19) * M(19, 20)
      M(36, 20) = M(36, 20) - temp
C     Upper part.
      M(20, 26) = M(20, 26) / M(20, 20)
C     Upper part.
      M(20, 27) = M(20, 27) / M(20, 20)
C     Upper part.
      M(20, 29) = M(20, 29) / M(20, 20)
C     Upper part.
      M(20, 35) = M(20, 35) / M(20, 20)

C     Upper part.
      temp = M(21, 20) * M(20, 26)
      M(21, 26) = ( M(21, 26) - temp ) / M(21, 21)
C     Upper part.
      temp = M(21, 20) * M(20, 27)
      M(21, 27) = ( M(21, 27) - temp ) / M(21, 21)
C     Upper part.
      temp = M(21, 20) * M(20, 29)
      M(21, 29) = ( M(21, 29) - temp ) / M(21, 21)
C     Upper part.
      temp = M(21, 20) * M(20, 35)
      M(21, 35) = ( M(21, 35) - temp ) / M(21, 21)

C     Lower part.
      temp = M(22, 14) * M(14, 22)
      M(22, 22) = M(22, 22) - temp
C     Lower part.
      temp = M(23, 14) * M(14, 22)
      M(23, 22) = M(23, 22) - temp
C     Lower part.
      temp = M(25, 14) * M(14, 22)
      M(25, 22) = M(25, 22) - temp
C     Lower part.
      temp = M(32, 14) * M(14, 22)
      M(32, 22) = M(32, 22) - temp
C     Lower part.
      temp = M(34, 14) * M(14, 22)
      M(34, 22) = M(34, 22) - temp
C     Lower part.
      temp = M(36, 14) * M(14, 22)
      M(36, 22) = M(36, 22) - temp
C     Upper part.
      temp = M(22, 20) * M(20, 26)
      temp = temp + M(22, 21) * M(21, 26)
      M(22, 26) = ( M(22, 26) - temp ) / M(22, 22)
C     Upper part.
      temp = M(22, 20) * M(20, 27)
      temp = temp + M(22, 21) * M(21, 27)
      M(22, 27) = ( M(22, 27) - temp ) / M(22, 22)
C     Upper part.
      temp = M(22, 20) * M(20, 29)
      temp = temp + M(22, 21) * M(21, 29)
      M(22, 29) = ( M(22, 29) - temp ) / M(22, 22)
C     Upper part.
      temp = M(22, 14) * M(14, 34)
      M(22, 34) = ( M(22, 34) - temp ) / M(22, 22)
C     Upper part.
      temp = M(22, 5) * M(5, 35)
      temp = temp + M(22, 14) * M(14, 35)
      temp = temp + M(22, 20) * M(20, 35)
      temp = temp + M(22, 21) * M(21, 35)
      M(22, 35) = ( M(22, 35) - temp ) / M(22, 22)

C     Upper part.
      temp = M(23, 11) * M(11, 26)
      temp = temp + M(23, 19) * M(19, 26)
      temp = temp + M(23, 20) * M(20, 26)
      temp = temp + M(23, 21) * M(21, 26)
      temp = temp + M(23, 22) * M(22, 26)
      M(23, 26) = ( M(23, 26) - temp ) / M(23, 23)
C     Upper part.
      temp = M(23, 19) * M(19, 27)
      temp = temp + M(23, 20) * M(20, 27)
      temp = temp + M(23, 21) * M(21, 27)
      temp = temp + M(23, 22) * M(22, 27)
      M(23, 27) = ( M(23, 27) - temp ) / M(23, 23)
C     Upper part.
      temp = M(23, 11) * M(11, 29)
      temp = temp + M(23, 20) * M(20, 29)
      temp = temp + M(23, 21) * M(21, 29)
      temp = temp + M(23, 22) * M(22, 29)
      M(23, 29) = ( M(23, 29) - temp ) / M(23, 23)
C     Upper part.
      temp = M(23, 11) * M(11, 33)
      M(23, 33) = ( M(23, 33) - temp ) / M(23, 23)
C     Upper part.
      temp = M(23, 14) * M(14, 34)
      temp = temp + M(23, 22) * M(22, 34)
      M(23, 34) = ( M(23, 34) - temp ) / M(23, 23)
C     Upper part.
      temp = M(23, 11) * M(11, 35)
      temp = temp + M(23, 14) * M(14, 35)
      temp = temp + M(23, 19) * M(19, 35)
      temp = temp + M(23, 20) * M(20, 35)
      temp = temp + M(23, 21) * M(21, 35)
      temp = temp + M(23, 22) * M(22, 35)
      M(23, 35) = ( M(23, 35) - temp ) / M(23, 23)

C     Upper part.
      temp = M(24, 16) * M(16, 26)
      temp = temp + M(24, 23) * M(23, 26)
      M(24, 26) = ( M(24, 26) - temp ) / M(24, 24)
C     Upper part.
      temp = M(24, 23) * M(23, 27)
      M(24, 27) = ( M(24, 27) - temp ) / M(24, 24)
C     Upper part.
      temp = M(24, 9) * M(9, 29)
      temp = temp + M(24, 10) * M(10, 29)
      temp = temp + M(24, 16) * M(16, 29)
      temp = temp + M(24, 23) * M(23, 29)
      M(24, 29) = ( M(24, 29) - temp ) / M(24, 24)
C     Upper part.
      M(24, 31) = M(24, 31) / M(24, 24)
C     Upper part.
      temp = M(24, 9) * M(9, 33)
      temp = temp + M(24, 16) * M(16, 33)
      temp = temp + M(24, 23) * M(23, 33)
      M(24, 33) = ( M(24, 33) - temp ) / M(24, 24)
C     Upper part.
      temp = M(24, 10) * M(10, 34)
      temp = temp + M(24, 16) * M(16, 34)
      temp = temp + M(24, 23) * M(23, 34)
      M(24, 34) = ( M(24, 34) - temp ) / M(24, 24)
C     Upper part.
      temp = M(24, 9) * M(9, 35)
      temp = temp + M(24, 23) * M(23, 35)
      M(24, 35) = ( M(24, 35) - temp ) / M(24, 24)
C     Upper part.
      temp = M(24, 16) * M(16, 36)
      M(24, 36) = ( M(24, 36) - temp ) / M(24, 24)

C     Upper part.
      temp = M(25, 20) * M(20, 26)
      temp = temp + M(25, 21) * M(21, 26)
      temp = temp + M(25, 22) * M(22, 26)
      M(25, 26) = ( M(25, 26) - temp ) / M(25, 25)
C     Upper part.
      temp = M(25, 20) * M(20, 27)
      temp = temp + M(25, 21) * M(21, 27)
      temp = temp + M(25, 22) * M(22, 27)
      M(25, 27) = ( M(25, 27) - temp ) / M(25, 25)
C     Upper part.
      temp = M(25, 20) * M(20, 29)
      temp = temp + M(25, 21) * M(21, 29)
      temp = temp + M(25, 22) * M(22, 29)
      M(25, 29) = ( M(25, 29) - temp ) / M(25, 25)
C     Upper part.
      M(25, 33) = M(25, 33) / M(25, 25)
C     Upper part.
      temp = M(25, 14) * M(14, 34)
      temp = temp + M(25, 22) * M(22, 34)
      M(25, 34) = ( M(25, 34) - temp ) / M(25, 25)
C     Upper part.
      temp = M(25, 14) * M(14, 35)
      temp = temp + M(25, 20) * M(20, 35)
      temp = temp + M(25, 21) * M(21, 35)
      temp = temp + M(25, 22) * M(22, 35)
      M(25, 35) = ( M(25, 35) - temp ) / M(25, 25)

C     Lower part.
      temp = M(26, 11) * M(11, 26)
      temp = temp + M(26, 19) * M(19, 26)
      temp = temp + M(26, 20) * M(20, 26)
      temp = temp + M(26, 21) * M(21, 26)
      M(26, 26) = M(26, 26) - temp
C     Lower part.
      temp = M(27, 6) * M(6, 26)
      temp = temp + M(27, 16) * M(16, 26)
      temp = temp + M(27, 19) * M(19, 26)
      temp = temp + M(27, 20) * M(20, 26)
      temp = temp + M(27, 21) * M(21, 26)
      temp = temp + M(27, 23) * M(23, 26)
      M(27, 26) = M(27, 26) - temp
C     Lower part.
      temp = M(28, 11) * M(11, 26)
      temp = temp + M(28, 12) * M(12, 26)
      temp = temp + M(28, 19) * M(19, 26)
      temp = temp + M(28, 20) * M(20, 26)
      temp = temp + M(28, 21) * M(21, 26)
      temp = temp + M(28, 23) * M(23, 26)
      M(28, 26) = M(28, 26) - temp
C     Lower part.
      temp = M(29, 16) * M(16, 26)
      temp = temp + M(29, 20) * M(20, 26)
      temp = temp + M(29, 21) * M(21, 26)
      temp = temp + M(29, 23) * M(23, 26)
      temp = temp + M(29, 24) * M(24, 26)
      M(29, 26) = M(29, 26) - temp
C     Lower part.
      temp = M(30, 11) * M(11, 26)
      temp = temp + M(30, 12) * M(12, 26)
      temp = temp + M(30, 20) * M(20, 26)
      temp = temp + M(30, 23) * M(23, 26)
      M(30, 26) = M(30, 26) - temp
C     Lower part.
      temp = M(31, 11) * M(11, 26)
      temp = temp + M(31, 19) * M(19, 26)
      temp = temp + M(31, 20) * M(20, 26)
      temp = temp + M(31, 21) * M(21, 26)
      temp = temp + M(31, 23) * M(23, 26)
      M(31, 26) = M(31, 26) - temp
C     Lower part.
      temp = M(32, 11) * M(11, 26)
      temp = temp + M(32, 12) * M(12, 26)
      temp = temp + M(32, 19) * M(19, 26)
      temp = temp + M(32, 20) * M(20, 26)
      temp = temp + M(32, 21) * M(21, 26)
      temp = temp + M(32, 22) * M(22, 26)
      temp = temp + M(32, 23) * M(23, 26)
      M(32, 26) = M(32, 26) - temp
C     Lower part.
      temp = M(33, 16) * M(16, 26)
      temp = temp + M(33, 17) * M(17, 26)
      temp = temp + M(33, 25) * M(25, 26)
      M(33, 26) = M(33, 26) - temp
C     Lower part.
      temp = M(34, 16) * M(16, 26)
      temp = temp + M(34, 17) * M(17, 26)
      temp = temp + M(34, 21) * M(21, 26)
      temp = temp + M(34, 22) * M(22, 26)
      M(34, 26) = M(34, 26) - temp
C     Lower part.
      temp = M(35, 6) * M(6, 26)
      temp = temp + M(35, 11) * M(11, 26)
      temp = temp + M(35, 12) * M(12, 26)
      temp = temp + M(35, 16) * M(16, 26)
      temp = temp + M(35, 17) * M(17, 26)
      temp = temp + M(35, 19) * M(19, 26)
      temp = temp + M(35, 20) * M(20, 26)
      temp = temp + M(35, 21) * M(21, 26)
      temp = temp + M(35, 22) * M(22, 26)
      temp = temp + M(35, 23) * M(23, 26)
      temp = temp + M(35, 24) * M(24, 26)
      M(35, 26) = M(35, 26) - temp
C     Lower part.
      temp = M(36, 11) * M(11, 26)
      temp = temp + M(36, 12) * M(12, 26)
      temp = temp + M(36, 16) * M(16, 26)
      temp = temp + M(36, 19) * M(19, 26)
      temp = temp + M(36, 20) * M(20, 26)
      temp = temp + M(36, 21) * M(21, 26)
      temp = temp + M(36, 22) * M(22, 26)
      temp = temp + M(36, 23) * M(23, 26)
      M(36, 26) = M(36, 26) - temp
C     Upper part.
      temp = M(26, 19) * M(19, 27)
      temp = temp + M(26, 20) * M(20, 27)
      temp = temp + M(26, 21) * M(21, 27)
      M(26, 27) = ( M(26, 27) - temp ) / M(26, 26)
C     Upper part.
      temp = M(26, 11) * M(11, 29)
      temp = temp + M(26, 20) * M(20, 29)
      temp = temp + M(26, 21) * M(21, 29)
      M(26, 29) = ( M(26, 29) - temp ) / M(26, 26)
C     Upper part.
      temp = M(26, 11) * M(11, 33)
      M(26, 33) = ( M(26, 33) - temp ) / M(26, 26)
C     Upper part.
      M(26, 34) = M(26, 34) / M(26, 26)
C     Upper part.
      temp = M(26, 11) * M(11, 35)
      temp = temp + M(26, 19) * M(19, 35)
      temp = temp + M(26, 20) * M(20, 35)
      temp = temp + M(26, 21) * M(21, 35)
      M(26, 35) = ( M(26, 35) - temp ) / M(26, 26)
C     Upper part.
      M(26, 36) = M(26, 36) / M(26, 26)

C     Lower part.
      temp = M(27, 19) * M(19, 27)
      temp = temp + M(27, 20) * M(20, 27)
      temp = temp + M(27, 21) * M(21, 27)
      temp = temp + M(27, 23) * M(23, 27)
      temp = temp + M(27, 26) * M(26, 27)
      M(27, 27) = M(27, 27) - temp
C     Lower part.
      temp = M(28, 19) * M(19, 27)
      temp = temp + M(28, 20) * M(20, 27)
      temp = temp + M(28, 21) * M(21, 27)
      temp = temp + M(28, 23) * M(23, 27)
      temp = temp + M(28, 26) * M(26, 27)
      M(28, 27) = M(28, 27) - temp
C     Lower part.
      temp = M(29, 20) * M(20, 27)
      temp = temp + M(29, 21) * M(21, 27)
      temp = temp + M(29, 23) * M(23, 27)
      temp = temp + M(29, 24) * M(24, 27)
      temp = temp + M(29, 26) * M(26, 27)
      M(29, 27) = M(29, 27) - temp
C     Lower part.
      temp = M(30, 20) * M(20, 27)
      temp = temp + M(30, 23) * M(23, 27)
      temp = temp + M(30, 26) * M(26, 27)
      M(30, 27) = M(30, 27) - temp
C     Lower part.
      temp = M(31, 19) * M(19, 27)
      temp = temp + M(31, 20) * M(20, 27)
      temp = temp + M(31, 21) * M(21, 27)
      temp = temp + M(31, 23) * M(23, 27)
      temp = temp + M(31, 26) * M(26, 27)
      M(31, 27) = M(31, 27) - temp
C     Lower part.
      temp = M(32, 19) * M(19, 27)
      temp = temp + M(32, 20) * M(20, 27)
      temp = temp + M(32, 21) * M(21, 27)
      temp = temp + M(32, 22) * M(22, 27)
      temp = temp + M(32, 23) * M(23, 27)
      temp = temp + M(32, 26) * M(26, 27)
      M(32, 27) = M(32, 27) - temp
C     Lower part.
      temp = M(33, 25) * M(25, 27)
      temp = temp + M(33, 26) * M(26, 27)
      M(33, 27) = M(33, 27) - temp
C     Lower part.
      temp = M(34, 21) * M(21, 27)
      temp = temp + M(34, 22) * M(22, 27)
      temp = temp + M(34, 26) * M(26, 27)
      M(34, 27) = M(34, 27) - temp
C     Lower part.
      temp = M(35, 19) * M(19, 27)
      temp = temp + M(35, 20) * M(20, 27)
      temp = temp + M(35, 21) * M(21, 27)
      temp = temp + M(35, 22) * M(22, 27)
      temp = temp + M(35, 23) * M(23, 27)
      temp = temp + M(35, 24) * M(24, 27)
      temp = temp + M(35, 26) * M(26, 27)
      M(35, 27) = M(35, 27) - temp
C     Lower part.
      temp = M(36, 19) * M(19, 27)
      temp = temp + M(36, 20) * M(20, 27)
      temp = temp + M(36, 21) * M(21, 27)
      temp = temp + M(36, 22) * M(22, 27)
      temp = temp + M(36, 23) * M(23, 27)
      temp = temp + M(36, 26) * M(26, 27)
      M(36, 27) = M(36, 27) - temp
C     Upper part.
      temp = M(27, 16) * M(16, 29)
      temp = temp + M(27, 20) * M(20, 29)
      temp = temp + M(27, 21) * M(21, 29)
      temp = temp + M(27, 23) * M(23, 29)
      temp = temp + M(27, 26) * M(26, 29)
      M(27, 29) = ( M(27, 29) - temp ) / M(27, 27)
C     Upper part.
      M(27, 31) = M(27, 31) / M(27, 27)
C     Upper part.
      temp = M(27, 16) * M(16, 33)
      temp = temp + M(27, 23) * M(23, 33)
      temp = temp + M(27, 26) * M(26, 33)
      M(27, 33) = ( M(27, 33) - temp ) / M(27, 27)
C     Upper part.
      temp = M(27, 16) * M(16, 34)
      temp = temp + M(27, 23) * M(23, 34)
      temp = temp + M(27, 26) * M(26, 34)
      M(27, 34) = ( M(27, 34) - temp ) / M(27, 27)
C     Upper part.
      temp = M(27, 19) * M(19, 35)
      temp = temp + M(27, 20) * M(20, 35)
      temp = temp + M(27, 21) * M(21, 35)
      temp = temp + M(27, 23) * M(23, 35)
      temp = temp + M(27, 26) * M(26, 35)
      M(27, 35) = ( M(27, 35) - temp ) / M(27, 27)
C     Upper part.
      temp = M(27, 16) * M(16, 36)
      temp = temp + M(27, 26) * M(26, 36)
      M(27, 36) = ( M(27, 36) - temp ) / M(27, 27)

C     Upper part.
      temp = M(28, 11) * M(11, 29)
      temp = temp + M(28, 12) * M(12, 29)
      temp = temp + M(28, 20) * M(20, 29)
      temp = temp + M(28, 21) * M(21, 29)
      temp = temp + M(28, 23) * M(23, 29)
      temp = temp + M(28, 26) * M(26, 29)
      temp = temp + M(28, 27) * M(27, 29)
      M(28, 29) = ( M(28, 29) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 27) * M(27, 31)
      M(28, 31) = ( M(28, 31) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 11) * M(11, 33)
      temp = temp + M(28, 12) * M(12, 33)
      temp = temp + M(28, 23) * M(23, 33)
      temp = temp + M(28, 26) * M(26, 33)
      temp = temp + M(28, 27) * M(27, 33)
      M(28, 33) = ( M(28, 33) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 23) * M(23, 34)
      temp = temp + M(28, 26) * M(26, 34)
      temp = temp + M(28, 27) * M(27, 34)
      M(28, 34) = ( M(28, 34) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 11) * M(11, 35)
      temp = temp + M(28, 12) * M(12, 35)
      temp = temp + M(28, 19) * M(19, 35)
      temp = temp + M(28, 20) * M(20, 35)
      temp = temp + M(28, 21) * M(21, 35)
      temp = temp + M(28, 23) * M(23, 35)
      temp = temp + M(28, 26) * M(26, 35)
      temp = temp + M(28, 27) * M(27, 35)
      M(28, 35) = ( M(28, 35) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 26) * M(26, 36)
      temp = temp + M(28, 27) * M(27, 36)
      M(28, 36) = ( M(28, 36) - temp ) / M(28, 28)

C     Lower part.
      temp = M(29, 9) * M(9, 29)
      temp = temp + M(29, 10) * M(10, 29)
      temp = temp + M(29, 16) * M(16, 29)
      temp = temp + M(29, 20) * M(20, 29)
      temp = temp + M(29, 21) * M(21, 29)
      temp = temp + M(29, 23) * M(23, 29)
      temp = temp + M(29, 24) * M(24, 29)
      temp = temp + M(29, 26) * M(26, 29)
      temp = temp + M(29, 27) * M(27, 29)
      M(29, 29) = M(29, 29) - temp
C     Lower part.
      temp = M(30, 11) * M(11, 29)
      temp = temp + M(30, 12) * M(12, 29)
      temp = temp + M(30, 20) * M(20, 29)
      temp = temp + M(30, 23) * M(23, 29)
      temp = temp + M(30, 26) * M(26, 29)
      temp = temp + M(30, 27) * M(27, 29)
      M(30, 29) = M(30, 29) - temp
C     Lower part.
      temp = M(31, 11) * M(11, 29)
      temp = temp + M(31, 20) * M(20, 29)
      temp = temp + M(31, 21) * M(21, 29)
      temp = temp + M(31, 23) * M(23, 29)
      temp = temp + M(31, 26) * M(26, 29)
      temp = temp + M(31, 27) * M(27, 29)
      M(31, 29) = M(31, 29) - temp
C     Lower part.
      temp = M(32, 9) * M(9, 29)
      temp = temp + M(32, 11) * M(11, 29)
      temp = temp + M(32, 12) * M(12, 29)
      temp = temp + M(32, 20) * M(20, 29)
      temp = temp + M(32, 21) * M(21, 29)
      temp = temp + M(32, 22) * M(22, 29)
      temp = temp + M(32, 23) * M(23, 29)
      temp = temp + M(32, 26) * M(26, 29)
      temp = temp + M(32, 27) * M(27, 29)
      M(32, 29) = M(32, 29) - temp
C     Lower part.
      temp = M(33, 16) * M(16, 29)
      temp = temp + M(33, 17) * M(17, 29)
      temp = temp + M(33, 25) * M(25, 29)
      temp = temp + M(33, 26) * M(26, 29)
      temp = temp + M(33, 27) * M(27, 29)
      M(33, 29) = M(33, 29) - temp
C     Lower part.
      temp = M(34, 10) * M(10, 29)
      temp = temp + M(34, 16) * M(16, 29)
      temp = temp + M(34, 17) * M(17, 29)
      temp = temp + M(34, 18) * M(18, 29)
      temp = temp + M(34, 21) * M(21, 29)
      temp = temp + M(34, 22) * M(22, 29)
      temp = temp + M(34, 26) * M(26, 29)
      temp = temp + M(34, 27) * M(27, 29)
      M(34, 29) = M(34, 29) - temp
C     Lower part.
      temp = M(35, 9) * M(9, 29)
      temp = temp + M(35, 11) * M(11, 29)
      temp = temp + M(35, 12) * M(12, 29)
      temp = temp + M(35, 16) * M(16, 29)
      temp = temp + M(35, 17) * M(17, 29)
      temp = temp + M(35, 20) * M(20, 29)
      temp = temp + M(35, 21) * M(21, 29)
      temp = temp + M(35, 22) * M(22, 29)
      temp = temp + M(35, 23) * M(23, 29)
      temp = temp + M(35, 24) * M(24, 29)
      temp = temp + M(35, 26) * M(26, 29)
      temp = temp + M(35, 27) * M(27, 29)
      temp = temp + M(35, 28) * M(28, 29)
      M(35, 29) = M(35, 29) - temp
C     Lower part.
      temp = M(36, 9) * M(9, 29)
      temp = temp + M(36, 11) * M(11, 29)
      temp = temp + M(36, 12) * M(12, 29)
      temp = temp + M(36, 16) * M(16, 29)
      temp = temp + M(36, 20) * M(20, 29)
      temp = temp + M(36, 21) * M(21, 29)
      temp = temp + M(36, 22) * M(22, 29)
      temp = temp + M(36, 23) * M(23, 29)
      temp = temp + M(36, 26) * M(26, 29)
      temp = temp + M(36, 27) * M(27, 29)
      temp = temp + M(36, 28) * M(28, 29)
      M(36, 29) = M(36, 29) - temp
C     Upper part.
      temp = M(29, 24) * M(24, 31)
      temp = temp + M(29, 27) * M(27, 31)
      M(29, 31) = ( M(29, 31) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 9) * M(9, 33)
      temp = temp + M(29, 16) * M(16, 33)
      temp = temp + M(29, 23) * M(23, 33)
      temp = temp + M(29, 24) * M(24, 33)
      temp = temp + M(29, 26) * M(26, 33)
      temp = temp + M(29, 27) * M(27, 33)
      M(29, 33) = ( M(29, 33) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 10) * M(10, 34)
      temp = temp + M(29, 16) * M(16, 34)
      temp = temp + M(29, 23) * M(23, 34)
      temp = temp + M(29, 24) * M(24, 34)
      temp = temp + M(29, 26) * M(26, 34)
      temp = temp + M(29, 27) * M(27, 34)
      M(29, 34) = ( M(29, 34) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 9) * M(9, 35)
      temp = temp + M(29, 20) * M(20, 35)
      temp = temp + M(29, 21) * M(21, 35)
      temp = temp + M(29, 23) * M(23, 35)
      temp = temp + M(29, 24) * M(24, 35)
      temp = temp + M(29, 26) * M(26, 35)
      temp = temp + M(29, 27) * M(27, 35)
      M(29, 35) = ( M(29, 35) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 16) * M(16, 36)
      temp = temp + M(29, 24) * M(24, 36)
      temp = temp + M(29, 26) * M(26, 36)
      temp = temp + M(29, 27) * M(27, 36)
      M(29, 36) = ( M(29, 36) - temp ) / M(29, 29)

C     Lower part.
      temp = M(30, 7) * M(7, 30)
      M(30, 30) = M(30, 30) - temp
C     Lower part.
      temp = M(34, 7) * M(7, 30)
      M(34, 30) = M(34, 30) - temp
C     Upper part.
      temp = M(30, 27) * M(27, 31)
      temp = temp + M(30, 29) * M(29, 31)
      M(30, 31) = ( M(30, 31) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 11) * M(11, 33)
      temp = temp + M(30, 12) * M(12, 33)
      temp = temp + M(30, 23) * M(23, 33)
      temp = temp + M(30, 26) * M(26, 33)
      temp = temp + M(30, 27) * M(27, 33)
      temp = temp + M(30, 29) * M(29, 33)
      M(30, 33) = ( M(30, 33) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 7) * M(7, 34)
      temp = temp + M(30, 23) * M(23, 34)
      temp = temp + M(30, 26) * M(26, 34)
      temp = temp + M(30, 27) * M(27, 34)
      temp = temp + M(30, 29) * M(29, 34)
      M(30, 34) = ( M(30, 34) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 11) * M(11, 35)
      temp = temp + M(30, 12) * M(12, 35)
      temp = temp + M(30, 20) * M(20, 35)
      temp = temp + M(30, 23) * M(23, 35)
      temp = temp + M(30, 26) * M(26, 35)
      temp = temp + M(30, 27) * M(27, 35)
      temp = temp + M(30, 29) * M(29, 35)
      M(30, 35) = ( M(30, 35) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 26) * M(26, 36)
      temp = temp + M(30, 27) * M(27, 36)
      temp = temp + M(30, 29) * M(29, 36)
      M(30, 36) = ( M(30, 36) - temp ) / M(30, 30)

C     Lower part.
      temp = M(31, 27) * M(27, 31)
      temp = temp + M(31, 29) * M(29, 31)
      temp = temp + M(31, 30) * M(30, 31)
      M(31, 31) = M(31, 31) - temp
C     Lower part.
      temp = M(32, 27) * M(27, 31)
      temp = temp + M(32, 29) * M(29, 31)
      temp = temp + M(32, 30) * M(30, 31)
      M(32, 31) = M(32, 31) - temp
C     Lower part.
      temp = M(33, 27) * M(27, 31)
      temp = temp + M(33, 29) * M(29, 31)
      temp = temp + M(33, 30) * M(30, 31)
      M(33, 31) = M(33, 31) - temp
C     Lower part.
      temp = M(34, 27) * M(27, 31)
      temp = temp + M(34, 29) * M(29, 31)
      temp = temp + M(34, 30) * M(30, 31)
      M(34, 31) = M(34, 31) - temp
C     Lower part.
      temp = M(35, 24) * M(24, 31)
      temp = temp + M(35, 27) * M(27, 31)
      temp = temp + M(35, 28) * M(28, 31)
      temp = temp + M(35, 29) * M(29, 31)
      temp = temp + M(35, 30) * M(30, 31)
      M(35, 31) = M(35, 31) - temp
C     Lower part.
      temp = M(36, 27) * M(27, 31)
      temp = temp + M(36, 28) * M(28, 31)
      temp = temp + M(36, 29) * M(29, 31)
      temp = temp + M(36, 30) * M(30, 31)
      M(36, 31) = M(36, 31) - temp
C     Upper part.
      temp = M(31, 11) * M(11, 33)
      temp = temp + M(31, 23) * M(23, 33)
      temp = temp + M(31, 26) * M(26, 33)
      temp = temp + M(31, 27) * M(27, 33)
      temp = temp + M(31, 29) * M(29, 33)
      temp = temp + M(31, 30) * M(30, 33)
      M(31, 33) = ( M(31, 33) - temp ) / M(31, 31)
C     Upper part.
      temp = M(31, 23) * M(23, 34)
      temp = temp + M(31, 26) * M(26, 34)
      temp = temp + M(31, 27) * M(27, 34)
      temp = temp + M(31, 29) * M(29, 34)
      temp = temp + M(31, 30) * M(30, 34)
      M(31, 34) = ( M(31, 34) - temp ) / M(31, 31)
C     Upper part.
      temp = M(31, 11) * M(11, 35)
      temp = temp + M(31, 19) * M(19, 35)
      temp = temp + M(31, 20) * M(20, 35)
      temp = temp + M(31, 21) * M(21, 35)
      temp = temp + M(31, 23) * M(23, 35)
      temp = temp + M(31, 26) * M(26, 35)
      temp = temp + M(31, 27) * M(27, 35)
      temp = temp + M(31, 29) * M(29, 35)
      temp = temp + M(31, 30) * M(30, 35)
      M(31, 35) = ( M(31, 35) - temp ) / M(31, 31)
C     Upper part.
      temp = M(31, 26) * M(26, 36)
      temp = temp + M(31, 27) * M(27, 36)
      temp = temp + M(31, 29) * M(29, 36)
      temp = temp + M(31, 30) * M(30, 36)
      M(31, 36) = ( M(31, 36) - temp ) / M(31, 31)

C     Upper part.
      temp = M(32, 9) * M(9, 33)
      temp = temp + M(32, 11) * M(11, 33)
      temp = temp + M(32, 12) * M(12, 33)
      temp = temp + M(32, 23) * M(23, 33)
      temp = temp + M(32, 26) * M(26, 33)
      temp = temp + M(32, 27) * M(27, 33)
      temp = temp + M(32, 29) * M(29, 33)
      temp = temp + M(32, 30) * M(30, 33)
      temp = temp + M(32, 31) * M(31, 33)
      M(32, 33) = ( M(32, 33) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 14) * M(14, 34)
      temp = temp + M(32, 22) * M(22, 34)
      temp = temp + M(32, 23) * M(23, 34)
      temp = temp + M(32, 26) * M(26, 34)
      temp = temp + M(32, 27) * M(27, 34)
      temp = temp + M(32, 29) * M(29, 34)
      temp = temp + M(32, 30) * M(30, 34)
      temp = temp + M(32, 31) * M(31, 34)
      M(32, 34) = ( M(32, 34) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 4) * M(4, 35)
      temp = temp + M(32, 5) * M(5, 35)
      temp = temp + M(32, 9) * M(9, 35)
      temp = temp + M(32, 11) * M(11, 35)
      temp = temp + M(32, 12) * M(12, 35)
      temp = temp + M(32, 14) * M(14, 35)
      temp = temp + M(32, 19) * M(19, 35)
      temp = temp + M(32, 20) * M(20, 35)
      temp = temp + M(32, 21) * M(21, 35)
      temp = temp + M(32, 22) * M(22, 35)
      temp = temp + M(32, 23) * M(23, 35)
      temp = temp + M(32, 26) * M(26, 35)
      temp = temp + M(32, 27) * M(27, 35)
      temp = temp + M(32, 29) * M(29, 35)
      temp = temp + M(32, 30) * M(30, 35)
      temp = temp + M(32, 31) * M(31, 35)
      M(32, 35) = ( M(32, 35) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 26) * M(26, 36)
      temp = temp + M(32, 27) * M(27, 36)
      temp = temp + M(32, 29) * M(29, 36)
      temp = temp + M(32, 30) * M(30, 36)
      temp = temp + M(32, 31) * M(31, 36)
      M(32, 36) = ( M(32, 36) - temp ) / M(32, 32)

C     Lower part.
      temp = M(33, 8) * M(8, 33)
      temp = temp + M(33, 16) * M(16, 33)
      temp = temp + M(33, 17) * M(17, 33)
      temp = temp + M(33, 25) * M(25, 33)
      temp = temp + M(33, 26) * M(26, 33)
      temp = temp + M(33, 27) * M(27, 33)
      temp = temp + M(33, 29) * M(29, 33)
      temp = temp + M(33, 30) * M(30, 33)
      temp = temp + M(33, 31) * M(31, 33)
      temp = temp + M(33, 32) * M(32, 33)
      M(33, 33) = M(33, 33) - temp
C     Lower part.
      temp = M(34, 8) * M(8, 33)
      temp = temp + M(34, 16) * M(16, 33)
      temp = temp + M(34, 17) * M(17, 33)
      temp = temp + M(34, 18) * M(18, 33)
      temp = temp + M(34, 26) * M(26, 33)
      temp = temp + M(34, 27) * M(27, 33)
      temp = temp + M(34, 29) * M(29, 33)
      temp = temp + M(34, 30) * M(30, 33)
      temp = temp + M(34, 31) * M(31, 33)
      temp = temp + M(34, 32) * M(32, 33)
      M(34, 33) = M(34, 33) - temp
C     Lower part.
      temp = M(35, 9) * M(9, 33)
      temp = temp + M(35, 11) * M(11, 33)
      temp = temp + M(35, 12) * M(12, 33)
      temp = temp + M(35, 16) * M(16, 33)
      temp = temp + M(35, 17) * M(17, 33)
      temp = temp + M(35, 23) * M(23, 33)
      temp = temp + M(35, 24) * M(24, 33)
      temp = temp + M(35, 26) * M(26, 33)
      temp = temp + M(35, 27) * M(27, 33)
      temp = temp + M(35, 28) * M(28, 33)
      temp = temp + M(35, 29) * M(29, 33)
      temp = temp + M(35, 30) * M(30, 33)
      temp = temp + M(35, 31) * M(31, 33)
      M(35, 33) = M(35, 33) - temp
C     Lower part.
      temp = M(36, 8) * M(8, 33)
      temp = temp + M(36, 9) * M(9, 33)
      temp = temp + M(36, 11) * M(11, 33)
      temp = temp + M(36, 12) * M(12, 33)
      temp = temp + M(36, 16) * M(16, 33)
      temp = temp + M(36, 23) * M(23, 33)
      temp = temp + M(36, 26) * M(26, 33)
      temp = temp + M(36, 27) * M(27, 33)
      temp = temp + M(36, 28) * M(28, 33)
      temp = temp + M(36, 29) * M(29, 33)
      temp = temp + M(36, 30) * M(30, 33)
      temp = temp + M(36, 31) * M(31, 33)
      M(36, 33) = M(36, 33) - temp
C     Upper part.
      temp = M(33, 16) * M(16, 34)
      temp = temp + M(33, 17) * M(17, 34)
      temp = temp + M(33, 25) * M(25, 34)
      temp = temp + M(33, 26) * M(26, 34)
      temp = temp + M(33, 27) * M(27, 34)
      temp = temp + M(33, 29) * M(29, 34)
      temp = temp + M(33, 30) * M(30, 34)
      temp = temp + M(33, 31) * M(31, 34)
      temp = temp + M(33, 32) * M(32, 34)
      M(33, 34) = ( M(33, 34) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 8) * M(8, 35)
      temp = temp + M(33, 17) * M(17, 35)
      temp = temp + M(33, 25) * M(25, 35)
      temp = temp + M(33, 26) * M(26, 35)
      temp = temp + M(33, 27) * M(27, 35)
      temp = temp + M(33, 29) * M(29, 35)
      temp = temp + M(33, 30) * M(30, 35)
      temp = temp + M(33, 31) * M(31, 35)
      temp = temp + M(33, 32) * M(32, 35)
      M(33, 35) = ( M(33, 35) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 16) * M(16, 36)
      temp = temp + M(33, 17) * M(17, 36)
      temp = temp + M(33, 26) * M(26, 36)
      temp = temp + M(33, 27) * M(27, 36)
      temp = temp + M(33, 29) * M(29, 36)
      temp = temp + M(33, 30) * M(30, 36)
      temp = temp + M(33, 31) * M(31, 36)
      temp = temp + M(33, 32) * M(32, 36)
      M(33, 36) = ( M(33, 36) - temp ) / M(33, 33)

C     Lower part.
      temp = M(34, 7) * M(7, 34)
      temp = temp + M(34, 10) * M(10, 34)
      temp = temp + M(34, 13) * M(13, 34)
      temp = temp + M(34, 14) * M(14, 34)
      temp = temp + M(34, 16) * M(16, 34)
      temp = temp + M(34, 17) * M(17, 34)
      temp = temp + M(34, 18) * M(18, 34)
      temp = temp + M(34, 22) * M(22, 34)
      temp = temp + M(34, 26) * M(26, 34)
      temp = temp + M(34, 27) * M(27, 34)
      temp = temp + M(34, 29) * M(29, 34)
      temp = temp + M(34, 30) * M(30, 34)
      temp = temp + M(34, 31) * M(31, 34)
      temp = temp + M(34, 32) * M(32, 34)
      temp = temp + M(34, 33) * M(33, 34)
      M(34, 34) = M(34, 34) - temp
C     Lower part.
      temp = M(35, 13) * M(13, 34)
      temp = temp + M(35, 16) * M(16, 34)
      temp = temp + M(35, 17) * M(17, 34)
      temp = temp + M(35, 22) * M(22, 34)
      temp = temp + M(35, 23) * M(23, 34)
      temp = temp + M(35, 24) * M(24, 34)
      temp = temp + M(35, 26) * M(26, 34)
      temp = temp + M(35, 27) * M(27, 34)
      temp = temp + M(35, 28) * M(28, 34)
      temp = temp + M(35, 29) * M(29, 34)
      temp = temp + M(35, 30) * M(30, 34)
      temp = temp + M(35, 31) * M(31, 34)
      temp = temp + M(35, 33) * M(33, 34)
      M(35, 34) = M(35, 34) - temp
C     Lower part.
      temp = M(36, 13) * M(13, 34)
      temp = temp + M(36, 14) * M(14, 34)
      temp = temp + M(36, 16) * M(16, 34)
      temp = temp + M(36, 22) * M(22, 34)
      temp = temp + M(36, 23) * M(23, 34)
      temp = temp + M(36, 26) * M(26, 34)
      temp = temp + M(36, 27) * M(27, 34)
      temp = temp + M(36, 28) * M(28, 34)
      temp = temp + M(36, 29) * M(29, 34)
      temp = temp + M(36, 30) * M(30, 34)
      temp = temp + M(36, 31) * M(31, 34)
      temp = temp + M(36, 33) * M(33, 34)
      M(36, 34) = M(36, 34) - temp
C     Upper part.
      temp = M(34, 8) * M(8, 35)
      temp = temp + M(34, 13) * M(13, 35)
      temp = temp + M(34, 14) * M(14, 35)
      temp = temp + M(34, 17) * M(17, 35)
      temp = temp + M(34, 18) * M(18, 35)
      temp = temp + M(34, 21) * M(21, 35)
      temp = temp + M(34, 22) * M(22, 35)
      temp = temp + M(34, 26) * M(26, 35)
      temp = temp + M(34, 27) * M(27, 35)
      temp = temp + M(34, 29) * M(29, 35)
      temp = temp + M(34, 30) * M(30, 35)
      temp = temp + M(34, 31) * M(31, 35)
      temp = temp + M(34, 32) * M(32, 35)
      temp = temp + M(34, 33) * M(33, 35)
      M(34, 35) = ( M(34, 35) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 13) * M(13, 36)
      temp = temp + M(34, 16) * M(16, 36)
      temp = temp + M(34, 17) * M(17, 36)
      temp = temp + M(34, 26) * M(26, 36)
      temp = temp + M(34, 27) * M(27, 36)
      temp = temp + M(34, 29) * M(29, 36)
      temp = temp + M(34, 30) * M(30, 36)
      temp = temp + M(34, 31) * M(31, 36)
      temp = temp + M(34, 32) * M(32, 36)
      temp = temp + M(34, 33) * M(33, 36)
      M(34, 36) = ( M(34, 36) - temp ) / M(34, 34)

C     Lower part.
      temp = M(35, 2) * M(2, 35)
      temp = temp + M(35, 4) * M(4, 35)
      temp = temp + M(35, 5) * M(5, 35)
      temp = temp + M(35, 9) * M(9, 35)
      temp = temp + M(35, 11) * M(11, 35)
      temp = temp + M(35, 12) * M(12, 35)
      temp = temp + M(35, 13) * M(13, 35)
      temp = temp + M(35, 15) * M(15, 35)
      temp = temp + M(35, 17) * M(17, 35)
      temp = temp + M(35, 19) * M(19, 35)
      temp = temp + M(35, 20) * M(20, 35)
      temp = temp + M(35, 21) * M(21, 35)
      temp = temp + M(35, 22) * M(22, 35)
      temp = temp + M(35, 23) * M(23, 35)
      temp = temp + M(35, 24) * M(24, 35)
      temp = temp + M(35, 26) * M(26, 35)
      temp = temp + M(35, 27) * M(27, 35)
      temp = temp + M(35, 28) * M(28, 35)
      temp = temp + M(35, 29) * M(29, 35)
      temp = temp + M(35, 30) * M(30, 35)
      temp = temp + M(35, 31) * M(31, 35)
      temp = temp + M(35, 33) * M(33, 35)
      temp = temp + M(35, 34) * M(34, 35)
      M(35, 35) = M(35, 35) - temp
C     Lower part.
      temp = M(36, 2) * M(2, 35)
      temp = temp + M(36, 4) * M(4, 35)
      temp = temp + M(36, 5) * M(5, 35)
      temp = temp + M(36, 8) * M(8, 35)
      temp = temp + M(36, 9) * M(9, 35)
      temp = temp + M(36, 11) * M(11, 35)
      temp = temp + M(36, 12) * M(12, 35)
      temp = temp + M(36, 13) * M(13, 35)
      temp = temp + M(36, 14) * M(14, 35)
      temp = temp + M(36, 15) * M(15, 35)
      temp = temp + M(36, 19) * M(19, 35)
      temp = temp + M(36, 20) * M(20, 35)
      temp = temp + M(36, 21) * M(21, 35)
      temp = temp + M(36, 22) * M(22, 35)
      temp = temp + M(36, 23) * M(23, 35)
      temp = temp + M(36, 26) * M(26, 35)
      temp = temp + M(36, 27) * M(27, 35)
      temp = temp + M(36, 28) * M(28, 35)
      temp = temp + M(36, 29) * M(29, 35)
      temp = temp + M(36, 30) * M(30, 35)
      temp = temp + M(36, 31) * M(31, 35)
      temp = temp + M(36, 33) * M(33, 35)
      temp = temp + M(36, 34) * M(34, 35)
      M(36, 35) = M(36, 35) - temp
C     Upper part.
      temp = M(35, 13) * M(13, 36)
      temp = temp + M(35, 15) * M(15, 36)
      temp = temp + M(35, 16) * M(16, 36)
      temp = temp + M(35, 17) * M(17, 36)
      temp = temp + M(35, 24) * M(24, 36)
      temp = temp + M(35, 26) * M(26, 36)
      temp = temp + M(35, 27) * M(27, 36)
      temp = temp + M(35, 28) * M(28, 36)
      temp = temp + M(35, 29) * M(29, 36)
      temp = temp + M(35, 30) * M(30, 36)
      temp = temp + M(35, 31) * M(31, 36)
      temp = temp + M(35, 33) * M(33, 36)
      temp = temp + M(35, 34) * M(34, 36)
      M(35, 36) = ( M(35, 36) - temp ) / M(35, 35)

C     Lower part.
      temp = M(36, 13) * M(13, 36)
      temp = temp + M(36, 15) * M(15, 36)
      temp = temp + M(36, 16) * M(16, 36)
      temp = temp + M(36, 26) * M(26, 36)
      temp = temp + M(36, 27) * M(27, 36)
      temp = temp + M(36, 28) * M(28, 36)
      temp = temp + M(36, 29) * M(29, 36)
      temp = temp + M(36, 30) * M(30, 36)
      temp = temp + M(36, 31) * M(31, 36)
      temp = temp + M(36, 33) * M(33, 36)
      temp = temp + M(36, 34) * M(34, 36)
      temp = temp + M(36, 35) * M(35, 36)
      M(36, 36) = M(36, 36) - temp


      END
