C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE LU_solve (M, x)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves M * y = x where M is an LU factorization
C     computed by LU_decompose.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     M: LU factorization computed by LU_decompose.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     x: on entry, the right-hand side of the equation. On exit,
C     the solution of the equation.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of 'chemical' arrays.

      INCLUDE 'PARACHEM.INC'

      DOUBLE PRECISION M(Nesp,Nesp)
      DOUBLE PRECISION x(Nesp)
      DOUBLE PRECISION temp


C     Forward substitution.

      x(1) = x(1) / M(1, 1)

      x(2) = x(2) / M(2, 2)

      temp = M(3, 2) * x(2)
      x(3) = ( x(3) - temp ) / M(3, 3)

      x(4) = x(4) / M(4, 4)

      x(5) = x(5) / M(5, 5)

      x(6) = x(6) / M(6, 6)

      x(7) = x(7) / M(7, 7)

      temp = M(8, 4) * x(4)
      temp = temp + M(8, 5) * x(5)
      x(8) = ( x(8) - temp ) / M(8, 8)

      temp = M(9, 4) * x(4)
      temp = temp + M(9, 5) * x(5)
      temp = temp + M(9, 8) * x(8)
      x(9) = ( x(9) - temp ) / M(9, 9)

      x(10) = x(10) / M(10, 10)

      temp = M(11, 8) * x(8)
      temp = temp + M(11, 9) * x(9)
      x(11) = ( x(11) - temp ) / M(11, 11)

      temp = M(12, 5) * x(5)
      temp = temp + M(12, 11) * x(11)
      x(12) = ( x(12) - temp ) / M(12, 12)

      x(13) = x(13) / M(13, 13)

      x(14) = x(14) / M(14, 14)

      x(15) = x(15) / M(15, 15)

      temp = M(16, 6) * x(6)
      temp = temp + M(16, 10) * x(10)
      x(16) = ( x(16) - temp ) / M(16, 16)

      temp = M(17, 16) * x(16)
      x(17) = ( x(17) - temp ) / M(17, 17)

      temp = M(18, 9) * x(9)
      x(18) = ( x(18) - temp ) / M(18, 18)

      x(19) = x(19) / M(19, 19)

      x(20) = x(20) / M(20, 20)

      temp = M(21, 20) * x(20)
      x(21) = ( x(21) - temp ) / M(21, 21)

      temp = M(22, 5) * x(5)
      temp = temp + M(22, 14) * x(14)
      temp = temp + M(22, 20) * x(20)
      temp = temp + M(22, 21) * x(21)
      x(22) = ( x(22) - temp ) / M(22, 22)

      temp = M(23, 11) * x(11)
      temp = temp + M(23, 14) * x(14)
      temp = temp + M(23, 19) * x(19)
      temp = temp + M(23, 20) * x(20)
      temp = temp + M(23, 21) * x(21)
      temp = temp + M(23, 22) * x(22)
      x(23) = ( x(23) - temp ) / M(23, 23)

      temp = M(24, 9) * x(9)
      temp = temp + M(24, 10) * x(10)
      temp = temp + M(24, 16) * x(16)
      temp = temp + M(24, 23) * x(23)
      x(24) = ( x(24) - temp ) / M(24, 24)

      temp = M(25, 14) * x(14)
      temp = temp + M(25, 20) * x(20)
      temp = temp + M(25, 21) * x(21)
      temp = temp + M(25, 22) * x(22)
      x(25) = ( x(25) - temp ) / M(25, 25)

      temp = M(26, 11) * x(11)
      temp = temp + M(26, 19) * x(19)
      temp = temp + M(26, 20) * x(20)
      temp = temp + M(26, 21) * x(21)
      x(26) = ( x(26) - temp ) / M(26, 26)

      temp = M(27, 6) * x(6)
      temp = temp + M(27, 16) * x(16)
      temp = temp + M(27, 19) * x(19)
      temp = temp + M(27, 20) * x(20)
      temp = temp + M(27, 21) * x(21)
      temp = temp + M(27, 23) * x(23)
      temp = temp + M(27, 26) * x(26)
      x(27) = ( x(27) - temp ) / M(27, 27)

      temp = M(28, 11) * x(11)
      temp = temp + M(28, 12) * x(12)
      temp = temp + M(28, 19) * x(19)
      temp = temp + M(28, 20) * x(20)
      temp = temp + M(28, 21) * x(21)
      temp = temp + M(28, 23) * x(23)
      temp = temp + M(28, 26) * x(26)
      temp = temp + M(28, 27) * x(27)
      x(28) = ( x(28) - temp ) / M(28, 28)

      temp = M(29, 9) * x(9)
      temp = temp + M(29, 10) * x(10)
      temp = temp + M(29, 16) * x(16)
      temp = temp + M(29, 20) * x(20)
      temp = temp + M(29, 21) * x(21)
      temp = temp + M(29, 23) * x(23)
      temp = temp + M(29, 24) * x(24)
      temp = temp + M(29, 26) * x(26)
      temp = temp + M(29, 27) * x(27)
      x(29) = ( x(29) - temp ) / M(29, 29)

      temp = M(30, 7) * x(7)
      temp = temp + M(30, 11) * x(11)
      temp = temp + M(30, 12) * x(12)
      temp = temp + M(30, 20) * x(20)
      temp = temp + M(30, 23) * x(23)
      temp = temp + M(30, 26) * x(26)
      temp = temp + M(30, 27) * x(27)
      temp = temp + M(30, 29) * x(29)
      x(30) = ( x(30) - temp ) / M(30, 30)

      temp = M(31, 11) * x(11)
      temp = temp + M(31, 19) * x(19)
      temp = temp + M(31, 20) * x(20)
      temp = temp + M(31, 21) * x(21)
      temp = temp + M(31, 23) * x(23)
      temp = temp + M(31, 26) * x(26)
      temp = temp + M(31, 27) * x(27)
      temp = temp + M(31, 29) * x(29)
      temp = temp + M(31, 30) * x(30)
      x(31) = ( x(31) - temp ) / M(31, 31)

      temp = M(32, 4) * x(4)
      temp = temp + M(32, 5) * x(5)
      temp = temp + M(32, 9) * x(9)
      temp = temp + M(32, 11) * x(11)
      temp = temp + M(32, 12) * x(12)
      temp = temp + M(32, 14) * x(14)
      temp = temp + M(32, 19) * x(19)
      temp = temp + M(32, 20) * x(20)
      temp = temp + M(32, 21) * x(21)
      temp = temp + M(32, 22) * x(22)
      temp = temp + M(32, 23) * x(23)
      temp = temp + M(32, 26) * x(26)
      temp = temp + M(32, 27) * x(27)
      temp = temp + M(32, 29) * x(29)
      temp = temp + M(32, 30) * x(30)
      temp = temp + M(32, 31) * x(31)
      x(32) = ( x(32) - temp ) / M(32, 32)

      temp = M(33, 8) * x(8)
      temp = temp + M(33, 16) * x(16)
      temp = temp + M(33, 17) * x(17)
      temp = temp + M(33, 25) * x(25)
      temp = temp + M(33, 26) * x(26)
      temp = temp + M(33, 27) * x(27)
      temp = temp + M(33, 29) * x(29)
      temp = temp + M(33, 30) * x(30)
      temp = temp + M(33, 31) * x(31)
      temp = temp + M(33, 32) * x(32)
      x(33) = ( x(33) - temp ) / M(33, 33)

      temp = M(34, 7) * x(7)
      temp = temp + M(34, 8) * x(8)
      temp = temp + M(34, 10) * x(10)
      temp = temp + M(34, 13) * x(13)
      temp = temp + M(34, 14) * x(14)
      temp = temp + M(34, 16) * x(16)
      temp = temp + M(34, 17) * x(17)
      temp = temp + M(34, 18) * x(18)
      temp = temp + M(34, 21) * x(21)
      temp = temp + M(34, 22) * x(22)
      temp = temp + M(34, 26) * x(26)
      temp = temp + M(34, 27) * x(27)
      temp = temp + M(34, 29) * x(29)
      temp = temp + M(34, 30) * x(30)
      temp = temp + M(34, 31) * x(31)
      temp = temp + M(34, 32) * x(32)
      temp = temp + M(34, 33) * x(33)
      x(34) = ( x(34) - temp ) / M(34, 34)

      temp = M(35, 2) * x(2)
      temp = temp + M(35, 4) * x(4)
      temp = temp + M(35, 5) * x(5)
      temp = temp + M(35, 6) * x(6)
      temp = temp + M(35, 9) * x(9)
      temp = temp + M(35, 11) * x(11)
      temp = temp + M(35, 12) * x(12)
      temp = temp + M(35, 13) * x(13)
      temp = temp + M(35, 15) * x(15)
      temp = temp + M(35, 16) * x(16)
      temp = temp + M(35, 17) * x(17)
      temp = temp + M(35, 19) * x(19)
      temp = temp + M(35, 20) * x(20)
      temp = temp + M(35, 21) * x(21)
      temp = temp + M(35, 22) * x(22)
      temp = temp + M(35, 23) * x(23)
      temp = temp + M(35, 24) * x(24)
      temp = temp + M(35, 26) * x(26)
      temp = temp + M(35, 27) * x(27)
      temp = temp + M(35, 28) * x(28)
      temp = temp + M(35, 29) * x(29)
      temp = temp + M(35, 30) * x(30)
      temp = temp + M(35, 31) * x(31)
      temp = temp + M(35, 33) * x(33)
      temp = temp + M(35, 34) * x(34)
      x(35) = ( x(35) - temp ) / M(35, 35)

      temp = M(36, 2) * x(2)
      temp = temp + M(36, 4) * x(4)
      temp = temp + M(36, 5) * x(5)
      temp = temp + M(36, 8) * x(8)
      temp = temp + M(36, 9) * x(9)
      temp = temp + M(36, 11) * x(11)
      temp = temp + M(36, 12) * x(12)
      temp = temp + M(36, 13) * x(13)
      temp = temp + M(36, 14) * x(14)
      temp = temp + M(36, 15) * x(15)
      temp = temp + M(36, 16) * x(16)
      temp = temp + M(36, 19) * x(19)
      temp = temp + M(36, 20) * x(20)
      temp = temp + M(36, 21) * x(21)
      temp = temp + M(36, 22) * x(22)
      temp = temp + M(36, 23) * x(23)
      temp = temp + M(36, 26) * x(26)
      temp = temp + M(36, 27) * x(27)
      temp = temp + M(36, 28) * x(28)
      temp = temp + M(36, 29) * x(29)
      temp = temp + M(36, 30) * x(30)
      temp = temp + M(36, 31) * x(31)
      temp = temp + M(36, 33) * x(33)
      temp = temp + M(36, 34) * x(34)
      temp = temp + M(36, 35) * x(35)
      x(36) = ( x(36) - temp ) / M(36, 36)


C     Backward substitution.

      temp = M(35, 36) * x(36)
      x(35) = x(35) - temp

      temp = M(34, 35) * x(35)
      temp = temp + M(34, 36) * x(36)
      x(34) = x(34) - temp

      temp = M(33, 34) * x(34)
      temp = temp + M(33, 35) * x(35)
      temp = temp + M(33, 36) * x(36)
      x(33) = x(33) - temp

      temp = M(32, 33) * x(33)
      temp = temp + M(32, 34) * x(34)
      temp = temp + M(32, 35) * x(35)
      temp = temp + M(32, 36) * x(36)
      x(32) = x(32) - temp

      temp = M(31, 33) * x(33)
      temp = temp + M(31, 34) * x(34)
      temp = temp + M(31, 35) * x(35)
      temp = temp + M(31, 36) * x(36)
      x(31) = x(31) - temp

      temp = M(30, 31) * x(31)
      temp = temp + M(30, 33) * x(33)
      temp = temp + M(30, 34) * x(34)
      temp = temp + M(30, 35) * x(35)
      temp = temp + M(30, 36) * x(36)
      x(30) = x(30) - temp

      temp = M(29, 31) * x(31)
      temp = temp + M(29, 33) * x(33)
      temp = temp + M(29, 34) * x(34)
      temp = temp + M(29, 35) * x(35)
      temp = temp + M(29, 36) * x(36)
      x(29) = x(29) - temp

      temp = M(28, 29) * x(29)
      temp = temp + M(28, 31) * x(31)
      temp = temp + M(28, 33) * x(33)
      temp = temp + M(28, 34) * x(34)
      temp = temp + M(28, 35) * x(35)
      temp = temp + M(28, 36) * x(36)
      x(28) = x(28) - temp

      temp = M(27, 29) * x(29)
      temp = temp + M(27, 31) * x(31)
      temp = temp + M(27, 33) * x(33)
      temp = temp + M(27, 34) * x(34)
      temp = temp + M(27, 35) * x(35)
      temp = temp + M(27, 36) * x(36)
      x(27) = x(27) - temp

      temp = M(26, 27) * x(27)
      temp = temp + M(26, 29) * x(29)
      temp = temp + M(26, 33) * x(33)
      temp = temp + M(26, 34) * x(34)
      temp = temp + M(26, 35) * x(35)
      temp = temp + M(26, 36) * x(36)
      x(26) = x(26) - temp

      temp = M(25, 26) * x(26)
      temp = temp + M(25, 27) * x(27)
      temp = temp + M(25, 29) * x(29)
      temp = temp + M(25, 33) * x(33)
      temp = temp + M(25, 34) * x(34)
      temp = temp + M(25, 35) * x(35)
      x(25) = x(25) - temp

      temp = M(24, 26) * x(26)
      temp = temp + M(24, 27) * x(27)
      temp = temp + M(24, 29) * x(29)
      temp = temp + M(24, 31) * x(31)
      temp = temp + M(24, 33) * x(33)
      temp = temp + M(24, 34) * x(34)
      temp = temp + M(24, 35) * x(35)
      temp = temp + M(24, 36) * x(36)
      x(24) = x(24) - temp

      temp = M(23, 26) * x(26)
      temp = temp + M(23, 27) * x(27)
      temp = temp + M(23, 29) * x(29)
      temp = temp + M(23, 33) * x(33)
      temp = temp + M(23, 34) * x(34)
      temp = temp + M(23, 35) * x(35)
      x(23) = x(23) - temp

      temp = M(22, 26) * x(26)
      temp = temp + M(22, 27) * x(27)
      temp = temp + M(22, 29) * x(29)
      temp = temp + M(22, 34) * x(34)
      temp = temp + M(22, 35) * x(35)
      x(22) = x(22) - temp

      temp = M(21, 26) * x(26)
      temp = temp + M(21, 27) * x(27)
      temp = temp + M(21, 29) * x(29)
      temp = temp + M(21, 35) * x(35)
      x(21) = x(21) - temp

      temp = M(20, 26) * x(26)
      temp = temp + M(20, 27) * x(27)
      temp = temp + M(20, 29) * x(29)
      temp = temp + M(20, 35) * x(35)
      x(20) = x(20) - temp

      temp = M(19, 20) * x(20)
      temp = temp + M(19, 26) * x(26)
      temp = temp + M(19, 27) * x(27)
      temp = temp + M(19, 35) * x(35)
      x(19) = x(19) - temp

      temp = M(18, 29) * x(29)
      temp = temp + M(18, 33) * x(33)
      temp = temp + M(18, 34) * x(34)
      temp = temp + M(18, 35) * x(35)
      x(18) = x(18) - temp

      temp = M(17, 26) * x(26)
      temp = temp + M(17, 29) * x(29)
      temp = temp + M(17, 33) * x(33)
      temp = temp + M(17, 34) * x(34)
      temp = temp + M(17, 35) * x(35)
      temp = temp + M(17, 36) * x(36)
      x(17) = x(17) - temp

      temp = M(16, 26) * x(26)
      temp = temp + M(16, 29) * x(29)
      temp = temp + M(16, 33) * x(33)
      temp = temp + M(16, 34) * x(34)
      temp = temp + M(16, 36) * x(36)
      x(16) = x(16) - temp

      temp = M(15, 16) * x(16)
      temp = temp + M(15, 35) * x(35)
      temp = temp + M(15, 36) * x(36)
      x(15) = x(15) - temp

      temp = M(14, 22) * x(22)
      temp = temp + M(14, 34) * x(34)
      temp = temp + M(14, 35) * x(35)
      x(14) = x(14) - temp

      temp = M(13, 34) * x(34)
      temp = temp + M(13, 35) * x(35)
      temp = temp + M(13, 36) * x(36)
      x(13) = x(13) - temp

      temp = M(12, 20) * x(20)
      temp = temp + M(12, 26) * x(26)
      temp = temp + M(12, 29) * x(29)
      temp = temp + M(12, 33) * x(33)
      temp = temp + M(12, 35) * x(35)
      x(12) = x(12) - temp

      temp = M(11, 26) * x(26)
      temp = temp + M(11, 29) * x(29)
      temp = temp + M(11, 33) * x(33)
      temp = temp + M(11, 35) * x(35)
      x(11) = x(11) - temp

      temp = M(10, 16) * x(16)
      temp = temp + M(10, 29) * x(29)
      temp = temp + M(10, 34) * x(34)
      x(10) = x(10) - temp

      temp = M(9, 29) * x(29)
      temp = temp + M(9, 33) * x(33)
      temp = temp + M(9, 35) * x(35)
      x(9) = x(9) - temp

      temp = M(8, 33) * x(33)
      temp = temp + M(8, 35) * x(35)
      x(8) = x(8) - temp

      temp = M(7, 30) * x(30)
      temp = temp + M(7, 34) * x(34)
      x(7) = x(7) - temp

      temp = M(6, 16) * x(16)
      temp = temp + M(6, 26) * x(26)
      x(6) = x(6) - temp

      temp = M(5, 35) * x(35)
      x(5) = x(5) - temp

      temp = M(4, 35) * x(35)
      x(4) = x(4) - temp

      temp = M(3, 35) * x(35)
      x(3) = x(3) - temp

      temp = M(2, 35) * x(35)
      x(2) = x(2) - temp


      END
