C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE CONVERS (Ni,DL,DLsourc,DLsourcf)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine makes unit conversions for gas-phase concentrations 
C     and volumic emissions in chemical mechanism RADM:
C     
C     NI=1: from \mu.g/m^3 to molecule/cm^3.
C     NI=2: from molecule/cm^3 to \mu.g/m^3.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     NI: flag for conversion.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     DL: 3D array of chemical concentrations (units depend on NI).
C     DLSOURC: 3D array of chemical volumic emissions at initial time.
C     DLSOURCF: 3D array of chemical volumic emissions at final time.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     CONST: constants.
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMUSE: flags and parameters for numerics. 
C     COMCHEM: global variables for chemistry. 
C     COMPHYS: physical data for chemical species (molar mass). 

      INCLUDE 'CONST.INC'
      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMUSE.INC'
      INCLUDE 'COMCHEM.INC'
      INCLUDE 'COMPHYS.INC'

      DOUBLE PRECISION DL(Nx,Ny,Nz,Nesp),DLsourc(Nx,Ny,Nzs,Nsrc)
      DOUBLE PRECISION DLsourcf(Nx,Ny,Nzs,Nsrc)
      DOUBLE PRECISION Facteur(Nesp)
      DOUBLE PRECISION DLmolarweight(Nesp)
      INTEGER Jsp,Ji,Jj,Jk,Ni

C     Setup
      
      DO Jsp=1,Nesp
         DLmolarweight(Jsp) = Wmol(Jsp) / (Navog * 1D-12)
      ENDDO

      IF(Ni.EQ.1)THEN

C     Conversion factor before call to chemistry

         DO Jsp=1,Nesp
            Facteur(Jsp) = 1.D0/DLmolarweight(Jsp)
         ENDDO
      ELSE

C     Conversion factor after call to chemistry

         DO Jsp=1,Nesp
            Facteur(Jsp) = DLmolarweight(Jsp)
         ENDDO
      ENDIF

C     Gas-phase concentrations.

      DO Jsp=1,Nesp
         DO Jk=1,Nz
            DO Jj=1,Ny
               DO Ji=1,Nx
                  DL(Ji,Jj,Jk,Jsp)=Facteur(Jsp)*DL(Ji,Jj,Jk,Jsp)
               ENDDO
            ENDDO
         ENDDO
      ENDDO

C     Volumic sources.

      IF(LSOURC) THEN    
         DO Jsp=1,Nsrc
            DO Jk=1,Nzs
               DO Jj=1,Ny
                  DO Ji=1,Nx
                     DLsourc(Ji,Jj,Jk,Jsp) = Facteur(Nesps(Jsp)) * 
     s                    DLsourc(Ji,Jj,Jk,Jsp)
                     DLsourcf(Ji,Jj,Jk,Jsp) = Facteur(Nesps(Jsp)) *  
     s                    DLsourcf(Ji,Jj,Jk,Jsp)
                  ENDDO
               ENDDO
            ENDDO
         ENDDO

      ENDIF

      END
