      subroutine jacdchemdc(y,rk,JacC)
      
C------------------------------------------------------------------------
C     
C     -- DESCRIPTION
C     
C     This routine computes the Jacobian matrix for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: CBM4_REG            
C     Species: _ciCBM4_REG         
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     JACC: Jacobian matrix.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C     The matrix JACC could be stored in a low-dimensional vector.
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     SPACK.
C     
C------------------------------------------------------------------------
      
      implicit none
      
C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of chemical arrays.
C     PARADOM: parameters for all forced fields.
      
      include 'PARACHEM.INC' 
      INCLUDE 'PARADOM.INC'  
      
      integer i,j
      double precision dw(nr,nesp),rk(nr),y(nesp),JacC(nesp,nesp)
      
      do j=1,nesp
         do i=1,nesp
            JacC(i,j)=0.d0
         enddo
      enddo
      
      call dratedc(rk,y,dw)
      
      JacC( 27, 34) = JacC( 27, 34) + dw(  1, 34)
      JacC( 33, 34) = JacC( 33, 34) + dw(  1, 34)
      JacC( 34, 34) = JacC( 34, 34) - dw(  1, 34)
      JacC( 26, 27) = JacC( 26, 27) + dw(  2, 27)
      JacC( 27, 27) = JacC( 27, 27) - dw(  2, 27)
      JacC( 26, 26) = JacC( 26, 26) - dw(  3, 26)
      JacC( 26, 33) = JacC( 26, 33) - dw(  3, 33)
      JacC( 33, 26) = JacC( 33, 26) - dw(  3, 26)
      JacC( 33, 33) = JacC( 33, 33) - dw(  3, 33)
      JacC( 34, 26) = JacC( 34, 26) + dw(  3, 26)
      JacC( 34, 33) = JacC( 34, 33) + dw(  3, 33)
      JacC( 27, 27) = JacC( 27, 27) - dw(  4, 27)
      JacC( 27, 34) = JacC( 27, 34) - dw(  4, 34)
      JacC( 33, 27) = JacC( 33, 27) + dw(  4, 27)
      JacC( 33, 34) = JacC( 33, 34) + dw(  4, 34)
      JacC( 34, 27) = JacC( 34, 27) - dw(  4, 27)
      JacC( 34, 34) = JacC( 34, 34) - dw(  4, 34)
      JacC( 27, 27) = JacC( 27, 27) - dw(  5, 27)
      JacC( 27, 34) = JacC( 27, 34) - dw(  5, 34)
      JacC( 29, 27) = JacC( 29, 27) + dw(  5, 27)
      JacC( 29, 34) = JacC( 29, 34) + dw(  5, 34)
      JacC( 34, 27) = JacC( 34, 27) - dw(  5, 27)
      JacC( 34, 34) = JacC( 34, 34) - dw(  5, 34)
      JacC( 27, 27) = JacC( 27, 27) - dw(  6, 27)
      JacC( 27, 33) = JacC( 27, 33) - dw(  6, 33)
      JacC( 33, 27) = JacC( 33, 27) - dw(  6, 27)
      JacC( 33, 33) = JacC( 33, 33) - dw(  6, 33)
      JacC( 34, 27) = JacC( 34, 27) + dw(  6, 27)
      JacC( 34, 33) = JacC( 34, 33) + dw(  6, 33)
      JacC( 26, 34) = JacC( 26, 34) - dw(  7, 34)
      JacC( 26, 26) = JacC( 26, 26) - dw(  7, 26)
      JacC( 29, 34) = JacC( 29, 34) + dw(  7, 34)
      JacC( 29, 26) = JacC( 29, 26) + dw(  7, 26)
      JacC( 34, 34) = JacC( 34, 34) - dw(  7, 34)
      JacC( 34, 26) = JacC( 34, 26) - dw(  7, 26)
      JacC( 26, 26) = JacC( 26, 26) - dw(  8, 26)
      JacC( 27, 26) = JacC( 27, 26) + dw(  8, 26)
      JacC(  6, 26) = JacC(  6, 26) + dw(  9, 26)
      JacC( 26, 26) = JacC( 26, 26) - dw(  9, 26)
      JacC(  6,  6) = JacC(  6,  6) - dw( 10,  6)
      JacC( 27,  6) = JacC( 27,  6) + dw( 10,  6)
      JacC(  6,  6) = JacC(  6,  6) - dw( 11,  6)
      JacC(  6, 16) = JacC(  6, 16) - dw( 11, 16)
      JacC( 16,  6) = JacC( 16,  6) - dw( 11,  6)
      JacC( 16, 16) = JacC( 16, 16) - dw( 11, 16)
      JacC( 35,  6) = JacC( 35,  6)+ 0.2000000000000000D+01*dw( 11,  6)
      JacC( 35, 16) = JacC( 35, 16)+ 0.2000000000000000D+01*dw( 11, 16)
      JacC( 26, 26) = JacC( 26, 26) - dw( 12, 26)
      JacC( 26, 35) = JacC( 26, 35) - dw( 12, 35)
      JacC( 35, 26) = JacC( 35, 26) - dw( 12, 26)
      JacC( 35, 35) = JacC( 35, 35) - dw( 12, 35)
      JacC( 36, 26) = JacC( 36, 26) + dw( 12, 26)
      JacC( 36, 35) = JacC( 36, 35) + dw( 12, 35)
      JacC( 26, 26) = JacC( 26, 26) - dw( 13, 26)
      JacC( 26, 36) = JacC( 26, 36) - dw( 13, 36)
      JacC( 35, 26) = JacC( 35, 26) + dw( 13, 26)
      JacC( 35, 36) = JacC( 35, 36) + dw( 13, 36)
      JacC( 36, 26) = JacC( 36, 26) - dw( 13, 26)
      JacC( 36, 36) = JacC( 36, 36) - dw( 13, 36)
      JacC( 27, 29) = JacC( 27, 29)+ 0.8900000000000000D+00*dw( 14, 29)
      JacC( 29, 29) = JacC( 29, 29) - dw( 14, 29)
      JacC( 33, 29) = JacC( 33, 29)+ 0.1100000000000000D+00*dw( 14, 29)
      JacC( 34, 29) = JacC( 34, 29)+ 0.8900000000000000D+00*dw( 14, 29)
      JacC( 29, 29) = JacC( 29, 29) - dw( 15, 29)
      JacC( 29, 33) = JacC( 29, 33) - dw( 15, 33)
      JacC( 33, 29) = JacC( 33, 29) - dw( 15, 29)
      JacC( 33, 33) = JacC( 33, 33) - dw( 15, 33)
      JacC( 34, 29) = JacC( 34, 29)+ 0.2000000000000000D+01*dw( 15, 29)
      JacC( 34, 33) = JacC( 34, 33)+ 0.2000000000000000D+01*dw( 15, 33)
      JacC( 29, 29) = JacC( 29, 29) - dw( 16, 29)
      JacC( 29, 34) = JacC( 29, 34) - dw( 16, 34)
      JacC( 33, 29) = JacC( 33, 29) + dw( 16, 29)
      JacC( 33, 34) = JacC( 33, 34) + dw( 16, 34)
      JacC( 10, 29) = JacC( 10, 29) + dw( 17, 29)
      JacC( 10, 34) = JacC( 10, 34) + dw( 17, 34)
      JacC( 29, 29) = JacC( 29, 29) - dw( 17, 29)
      JacC( 29, 34) = JacC( 29, 34) - dw( 17, 34)
      JacC( 34, 29) = JacC( 34, 29) - dw( 17, 29)
      JacC( 34, 34) = JacC( 34, 34) - dw( 17, 34)
      JacC( 10, 10) = JacC( 10, 10) - dw( 18, 10)
      JacC( 10, 16) = JacC( 10, 16) - dw( 18, 16)
      JacC( 16, 10) = JacC( 16, 10) - dw( 18, 10)
      JacC( 16, 16) = JacC( 16, 16) - dw( 18, 16)
      JacC( 24, 10) = JacC( 24, 10)+ 0.2000000000000000D+01*dw( 18, 10)
      JacC( 24, 16) = JacC( 24, 16)+ 0.2000000000000000D+01*dw( 18, 16)
      JacC( 10, 10) = JacC( 10, 10) - dw( 19, 10)
      JacC( 29, 10) = JacC( 29, 10) + dw( 19, 10)
      JacC( 34, 10) = JacC( 34, 10) + dw( 19, 10)
      JacC( 33, 33) = JacC( 33, 33)- 0.2000000000000000D+01*dw( 20, 33)
      JacC( 33, 33) = JacC( 33, 33)- 0.2000000000000000D+01*dw( 20, 33)
      JacC( 34, 33) = JacC( 34, 33)+ 0.2000000000000000D+01*dw( 20, 33)
      JacC( 34, 33) = JacC( 34, 33)+ 0.2000000000000000D+01*dw( 20, 33)
      JacC( 16, 33) = JacC( 16, 33) - dw( 21, 33)
      JacC( 16, 34) = JacC( 16, 34) - dw( 21, 34)
      JacC( 16, 16) = JacC( 16, 16) - dw( 21, 16)
      JacC( 17, 33) = JacC( 17, 33)+ 0.2000000000000000D+01*dw( 21, 33)
      JacC( 17, 34) = JacC( 17, 34)+ 0.2000000000000000D+01*dw( 21, 34)
      JacC( 17, 16) = JacC( 17, 16)+ 0.2000000000000000D+01*dw( 21, 16)
      JacC( 33, 33) = JacC( 33, 33) - dw( 21, 33)
      JacC( 33, 34) = JacC( 33, 34) - dw( 21, 34)
      JacC( 33, 16) = JacC( 33, 16) - dw( 21, 16)
      JacC( 34, 33) = JacC( 34, 33) - dw( 21, 33)
      JacC( 34, 34) = JacC( 34, 34) - dw( 21, 34)
      JacC( 34, 16) = JacC( 34, 16) - dw( 21, 16)
      JacC( 17, 33) = JacC( 17, 33) + dw( 22, 33)
      JacC( 17, 35) = JacC( 17, 35) + dw( 22, 35)
      JacC( 33, 33) = JacC( 33, 33) - dw( 22, 33)
      JacC( 33, 35) = JacC( 33, 35) - dw( 22, 35)
      JacC( 35, 33) = JacC( 35, 33) - dw( 22, 33)
      JacC( 35, 35) = JacC( 35, 35) - dw( 22, 35)
      JacC( 17, 17) = JacC( 17, 17) - dw( 23, 17)
      JacC( 33, 17) = JacC( 33, 17) + dw( 23, 17)
      JacC( 35, 17) = JacC( 35, 17) + dw( 23, 17)
      JacC( 17, 35) = JacC( 17, 35) - dw( 24, 35)
      JacC( 17, 17) = JacC( 17, 17) - dw( 24, 17)
      JacC( 34, 35) = JacC( 34, 35) + dw( 24, 35)
      JacC( 34, 17) = JacC( 34, 17) + dw( 24, 17)
      JacC( 35, 35) = JacC( 35, 35) - dw( 24, 35)
      JacC( 35, 17) = JacC( 35, 17) - dw( 24, 17)
      JacC( 17, 17) = JacC( 17, 17)- 0.2000000000000000D+01*dw( 25, 17)
      JacC( 17, 17) = JacC( 17, 17)- 0.2000000000000000D+01*dw( 25, 17)
      JacC( 33, 17) = JacC( 33, 17) + dw( 25, 17)
      JacC( 33, 17) = JacC( 33, 17) + dw( 25, 17)
      JacC( 34, 17) = JacC( 34, 17) + dw( 25, 17)
      JacC( 34, 17) = JacC( 34, 17) + dw( 25, 17)
      JacC( 24, 34) = JacC( 24, 34) + dw( 26, 34)
      JacC( 24, 35) = JacC( 24, 35) + dw( 26, 35)
      JacC( 34, 34) = JacC( 34, 34) - dw( 26, 34)
      JacC( 34, 35) = JacC( 34, 35) - dw( 26, 35)
      JacC( 35, 34) = JacC( 35, 34) - dw( 26, 34)
      JacC( 35, 35) = JacC( 35, 35) - dw( 26, 35)
      JacC( 24, 35) = JacC( 24, 35) - dw( 27, 35)
      JacC( 24, 24) = JacC( 24, 24) - dw( 27, 24)
      JacC( 29, 35) = JacC( 29, 35) + dw( 27, 35)
      JacC( 29, 24) = JacC( 29, 24) + dw( 27, 24)
      JacC( 35, 35) = JacC( 35, 35) - dw( 27, 35)
      JacC( 35, 24) = JacC( 35, 24) - dw( 27, 24)
      JacC( 33, 36) = JacC( 33, 36) - dw( 28, 36)
      JacC( 33, 33) = JacC( 33, 33) - dw( 28, 33)
      JacC( 34, 36) = JacC( 34, 36) + dw( 28, 36)
      JacC( 34, 33) = JacC( 34, 33) + dw( 28, 33)
      JacC( 35, 36) = JacC( 35, 36) + dw( 28, 36)
      JacC( 35, 33) = JacC( 35, 33) + dw( 28, 33)
      JacC( 36, 36) = JacC( 36, 36) - dw( 28, 36)
      JacC( 36, 33) = JacC( 36, 33) - dw( 28, 33)
      JacC( 13, 36) = JacC( 13, 36) + dw( 29, 36)
      JacC( 13, 34) = JacC( 13, 34) + dw( 29, 34)
      JacC( 34, 36) = JacC( 34, 36) - dw( 29, 36)
      JacC( 34, 34) = JacC( 34, 34) - dw( 29, 34)
      JacC( 36, 36) = JacC( 36, 36) - dw( 29, 36)
      JacC( 36, 34) = JacC( 36, 34) - dw( 29, 34)
      JacC( 13, 13) = JacC( 13, 13) - dw( 30, 13)
      JacC( 34, 13) = JacC( 34, 13) + dw( 30, 13)
      JacC( 36, 13) = JacC( 36, 13) + dw( 30, 13)
      JacC( 13, 35) = JacC( 13, 35) - dw( 31, 35)
      JacC( 13, 13) = JacC( 13, 13) - dw( 31, 13)
      JacC( 34, 35) = JacC( 34, 35) + dw( 31, 35)
      JacC( 34, 13) = JacC( 34, 13) + dw( 31, 13)
      JacC( 35, 35) = JacC( 35, 35) - dw( 31, 35)
      JacC( 35, 13) = JacC( 35, 13) - dw( 31, 13)
      JacC( 15, 36) = JacC( 15, 36) + dw( 32, 36)
      JacC( 15, 36) = JacC( 15, 36) + dw( 32, 36)
      JacC( 36, 36) = JacC( 36, 36)- 0.2000000000000000D+01*dw( 32, 36)
      JacC( 36, 36) = JacC( 36, 36)- 0.2000000000000000D+01*dw( 32, 36)
      JacC( 15, 36) = JacC( 15, 36) + dw( 33, 36)
      JacC( 15, 36) = JacC( 15, 36) + dw( 33, 36)
      JacC( 15, 16) = JacC( 15, 16) + dw( 33, 16)
      JacC( 16, 36) = JacC( 16, 36) - dw( 33, 36)
      JacC( 16, 36) = JacC( 16, 36) - dw( 33, 36)
      JacC( 16, 16) = JacC( 16, 16) - dw( 33, 16)
      JacC( 36, 36) = JacC( 36, 36)- 0.2000000000000000D+01*dw( 33, 36)
      JacC( 36, 36) = JacC( 36, 36)- 0.2000000000000000D+01*dw( 33, 36)
      JacC( 36, 16) = JacC( 36, 16)- 0.2000000000000000D+01*dw( 33, 16)
      JacC( 15, 15) = JacC( 15, 15) - dw( 34, 15)
      JacC( 35, 15) = JacC( 35, 15)+ 0.2000000000000000D+01*dw( 34, 15)
      JacC( 15, 35) = JacC( 15, 35) - dw( 35, 35)
      JacC( 15, 15) = JacC( 15, 15) - dw( 35, 15)
      JacC( 35, 35) = JacC( 35, 35) - dw( 35, 35)
      JacC( 35, 15) = JacC( 35, 15) - dw( 35, 15)
      JacC( 36, 35) = JacC( 36, 35) + dw( 35, 35)
      JacC( 36, 15) = JacC( 36, 15) + dw( 35, 15)
      JacC( 28, 35) = JacC( 28, 35) - dw( 36, 35)
      JacC( 28, 28) = JacC( 28, 28) - dw( 36, 28)
      JacC( 35, 35) = JacC( 35, 35) - dw( 36, 35)
      JacC( 35, 28) = JacC( 35, 28) - dw( 36, 28)
      JacC( 36, 35) = JacC( 36, 35) + dw( 36, 35)
      JacC( 36, 28) = JacC( 36, 28) + dw( 36, 28)
      JacC( 28, 31) = JacC( 28, 31) + dw( 37, 31)
      JacC( 28, 35) = JacC( 28, 35) + dw( 37, 35)
      JacC( 31, 31) = JacC( 31, 31) - dw( 37, 31)
      JacC( 31, 35) = JacC( 31, 35) - dw( 37, 35)
      JacC( 35, 31) = JacC( 35, 31) - dw( 37, 31)
      JacC( 35, 35) = JacC( 35, 35) - dw( 37, 35)
      JacC( 36, 31) = JacC( 36, 31) + dw( 37, 31)
      JacC( 36, 35) = JacC( 36, 35) + dw( 37, 35)
      JacC( 28, 31) = JacC( 28, 31) + dw( 38, 31)
      JacC( 31, 31) = JacC( 31, 31) - dw( 38, 31)
      JacC( 36, 31) = JacC( 36, 31)+ 0.2000000000000000D+01*dw( 38, 31)
      JacC( 28, 31) = JacC( 28, 31) + dw( 39, 31)
      JacC( 31, 31) = JacC( 31, 31) - dw( 39, 31)
      JacC( 27, 31) = JacC( 27, 31) - dw( 40, 31)
      JacC( 27, 27) = JacC( 27, 27) - dw( 40, 27)
      JacC( 28, 31) = JacC( 28, 31) + dw( 40, 31)
      JacC( 28, 27) = JacC( 28, 27) + dw( 40, 27)
      JacC( 31, 31) = JacC( 31, 31) - dw( 40, 31)
      JacC( 31, 27) = JacC( 31, 27) - dw( 40, 27)
      JacC( 35, 31) = JacC( 35, 31) + dw( 40, 31)
      JacC( 35, 27) = JacC( 35, 27) + dw( 40, 27)
      JacC( 36, 31) = JacC( 36, 31) + dw( 40, 31)
      JacC( 36, 27) = JacC( 36, 27) + dw( 40, 27)
      JacC( 24, 31) = JacC( 24, 31) + dw( 41, 31)
      JacC( 24, 29) = JacC( 24, 29) + dw( 41, 29)
      JacC( 28, 31) = JacC( 28, 31) + dw( 41, 31)
      JacC( 28, 29) = JacC( 28, 29) + dw( 41, 29)
      JacC( 29, 31) = JacC( 29, 31) - dw( 41, 31)
      JacC( 29, 29) = JacC( 29, 29) - dw( 41, 29)
      JacC( 31, 31) = JacC( 31, 31) - dw( 41, 31)
      JacC( 31, 29) = JacC( 31, 29) - dw( 41, 29)
      JacC( 36, 31) = JacC( 36, 31) + dw( 41, 31)
      JacC( 36, 29) = JacC( 36, 29) + dw( 41, 29)
      JacC( 23, 23) = JacC( 23, 23) - dw( 42, 23)
      JacC( 23, 27) = JacC( 23, 27) - dw( 42, 27)
      JacC( 27, 23) = JacC( 27, 23) - dw( 42, 23)
      JacC( 27, 27) = JacC( 27, 27) - dw( 42, 27)
      JacC( 30, 23) = JacC( 30, 23) + dw( 42, 23)
      JacC( 30, 27) = JacC( 30, 27) + dw( 42, 27)
      JacC( 35, 23) = JacC( 35, 23) + dw( 42, 23)
      JacC( 35, 27) = JacC( 35, 27) + dw( 42, 27)
      JacC( 23, 23) = JacC( 23, 23) - dw( 43, 23)
      JacC( 23, 35) = JacC( 23, 35) - dw( 43, 35)
      JacC( 30, 23) = JacC( 30, 23) + dw( 43, 23)
      JacC( 30, 35) = JacC( 30, 35) + dw( 43, 35)
      JacC( 35, 23) = JacC( 35, 23) - dw( 43, 23)
      JacC( 35, 35) = JacC( 35, 35) - dw( 43, 35)
      JacC( 23, 23) = JacC( 23, 23) - dw( 44, 23)
      JacC( 23, 29) = JacC( 23, 29) - dw( 44, 29)
      JacC( 24, 23) = JacC( 24, 23) + dw( 44, 23)
      JacC( 24, 29) = JacC( 24, 29) + dw( 44, 29)
      JacC( 29, 23) = JacC( 29, 23) - dw( 44, 23)
      JacC( 29, 29) = JacC( 29, 29) - dw( 44, 29)
      JacC( 30, 23) = JacC( 30, 23) + dw( 44, 23)
      JacC( 30, 29) = JacC( 30, 29) + dw( 44, 29)
      JacC( 23, 23) = JacC( 23, 23) - dw( 45, 23)
      JacC( 28, 23) = JacC( 28, 23) + dw( 45, 23)
      JacC( 31, 23) = JacC( 31, 23) + dw( 45, 23)
      JacC( 32, 23) = JacC( 32, 23) + dw( 45, 23)
      JacC( 36, 23) = JacC( 36, 23)+ 0.2000000000000000D+01*dw( 45, 23)
      JacC( 30, 30) = JacC( 30, 30) - dw( 46, 30)
      JacC( 30, 33) = JacC( 30, 33) - dw( 46, 33)
      JacC( 31, 30) = JacC( 31, 30) + dw( 46, 30)
      JacC( 31, 33) = JacC( 31, 33) + dw( 46, 33)
      JacC( 32, 30) = JacC( 32, 30) + dw( 46, 30)
      JacC( 32, 33) = JacC( 32, 33) + dw( 46, 33)
      JacC( 33, 30) = JacC( 33, 30) - dw( 46, 30)
      JacC( 33, 33) = JacC( 33, 33) - dw( 46, 33)
      JacC( 34, 30) = JacC( 34, 30) + dw( 46, 30)
      JacC( 34, 33) = JacC( 34, 33) + dw( 46, 33)
      JacC( 36, 30) = JacC( 36, 30) + dw( 46, 30)
      JacC( 36, 33) = JacC( 36, 33) + dw( 46, 33)
      JacC(  7, 30) = JacC(  7, 30) + dw( 47, 30)
      JacC(  7, 34) = JacC(  7, 34) + dw( 47, 34)
      JacC( 30, 30) = JacC( 30, 30) - dw( 47, 30)
      JacC( 30, 34) = JacC( 30, 34) - dw( 47, 34)
      JacC( 34, 30) = JacC( 34, 30) - dw( 47, 30)
      JacC( 34, 34) = JacC( 34, 34) - dw( 47, 34)
      JacC(  7,  7) = JacC(  7,  7) - dw( 48,  7)
      JacC( 30,  7) = JacC( 30,  7) + dw( 48,  7)
      JacC( 34,  7) = JacC( 34,  7) + dw( 48,  7)
      JacC( 30, 30) = JacC( 30, 30)- 0.2000000000000000D+01*dw( 49, 30)
      JacC( 30, 30) = JacC( 30, 30)- 0.2000000000000000D+01*dw( 49, 30)
      JacC( 31, 30) = JacC( 31, 30)+ 0.2000000000000000D+01*dw( 49, 30)
      JacC( 31, 30) = JacC( 31, 30)+ 0.2000000000000000D+01*dw( 49, 30)
      JacC( 32, 30) = JacC( 32, 30)+ 0.2000000000000000D+01*dw( 49, 30)
      JacC( 32, 30) = JacC( 32, 30)+ 0.2000000000000000D+01*dw( 49, 30)
      JacC( 36, 30) = JacC( 36, 30)+ 0.2000000000000000D+01*dw( 49, 30)
      JacC( 36, 30) = JacC( 36, 30)+ 0.2000000000000000D+01*dw( 49, 30)
      JacC( 30, 30) = JacC( 30, 30) - dw( 50, 30)
      JacC( 30, 36) = JacC( 30, 36) - dw( 50, 36)
      JacC( 31, 30) = JacC( 31, 30)+ 0.7900000000000000D+00*dw( 50, 30)
      JacC( 31, 36) = JacC( 31, 36)+ 0.7900000000000000D+00*dw( 50, 36)
      JacC( 32, 30) = JacC( 32, 30)+ 0.7900000000000000D+00*dw( 50, 30)
      JacC( 32, 36) = JacC( 32, 36)+ 0.7900000000000000D+00*dw( 50, 36)
      JacC( 35, 30) = JacC( 35, 30)+ 0.7900000000000000D+00*dw( 50, 30)
      JacC( 35, 36) = JacC( 35, 36)+ 0.7900000000000000D+00*dw( 50, 36)
      JacC( 36, 30) = JacC( 36, 30)- 0.2100000000000000D+00*dw( 50, 30)
      JacC( 36, 36) = JacC( 36, 36)- 0.2100000000000000D+00*dw( 50, 36)
      JacC( 31, 35) = JacC( 31, 35) + dw( 51, 35)
      JacC( 32, 35) = JacC( 32, 35) + dw( 51, 35)
      JacC( 35, 35) = JacC( 35, 35) - dw( 51, 35)
      JacC( 36, 35) = JacC( 36, 35) + dw( 51, 35)
      JacC( 14, 22) = JacC( 14, 22)+ 0.7600000000000000D+00*dw( 52, 22)
      JacC( 14, 35) = JacC( 14, 35)+ 0.7600000000000000D+00*dw( 52, 35)
      JacC( 22, 22) = JacC( 22, 22)- 0.8900000000000000D+00*dw( 52, 22)
      JacC( 22, 35) = JacC( 22, 35)- 0.8900000000000000D+00*dw( 52, 35)
      JacC( 23, 22) = JacC( 23, 22)+ 0.1100000000000000D+00*dw( 52, 22)
      JacC( 23, 35) = JacC( 23, 35)+ 0.1100000000000000D+00*dw( 52, 35)
      JacC( 25, 22) = JacC( 25, 22)+ 0.1300000000000000D+00*dw( 52, 22)
      JacC( 25, 35) = JacC( 25, 35)+ 0.1300000000000000D+00*dw( 52, 35)
      JacC( 32, 22) = JacC( 32, 22)+ 0.8700000000000000D+00*dw( 52, 22)
      JacC( 32, 35) = JacC( 32, 35)+ 0.8700000000000000D+00*dw( 52, 35)
      JacC( 35, 22) = JacC( 35, 22) - dw( 52, 22)
      JacC( 35, 35) = JacC( 35, 35) - dw( 52, 35)
      JacC( 36, 22) = JacC( 36, 22)+ 0.1100000000000000D+00*dw( 52, 22)
      JacC( 36, 35) = JacC( 36, 35)+ 0.1100000000000000D+00*dw( 52, 35)
      JacC( 14, 14) = JacC( 14, 14)- 0.9800000000000000D+00*dw( 53, 14)
      JacC( 22, 14) = JacC( 22, 14)+ 0.2100000000000000D+01*dw( 53, 14)
      JacC( 23, 14) = JacC( 23, 14)+ 0.1100000000000000D+01*dw( 53, 14)
      JacC( 25, 14) = JacC( 25, 14)+ 0.4000000000000000D-01*dw( 53, 14)
      JacC( 32, 14) = JacC( 32, 14)+ 0.9600000000000000D+00*dw( 53, 14)
      JacC( 36, 14) = JacC( 36, 14)+ 0.9399999999999999D+00*dw( 53, 14)
      JacC( 14, 14) = JacC( 14, 14) - dw( 54, 14)
      JacC( 36, 14) = JacC( 36, 14) + dw( 54, 14)
      JacC( 14, 14) = JacC( 14, 14) - dw( 55, 14)
      JacC( 14, 34) = JacC( 14, 34) - dw( 55, 34)
      JacC( 34, 14) = JacC( 34, 14) - dw( 55, 14)
      JacC( 34, 34) = JacC( 34, 34) - dw( 55, 34)
      JacC( 21, 27) = JacC( 21, 27) - dw( 56, 27)
      JacC( 21, 21) = JacC( 21, 21) - dw( 56, 21)
      JacC( 22, 27) = JacC( 22, 27)+ 0.2200000000000000D+00*dw( 56, 27)
      JacC( 22, 21) = JacC( 22, 21)+ 0.2200000000000000D+00*dw( 56, 21)
      JacC( 23, 27) = JacC( 23, 27)+ 0.6300000000000000D+00*dw( 56, 27)
      JacC( 23, 21) = JacC( 23, 21)+ 0.6300000000000000D+00*dw( 56, 21)
      JacC( 25, 27) = JacC( 25, 27)+ 0.2000000000000000D-01*dw( 56, 27)
      JacC( 25, 21) = JacC( 25, 21)+ 0.2000000000000000D-01*dw( 56, 21)
      JacC( 27, 27) = JacC( 27, 27) - dw( 56, 27)
      JacC( 27, 21) = JacC( 27, 21) - dw( 56, 21)
      JacC( 28, 27) = JacC( 28, 27)+ 0.3000000000000000D+00*dw( 56, 27)
      JacC( 28, 21) = JacC( 28, 21)+ 0.3000000000000000D+00*dw( 56, 21)
      JacC( 31, 27) = JacC( 31, 27)+ 0.2000000000000000D+00*dw( 56, 27)
      JacC( 31, 21) = JacC( 31, 21)+ 0.2000000000000000D+00*dw( 56, 21)
      JacC( 32, 27) = JacC( 32, 27)+ 0.2800000000000000D+00*dw( 56, 27)
      JacC( 32, 21) = JacC( 32, 21)+ 0.2800000000000000D+00*dw( 56, 21)
      JacC( 35, 27) = JacC( 35, 27)+ 0.2000000000000000D+00*dw( 56, 27)
      JacC( 35, 21) = JacC( 35, 21)+ 0.2000000000000000D+00*dw( 56, 21)
      JacC( 36, 27) = JacC( 36, 27)+ 0.3800000000000000D+00*dw( 56, 27)
      JacC( 36, 21) = JacC( 36, 21)+ 0.3800000000000000D+00*dw( 56, 21)
      JacC( 21, 35) = JacC( 21, 35) - dw( 57, 35)
      JacC( 21, 21) = JacC( 21, 21) - dw( 57, 21)
      JacC( 22, 35) = JacC( 22, 35) + dw( 57, 35)
      JacC( 22, 21) = JacC( 22, 21) + dw( 57, 21)
      JacC( 23, 35) = JacC( 23, 35) + dw( 57, 35)
      JacC( 23, 21) = JacC( 23, 21) + dw( 57, 21)
      JacC( 31, 35) = JacC( 31, 35) + dw( 57, 35)
      JacC( 31, 21) = JacC( 31, 21) + dw( 57, 21)
      JacC( 32, 35) = JacC( 32, 35) + dw( 57, 35)
      JacC( 32, 21) = JacC( 32, 21) + dw( 57, 21)
      JacC( 35, 35) = JacC( 35, 35) - dw( 57, 35)
      JacC( 35, 21) = JacC( 35, 21) - dw( 57, 21)
      JacC( 36, 35) = JacC( 36, 35) + dw( 57, 35)
      JacC( 36, 21) = JacC( 36, 21) + dw( 57, 21)
      JacC( 21, 26) = JacC( 21, 26) - dw( 58, 26)
      JacC( 21, 21) = JacC( 21, 21) - dw( 58, 21)
      JacC( 22, 26) = JacC( 22, 26) + dw( 58, 26)
      JacC( 22, 21) = JacC( 22, 21) + dw( 58, 21)
      JacC( 23, 26) = JacC( 23, 26)+ 0.5000000000000000D+00*dw( 58, 26)
      JacC( 23, 21) = JacC( 23, 21)+ 0.5000000000000000D+00*dw( 58, 21)
      JacC( 26, 26) = JacC( 26, 26) - dw( 58, 26)
      JacC( 26, 21) = JacC( 26, 21) - dw( 58, 21)
      JacC( 28, 26) = JacC( 28, 26)+ 0.3300000000000000D+00*dw( 58, 26)
      JacC( 28, 21) = JacC( 28, 21)+ 0.3300000000000000D+00*dw( 58, 21)
      JacC( 31, 26) = JacC( 31, 26)+ 0.7400000000000000D+00*dw( 58, 26)
      JacC( 31, 21) = JacC( 31, 21)+ 0.7400000000000000D+00*dw( 58, 21)
      JacC( 32, 26) = JacC( 32, 26)+ 0.2200000000000000D+00*dw( 58, 26)
      JacC( 32, 21) = JacC( 32, 21)+ 0.2200000000000000D+00*dw( 58, 21)
      JacC( 35, 26) = JacC( 35, 26)+ 0.1000000000000000D+00*dw( 58, 26)
      JacC( 35, 21) = JacC( 35, 21)+ 0.1000000000000000D+00*dw( 58, 21)
      JacC( 36, 26) = JacC( 36, 26)+ 0.4400000000000000D+00*dw( 58, 26)
      JacC( 36, 21) = JacC( 36, 21)+ 0.4400000000000000D+00*dw( 58, 21)
      JacC( 21, 29) = JacC( 21, 29) - dw( 59, 29)
      JacC( 21, 21) = JacC( 21, 21) - dw( 59, 21)
      JacC( 22, 29) = JacC( 22, 29) + dw( 59, 29)
      JacC( 22, 21) = JacC( 22, 21) + dw( 59, 21)
      JacC( 23, 29) = JacC( 23, 29) + dw( 59, 29)
      JacC( 23, 21) = JacC( 23, 21) + dw( 59, 21)
      JacC( 25, 29) = JacC( 25, 29)+ 0.9000000000000000D-01*dw( 59, 29)
      JacC( 25, 21) = JacC( 25, 21)+ 0.9000000000000000D-01*dw( 59, 21)
      JacC( 29, 29) = JacC( 29, 29) - dw( 59, 29)
      JacC( 29, 21) = JacC( 29, 21) - dw( 59, 21)
      JacC( 31, 29) = JacC( 31, 29) + dw( 59, 29)
      JacC( 31, 21) = JacC( 31, 21) + dw( 59, 21)
      JacC( 32, 29) = JacC( 32, 29)+ 0.9100000000000000D+00*dw( 59, 29)
      JacC( 32, 21) = JacC( 32, 21)+ 0.9100000000000000D+00*dw( 59, 21)
      JacC( 34, 29) = JacC( 34, 29) + dw( 59, 29)
      JacC( 34, 21) = JacC( 34, 21) + dw( 59, 21)
      JacC( 19, 27) = JacC( 19, 27) - dw( 60, 27)
      JacC( 19, 19) = JacC( 19, 19) - dw( 60, 19)
      JacC( 27, 27) = JacC( 27, 27) - dw( 60, 27)
      JacC( 27, 19) = JacC( 27, 19) - dw( 60, 19)
      JacC( 28, 27) = JacC( 28, 27) + dw( 60, 27)
      JacC( 28, 19) = JacC( 28, 19) + dw( 60, 19)
      JacC( 31, 27) = JacC( 31, 27) + dw( 60, 27)
      JacC( 31, 19) = JacC( 31, 19) + dw( 60, 19)
      JacC( 32, 27) = JacC( 32, 27)+ 0.7000000000000000D+00*dw( 60, 27)
      JacC( 32, 19) = JacC( 32, 19)+ 0.7000000000000000D+00*dw( 60, 19)
      JacC( 35, 27) = JacC( 35, 27)+ 0.3000000000000000D+00*dw( 60, 27)
      JacC( 35, 19) = JacC( 35, 19)+ 0.3000000000000000D+00*dw( 60, 19)
      JacC( 36, 27) = JacC( 36, 27)+ 0.1700000000000000D+01*dw( 60, 27)
      JacC( 36, 19) = JacC( 36, 19)+ 0.1700000000000000D+01*dw( 60, 19)
      JacC( 19, 35) = JacC( 19, 35) - dw( 61, 35)
      JacC( 19, 19) = JacC( 19, 19) - dw( 61, 19)
      JacC( 23, 35) = JacC( 23, 35)+ 0.2200000000000000D+00*dw( 61, 35)
      JacC( 23, 19) = JacC( 23, 19)+ 0.2200000000000000D+00*dw( 61, 19)
      JacC( 31, 35) = JacC( 31, 35)+ 0.1560000000000000D+01*dw( 61, 35)
      JacC( 31, 19) = JacC( 31, 19)+ 0.1560000000000000D+01*dw( 61, 19)
      JacC( 32, 35) = JacC( 32, 35) + dw( 61, 35)
      JacC( 32, 19) = JacC( 32, 19) + dw( 61, 19)
      JacC( 35, 35) = JacC( 35, 35) - dw( 61, 35)
      JacC( 35, 19) = JacC( 35, 19) - dw( 61, 19)
      JacC( 36, 35) = JacC( 36, 35) + dw( 61, 35)
      JacC( 36, 19) = JacC( 36, 19) + dw( 61, 19)
      JacC( 19, 26) = JacC( 19, 26) - dw( 62, 26)
      JacC( 19, 19) = JacC( 19, 19) - dw( 62, 19)
      JacC( 26, 26) = JacC( 26, 26) - dw( 62, 26)
      JacC( 26, 19) = JacC( 26, 19) - dw( 62, 19)
      JacC( 28, 26) = JacC( 28, 26)+ 0.4200000000000000D+00*dw( 62, 26)
      JacC( 28, 19) = JacC( 28, 19)+ 0.4200000000000000D+00*dw( 62, 19)
      JacC( 31, 26) = JacC( 31, 26) + dw( 62, 26)
      JacC( 31, 19) = JacC( 31, 19) + dw( 62, 19)
      JacC( 36, 26) = JacC( 36, 26)+ 0.1200000000000000D+00*dw( 62, 26)
      JacC( 36, 19) = JacC( 36, 19)+ 0.1200000000000000D+00*dw( 62, 19)
      JacC(  4,  4) = JacC(  4,  4) - dw( 63,  4)
      JacC(  4, 35) = JacC(  4, 35) - dw( 63, 35)
      JacC(  8,  4) = JacC(  8,  4)+ 0.5600000000000001D+00*dw( 63,  4)
      JacC(  8, 35) = JacC(  8, 35)+ 0.5600000000000001D+00*dw( 63, 35)
      JacC(  9,  4) = JacC(  9,  4)+ 0.3600000000000000D+00*dw( 63,  4)
      JacC(  9, 35) = JacC(  9, 35)+ 0.3600000000000000D+00*dw( 63, 35)
      JacC( 32,  4) = JacC( 32,  4)+ 0.8000000000000000D-01*dw( 63,  4)
      JacC( 32, 35) = JacC( 32, 35)+ 0.8000000000000000D-01*dw( 63, 35)
      JacC( 35,  4) = JacC( 35,  4) - dw( 63,  4)
      JacC( 35, 35) = JacC( 35, 35) - dw( 63, 35)
      JacC( 36,  4) = JacC( 36,  4)+ 0.4400000000000000D+00*dw( 63,  4)
      JacC( 36, 35) = JacC( 36, 35)+ 0.4400000000000000D+00*dw( 63, 35)
      JacC(  8,  8) = JacC(  8,  8) - dw( 64,  8)
      JacC(  8, 33) = JacC(  8, 33) - dw( 64, 33)
      JacC( 11,  8) = JacC( 11,  8)+ 0.9000000000000000D+00*dw( 64,  8)
      JacC( 11, 33) = JacC( 11, 33)+ 0.9000000000000000D+00*dw( 64, 33)
      JacC( 33,  8) = JacC( 33,  8) - dw( 64,  8)
      JacC( 33, 33) = JacC( 33, 33) - dw( 64, 33)
      JacC( 34,  8) = JacC( 34,  8)+ 0.9000000000000000D+00*dw( 64,  8)
      JacC( 34, 33) = JacC( 34, 33)+ 0.9000000000000000D+00*dw( 64, 33)
      JacC( 36,  8) = JacC( 36,  8)+ 0.9000000000000000D+00*dw( 64,  8)
      JacC( 36, 33) = JacC( 36, 33)+ 0.9000000000000000D+00*dw( 64, 33)
      JacC(  8,  8) = JacC(  8,  8) - dw( 65,  8)
      JacC(  9,  8) = JacC(  9,  8) + dw( 65,  8)
      JacC( 36,  8) = JacC( 36,  8) + dw( 65,  8)
      JacC(  9, 35) = JacC(  9, 35) - dw( 66, 35)
      JacC(  9,  9) = JacC(  9,  9) - dw( 66,  9)
      JacC( 11, 35) = JacC( 11, 35)+ 0.3000000000000000D+00*dw( 66, 35)
      JacC( 11,  9) = JacC( 11,  9)+ 0.3000000000000000D+00*dw( 66,  9)
      JacC( 18, 35) = JacC( 18, 35)+ 0.4000000000000000D+00*dw( 66, 35)
      JacC( 18,  9) = JacC( 18,  9)+ 0.4000000000000000D+00*dw( 66,  9)
      JacC( 32, 35) = JacC( 32, 35)+ 0.6000000000000000D+00*dw( 66, 35)
      JacC( 32,  9) = JacC( 32,  9)+ 0.6000000000000000D+00*dw( 66,  9)
      JacC( 35, 35) = JacC( 35, 35) - dw( 66, 35)
      JacC( 35,  9) = JacC( 35,  9) - dw( 66,  9)
      JacC( 36, 35) = JacC( 36, 35)+ 0.6000000000000000D+00*dw( 66, 35)
      JacC( 36,  9) = JacC( 36,  9)+ 0.6000000000000000D+00*dw( 66,  9)
      JacC(  9,  9) = JacC(  9,  9) - dw( 67,  9)
      JacC(  9, 29) = JacC(  9, 29) - dw( 67, 29)
      JacC( 18,  9) = JacC( 18,  9) + dw( 67,  9)
      JacC( 18, 29) = JacC( 18, 29) + dw( 67, 29)
      JacC( 24,  9) = JacC( 24,  9) + dw( 67,  9)
      JacC( 24, 29) = JacC( 24, 29) + dw( 67, 29)
      JacC( 29,  9) = JacC( 29,  9) - dw( 67,  9)
      JacC( 29, 29) = JacC( 29, 29) - dw( 67, 29)
      JacC( 18, 18) = JacC( 18, 18) - dw( 68, 18)
      JacC( 18, 34) = JacC( 18, 34) - dw( 68, 34)
      JacC( 34, 18) = JacC( 34, 18) - dw( 68, 18)
      JacC( 34, 34) = JacC( 34, 34) - dw( 68, 34)
      JacC( 11, 11) = JacC( 11, 11) - dw( 69, 11)
      JacC( 28, 11) = JacC( 28, 11) + dw( 69, 11)
      JacC( 30, 11) = JacC( 30, 11) + dw( 69, 11)
      JacC( 36, 11) = JacC( 36, 11) + dw( 69, 11)
      JacC( 11, 11) = JacC( 11, 11) - dw( 70, 11)
      JacC( 11, 35) = JacC( 11, 35) - dw( 70, 35)
      JacC( 28, 11) = JacC( 28, 11)+ 0.2000000000000000D+01*dw( 70, 11)
      JacC( 28, 35) = JacC( 28, 35)+ 0.2000000000000000D+01*dw( 70, 35)
      JacC( 30, 11) = JacC( 30, 11) + dw( 70, 11)
      JacC( 30, 35) = JacC( 30, 35) + dw( 70, 35)
      JacC( 31, 11) = JacC( 31, 11) + dw( 70, 11)
      JacC( 31, 35) = JacC( 31, 35) + dw( 70, 35)
      JacC( 32, 11) = JacC( 32, 11) + dw( 70, 11)
      JacC( 32, 35) = JacC( 32, 35) + dw( 70, 35)
      JacC( 35, 11) = JacC( 35, 11) - dw( 70, 11)
      JacC( 35, 35) = JacC( 35, 35) - dw( 70, 35)
      JacC( 36, 11) = JacC( 36, 11)+ 0.2000000000000000D+01*dw( 70, 11)
      JacC( 36, 35) = JacC( 36, 35)+ 0.2000000000000000D+01*dw( 70, 35)
      JacC( 11, 11) = JacC( 11, 11) - dw( 71, 11)
      JacC( 11, 26) = JacC( 11, 26) - dw( 71, 26)
      JacC( 12, 11) = JacC( 12, 11)+ 0.2000000000000000D+00*dw( 71, 11)
      JacC( 12, 26) = JacC( 12, 26)+ 0.2000000000000000D+00*dw( 71, 26)
      JacC( 23, 11) = JacC( 23, 11)+ 0.3000000000000000D-01*dw( 71, 11)
      JacC( 23, 26) = JacC( 23, 26)+ 0.3000000000000000D-01*dw( 71, 26)
      JacC( 26, 11) = JacC( 26, 11) - dw( 71, 11)
      JacC( 26, 26) = JacC( 26, 26) - dw( 71, 26)
      JacC( 28, 11) = JacC( 28, 11)+ 0.6899999999999999D+00*dw( 71, 11)
      JacC( 28, 26) = JacC( 28, 26)+ 0.6899999999999999D+00*dw( 71, 26)
      JacC( 30, 11) = JacC( 30, 11)+ 0.6200000000000000D+00*dw( 71, 11)
      JacC( 30, 26) = JacC( 30, 26)+ 0.6200000000000000D+00*dw( 71, 26)
      JacC( 31, 11) = JacC( 31, 11)+ 0.7000000000000000D+00*dw( 71, 11)
      JacC( 31, 26) = JacC( 31, 26)+ 0.7000000000000000D+00*dw( 71, 26)
      JacC( 32, 11) = JacC( 32, 11)+ 0.3000000000000000D-01*dw( 71, 11)
      JacC( 32, 26) = JacC( 32, 26)+ 0.3000000000000000D-01*dw( 71, 26)
      JacC( 35, 11) = JacC( 35, 11)+ 0.8000000000000000D-01*dw( 71, 11)
      JacC( 35, 26) = JacC( 35, 26)+ 0.8000000000000000D-01*dw( 71, 26)
      JacC( 36, 11) = JacC( 36, 11)+ 0.7600000000000000D+00*dw( 71, 11)
      JacC( 36, 26) = JacC( 36, 26)+ 0.7600000000000000D+00*dw( 71, 26)
      JacC(  5, 35) = JacC(  5, 35) - dw( 72, 35)
      JacC(  5,  5) = JacC(  5,  5) - dw( 72,  5)
      JacC(  8, 35) = JacC(  8, 35)+ 0.3000000000000000D+00*dw( 72, 35)
      JacC(  8,  5) = JacC(  8,  5)+ 0.3000000000000000D+00*dw( 72,  5)
      JacC(  9, 35) = JacC(  9, 35)+ 0.2000000000000000D+00*dw( 72, 35)
      JacC(  9,  5) = JacC(  9,  5)+ 0.2000000000000000D+00*dw( 72,  5)
      JacC( 12, 35) = JacC( 12, 35)+ 0.8000000000000000D+00*dw( 72, 35)
      JacC( 12,  5) = JacC( 12,  5)+ 0.8000000000000000D+00*dw( 72,  5)
      JacC( 22, 35) = JacC( 22, 35)+ 0.1100000000000000D+01*dw( 72, 35)
      JacC( 22,  5) = JacC( 22,  5)+ 0.1100000000000000D+01*dw( 72,  5)
      JacC( 32, 35) = JacC( 32, 35)+ 0.5000000000000000D+00*dw( 72, 35)
      JacC( 32,  5) = JacC( 32,  5)+ 0.5000000000000000D+00*dw( 72,  5)
      JacC( 35, 35) = JacC( 35, 35) - dw( 72, 35)
      JacC( 35,  5) = JacC( 35,  5) - dw( 72,  5)
      JacC( 36, 35) = JacC( 36, 35)+ 0.7000000000000000D+00*dw( 72, 35)
      JacC( 36,  5) = JacC( 36,  5)+ 0.7000000000000000D+00*dw( 72,  5)
      JacC( 12, 35) = JacC( 12, 35) - dw( 73, 35)
      JacC( 12, 12) = JacC( 12, 12) - dw( 73, 12)
      JacC( 30, 35) = JacC( 30, 35) + dw( 73, 35)
      JacC( 30, 12) = JacC( 30, 12) + dw( 73, 12)
      JacC( 32, 35) = JacC( 32, 35) + dw( 73, 35)
      JacC( 32, 12) = JacC( 32, 12) + dw( 73, 12)
      JacC( 35, 35) = JacC( 35, 35) - dw( 73, 35)
      JacC( 35, 12) = JacC( 35, 12) - dw( 73, 12)
      JacC( 12, 12) = JacC( 12, 12) - dw( 74, 12)
      JacC( 28, 12) = JacC( 28, 12) + dw( 74, 12)
      JacC( 30, 12) = JacC( 30, 12) + dw( 74, 12)
      JacC( 36, 12) = JacC( 36, 12) + dw( 74, 12)
      JacC( 19, 27) = JacC( 19, 27)+ 0.4500000000000000D+00*dw( 75, 27)
      JacC( 19, 20) = JacC( 19, 20)+ 0.4500000000000000D+00*dw( 75, 20)
      JacC( 20, 27) = JacC( 20, 27) - dw( 75, 27)
      JacC( 20, 20) = JacC( 20, 20) - dw( 75, 20)
      JacC( 21, 27) = JacC( 21, 27)+ 0.5500000000000000D+00*dw( 75, 27)
      JacC( 21, 20) = JacC( 21, 20)+ 0.5500000000000000D+00*dw( 75, 20)
      JacC( 22, 27) = JacC( 22, 27)+ 0.9000000000000000D+00*dw( 75, 27)
      JacC( 22, 20) = JacC( 22, 20)+ 0.9000000000000000D+00*dw( 75, 20)
      JacC( 23, 27) = JacC( 23, 27)+ 0.8000000000000000D+00*dw( 75, 27)
      JacC( 23, 20) = JacC( 23, 20)+ 0.8000000000000000D+00*dw( 75, 20)
      JacC( 27, 27) = JacC( 27, 27) - dw( 75, 27)
      JacC( 27, 20) = JacC( 27, 20) - dw( 75, 20)
      JacC( 28, 27) = JacC( 28, 27)+ 0.5000000000000000D+00*dw( 75, 27)
      JacC( 28, 20) = JacC( 28, 20)+ 0.5000000000000000D+00*dw( 75, 20)
      JacC( 32, 27) = JacC( 32, 27)+ 0.5000000000000000D+00*dw( 75, 27)
      JacC( 32, 20) = JacC( 32, 20)+ 0.5000000000000000D+00*dw( 75, 20)
      JacC( 36, 27) = JacC( 36, 27)+ 0.6000000000000000D+00*dw( 75, 27)
      JacC( 36, 20) = JacC( 36, 20)+ 0.6000000000000000D+00*dw( 75, 20)
      JacC( 12, 35) = JacC( 12, 35)+ 0.4000000000000000D+00*dw( 76, 35)
      JacC( 12, 20) = JacC( 12, 20)+ 0.4000000000000000D+00*dw( 76, 20)
      JacC( 19, 35) = JacC( 19, 35) + dw( 76, 35)
      JacC( 19, 20) = JacC( 19, 20) + dw( 76, 20)
      JacC( 20, 35) = JacC( 20, 35) - dw( 76, 35)
      JacC( 20, 20) = JacC( 20, 20) - dw( 76, 20)
      JacC( 23, 35) = JacC( 23, 35)+ 0.2000000000000000D+00*dw( 76, 35)
      JacC( 23, 20) = JacC( 23, 20)+ 0.2000000000000000D+00*dw( 76, 20)
      JacC( 25, 35) = JacC( 25, 35)+ 0.1300000000000000D+00*dw( 76, 35)
      JacC( 25, 20) = JacC( 25, 20)+ 0.1300000000000000D+00*dw( 76, 20)
      JacC( 30, 35) = JacC( 30, 35)+ 0.2000000000000000D+00*dw( 76, 35)
      JacC( 30, 20) = JacC( 30, 20)+ 0.2000000000000000D+00*dw( 76, 20)
      JacC( 31, 35) = JacC( 31, 35) + dw( 76, 35)
      JacC( 31, 20) = JacC( 31, 20) + dw( 76, 20)
      JacC( 32, 35) = JacC( 32, 35) + dw( 76, 35)
      JacC( 32, 20) = JacC( 32, 20) + dw( 76, 20)
      JacC( 35, 35) = JacC( 35, 35) - dw( 76, 35)
      JacC( 35, 20) = JacC( 35, 20) - dw( 76, 20)
      JacC( 36, 35) = JacC( 36, 35)+ 0.6700000000000000D+00*dw( 76, 35)
      JacC( 36, 20) = JacC( 36, 20)+ 0.6700000000000000D+00*dw( 76, 20)
      JacC( 12, 26) = JacC( 12, 26)+ 0.2000000000000000D+00*dw( 77, 26)
      JacC( 12, 20) = JacC( 12, 20)+ 0.2000000000000000D+00*dw( 77, 20)
      JacC( 19, 26) = JacC( 19, 26)+ 0.5500000000000000D+00*dw( 77, 26)
      JacC( 19, 20) = JacC( 19, 20)+ 0.5500000000000000D+00*dw( 77, 20)
      JacC( 20, 26) = JacC( 20, 26) - dw( 77, 26)
      JacC( 20, 20) = JacC( 20, 20) - dw( 77, 20)
      JacC( 22, 26) = JacC( 22, 26)+ 0.1000000000000000D+00*dw( 77, 26)
      JacC( 22, 20) = JacC( 22, 20)+ 0.1000000000000000D+00*dw( 77, 20)
      JacC( 23, 26) = JacC( 23, 26)+ 0.4000000000000000D+00*dw( 77, 26)
      JacC( 23, 20) = JacC( 23, 20)+ 0.4000000000000000D+00*dw( 77, 20)
      JacC( 26, 26) = JacC( 26, 26) - dw( 77, 26)
      JacC( 26, 20) = JacC( 26, 20) - dw( 77, 20)
      JacC( 28, 26) = JacC( 28, 26)+ 0.6000000000000000D-01*dw( 77, 26)
      JacC( 28, 20) = JacC( 28, 20)+ 0.6000000000000000D-01*dw( 77, 20)
      JacC( 31, 26) = JacC( 31, 26) + dw( 77, 26)
      JacC( 31, 20) = JacC( 31, 20) + dw( 77, 20)
      JacC( 35, 26) = JacC( 35, 26)+ 0.1000000000000000D+00*dw( 77, 26)
      JacC( 35, 20) = JacC( 35, 20)+ 0.1000000000000000D+00*dw( 77, 20)
      JacC( 36, 26) = JacC( 36, 26)+ 0.4400000000000000D+00*dw( 77, 26)
      JacC( 36, 20) = JacC( 36, 20)+ 0.4400000000000000D+00*dw( 77, 20)
      JacC( 20, 29) = JacC( 20, 29) - dw( 78, 29)
      JacC( 20, 20) = JacC( 20, 20) - dw( 78, 20)
      JacC( 25, 29) = JacC( 25, 29) + dw( 78, 29)
      JacC( 25, 20) = JacC( 25, 20) + dw( 78, 20)
      JacC( 29, 29) = JacC( 29, 29) - dw( 78, 29)
      JacC( 29, 20) = JacC( 29, 20) - dw( 78, 20)
      JacC( 32, 32) = JacC( 32, 32) - dw( 79, 32)
      JacC( 32, 33) = JacC( 32, 33) - dw( 79, 33)
      JacC( 33, 32) = JacC( 33, 32) - dw( 79, 32)
      JacC( 33, 33) = JacC( 33, 33) - dw( 79, 33)
      JacC( 34, 32) = JacC( 34, 32) + dw( 79, 32)
      JacC( 34, 33) = JacC( 34, 33) + dw( 79, 33)
      JacC( 25, 25) = JacC( 25, 25) - dw( 80, 25)
      JacC( 25, 33) = JacC( 25, 33) - dw( 80, 33)
      JacC( 33, 25) = JacC( 33, 25) - dw( 80, 25)
      JacC( 33, 33) = JacC( 33, 33) - dw( 80, 33)
      JacC( 32, 32) = JacC( 32, 32)- 0.2000000000000000D+01*dw( 81, 32)
      JacC( 32, 32) = JacC( 32, 32)- 0.2000000000000000D+01*dw( 81, 32)
      JacC(  2,  2) = JacC(  2,  2) - dw( 82,  2)
      JacC(  2, 35) = JacC(  2, 35) - dw( 82, 35)
      JacC(  3,  2) = JacC(  3,  2) + dw( 82,  2)
      JacC(  3, 35) = JacC(  3, 35) + dw( 82, 35)
      JacC( 35,  2) = JacC( 35,  2) - dw( 82,  2)
      JacC( 35, 35) = JacC( 35, 35) - dw( 82, 35)
      JacC( 36,  2) = JacC( 36,  2) + dw( 82,  2)
      JacC( 36, 35) = JacC( 36, 35) + dw( 82, 35)
      JacC(  2,  2) = JacC(  2,  2) - dw( 83,  2)
      JacC(  3,  2) = JacC(  3,  2) + dw( 83,  2)
      
      RETURN
      END
      
