      subroutine kinetic(rk,temp,xlw,Press,azi,att)
      
C------------------------------------------------------------------------
C     
C     -- DESCRIPTION
C     
C     This routine computes the kinetic rates for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: CBM4_REG            
C     Species: _ciCBM4_REG         
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     TEMP: temperature ([K]).
C     XLW: water massic fraction.
C     PRESS: pressure ([Pa]).
C     AZI: zenithal angle ([degree]).
C     ATT: attenuation variable.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     RK: kinetic rates.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     SPACK.
C     
C------------------------------------------------------------------------
      
      implicit none
      
C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of chemical arrays.
      
      include 'PARACHEM.INC' 
      INCLUDE 'PARADOM.INC'  
      
      double precision rk(nr),temp,xlw,Press
      double precision SumM,azi,att
      double precision YlH2O
      
C     Compute third body.
C     Conversion = Avogadro*1d-6/Perfect gas constant.
C     PRESS in Pascal, SUMM in molecules/cm3, TEMP in Kelvin
      
      SumM = Press * 7.243D16 / temp
      
C     Number of water molecules computed from the massic fraction
C     (absolute humidity)
      
      YlH2O = 29.d0*SumM*xlw/(18.d0+11.d0*xlw)
      
C     For the zenithal angle at tropics
      
      azi=abs(azi)
      
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(  1)=-0.3720822851761480D-08
         rk(  1)=-0.6672987683346889D-06+(azi- 0.00D+00) * rk(  1)
         rk(  1)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  1)
         rk(  1)= 0.9821699999999999D-02+(azi- 0.00D+00) * rk(  1)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(  1)=-0.4896790703974585D-08
         rk(  1)=-0.8347357966639553D-06+(azi- 0.15D+02) * rk(  1)
         rk(  1)=-0.2253051847497966D-04+(azi- 0.15D+02) * rk(  1)
         rk(  1)= 0.9658999999999999D-02+(azi- 0.15D+02) * rk(  1)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(  1)=-0.1426238470271076D-07
         rk(  1)=-0.1055091378342813D-05+(azi- 0.30D+02) * rk(  1)
         rk(  1)=-0.5087792610008118D-04+(azi- 0.30D+02) * rk(  1)
         rk(  1)= 0.9116700000000000D-02+(azi- 0.30D+02) * rk(  1)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(  1)=-0.2089811492962754D-07
         rk(  1)=-0.1696898689964795D-05+(azi- 0.45D+02) * rk(  1)
         rk(  1)=-0.9215777712469530D-04+(azi- 0.45D+02) * rk(  1)
         rk(  1)= 0.8068000000000001D-02+(azi- 0.45D+02) * rk(  1)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(  1)=-0.1011589598088173D-06
         rk(  1)=-0.2637313861798039D-05+(azi- 0.60D+02) * rk(  1)
         rk(  1)=-0.1571709654011378D-03+(azi- 0.60D+02) * rk(  1)
         rk(  1)= 0.6233300000000000D-02+(azi- 0.60D+02) * rk(  1)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(  1)= 0.4738137544022595D-06
         rk(  1)=-0.5672082656062538D-05+(azi- 0.70D+02) * rk(  1)
         rk(  1)=-0.2402649305797437D-03+(azi- 0.70D+02) * rk(  1)
         rk(  1)= 0.4296700000000000D-02+(azi- 0.70D+02) * rk(  1)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(  1)= 0.5736429041365249D-07
         rk(  1)= 0.1435123659971392D-05+(azi- 0.75D+02) * rk(  1)
         rk(  1)=-0.2614497255601986D-03+(azi- 0.75D+02) * rk(  1)
         rk(  1)= 0.3012800000000000D-02+(azi- 0.75D+02) * rk(  1)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(  1)= 0.7899336812152115D-06
         rk(  1)= 0.2295588016175659D-05+(azi- 0.80D+02) * rk(  1)
         rk(  1)=-0.2427961671794606D-03+(azi- 0.80D+02) * rk(  1)
         rk(  1)= 0.1748600000000000D-02+(azi- 0.80D+02) * rk(  1)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(  1)=-0.4461541898341404D-05
         rk(  1)= 0.9404991147112909D-05+(azi- 0.83D+02) * rk(  1)
         rk(  1)=-0.2076944296896013D-03+(azi- 0.83D+02) * rk(  1)
         rk(  1)= 0.1062200000000000D-02+(azi- 0.83D+02) * rk(  1)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(  1)= 0.3289347148449568D-04
         rk(  1)=-0.3074888593795036D-04+(azi- 0.86D+02) * rk(  1)
         rk(  1)=-0.2717261140621463D-03+(azi- 0.86D+02) * rk(  1)
         rk(  1)= 0.4033000000000000D-03+(azi- 0.86D+02) * rk(  1)
      elseif(azi.ge.90.D0)then
         rk(  1)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk(  1) = rk(  1) * att
C     
      rk(  2) =  DEXP( 0.7242082359256962D+01
     &     - ( -0.1175000000000000D+04 )/temp)
      rk(  3) =  DEXP(-0.2704936431140197D+02
     &     - (  0.1370000000000000D+04 )/temp)
      rk(  4) =  0.9308999999999999D-11
      rk(  5) =  DEXP(-0.2948956161884696D+02
     &     - ( -0.6870000000000000D+03 )/temp)
      rk(  6) =  DEXP(-0.2915016139038187D+02
     &     - ( -0.6020000000000000D+03 )/temp)
      rk(  7) =  DEXP(-0.2975797364027943D+02
     &     - (  0.2450000000000000D+04 )/temp)
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(  8)=-0.1995548580126773D-09
         rk(  8)=-0.3531778824092135D-07+(azi- 0.00D+00) * rk(  8)
         rk(  8)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  8)
         rk(  8)= 0.5205500000000000D-03+(azi- 0.00D+00) * rk(  8)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(  8)=-0.2576317222581757D-09
         rk(  8)=-0.4429775685149183D-07+(azi- 0.15D+02) * rk(  8)
         rk(  8)=-0.1194233176386197D-05+(azi- 0.15D+02) * rk(  8)
         rk(  8)= 0.5119300000000000D-03+(azi- 0.15D+02) * rk(  8)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(  8)=-0.7551034381398434D-09
         rk(  8)=-0.5589118435310978D-07+(azi- 0.30D+02) * rk(  8)
         rk(  8)=-0.2697067294455221D-05+(azi- 0.30D+02) * rk(  8)
         rk(  8)= 0.4831800000000000D-03+(azi- 0.30D+02) * rk(  8)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(  8)=-0.1113065636293564D-08
         rk(  8)=-0.8987083906940262D-07+(azi- 0.45D+02) * rk(  8)
         rk(  8)=-0.4883497645792907D-05+(azi- 0.45D+02) * rk(  8)
         rk(  8)= 0.4276000000000000D-03+(azi- 0.45D+02) * rk(  8)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(  8)=-0.5344699506007117D-08
         rk(  8)=-0.1399587927026135D-06+(azi- 0.60D+02) * rk(  8)
         rk(  8)=-0.8330942122373152D-05+(azi- 0.60D+02) * rk(  8)
         rk(  8)= 0.3303700000000000D-03+(azi- 0.60D+02) * rk(  8)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(  8)= 0.2508106870566623D-07
         rk(  8)=-0.3002997778828253D-06+(azi- 0.70D+02) * rk(  8)
         rk(  8)=-0.1273352782822756D-04+(azi- 0.70D+02) * rk(  8)
         rk(  8)= 0.2277200000000000D-03+(azi- 0.70D+02) * rk(  8)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(  8)= 0.3034567624796274D-08
         rk(  8)= 0.7591625270216763D-07+(azi- 0.75D+02) * rk(  8)
         rk(  8)=-0.1385544545413076D-04+(azi- 0.75D+02) * rk(  8)
         rk(  8)= 0.1596800000000000D-03+(azi- 0.75D+02) * rk(  8)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(  8)= 0.4196882081785659D-07
         rk(  8)= 0.1214347670740652D-06+(azi- 0.80D+02) * rk(  8)
         rk(  8)=-0.1286869035524960D-04+(azi- 0.80D+02) * rk(  8)
         rk(  8)= 0.9268000000000000D-04+(azi- 0.80D+02) * rk(  8)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(  8)=-0.2367265413981247D-06
         rk(  8)= 0.4991541544349742D-06+(azi- 0.83D+02) * rk(  8)
         rk(  8)=-0.1100692359072260D-04+(azi- 0.83D+02) * rk(  8)
         rk(  8)= 0.5630000000000000D-04+(azi- 0.83D+02) * rk(  8)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(  8)= 0.1744096179538791D-05
         rk(  8)=-0.1631384718148128D-05+(azi- 0.86D+02) * rk(  8)
         rk(  8)=-0.1440361528186166D-04+(azi- 0.86D+02) * rk(  8)
         rk(  8)= 0.2138000000000000D-04+(azi- 0.86D+02) * rk(  8)
      elseif(azi.ge.90.D0)then
         rk(  8)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk(  8) = rk(  8) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(  9)= 0.8438452539811389D-10
         rk(  9)=-0.1648354565874949D-07+(azi- 0.00D+00) * rk(  9)
         rk(  9)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  9)
         rk(  9)= 0.4527800000000000D-04+(azi- 0.00D+00) * rk(  9)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(  9)= 0.8669827565750889D-10
         rk(  9)=-0.1268624201583436D-07+(azi- 0.15D+02) * rk(  9)
         rk(  9)=-0.4375468151187577D-06+(azi- 0.15D+02) * rk(  9)
         rk(  9)= 0.4185400000000000D-04+(azi- 0.15D+02) * rk(  9)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(  9)= 0.1987482978977842D-09
         rk(  9)=-0.8784819611246491D-08+(azi- 0.30D+02) * rk(  9)
         rk(  9)=-0.7596127395249705D-06+(azi- 0.30D+02) * rk(  9)
         rk(  9)= 0.3272900000000000D-04+(azi- 0.30D+02) * rk(  9)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(  9)= 0.2869603846031909D-09
         rk(  9)= 0.1588537941538388D-09+(azi- 0.45D+02) * rk(  9)
         rk(  9)=-0.8890022267813598D-06+(azi- 0.45D+02) * rk(  9)
         rk(  9)= 0.2002900000000000D-04+(azi- 0.45D+02) * rk(  9)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(  9)= 0.2201764233663305D-09
         rk(  9)= 0.1307207110129700D-07+(azi- 0.60D+02) * rk(  9)
         rk(  9)=-0.6905383533495969D-06+(azi- 0.60D+02) * rk(  9)
         rk(  9)= 0.7698200000000000D-05+(azi- 0.60D+02) * rk(  9)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(  9)=-0.3526725879067774D-09
         rk(  9)= 0.1967736380228654D-07+(azi- 0.70D+02) * rk(  9)
         rk(  9)=-0.3630440043137691D-06+(azi- 0.70D+02) * rk(  9)
         rk(  9)= 0.2320200000000000D-05+(azi- 0.70D+02) * rk(  9)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(  9)=-0.3811825813819434D-09
         rk(  9)= 0.1438727498368539D-07+(azi- 0.75D+02) * rk(  9)
         rk(  9)=-0.1927208103838886D-06+(azi- 0.75D+02) * rk(  9)
         rk(  9)= 0.9528300000000000D-06+(azi- 0.75D+02) * rk(  9)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(  9)=-0.3331690338707346D-09
         rk(  9)= 0.8669536262979241D-08+(azi- 0.80D+02) * rk(  9)
         rk(  9)=-0.7743675415063180D-07+(azi- 0.80D+02) * rk(  9)
         rk(  9)= 0.3012600000000000D-06+(azi- 0.80D+02) * rk(  9)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(  9)=-0.1234845672681212D-08
         rk(  9)= 0.5671014958131902D-08+(azi- 0.83D+02) * rk(  9)
         rk(  9)=-0.3441510048732831D-07+(azi- 0.83D+02) * rk(  9)
         rk(  9)= 0.1379800000000000D-06+(azi- 0.83D+02) * rk(  9)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(  9)= 0.4625019023572655D-08
         rk(  9)=-0.5442596096318573D-08+(azi- 0.86D+02) * rk(  9)
         rk(  9)=-0.3372984390179123D-07+(azi- 0.86D+02) * rk(  9)
         rk(  9)= 0.5243300000000000D-07+(azi- 0.86D+02) * rk(  9)
      elseif(azi.ge.90.D0)then
         rk(  9)= 0.2030800000000000D-09
      endif
      if(att.lt.0.99999) rk(  9) = rk(  9) * att
C     
      rk( 10) =  DEXP( 0.7555381944240273D+01
     &     - ( -0.3900000000000000D+03 )/temp)
      rk( 11) =  0.2207000000000000D-14
      rk( 12) =  DEXP(-0.2716791622837397D+02
     &     - (  0.9400000000000000D+03 )/temp)
      rk( 13) =  DEXP(-0.3188412697053559D+02
     &     - (  0.5800000000000000D+03 )/temp)
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk( 14)=-0.1291447958880908D-06
         rk( 14)=-0.2255171695056759D-04+(azi- 0.00D+00) * rk( 14)
         rk( 14)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 14)
         rk( 14)= 0.3329500000000000D+00+(azi- 0.00D+00) * rk( 14)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk( 14)=-0.1636767234468293D-06
         rk( 14)=-0.2836323276553169D-04+(azi- 0.15D+02) * rk( 14)
         rk( 14)=-0.7637242457414892D-03+(azi- 0.15D+02) * rk( 14)
         rk( 14)= 0.3274400000000000D+00+(azi- 0.15D+02) * rk( 14)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk( 14)=-0.4842964584727183D-06
         rk( 14)=-0.3572868532063904D-04+(azi- 0.30D+02) * rk( 14)
         rk( 14)=-0.1725103017034050D-02+(azi- 0.30D+02) * rk( 14)
         rk( 14)= 0.3090500000000000D+00+(azi- 0.30D+02) * rk( 14)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk( 14)=-0.7080263315512322D-06
         rk( 14)=-0.5752202595191126D-04+(azi- 0.45D+02) * rk( 14)
         rk( 14)=-0.3123863686122305D-02+(azi- 0.45D+02) * rk( 14)
         rk( 14)= 0.2735000000000000D+00+(azi- 0.45D+02) * rk( 14)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 14)=-0.3437256528060973D-05
         rk( 14)=-0.8938321087171682D-04+(azi- 0.60D+02) * rk( 14)
         rk( 14)=-0.5327442238476729D-02+(azi- 0.60D+02) * rk( 14)
         rk( 14)= 0.2113100000000000D+00+(azi- 0.60D+02) * rk( 14)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk( 14)= 0.1611151791588542D-04
         rk( 14)=-0.1925009067135483D-03+(azi- 0.70D+02) * rk( 14)
         rk( 14)=-0.8146283414329386D-02+(azi- 0.70D+02) * rk( 14)
         rk( 14)= 0.1456600000000000D+00+(azi- 0.70D+02) * rk( 14)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk( 14)= 0.1882773105989380D-05
         rk( 14)= 0.4917186202473245D-04+(azi- 0.75D+02) * rk( 14)
         rk( 14)=-0.8862928637773425D-02+(azi- 0.75D+02) * rk( 14)
         rk( 14)= 0.1021300000000000D+00+(azi- 0.75D+02) * rk( 14)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk( 14)= 0.2678833245186107D-04
         rk( 14)= 0.7741345861455247D-04+(azi- 0.80D+02) * rk( 14)
         rk( 14)=-0.8230002034576918D-02+(azi- 0.80D+02) * rk( 14)
         rk( 14)= 0.5928000000000000D-01+(azi- 0.80D+02) * rk( 14)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk( 14)=-0.1511061902246040D-03
         rk( 14)= 0.3185084506813432D-03+(azi- 0.83D+02) * rk( 14)
         rk( 14)=-0.7042236306689272D-02+(azi- 0.83D+02) * rk( 14)
         rk( 14)= 0.3601000000000000D-01+(azi- 0.83D+02) * rk( 14)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk( 14)= 0.1114736815335251D-02
         rk( 14)=-0.1041447261339456D-02+(azi- 0.86D+02) * rk( 14)
         rk( 14)=-0.9211052738663995D-02+(azi- 0.86D+02) * rk( 14)
         rk( 14)= 0.1367000000000000D-01+(azi- 0.86D+02) * rk( 14)
      elseif(azi.ge.90.D0)then
         rk( 14)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 14) = rk( 14) * att
C     
      rk( 15) =  DEXP(-0.2507224461757409D+02
     &     - ( -0.2500000000000000D+03 )/temp)
      rk( 16) =  DEXP(-0.3132873951870969D+02
     &     - (  0.1230000000000000D+04 )/temp)
      rk( 17) =  DEXP(-0.2826326136158497D+02
     &     - ( -0.2560000000000000D+03 )/temp)
      rk( 18) =  0.1286000000000000D-20
      rk( 19) =  DEXP( 0.3350398361895553D+02
     &     - (  0.1090000000000000D+05 )/temp)
      rk( 20) =  DEXP(-0.4548638805083085D+02
     &     - ( -0.5300000000000000D+03 )/temp)
      rk( 21) =  0.4400000000000000D-39
      rk( 22) =  DEXP(-0.2844340238441219D+02
     &     - ( -0.8060000000000000D+03 )/temp)
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk( 23)=-0.7633530294737342D-09
         rk( 23)=-0.1312163712245605D-06+(azi- 0.00D+00) * rk( 23)
         rk( 23)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 23)
         rk( 23)= 0.1939800000000000D-02+(azi- 0.00D+00) * rk( 23)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk( 23)=-0.9395705412084575D-09
         rk( 23)=-0.1655672575508785D-06+(azi- 0.15D+02) * rk( 23)
         rk( 23)=-0.4451754431631586D-05+(azi- 0.15D+02) * rk( 23)
         rk( 23)= 0.1907700000000000D-02+(azi- 0.15D+02) * rk( 23)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk( 23)=-0.2826512953840508D-08
         rk( 23)=-0.2078479319052595D-06+(azi- 0.30D+02) * rk( 23)
         rk( 23)=-0.1005298227347366D-04+(azi- 0.30D+02) * rk( 23)
         rk( 23)= 0.1800500000000000D-02+(azi- 0.30D+02) * rk( 23)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk( 23)=-0.4139562828614817D-08
         rk( 23)=-0.3350410148280820D-06+(azi- 0.45D+02) * rk( 23)
         rk( 23)=-0.1819631647447377D-04+(azi- 0.45D+02) * rk( 23)
         rk( 23)= 0.1593400000000000D-02+(azi- 0.45D+02) * rk( 23)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 23)=-0.1995034750211215D-07
         rk( 23)=-0.5213213421157494D-06+(azi- 0.60D+02) * rk( 23)
         rk( 23)=-0.3104175182863126D-04+(azi- 0.60D+02) * rk( 23)
         rk( 23)= 0.1231100000000000D-02+(azi- 0.60D+02) * rk( 23)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk( 23)= 0.9353767029902275D-07
         rk( 23)=-0.1119831767179117D-05+(azi- 0.70D+02) * rk( 23)
         rk( 23)=-0.4745328292157999D-04+(azi- 0.70D+02) * rk( 23)
         rk( 23)= 0.8486000000000000D-03+(azi- 0.70D+02) * rk( 23)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk( 23)= 0.1136435537652095D-07
         rk( 23)= 0.2832332873062286D-06+(azi- 0.75D+02) * rk( 23)
         rk( 23)=-0.5163627532094411D-04+(azi- 0.75D+02) * rk( 23)
         rk( 23)= 0.5950300000000000D-03+(azi- 0.75D+02) * rk( 23)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk( 23)= 0.1559836971239240D-06
         rk( 23)= 0.4536986179539832D-06+(azi- 0.80D+02) * rk( 23)
         rk( 23)=-0.4795161579464298D-04+(azi- 0.80D+02) * rk( 23)
         rk( 23)= 0.3453500000000000D-03+(azi- 0.80D+02) * rk( 23)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk( 23)=-0.8813471938858471D-06
         rk( 23)= 0.1857551892070080D-05+(azi- 0.83D+02) * rk( 23)
         rk( 23)=-0.4101786426457212D-04+(azi- 0.83D+02) * rk( 23)
         rk( 23)= 0.2097900000000000D-03+(azi- 0.83D+02) * rk( 23)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk( 23)= 0.6497268213217274D-05
         rk( 23)=-0.6074572852900332D-05+(azi- 0.86D+02) * rk( 23)
         rk( 23)=-0.5366892714706730D-04+(azi- 0.86D+02) * rk( 23)
         rk( 23)= 0.7965800000000000D-04+(azi- 0.86D+02) * rk( 23)
      elseif(azi.ge.90.D0)then
         rk( 23)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 23) = rk( 23) * att
C     
      rk( 24) =  0.6614000000000000D-11
      rk( 25) =  0.1016000000000000D-19
      rk( 26) =  DEXP(-0.2759083932629571D+02
     &     - ( -0.7130000000000000D+03 )/temp)
      rk( 27) =  DEXP(-0.3290055668105114D+02
     &     - ( -0.1000000000000000D+04 )/temp)
      rk( 28) =  DEXP(-0.2631918094073361D+02
     &     - ( -0.2400000000000000D+03 )/temp)
      rk( 29) =  DEXP(-0.2982924619359835D+02
     &     - ( -0.7490000000000000D+03 )/temp)
      rk( 30) =  DEXP( 0.3149762825782621D+02
     &     - (  0.1012000000000000D+05 )/temp)
      rk( 31) =  DEXP(-0.2740787756461434D+02
     &     - ( -0.3800000000000000D+03 )/temp)
      rk( 32) =  DEXP(-0.3045853075706809D+02
     &     - ( -0.1150000000000000D+04 )/temp)
      rk( 33) =  DEXP(-0.8674917872127550D+02
     &     - ( -0.5800000000000000D+04 )/temp)
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk( 34)=-0.1152006903094048D-10
         rk( 34)=-0.9605322978692267D-09+(azi- 0.00D+00) * rk( 34)
         rk( 34)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 34)
         rk( 34)= 0.1067400000000000D-04+(azi- 0.00D+00) * rk( 34)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk( 34)= 0.2471318203932928D-11
         rk( 34)=-0.1478935404261548D-08+(azi- 0.15D+02) * rk( 34)
         rk( 34)=-0.3659201553196161D-07+(azi- 0.15D+02) * rk( 34)
         rk( 34)= 0.1041900000000000D-04+(azi- 0.15D+02) * rk( 34)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk( 34)=-0.2135779637738438D-10
         rk( 34)=-0.1367726085084567D-08+(azi- 0.30D+02) * rk( 34)
         rk( 34)=-0.7929193787215334D-07+(azi- 0.30D+02) * rk( 34)
         rk( 34)= 0.9545700000000001D-05+(azi- 0.30D+02) * rk( 34)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk( 34)= 0.6870978416715187D-11
         rk( 34)=-0.2328826922066862D-08+(azi- 0.45D+02) * rk( 34)
         rk( 34)=-0.1347402329794247D-06+(azi- 0.45D+02) * rk( 34)
         rk( 34)= 0.7976500000000001D-05+(azi- 0.45D+02) * rk( 34)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 34)= 0.3434591432948028D-11
         rk( 34)=-0.2019632893314692D-08+(azi- 0.60D+02) * rk( 34)
         rk( 34)=-0.1999671302101481D-06+(azi- 0.60D+02) * rk( 34)
         rk( 34)= 0.5454600000000000D-05+(azi- 0.60D+02) * rk( 34)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk( 34)= 0.5220954559275473D-09
         rk( 34)=-0.1916595150326259D-08+(azi- 0.70D+02) * rk( 34)
         rk( 34)=-0.2393294106465577D-06+(azi- 0.70D+02) * rk( 34)
         rk( 34)= 0.3256400000000000D-05+(azi- 0.70D+02) * rk( 34)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk( 34)= 0.6736078049279334D-10
         rk( 34)= 0.5914836688586528D-08+(azi- 0.75D+02) * rk( 34)
         rk( 34)=-0.2193382029552540D-06+(azi- 0.75D+02) * rk( 34)
         rk( 34)= 0.2077100000000000D-05+(azi- 0.75D+02) * rk( 34)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk( 34)= 0.1717072975367827D-09
         rk( 34)= 0.6925248395977991D-08+(azi- 0.80D+02) * rk( 34)
         rk( 34)=-0.1551377775324263D-06+(azi- 0.80D+02) * rk( 34)
         rk( 34)= 0.1136700000000000D-05+(azi- 0.80D+02) * rk( 34)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk( 34)=-0.3237961344268929D-08
         rk( 34)= 0.8470614073814170D-08+(azi- 0.83D+02) * rk( 34)
         rk( 34)=-0.1089501901230617D-06+(azi- 0.83D+02) * rk( 34)
         rk( 34)= 0.7382500000000000D-06+(azi- 0.83D+02) * rk( 34)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk( 34)= 0.1901963450615440D-07
         rk( 34)=-0.2067103802460270D-07+(azi- 0.86D+02) * rk( 34)
         rk( 34)=-0.1455514619754614D-06+(azi- 0.86D+02) * rk( 34)
         rk( 34)= 0.4002100000000000D-06+(azi- 0.86D+02) * rk( 34)
      elseif(azi.ge.90.D0)then
         rk( 34)= 0.1785800000000000D-06
      endif
      if(att.lt.0.99999) rk( 34) = rk( 34) * att
C     
      rk( 35) =  DEXP(-0.2646943402809905D+02
     &     - (  0.1870000000000000D+03 )/temp)
      rk( 36) =  0.2180000000000000D-12
      rk( 37) =  0.1016000000000000D-10
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk( 38)= 0.4211224881086122D-10
         rk( 38)=-0.6845017065496263D-08+(azi- 0.00D+00) * rk( 38)
         rk( 38)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 38)
         rk( 38)= 0.3634000000000000D-04+(azi- 0.00D+00) * rk( 38)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk( 38)=-0.5255896865480285D-10
         rk( 38)=-0.4949965869007507D-08+(azi- 0.15D+02) * rk( 38)
         rk( 38)=-0.1769247440175566D-06+(azi- 0.15D+02) * rk( 38)
         rk( 38)= 0.3494200000000000D-04+(azi- 0.15D+02) * rk( 38)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk( 38)= 0.3479029247501562D-10
         rk( 38)=-0.7315119458473644D-08+(azi- 0.30D+02) * rk( 38)
         rk( 38)=-0.3609010239297738D-06+(azi- 0.30D+02) * rk( 38)
         rk( 38)= 0.3099700000000000D-04+(azi- 0.30D+02) * rk( 38)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk( 38)= 0.4169409505103043D-10
         rk( 38)=-0.5749556297097909D-08+(azi- 0.45D+02) * rk( 38)
         rk( 38)=-0.5568711602633472D-06+(azi- 0.45D+02) * rk( 38)
         rk( 38)= 0.2405500000000000D-04+(azi- 0.45D+02) * rk( 38)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 38)= 0.3180755521485836D-09
         rk( 38)=-0.3873322019801656D-08+(azi- 0.60D+02) * rk( 38)
         rk( 38)=-0.7012143350168409D-06+(azi- 0.60D+02) * rk( 38)
         rk( 38)= 0.1454900000000000D-04+(azi- 0.60D+02) * rk( 38)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk( 38)= 0.1062135481800989D-08
         rk( 38)= 0.5668944544655450D-08+(azi- 0.70D+02) * rk( 38)
         rk( 38)=-0.6832581097683045D-06+(azi- 0.70D+02) * rk( 38)
         rk( 38)= 0.7467600000000000D-05+(azi- 0.70D+02) * rk( 38)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk( 38)= 0.9744773132696720D-11
         rk( 38)= 0.2160097677167046D-07+(azi- 0.75D+02) * rk( 38)
         rk( 38)=-0.5469085031866732D-06+(azi- 0.75D+02) * rk( 38)
         rk( 38)= 0.4325800000000000D-05+(azi- 0.75D+02) * rk( 38)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk( 38)=-0.2563223282485365D-09
         rk( 38)= 0.2174714836866119D-07+(azi- 0.80D+02) * rk( 38)
         rk( 38)=-0.3301678774850391D-06+(azi- 0.80D+02) * rk( 38)
         rk( 38)= 0.2132500000000000D-05+(azi- 0.80D+02) * rk( 38)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk( 38)=-0.6372042826804218D-08
         rk( 38)= 0.1944024741447748D-07+(azi- 0.83D+02) * rk( 38)
         rk( 38)=-0.2066056901356627D-06+(azi- 0.83D+02) * rk( 38)
         rk( 38)= 0.1330800000000000D-05+(azi- 0.83D+02) * rk( 38)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk( 38)= 0.3447015950661836D-07
         rk( 38)=-0.3790813802684403D-07+(azi- 0.86D+02) * rk( 38)
         rk( 38)=-0.2620093619730833D-06+(azi- 0.86D+02) * rk( 38)
         rk( 38)= 0.7139000000000000D-06+(azi- 0.86D+02) * rk( 38)
      elseif(azi.ge.90.D0)then
         rk( 38)= 0.3140100000000000D-06
      endif
      if(att.lt.0.99999) rk( 38) = rk( 38) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk( 39)=-0.6254611976819975D-10
         rk( 39)=-0.5044030425699212D-08+(azi- 0.00D+00) * rk( 39)
         rk( 39)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 39)
         rk( 39)= 0.5647500000000000D-04+(azi- 0.00D+00) * rk( 39)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk( 39)= 0.1430502597126309D-10
         rk( 39)=-0.7858605815268199D-08+(azi- 0.15D+02) * rk( 39)
         rk( 39)=-0.1935395436145112D-06+(azi- 0.15D+02) * rk( 39)
         rk( 39)= 0.5512900000000000D-04+(azi- 0.15D+02) * rk( 39)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk( 39)=-0.1137850952279627D-09
         rk( 39)=-0.7214879646561365D-08+(azi- 0.30D+02) * rk( 39)
         rk( 39)=-0.4196418255419546D-06+(azi- 0.30D+02) * rk( 39)
         rk( 39)= 0.5050600000000000D-04+(azi- 0.30D+02) * rk( 39)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk( 39)= 0.3698350308873324D-10
         rk( 39)=-0.1233520893181966D-07+(azi- 0.45D+02) * rk( 39)
         rk( 39)=-0.7128931542176699D-06+(azi- 0.45D+02) * rk( 39)
         rk( 39)= 0.4220400000000000D-04+(azi- 0.45D+02) * rk( 39)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 39)= 0.1695070515635938D-10
         rk( 39)=-0.1067095129282681D-07+(azi- 0.60D+02) * rk( 39)
         rk( 39)=-0.1057985557587367D-05+(azi- 0.60D+02) * rk( 39)
         rk( 39)= 0.2886000000000000D-04+(azi- 0.60D+02) * rk( 39)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk( 39)= 0.2765260903506995D-08
         rk( 39)=-0.1016243013813631D-07+(azi- 0.70D+02) * rk( 39)
         rk( 39)=-0.1266319371896996D-05+(azi- 0.70D+02) * rk( 39)
         rk( 39)= 0.1723000000000000D-04+(azi- 0.70D+02) * rk( 39)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk( 39)= 0.3538675377194349D-09
         rk( 39)= 0.3131648341446849D-07+(azi- 0.75D+02) * rk( 39)
         rk( 39)=-0.1160549105515323D-05+(azi- 0.75D+02) * rk( 39)
         rk( 39)= 0.1099000000000000D-04+(azi- 0.75D+02) * rk( 39)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk( 39)= 0.9115611038110188D-09
         rk( 39)= 0.3662449648025348D-07+(azi- 0.80D+02) * rk( 39)
         rk( 39)=-0.8208442060417083D-06+(azi- 0.80D+02) * rk( 39)
         rk( 39)= 0.6014400000000000D-05+(azi- 0.80D+02) * rk( 39)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk( 39)=-0.1713339576515520D-07
         rk( 39)= 0.4482854641455506D-07+(azi- 0.83D+02) * rk( 39)
         rk( 39)=-0.5764850773572987D-06+(azi- 0.83D+02) * rk( 39)
         rk( 39)= 0.3906100000000000D-05+(azi- 0.83D+02) * rk( 39)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk( 39)= 0.1006336288679506D-06
         rk( 39)=-0.1093720154717420D-06+(azi- 0.86D+02) * rk( 39)
         rk( 39)=-0.7701154845287336D-06+(azi- 0.86D+02) * rk( 39)
         rk( 39)= 0.2117500000000000D-05+(azi- 0.86D+02) * rk( 39)
      elseif(azi.ge.90.D0)then
         rk( 39)= 0.9448500000000000D-06
      endif
      if(att.lt.0.99999) rk( 39) = rk( 39) * att
C     
      rk( 40) =  DEXP(-0.2425925254495721D+02
     &     - (  0.1550000000000000D+04 )/temp)
      rk( 41) =  0.6296000000000000D-15
      rk( 42) =  DEXP(-0.2516461793770511D+02
     &     - (  0.9860000000000000D+03 )/temp)
      rk( 43) =  DEXP(-0.2568211545789343D+02
     &     - ( -0.2500000000000000D+03 )/temp)
      rk( 44) =  0.2505000000000000D-14
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk( 45)= 0.2880958768951989D-11
         rk( 45)=-0.1434769937089834D-08+(azi- 0.00D+00) * rk( 45)
         rk( 45)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 45)
         rk( 45)= 0.5785000000000000D-05+(azi- 0.00D+00) * rk( 45)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk( 45)= 0.4394160730180771D-11
         rk( 45)=-0.1305126792486994D-08+(azi- 0.15D+02) * rk( 45)
         rk( 45)=-0.4109845094365241D-07+(azi- 0.15D+02) * rk( 45)
         rk( 45)= 0.5471900000000000D-05+(azi- 0.15D+02) * rk( 45)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk( 45)= 0.1014980571773252D-10
         rk( 45)=-0.1107389559628861D-08+(azi- 0.30D+02) * rk( 45)
         rk( 45)=-0.7728619622539023D-07+(azi- 0.30D+02) * rk( 45)
         rk( 45)= 0.4576600000000000D-05+(azi- 0.30D+02) * rk( 45)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk( 45)= 0.2988069047296315D-10
         rk( 45)=-0.6506483023308959D-09+(azi- 0.45D+02) * rk( 45)
         rk( 45)=-0.1036567641547866D-06+(azi- 0.45D+02) * rk( 45)
         rk( 45)= 0.3202400000000000D-05+(azi- 0.45D+02) * rk( 45)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 45)= 0.3753919465939232D-10
         rk( 45)= 0.6939827689524307D-09+(azi- 0.60D+02) * rk( 45)
         rk( 45)=-0.1030067471554634D-06+(azi- 0.60D+02) * rk( 45)
         rk( 45)= 0.1602000000000000D-05+(azi- 0.60D+02) * rk( 45)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk( 45)= 0.6826161339710072D-10
         rk( 45)= 0.1820158608734149D-08+(azi- 0.70D+02) * rk( 45)
         rk( 45)=-0.7786533337859790D-07+(azi- 0.70D+02) * rk( 45)
         rk( 45)= 0.6788700000000000D-06+(azi- 0.70D+02) * rk( 45)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk( 45)=-0.1817151047932434D-10
         rk( 45)= 0.2844082809690688D-08+(azi- 0.75D+02) * rk( 45)
         rk( 45)=-0.5454412628647281D-07+(azi- 0.75D+02) * rk( 45)
         rk( 45)= 0.3435800000000000D-06+(azi- 0.75D+02) * rk( 45)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk( 45)=-0.8874470170229272D-10
         rk( 45)= 0.2571510152501230D-08+(azi- 0.80D+02) * rk( 45)
         rk( 45)=-0.2746616147550937D-07+(azi- 0.80D+02) * rk( 45)
         rk( 45)= 0.1396900000000000D-06+(azi- 0.80D+02) * rk( 45)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk( 45)=-0.4733943709367084D-09
         rk( 45)= 0.1772807837186593D-08+(azi- 0.83D+02) * rk( 45)
         rk( 45)=-0.1443320750645190D-07+(azi- 0.83D+02) * rk( 45)
         rk( 45)= 0.7803900000000000D-07+(azi- 0.83D+02) * rk( 45)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk( 45)= 0.2210747875280200D-08
         rk( 45)=-0.2487741501231775D-08+(azi- 0.86D+02) * rk( 45)
         rk( 45)=-0.1657800849869277D-07+(azi- 0.86D+02) * rk( 45)
         rk( 45)= 0.3791300000000000D-07+(azi- 0.86D+02) * rk( 45)
      elseif(azi.ge.90.D0)then
         rk( 45)= 0.1249200000000000D-07
      endif
      if(att.lt.0.99999) rk( 45) = rk( 45) * att
C     
      rk( 46) =  DEXP(-0.2595205714084584D+02
     &     - ( -0.2500000000000000D+03 )/temp)
      rk( 47) =  DEXP(-0.4397363626438101D+02
     &     - ( -0.5500000000000000D+04 )/temp)
      rk( 48) =  DEXP( 0.3907780677839423D+02
     &     - (  0.1400000000000000D+05 )/temp)
      rk( 49) =  0.2505000000000000D-11
      rk( 50) =  0.6499000000000000D-11
      rk( 51) =  DEXP( 0.4688591794127164D+01
     &     - (  0.1710000000000000D+04 )/temp)
      rk( 52) =  0.8140000000000000D-12
      rk( 53) =  DEXP( 0.3457991833824186D+02
     &     - (  0.8000000000000000D+04 )/temp)
      rk( 54) =  0.1591000000000000D+04
      rk( 55) =  0.1489000000000000D-10
      rk( 56) =  DEXP(-0.2515532340522586D+02
     &     - (  0.3240000000000000D+03 )/temp)
      rk( 57) =  DEXP(-0.2597469961759560D+02
     &     - ( -0.5040000000000000D+03 )/temp)
      rk( 58) =  DEXP(-0.3188272148892685D+02
     &     - (  0.2105000000000000D+04 )/temp)
      rk( 59) =  0.7683999999999999D-14
      rk( 60) =  DEXP(-0.2528633484691587D+02
     &     - (  0.7920000000000000D+03 )/temp)
      rk( 61) =  DEXP(-0.2692200058621231D+02
     &     - ( -0.4110000000000000D+03 )/temp)
      rk( 62) =  DEXP(-0.3200666814363839D+02
     &     - (  0.2633000000000000D+04 )/temp)
      rk( 63) =  DEXP(-0.2688908377119917D+02
     &     - ( -0.3220000000000000D+03 )/temp)
      rk( 64) =  0.8124000000000001D-11
      rk( 65) =  0.4167000000000000D+01
      rk( 66) =  0.4130000000000000D-10
      rk( 67) =  0.2200000000000000D-10
      rk( 68) =  0.1354000000000000D-10
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk( 69)= 0.3556677063003862D-09
         rk( 69)=-0.5755723781672820D-07+(azi- 0.00D+00) * rk( 69)
         rk( 69)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 69)
         rk( 69)= 0.3052600000000000D-03+(azi- 0.00D+00) * rk( 69)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk( 69)=-0.4418179337159288D-09
         rk( 69)=-0.4155219103321082D-07+(azi- 0.15D+02) * rk( 69)
         rk( 69)=-0.1486641432749085D-05+(azi- 0.15D+02) * rk( 69)
         rk( 69)= 0.2935100000000000D-03+(azi- 0.15D+02) * rk( 69)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk( 69)= 0.2916040285633032D-09
         rk( 69)=-0.6143399805042762D-07+(azi- 0.30D+02) * rk( 69)
         rk( 69)=-0.3031434269003662D-05+(azi- 0.30D+02) * rk( 69)
         rk( 69)= 0.2603700000000000D-03+(azi- 0.30D+02) * rk( 69)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk( 69)= 0.3509573750182369D-09
         rk( 69)=-0.4831181676507863D-07+(azi- 0.45D+02) * rk( 69)
         rk( 69)=-0.4677621491236254D-05+(azi- 0.45D+02) * rk( 69)
         rk( 69)= 0.2020600000000000D-03+(azi- 0.45D+02) * rk( 69)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 69)= 0.2670671149439208D-08
         rk( 69)=-0.3251873488925926D-07+(azi- 0.60D+02) * rk( 69)
         rk( 69)=-0.5890079766051317D-05+(azi- 0.60D+02) * rk( 69)
         rk( 69)= 0.1222100000000000D-03+(azi- 0.60D+02) * rk( 69)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk( 69)= 0.8921844841405100D-08
         rk( 69)= 0.4760139959391535D-07+(azi- 0.70D+02) * rk( 69)
         rk( 69)=-0.5739253119004732D-05+(azi- 0.70D+02) * rk( 69)
         rk( 69)= 0.6272800000000000D-04+(azi- 0.70D+02) * rk( 69)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk( 69)= 0.8621595540130090D-10
         rk( 69)= 0.1814290722150036D-06+(azi- 0.75D+02) * rk( 69)
         rk( 69)=-0.4594100759960039D-05+(azi- 0.75D+02) * rk( 69)
         rk( 69)= 0.3633700000000000D-04+(azi- 0.75D+02) * rk( 69)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk( 69)=-0.2165528905513296D-08
         rk( 69)= 0.1827223115460376D-06+(azi- 0.80D+02) * rk( 69)
         rk( 69)=-0.2773343841154591D-05+(azi- 0.80D+02) * rk( 69)
         rk( 69)= 0.1791300000000000D-04+(azi- 0.80D+02) * rk( 69)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk( 69)=-0.5351315576280364D-07
         rk( 69)= 0.1632325513966310D-06+(azi- 0.83D+02) * rk( 69)
         rk( 69)=-0.1735479252325822D-05+(azi- 0.83D+02) * rk( 69)
         rk( 69)= 0.1117900000000000D-04+(azi- 0.83D+02) * rk( 69)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk( 69)= 0.2895402126177489D-06
         rk( 69)=-0.3183858504683926D-06+(azi- 0.86D+02) * rk( 69)
         rk( 69)=-0.2200939149542392D-05+(azi- 0.86D+02) * rk( 69)
         rk( 69)= 0.5996800000000000D-05+(azi- 0.86D+02) * rk( 69)
      elseif(azi.ge.90.D0)then
         rk( 69)= 0.2637700000000000D-05
      endif
      if(att.lt.0.99999) rk( 69) = rk( 69) * att
C     
      rk( 70) =  0.2979000000000000D-10
      rk( 71) =  DEXP(-0.3745071914273499D+02
     &     - (  0.5000000000000000D+03 )/temp)
      rk( 72) =  DEXP(-0.2482101619230334D+02
     &     - ( -0.1160000000000000D+03 )/temp)
      rk( 73) =  0.1760000000000000D-10
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk( 74)= 0.3782696454602676D-09
         rk( 74)=-0.6136293357079298D-07+(azi- 0.00D+00) * rk( 74)
         rk( 74)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 74)
         rk( 74)= 0.3256100000000000D-03+(azi- 0.00D+00) * rk( 74)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk( 74)=-0.4711052326770784D-09
         rk( 74)=-0.4434079952508091D-07+(azi- 0.15D+02) * rk( 74)
         rk( 74)=-0.1585555996438108D-05+(azi- 0.15D+02) * rk( 74)
         rk( 74)= 0.3130800000000000D-03+(azi- 0.15D+02) * rk( 74)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk( 74)= 0.3120772111739571D-09
         rk( 74)=-0.6554053499554954D-07+(azi- 0.30D+02) * rk( 74)
         rk( 74)=-0.3233776014247565D-05+(azi- 0.30D+02) * rk( 74)
         rk( 74)= 0.2777300000000000D-03+(azi- 0.30D+02) * rk( 74)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk( 74)= 0.3724260176108762D-09
         rk( 74)=-0.5149706049272132D-07+(azi- 0.45D+02) * rk( 74)
         rk( 74)=-0.4989339946571625D-05+(azi- 0.45D+02) * rk( 74)
         rk( 74)= 0.2155300000000000D-03+(azi- 0.45D+02) * rk( 74)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 74)= 0.2852430964682701D-08
         rk( 74)=-0.3473788970023322D-07+(azi- 0.60D+02) * rk( 74)
         rk( 74)=-0.6282864199465946D-05+(azi- 0.60D+02) * rk( 74)
         rk( 74)= 0.1303600000000000D-03+(azi- 0.60D+02) * rk( 74)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk( 74)= 0.9508700314583169D-08
         rk( 74)= 0.5083503924024775D-07+(azi- 0.70D+02) * rk( 74)
         rk( 74)=-0.6121892704065800D-05+(azi- 0.70D+02) * rk( 74)
         rk( 74)= 0.6690999999999999D-04+(azi- 0.70D+02) * rk( 74)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk( 74)= 0.9848273097648983D-10
         rk( 74)= 0.1934655439590191D-06+(azi- 0.75D+02) * rk( 74)
         rk( 74)=-0.4900389788069447D-05+(azi- 0.75D+02) * rk( 74)
         rk( 74)= 0.3876000000000000D-04+(azi- 0.75D+02) * rk( 74)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk( 74)=-0.2312616049730296D-08
         rk( 74)= 0.1949427849235776D-06+(azi- 0.80D+02) * rk( 74)
         rk( 74)=-0.2958348143656381D-05+(azi- 0.80D+02) * rk( 74)
         rk( 74)= 0.1910700000000000D-04+(azi- 0.80D+02) * rk( 74)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk( 74)=-0.5708396155257200D-07
         rk( 74)= 0.1741292404763334D-06+(azi- 0.83D+02) * rk( 74)
         rk( 74)=-0.1851132067456001D-05+(azi- 0.83D+02) * rk( 74)
         rk( 74)= 0.1192400000000000D-04+(azi- 0.83D+02) * rk( 74)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk( 74)= 0.3088441033740344D-06
         rk( 74)=-0.3396264134948571D-06+(azi- 0.86D+02) * rk( 74)
         rk( 74)=-0.2347623586510716D-05+(azi- 0.86D+02) * rk( 74)
         rk( 74)= 0.6396500000000000D-05+(azi- 0.86D+02) * rk( 74)
      elseif(azi.ge.90.D0)then
         rk( 74)= 0.2813500000000000D-05
      endif
      if(att.lt.0.99999) rk( 74) = rk( 74) * att
C     
      rk( 75) =  0.1828000000000000D-10
      rk( 76) =  0.9613000000000000D-10
      rk( 77) =  0.1219000000000000D-16
      rk( 78) =  0.3182000000000000D-12
      rk( 79) =  0.8124000000000001D-11
      rk( 80) =  0.6770000000000000D-12
      rk( 81) =  DEXP(-0.3169038470925540D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk( 82) =  0.1012000000000000D-11
      rk( 83) =  0.1383000000000000D-05
      rk( 84) =  0.1667000000000000D-01
      
      RETURN
      END
      
