      DOUBLE PRECISION function keq(T,hum)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This function computes the equilibrium constant for the reaction
C     (NH3)g+(HNO3)g = (NH4NO3)s
C     for EMEP mechanism.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     T: temperature ([K]).
C     HUM: relative humidity ([%]).
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     KEQ: equilibrium constant for the reaction
C     (NH3)g+(HNO3)g = (NH4NO3)s ([ppb^2]).
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar (CEREA) and Denis Wendum (EDF), June 2001.
C     
C------------------------------------------------------------------------

      implicit none

      DOUBLE PRECISION T,hum,qlim,qdel
      external qdel
C     
      keq=dexp(84.6D0-24200.D0/T-6.1D0*dlog(T/298.D0))
      qlim=qdel(T)
C     
      
      if( (100.D0.gt.qlim) .and. (hum.gt.qlim) )then
         if (hum.GE.100.D0) write (*,*) 'PB Relative humidity.'
         keq=keq*(1000.D0)**(dsqrt((100.D0-hum)/(100.D0-qlim))-1.D0)
      endif
C     
      end
C     
C     **********************************************************************
C     
      DOUBLE PRECISION function qdel(T)
      
C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This function computes the deliquescence relative humidity for
C     ammonium nitrate (NH4NO3)s.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     T: temperature ([K]).
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     QDEL: deliquescence relative humidity for
C     ammonium nitrate (NH4NO3)s.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar (CEREA) and Denis Wendum (EDF), June 2001.
C     
C------------------------------------------------------------------------
      implicit none
C     
      DOUBLE PRECISION T
C     
      qdel=dexp(724.D0/T+1.7D0)
      qdel=dmin1(qdel,100.D0)
C     
      end


