C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE CONVERS (Ni,DLCG,DLCsourc,DLCsourcf,
     s     DLCforc2d,DLCforc2Df)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine makes unit conversions for gas-phase concentrations 
C     volumic emissions and forced concentrations in chemical mechanism 
C     EMEP:
C     
C     NI=1: from \mu.g/m^3 to molecule/cm^3.
C     NI=2: from molecule/cm^3 to \mu.g/m^3.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     NI: flag for conversion.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     DL: 3D array of chemical concentrations (units depend on NI).
C     DLSOURC: 3D array of chemical volumic emissions at initial time.
C     DLSOURCF: 3D array of chemical volumic emissions at final time.
C     DLCFORC2D: array of 2D fields of forced concentrations at initial
C     # time.
C     DLCFORC2DF: array of 2D fields of forced concentrations at final
C     # time.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     CONST: constants.
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMUSE: flags and parameters for numerics. 
C     COMCHEM: global variables for chemistry. 
C     COMDATA: global variables for chemical data. 
C     COMPHYS: physical data for chemical species (molar mass). 

      INCLUDE 'CONST.INC'
      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMUSE.INC'
      INCLUDE 'COMDATA.INC'
      INCLUDE 'COMCHEM.INC'
      INCLUDE 'COMPHYS.INC'

      DOUBLE PRECISION DLCG(Nx,Ny,Nz,NESP)
      DOUBLE PRECISION DLCsourc(Nx,Ny,Nzs,Nsrc)
      DOUBLE PRECISION DLCsourcf(Nx,Ny,Nzs,Nsrc)
      DOUBLE PRECISION DLCforc2d(Nx,Ny,NESPF),DLCforc2df(Nx,Ny,NESPF)

      DOUBLE PRECISION DLalfa(Nesp)
      DOUBLE PRECISION DLalfaf(Nespf)
      INTEGER Jsp,Ji,Jj,Jk,Ni

C     Setup

      IF(LITER) THEN

         DO Jsp=1,Nesp
            Dalfa(Jsp)=1.66D-12*Wmol(Jsp)
         ENDDO

         DO Jsp=1,Nespf
            Dalfaf(Jsp)=1.66D-12*Wmol(Nesp+Jsp)
         ENDDO

      ENDIF

      IF(Ni.EQ.1)THEN

C     Conversion before Emep.

         DO Jsp=1,Nesp
            DLalfa(Jsp)=1.D0/Dalfa(Jsp)
         ENDDO

         DO Jsp=1,Nespf
            DLalfaf(Jsp)=1.D0/Dalfaf(Jsp)
         ENDDO
      ELSE

         DO Jsp=1,Nesp
            DLalfa(Jsp)=Dalfa(Jsp)
         ENDDO

         DO Jsp=1,Nespf
            DLalfaf(Jsp)=Dalfaf(Jsp)
         ENDDO

      ENDIF

C     Conversion after Emep.

      DO Jsp=1,Nesp
         DO Jk=1,Nz
            DO Jj=1,Ny
               DO Ji=1,Nx
                  DLCG(Ji,Jj,Jk,Jsp)=DLalfa(Jsp)*DLCG(Ji,Jj,Jk,Jsp)
               ENDDO
            ENDDO
         ENDDO
      ENDDO

      DO Jsp=1,Nespf
         DO Jj=1,Ny
            DO Ji=1,Nx
               DLCforc2d(Ji,Jj,Jsp)=DLalfaf(Jsp)*DLCforc2d(Ji,Jj,Jsp)
               DLCforc2df(Ji,Jj,Jsp)=DLalfaf(Jsp)*DLCforc2df(Ji,Jj,Jsp)
            ENDDO
         ENDDO
      ENDDO

      IF(LSOURC)THEN    

         DO Jsp=1,Nsrc
            DO Jk=1,Nzs
               DO Jj=1,Ny
                  DO Ji=1,Nx
                     DLCsourc(Ji,Jj,Jk,Jsp)=DLalfa(Nesps(Jsp))*
     s                    DLCsourc(Ji,Jj,Jk,Jsp)

                     DLCsourcf(Ji,Jj,Jk,Jsp)=DLalfa(Nesps(Jsp))*
     s                    DLCsourcf(Ji,Jj,Jk,Jsp)
                  ENDDO
               ENDDO
            ENDDO
         ENDDO

      ENDIF

      END
