C------------------------------------------------------------------------
C       
C       Copyright (C) 2001-2003 CEREA (ENPC)
C       
C       This file is part of Polair.
C       Polair is a 3D eulerian chemistry-transport-model.
C       
C       Polair is free software; you can redistribute it and/or modify
C       it under the terms of the GNU General Public License as published by
C       the Free Software Foundation; either version 2 of the License, or
C       (at your option) any later version.
C       
C       Polair is distributed in the hope that it will be useful,
C       but WITHOUT ANY WARRANTY; without even the implied warranty of
C       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C       GNU General Public License (file "LICENSE") for more details.
C       
C------------------------------------------------------------------------

	SUBROUTINE jacdchemdc (RK,O3,OH,ROH,DLdchemdc)

C------------------------------------------------------------------------
C       
C       -- DESCRIPTION 
C       
C       This routine computes the Jacobian Matrix for the
C       gas-phase mechanism EMEP.
C       
C------------------------------------------------------------------------
C       
C       -- INPUT VARIABLES
C       
C       O3, OH, ROH: forced chemical concentrations.
C       RK: kinetic rates.
C       
C       -- INPUT/OUTPUT VARIABLES
C       
C       -- OUTPUT VARIABLES
C       
C       DLCHEMDC: Jacobian matrix.
C       
C------------------------------------------------------------------------
C       
C       -- REMARKS
C       
C------------------------------------------------------------------------
C       
C       -- MODIFICATIONS
C       
C------------------------------------------------------------------------
C       
C       -- AUTHOR(S)
C       
C       Jaouad Boutahar, CEREA, November 2001.
C       
C------------------------------------------------------------------------

	IMPLICIT NONE

C       -- INCLUDE FILES
C       PARACHEM: parameters for sizes of 'chemical' arrays.
C       PARADOM: parameters for all forced fields.

	INCLUDE 'PARADOM.INC' 
	INCLUDE 'PARACHEM.INC' 

	DOUBLE PRECISION DLdchemdc(nespl,nespl),RK(Nr)
	DOUBLE PRECISION O3,OH,ROH

C       *
C       First row of Jacobian Matrix
C       *
	DLdchemdc(1,1)=-RK(1)*O3
	DLdchemdc(1,2)=RK(2)
	DLdchemdc(1,3)=0.D0
	DLdchemdc(1,4)=0.D0
	DLdchemdc(1,5)=0.D0
	DLdchemdc(1,6)=0.D0
	DLdchemdc(1,7)=0.D0

C       *
C       2nd row of Jacobian Matrix
C       *
	DLdchemdc(2,1)=RK(1)*O3
	DLdchemdc(2,2)=-RK(2)-RK(3)*OH-2.D0*RK(4)*O3-RK(5)*ROH
	DLdchemdc(2,3)=0.D0
	DLdchemdc(2,4)=RK(6)
	DLdchemdc(2,5)=0.D0
	DLdchemdc(2,6)=0.D0
	DLdchemdc(2,7)=0.D0
C       *
C       3rd row of Jacobian Matrix
C       *
        
	DLdchemdc(3,1)=0.D0
	DLdchemdc(3,2)=RK(3)*OH
	DLdchemdc(3,3)=-RK(7)
	DLdchemdc(3,4)=0.D0
	DLdchemdc(3,5)=RK(8)
	DLdchemdc(3,6)=0.D0
	DLdchemdc(3,7)=0.D0
        
C       *
C       4rd row of Jacobian Matrix
C       *
	DLdchemdc(4,1)=0.D0
	DLdchemdc(4,2)=RK(5)*ROH
	DLdchemdc(4,3)=0.D0
	DLdchemdc(4,4)=-RK(6)
	DLdchemdc(4,5)=0.D0
	DLdchemdc(4,6)=0.D0
	DLdchemdc(4,7)=0.D0
        
C       *
C       5rd row of Jacobian Matrix
C       *
	DLdchemdc(5,1)=0.D0
	DLdchemdc(5,2)=2.D0*RK(4)*O3
	DLdchemdc(5,3)=RK(7)
	DLdchemdc(5,4)=0.D0
	DLdchemdc(5,5)=-RK(8)
	DLdchemdc(5,6)=0.D0
	DLdchemdc(5,7)=0.D0
        
C       *
C       6rd row of Jacobian Matrix
C       *
	DLdchemdc(6,1)=0.D0
	DLdchemdc(6,2)=0.D0
	DLdchemdc(6,3)=0.D0
	DLdchemdc(6,4)=0.D0
	DLdchemdc(6,5)=0.D0
	DLdchemdc(6,6)=-RK(9)
	DLdchemdc(6,7)=0.D0
C       *
C       7rd row of Jacobian Matrix
C       *
        
	DLdchemdc(7,1)=0.D0
	DLdchemdc(7,2)=0.D0
	DLdchemdc(7,3)=0.D0
	DLdchemdc(7,4)=0.D0
	DLdchemdc(7,5)=0.D0
	DLdchemdc(7,6)=RK(9)
	DLdchemdc(7,7)=0.D0
        
	END
	

