C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE KINETIC (ts,DLmu,DLtemp,DLcc,RK)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes the kinetic rates for the gas-phase 
C     mechanism EMEP.
C     
C     NO  + O3             --k1--> NO2 + O2
C     NO2 + hv             --k2--> NO  + O
C     NO2 + OH             --k3--> HNO3
C     2NO2 + O3 + H2O      --k4--> 2NO3- + 2H+
C     NO2 + CH3COO2 (ROH)  --k5--> CH3COO2NO2 (PAN)
C     PAN                  --k6--> NO2 + ROH
C     HNO3                 --k7--> NO3-
C     NO3-                 --k8--> HNO3
C     SO2 + (OH,H2O2,O3)   --k9--> SO4,2-
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     TS: initial time (GMT, computed from January 1st, [s]).
C     DLMU: cosine of the zenithal angle.
C     DLTEMP: temperature ([K]).
C     DLCC: first-level diagnostic for rain.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     RK: kinetic rates.
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, November 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     CONST: constants.
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.

      INCLUDE 'CONST.INC'
      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'

      DOUBLE PRECISION DLtemp,DLcc,ts
      DOUBLE PRECISION DLmu
      DOUBLE PRECISION RK(Nr)
      
      RK(1)=2.1D-12*dexp(-1450.D0/DLtemp)

      IF (DLmu.GT.1.D-2)THEN
         RK(2)=0.01D0*(1-DLcc/2.D0)*dexp(-0.39D0/DLmu)
      ELSE
         RK(2)=0.D0
      ENDIF

      RK(3)=1.1D-11

      IF(DLmu .lt. 0.D0 )then
         RK(4)=1.2D-13*dexp(-2450.D0/DLtemp)
      ELSE
         RK(4)=0.D0
      ENDIF

      RK(5)=3.2D-12

      RK(6)=7.94D+14*dexp(-12530.D0/DLtemp)

      RK(7)=1.D-5

      RK(8)=0.5D-5

C     Time in days: TS/86400.
      RK(9)=3.D-6+
     s     2.D-6*dsin(2.D0*Pi*(ts/86400.D0-80.D0)/365.D0)

      END
