C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE SOLNLIN (ZCn,ZC,DLkec)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves the equilibrium for ammonium nitrate and
C     ammonium sulfate for EMEP mechanism.
C     Ammonium sulfate:
C     ----------------
C     
C     3NH3+2SO4=   -> 2 {(NH4)1.5SO4}
C     
C     criterion (DLepuis=3(SO4=)-2(NH3))
C     
C     IF criterion > O  THEN NH3 disappears completly.
C     IF criterion < O  THEN SO4 disappears completly.
C     
C     Ammonium nitrate:
C     ----------------
C     
C     NH3(gas)+HNO3(gas) <=> NH4NO3 (solid)
C     
C     criterion (DLceq={NH3+NH4NO3}*{HNO3+NH4NO3})
C     K= equilibrium constant
C     
C     IF criterion > K THEN  Eq. of NH3, HNO3 with ammonium nitrate. 
C     IF criterion < K THEN  evaporation of ammonium nitrate.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     DLKEC: equilibrium constant for ammonium nitrate ([ppb^2]).
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     ZCN: conc. of nonlinear species (NH3, HNO3, total Nitrate).
C     ZC:  concentration of linear species.
C     # Before entry, it is given after integration of gas-phase chem.
C     # On exit, it is computed after thermodynamical equilibria.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, November 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of 'chemical' arrays.

      INCLUDE 'PARACHEM.INC'
      
      DOUBLE PRECISION DLepuis,DLceq,DLkec,DLdelta
      DOUBLE PRECISION ZC(nespl)
      DOUBLE PRECISION ZCn(nesph)
      DOUBLE PRECISION DLihno3,DLinh3,DLinitram

C------------------------------------------------------------------------
C     1 - Solve equilibrium for ammonium sulfate

      DLepuis=3.D0*Zc(7)-2.D0*Zcn(1)

      IF(DLepuis.GT.0.D0 )THEN
         ZC(7)=DLepuis/3.D0
         ZCn(3)=ZCn(3)+2.D0/3.D0*ZCn(1)
         ZCn(1)=0.D0
      ELSE
         ZCn(1)=-DLepuis/2.D0
         ZCn(3)=ZCn(3)+ZC(7)
         ZC(7)=0.D0
      ENDIF

C------------------------------------------------------------------------
C     2 - Solve equilibrium for ammonium nitrate
      
      DLceq=(ZCn(1)+ZCn(2))*(ZC(3)+ZCn(2))

C     DLinitram: Concentration of Nitram
C     DLinh3: Concentration of NH3
C     DLihno3: Concentration of HNO3

      DLihno3=ZC(3)
      DLinh3=ZCn(1)
      DLinitram=ZCn(2)

      IF(DLceq.GT.(DLkec/(1.66D-12)**2))THEN

         DLdelta=dsqrt((DLinh3-DLihno3)**2+4.D0*DLkec/(1.66D-12)**2)

         ZC(3)=(DLihno3-DLinh3+DLdelta)/2.D0
C     
         ZCn(1)=(DLinh3-DLihno3+DLdelta)/2.D0
C     
         ZCn(2)=((DLinh3+DLihno3+2.D0*DLinitram)-DLdelta)/2.D0
C     
      ELSE

         ZC(3)=DLihno3+DLinitram
         ZCn(1)=DLinh3+DLinitram
         ZCn(2)=0.D0

      ENDIF

      END











