C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE LU_solve (M, x)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves M * y = x where M is an LU factorization
C     computed by LU_decompose.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     M: LU factorization computed by LU_decompose.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     x: on entry, the right-hand side of the equation. On exit,
C     the solution of the equation.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of 'chemical' arrays.

      INCLUDE 'PARACHEM.INC'

      DOUBLE PRECISION M(Nesp,Nesp)
      DOUBLE PRECISION x(Nesp)
      DOUBLE PRECISION temp


C     Forward substitution.

      x(1) = x(1) / M(1, 1)

      temp = M(2, 1) * x(1)
      x(2) = ( x(2) - temp ) / M(2, 2)

      x(3) = x(3) / M(3, 3)

      x(4) = x(4) / M(4, 4)

      x(5) = x(5) / M(5, 5)

      x(6) = x(6) / M(6, 6)

      x(7) = x(7) / M(7, 7)

      x(8) = x(8) / M(8, 8)

      x(9) = x(9) / M(9, 9)

      x(10) = x(10) / M(10, 10)

      x(11) = x(11) / M(11, 11)

      x(12) = x(12) / M(12, 12)

      x(13) = x(13) / M(13, 13)

      x(14) = x(14) / M(14, 14)

      x(15) = x(15) / M(15, 15)

      temp = M(16, 12) * x(12)
      temp = temp + M(16, 13) * x(13)
      x(16) = ( x(16) - temp ) / M(16, 16)

      x(17) = x(17) / M(17, 17)

      x(18) = x(18) / M(18, 18)

      x(19) = x(19) / M(19, 19)

      x(20) = x(20) / M(20, 20)

      x(21) = x(21) / M(21, 21)

      x(22) = x(22) / M(22, 22)

      temp = M(23, 22) * x(22)
      x(23) = ( x(23) - temp ) / M(23, 23)

      x(24) = x(24) / M(24, 24)

      x(25) = x(25) / M(25, 25)

      x(26) = x(26) / M(26, 26)

      x(27) = x(27) / M(27, 27)

      x(28) = x(28) / M(28, 28)

      temp = M(29, 24) * x(24)
      temp = temp + M(29, 25) * x(25)
      x(29) = ( x(29) - temp ) / M(29, 29)

      x(30) = x(30) / M(30, 30)

      x(31) = x(31) / M(31, 31)

      temp = M(32, 3) * x(3)
      temp = temp + M(32, 22) * x(22)
      x(32) = ( x(32) - temp ) / M(32, 32)

      x(33) = x(33) / M(33, 33)

      temp = M(34, 19) * x(19)
      temp = temp + M(34, 20) * x(20)
      temp = temp + M(34, 21) * x(21)
      temp = temp + M(34, 22) * x(22)
      temp = temp + M(34, 25) * x(25)
      x(34) = ( x(34) - temp ) / M(34, 34)

      temp = M(35, 6) * x(6)
      x(35) = ( x(35) - temp ) / M(35, 35)

      temp = M(36, 7) * x(7)
      x(36) = ( x(36) - temp ) / M(36, 36)

      temp = M(37, 8) * x(8)
      x(37) = ( x(37) - temp ) / M(37, 37)

      temp = M(38, 9) * x(9)
      x(38) = ( x(38) - temp ) / M(38, 38)

      temp = M(39, 10) * x(10)
      x(39) = ( x(39) - temp ) / M(39, 39)

      temp = M(40, 11) * x(11)
      x(40) = ( x(40) - temp ) / M(40, 40)

      temp = M(41, 19) * x(19)
      x(41) = ( x(41) - temp ) / M(41, 41)

      temp = M(42, 20) * x(20)
      x(42) = ( x(42) - temp ) / M(42, 42)

      temp = M(43, 21) * x(21)
      x(43) = ( x(43) - temp ) / M(43, 43)

      temp = M(44, 22) * x(22)
      x(44) = ( x(44) - temp ) / M(44, 44)

      temp = M(45, 22) * x(22)
      temp = temp + M(45, 25) * x(25)
      temp = temp + M(45, 44) * x(44)
      x(45) = ( x(45) - temp ) / M(45, 45)

      temp = M(46, 45) * x(45)
      x(46) = ( x(46) - temp ) / M(46, 46)

      temp = M(47, 12) * x(12)
      x(47) = ( x(47) - temp ) / M(47, 47)

      temp = M(48, 13) * x(13)
      x(48) = ( x(48) - temp ) / M(48, 48)

      temp = M(49, 44) * x(44)
      x(49) = ( x(49) - temp ) / M(49, 49)

      temp = M(50, 22) * x(22)
      temp = temp + M(50, 23) * x(23)
      temp = temp + M(50, 44) * x(44)
      temp = temp + M(50, 49) * x(49)
      x(50) = ( x(50) - temp ) / M(50, 50)

      temp = M(51, 44) * x(44)
      temp = temp + M(51, 49) * x(49)
      temp = temp + M(51, 50) * x(50)
      x(51) = ( x(51) - temp ) / M(51, 51)

      temp = M(52, 44) * x(44)
      temp = temp + M(52, 47) * x(47)
      temp = temp + M(52, 48) * x(48)
      temp = temp + M(52, 49) * x(49)
      temp = temp + M(52, 51) * x(51)
      x(52) = ( x(52) - temp ) / M(52, 52)

      temp = M(53, 16) * x(16)
      x(53) = ( x(53) - temp ) / M(53, 53)

      x(54) = x(54) / M(54, 54)

      temp = M(55, 24) * x(24)
      x(55) = ( x(55) - temp ) / M(55, 55)

      temp = M(56, 25) * x(25)
      x(56) = ( x(56) - temp ) / M(56, 56)

      temp = M(57, 22) * x(22)
      temp = temp + M(57, 23) * x(23)
      temp = temp + M(57, 25) * x(25)
      temp = temp + M(57, 44) * x(44)
      temp = temp + M(57, 49) * x(49)
      temp = temp + M(57, 51) * x(51)
      temp = temp + M(57, 56) * x(56)
      x(57) = ( x(57) - temp ) / M(57, 57)

      temp = M(58, 19) * x(19)
      temp = temp + M(58, 20) * x(20)
      temp = temp + M(58, 21) * x(21)
      temp = temp + M(58, 22) * x(22)
      temp = temp + M(58, 24) * x(24)
      temp = temp + M(58, 25) * x(25)
      temp = temp + M(58, 32) * x(32)
      temp = temp + M(58, 45) * x(45)
      temp = temp + M(58, 49) * x(49)
      temp = temp + M(58, 50) * x(50)
      temp = temp + M(58, 51) * x(51)
      temp = temp + M(58, 57) * x(57)
      x(58) = ( x(58) - temp ) / M(58, 58)

      temp = M(59, 44) * x(44)
      temp = temp + M(59, 49) * x(49)
      temp = temp + M(59, 51) * x(51)
      temp = temp + M(59, 56) * x(56)
      temp = temp + M(59, 57) * x(57)
      temp = temp + M(59, 58) * x(58)
      x(59) = ( x(59) - temp ) / M(59, 59)

      temp = M(60, 19) * x(19)
      temp = temp + M(60, 20) * x(20)
      temp = temp + M(60, 21) * x(21)
      temp = temp + M(60, 24) * x(24)
      temp = temp + M(60, 25) * x(25)
      temp = temp + M(60, 45) * x(45)
      temp = temp + M(60, 49) * x(49)
      temp = temp + M(60, 51) * x(51)
      temp = temp + M(60, 57) * x(57)
      temp = temp + M(60, 58) * x(58)
      temp = temp + M(60, 59) * x(59)
      x(60) = ( x(60) - temp ) / M(60, 60)

      temp = M(61, 35) * x(35)
      temp = temp + M(61, 36) * x(36)
      temp = temp + M(61, 37) * x(37)
      temp = temp + M(61, 38) * x(38)
      temp = temp + M(61, 39) * x(39)
      temp = temp + M(61, 44) * x(44)
      temp = temp + M(61, 49) * x(49)
      temp = temp + M(61, 51) * x(51)
      temp = temp + M(61, 53) * x(53)
      temp = temp + M(61, 55) * x(55)
      temp = temp + M(61, 56) * x(56)
      temp = temp + M(61, 57) * x(57)
      temp = temp + M(61, 58) * x(58)
      temp = temp + M(61, 59) * x(59)
      temp = temp + M(61, 60) * x(60)
      x(61) = ( x(61) - temp ) / M(61, 61)

      temp = M(62, 20) * x(20)
      temp = temp + M(62, 21) * x(21)
      temp = temp + M(62, 24) * x(24)
      temp = temp + M(62, 35) * x(35)
      temp = temp + M(62, 36) * x(36)
      temp = temp + M(62, 37) * x(37)
      temp = temp + M(62, 38) * x(38)
      temp = temp + M(62, 39) * x(39)
      temp = temp + M(62, 54) * x(54)
      temp = temp + M(62, 55) * x(55)
      temp = temp + M(62, 58) * x(58)
      temp = temp + M(62, 59) * x(59)
      temp = temp + M(62, 61) * x(61)
      x(62) = ( x(62) - temp ) / M(62, 62)

      temp = M(63, 4) * x(4)
      temp = temp + M(63, 24) * x(24)
      temp = temp + M(63, 25) * x(25)
      temp = temp + M(63, 58) * x(58)
      temp = temp + M(63, 59) * x(59)
      temp = temp + M(63, 62) * x(62)
      x(63) = ( x(63) - temp ) / M(63, 63)

      temp = M(64, 24) * x(24)
      temp = temp + M(64, 25) * x(25)
      temp = temp + M(64, 58) * x(58)
      temp = temp + M(64, 59) * x(59)
      temp = temp + M(64, 62) * x(62)
      x(64) = ( x(64) - temp ) / M(64, 64)

      temp = M(65, 35) * x(35)
      temp = temp + M(65, 36) * x(36)
      temp = temp + M(65, 37) * x(37)
      temp = temp + M(65, 38) * x(38)
      temp = temp + M(65, 39) * x(39)
      temp = temp + M(65, 40) * x(40)
      temp = temp + M(65, 41) * x(41)
      temp = temp + M(65, 42) * x(42)
      temp = temp + M(65, 43) * x(43)
      temp = temp + M(65, 44) * x(44)
      temp = temp + M(65, 46) * x(46)
      temp = temp + M(65, 47) * x(47)
      temp = temp + M(65, 48) * x(48)
      temp = temp + M(65, 49) * x(49)
      temp = temp + M(65, 51) * x(51)
      temp = temp + M(65, 53) * x(53)
      temp = temp + M(65, 54) * x(54)
      temp = temp + M(65, 55) * x(55)
      temp = temp + M(65, 56) * x(56)
      temp = temp + M(65, 57) * x(57)
      temp = temp + M(65, 58) * x(58)
      temp = temp + M(65, 59) * x(59)
      temp = temp + M(65, 63) * x(63)
      temp = temp + M(65, 64) * x(64)
      x(65) = ( x(65) - temp ) / M(65, 65)

      temp = M(66, 5) * x(5)
      temp = temp + M(66, 61) * x(61)
      temp = temp + M(66, 65) * x(65)
      x(66) = ( x(66) - temp ) / M(66, 66)

      temp = M(67, 20) * x(20)
      temp = temp + M(67, 21) * x(21)
      temp = temp + M(67, 24) * x(24)
      temp = temp + M(67, 35) * x(35)
      temp = temp + M(67, 36) * x(36)
      temp = temp + M(67, 37) * x(37)
      temp = temp + M(67, 38) * x(38)
      temp = temp + M(67, 39) * x(39)
      temp = temp + M(67, 41) * x(41)
      temp = temp + M(67, 42) * x(42)
      temp = temp + M(67, 43) * x(43)
      temp = temp + M(67, 45) * x(45)
      temp = temp + M(67, 46) * x(46)
      temp = temp + M(67, 49) * x(49)
      temp = temp + M(67, 50) * x(50)
      temp = temp + M(67, 51) * x(51)
      temp = temp + M(67, 54) * x(54)
      temp = temp + M(67, 55) * x(55)
      temp = temp + M(67, 57) * x(57)
      temp = temp + M(67, 58) * x(58)
      temp = temp + M(67, 59) * x(59)
      temp = temp + M(67, 60) * x(60)
      temp = temp + M(67, 61) * x(61)
      temp = temp + M(67, 63) * x(63)
      temp = temp + M(67, 65) * x(65)
      temp = temp + M(67, 66) * x(66)
      x(67) = ( x(67) - temp ) / M(67, 67)

      temp = M(68, 20) * x(20)
      temp = temp + M(68, 21) * x(21)
      temp = temp + M(68, 22) * x(22)
      temp = temp + M(68, 25) * x(25)
      temp = temp + M(68, 30) * x(30)
      temp = temp + M(68, 35) * x(35)
      temp = temp + M(68, 36) * x(36)
      temp = temp + M(68, 37) * x(37)
      temp = temp + M(68, 38) * x(38)
      temp = temp + M(68, 39) * x(39)
      temp = temp + M(68, 40) * x(40)
      temp = temp + M(68, 41) * x(41)
      temp = temp + M(68, 42) * x(42)
      temp = temp + M(68, 43) * x(43)
      temp = temp + M(68, 44) * x(44)
      temp = temp + M(68, 45) * x(45)
      temp = temp + M(68, 46) * x(46)
      temp = temp + M(68, 49) * x(49)
      temp = temp + M(68, 50) * x(50)
      temp = temp + M(68, 51) * x(51)
      temp = temp + M(68, 54) * x(54)
      temp = temp + M(68, 57) * x(57)
      temp = temp + M(68, 58) * x(58)
      temp = temp + M(68, 59) * x(59)
      temp = temp + M(68, 60) * x(60)
      temp = temp + M(68, 63) * x(63)
      temp = temp + M(68, 64) * x(64)
      temp = temp + M(68, 66) * x(66)
      x(68) = ( x(68) - temp ) / M(68, 68)

      temp = M(69, 20) * x(20)
      temp = temp + M(69, 21) * x(21)
      temp = temp + M(69, 22) * x(22)
      temp = temp + M(69, 27) * x(27)
      temp = temp + M(69, 28) * x(28)
      temp = temp + M(69, 30) * x(30)
      temp = temp + M(69, 31) * x(31)
      temp = temp + M(69, 33) * x(33)
      temp = temp + M(69, 35) * x(35)
      temp = temp + M(69, 36) * x(36)
      temp = temp + M(69, 37) * x(37)
      temp = temp + M(69, 38) * x(38)
      temp = temp + M(69, 39) * x(39)
      temp = temp + M(69, 40) * x(40)
      temp = temp + M(69, 41) * x(41)
      temp = temp + M(69, 42) * x(42)
      temp = temp + M(69, 43) * x(43)
      temp = temp + M(69, 44) * x(44)
      temp = temp + M(69, 45) * x(45)
      temp = temp + M(69, 46) * x(46)
      temp = temp + M(69, 47) * x(47)
      temp = temp + M(69, 48) * x(48)
      temp = temp + M(69, 49) * x(49)
      temp = temp + M(69, 51) * x(51)
      temp = temp + M(69, 53) * x(53)
      temp = temp + M(69, 54) * x(54)
      temp = temp + M(69, 55) * x(55)
      temp = temp + M(69, 56) * x(56)
      temp = temp + M(69, 57) * x(57)
      temp = temp + M(69, 58) * x(58)
      temp = temp + M(69, 59) * x(59)
      temp = temp + M(69, 60) * x(60)
      temp = temp + M(69, 63) * x(63)
      temp = temp + M(69, 64) * x(64)
      temp = temp + M(69, 66) * x(66)
      temp = temp + M(69, 67) * x(67)
      x(69) = ( x(69) - temp ) / M(69, 69)

      temp = M(70, 44) * x(44)
      temp = temp + M(70, 47) * x(47)
      temp = temp + M(70, 48) * x(48)
      temp = temp + M(70, 49) * x(49)
      temp = temp + M(70, 50) * x(50)
      temp = temp + M(70, 51) * x(51)
      temp = temp + M(70, 57) * x(57)
      temp = temp + M(70, 58) * x(58)
      temp = temp + M(70, 59) * x(59)
      temp = temp + M(70, 64) * x(64)
      temp = temp + M(70, 66) * x(66)
      temp = temp + M(70, 69) * x(69)
      x(70) = ( x(70) - temp ) / M(70, 70)

      temp = M(71, 22) * x(22)
      temp = temp + M(71, 33) * x(33)
      temp = temp + M(71, 40) * x(40)
      temp = temp + M(71, 41) * x(41)
      temp = temp + M(71, 44) * x(44)
      temp = temp + M(71, 47) * x(47)
      temp = temp + M(71, 49) * x(49)
      temp = temp + M(71, 51) * x(51)
      temp = temp + M(71, 57) * x(57)
      temp = temp + M(71, 58) * x(58)
      temp = temp + M(71, 59) * x(59)
      temp = temp + M(71, 69) * x(69)
      x(71) = ( x(71) - temp ) / M(71, 71)

      temp = M(72, 16) * x(16)
      temp = temp + M(72, 52) * x(52)
      temp = temp + M(72, 57) * x(57)
      temp = temp + M(72, 58) * x(58)
      temp = temp + M(72, 59) * x(59)
      temp = temp + M(72, 67) * x(67)
      temp = temp + M(72, 69) * x(69)
      temp = temp + M(72, 70) * x(70)
      temp = temp + M(72, 71) * x(71)
      x(72) = ( x(72) - temp ) / M(72, 72)

      temp = M(73, 15) * x(15)
      temp = temp + M(73, 16) * x(16)
      temp = temp + M(73, 18) * x(18)
      temp = temp + M(73, 19) * x(19)
      temp = temp + M(73, 20) * x(20)
      temp = temp + M(73, 21) * x(21)
      temp = temp + M(73, 22) * x(22)
      temp = temp + M(73, 24) * x(24)
      temp = temp + M(73, 25) * x(25)
      temp = temp + M(73, 26) * x(26)
      temp = temp + M(73, 45) * x(45)
      temp = temp + M(73, 49) * x(49)
      temp = temp + M(73, 50) * x(50)
      temp = temp + M(73, 51) * x(51)
      temp = temp + M(73, 52) * x(52)
      temp = temp + M(73, 55) * x(55)
      temp = temp + M(73, 56) * x(56)
      temp = temp + M(73, 57) * x(57)
      temp = temp + M(73, 58) * x(58)
      temp = temp + M(73, 59) * x(59)
      temp = temp + M(73, 67) * x(67)
      temp = temp + M(73, 69) * x(69)
      temp = temp + M(73, 70) * x(70)
      temp = temp + M(73, 71) * x(71)
      temp = temp + M(73, 72) * x(72)
      x(73) = ( x(73) - temp ) / M(73, 73)

      temp = M(74, 19) * x(19)
      temp = temp + M(74, 20) * x(20)
      temp = temp + M(74, 21) * x(21)
      temp = temp + M(74, 22) * x(22)
      temp = temp + M(74, 23) * x(23)
      temp = temp + M(74, 25) * x(25)
      temp = temp + M(74, 26) * x(26)
      temp = temp + M(74, 27) * x(27)
      temp = temp + M(74, 30) * x(30)
      temp = temp + M(74, 33) * x(33)
      temp = temp + M(74, 35) * x(35)
      temp = temp + M(74, 36) * x(36)
      temp = temp + M(74, 37) * x(37)
      temp = temp + M(74, 38) * x(38)
      temp = temp + M(74, 39) * x(39)
      temp = temp + M(74, 40) * x(40)
      temp = temp + M(74, 41) * x(41)
      temp = temp + M(74, 42) * x(42)
      temp = temp + M(74, 43) * x(43)
      temp = temp + M(74, 44) * x(44)
      temp = temp + M(74, 45) * x(45)
      temp = temp + M(74, 46) * x(46)
      temp = temp + M(74, 47) * x(47)
      temp = temp + M(74, 48) * x(48)
      temp = temp + M(74, 49) * x(49)
      temp = temp + M(74, 50) * x(50)
      temp = temp + M(74, 51) * x(51)
      temp = temp + M(74, 53) * x(53)
      temp = temp + M(74, 54) * x(54)
      temp = temp + M(74, 55) * x(55)
      temp = temp + M(74, 56) * x(56)
      temp = temp + M(74, 57) * x(57)
      temp = temp + M(74, 58) * x(58)
      temp = temp + M(74, 59) * x(59)
      temp = temp + M(74, 60) * x(60)
      temp = temp + M(74, 63) * x(63)
      temp = temp + M(74, 64) * x(64)
      temp = temp + M(74, 66) * x(66)
      temp = temp + M(74, 69) * x(69)
      temp = temp + M(74, 71) * x(71)
      temp = temp + M(74, 73) * x(73)
      x(74) = ( x(74) - temp ) / M(74, 74)

      temp = M(75, 1) * x(1)
      temp = temp + M(75, 3) * x(3)
      temp = temp + M(75, 4) * x(4)
      temp = temp + M(75, 5) * x(5)
      temp = temp + M(75, 6) * x(6)
      temp = temp + M(75, 7) * x(7)
      temp = temp + M(75, 8) * x(8)
      temp = temp + M(75, 9) * x(9)
      temp = temp + M(75, 10) * x(10)
      temp = temp + M(75, 11) * x(11)
      temp = temp + M(75, 12) * x(12)
      temp = temp + M(75, 13) * x(13)
      temp = temp + M(75, 14) * x(14)
      temp = temp + M(75, 16) * x(16)
      temp = temp + M(75, 18) * x(18)
      temp = temp + M(75, 19) * x(19)
      temp = temp + M(75, 20) * x(20)
      temp = temp + M(75, 21) * x(21)
      temp = temp + M(75, 22) * x(22)
      temp = temp + M(75, 24) * x(24)
      temp = temp + M(75, 25) * x(25)
      temp = temp + M(75, 26) * x(26)
      temp = temp + M(75, 27) * x(27)
      temp = temp + M(75, 28) * x(28)
      temp = temp + M(75, 29) * x(29)
      temp = temp + M(75, 30) * x(30)
      temp = temp + M(75, 31) * x(31)
      temp = temp + M(75, 33) * x(33)
      temp = temp + M(75, 41) * x(41)
      temp = temp + M(75, 44) * x(44)
      temp = temp + M(75, 45) * x(45)
      temp = temp + M(75, 49) * x(49)
      temp = temp + M(75, 50) * x(50)
      temp = temp + M(75, 51) * x(51)
      temp = temp + M(75, 52) * x(52)
      temp = temp + M(75, 57) * x(57)
      temp = temp + M(75, 58) * x(58)
      temp = temp + M(75, 59) * x(59)
      temp = temp + M(75, 61) * x(61)
      temp = temp + M(75, 62) * x(62)
      temp = temp + M(75, 65) * x(65)
      temp = temp + M(75, 66) * x(66)
      temp = temp + M(75, 67) * x(67)
      temp = temp + M(75, 69) * x(69)
      temp = temp + M(75, 70) * x(70)
      temp = temp + M(75, 71) * x(71)
      temp = temp + M(75, 72) * x(72)
      temp = temp + M(75, 73) * x(73)
      temp = temp + M(75, 74) * x(74)
      x(75) = ( x(75) - temp ) / M(75, 75)

      temp = M(76, 19) * x(19)
      temp = temp + M(76, 20) * x(20)
      temp = temp + M(76, 21) * x(21)
      temp = temp + M(76, 22) * x(22)
      temp = temp + M(76, 24) * x(24)
      temp = temp + M(76, 25) * x(25)
      temp = temp + M(76, 33) * x(33)
      temp = temp + M(76, 41) * x(41)
      temp = temp + M(76, 44) * x(44)
      temp = temp + M(76, 45) * x(45)
      temp = temp + M(76, 49) * x(49)
      temp = temp + M(76, 51) * x(51)
      temp = temp + M(76, 57) * x(57)
      temp = temp + M(76, 58) * x(58)
      temp = temp + M(76, 59) * x(59)
      temp = temp + M(76, 67) * x(67)
      temp = temp + M(76, 69) * x(69)
      temp = temp + M(76, 70) * x(70)
      temp = temp + M(76, 71) * x(71)
      temp = temp + M(76, 73) * x(73)
      temp = temp + M(76, 74) * x(74)
      temp = temp + M(76, 75) * x(75)
      x(76) = ( x(76) - temp ) / M(76, 76)

      temp = M(77, 16) * x(16)
      temp = temp + M(77, 17) * x(17)
      temp = temp + M(77, 52) * x(52)
      temp = temp + M(77, 57) * x(57)
      temp = temp + M(77, 58) * x(58)
      temp = temp + M(77, 59) * x(59)
      temp = temp + M(77, 69) * x(69)
      temp = temp + M(77, 73) * x(73)
      temp = temp + M(77, 74) * x(74)
      temp = temp + M(77, 75) * x(75)
      temp = temp + M(77, 76) * x(76)
      x(77) = ( x(77) - temp ) / M(77, 77)

      temp = M(78, 6) * x(6)
      temp = temp + M(78, 7) * x(7)
      temp = temp + M(78, 8) * x(8)
      temp = temp + M(78, 9) * x(9)
      temp = temp + M(78, 10) * x(10)
      temp = temp + M(78, 16) * x(16)
      temp = temp + M(78, 26) * x(26)
      temp = temp + M(78, 69) * x(69)
      temp = temp + M(78, 73) * x(73)
      temp = temp + M(78, 74) * x(74)
      temp = temp + M(78, 75) * x(75)
      temp = temp + M(78, 76) * x(76)
      temp = temp + M(78, 77) * x(77)
      x(78) = ( x(78) - temp ) / M(78, 78)

      temp = M(79, 1) * x(1)
      temp = temp + M(79, 11) * x(11)
      temp = temp + M(79, 12) * x(12)
      temp = temp + M(79, 13) * x(13)
      temp = temp + M(79, 16) * x(16)
      temp = temp + M(79, 18) * x(18)
      temp = temp + M(79, 19) * x(19)
      temp = temp + M(79, 20) * x(20)
      temp = temp + M(79, 21) * x(21)
      temp = temp + M(79, 22) * x(22)
      temp = temp + M(79, 24) * x(24)
      temp = temp + M(79, 25) * x(25)
      temp = temp + M(79, 27) * x(27)
      temp = temp + M(79, 29) * x(29)
      temp = temp + M(79, 30) * x(30)
      temp = temp + M(79, 33) * x(33)
      temp = temp + M(79, 35) * x(35)
      temp = temp + M(79, 36) * x(36)
      temp = temp + M(79, 37) * x(37)
      temp = temp + M(79, 38) * x(38)
      temp = temp + M(79, 39) * x(39)
      temp = temp + M(79, 40) * x(40)
      temp = temp + M(79, 41) * x(41)
      temp = temp + M(79, 42) * x(42)
      temp = temp + M(79, 43) * x(43)
      temp = temp + M(79, 44) * x(44)
      temp = temp + M(79, 45) * x(45)
      temp = temp + M(79, 46) * x(46)
      temp = temp + M(79, 47) * x(47)
      temp = temp + M(79, 48) * x(48)
      temp = temp + M(79, 49) * x(49)
      temp = temp + M(79, 51) * x(51)
      temp = temp + M(79, 52) * x(52)
      temp = temp + M(79, 53) * x(53)
      temp = temp + M(79, 54) * x(54)
      temp = temp + M(79, 55) * x(55)
      temp = temp + M(79, 56) * x(56)
      temp = temp + M(79, 57) * x(57)
      temp = temp + M(79, 58) * x(58)
      temp = temp + M(79, 59) * x(59)
      temp = temp + M(79, 60) * x(60)
      temp = temp + M(79, 61) * x(61)
      temp = temp + M(79, 63) * x(63)
      temp = temp + M(79, 64) * x(64)
      temp = temp + M(79, 65) * x(65)
      temp = temp + M(79, 66) * x(66)
      temp = temp + M(79, 67) * x(67)
      temp = temp + M(79, 69) * x(69)
      temp = temp + M(79, 70) * x(70)
      temp = temp + M(79, 71) * x(71)
      temp = temp + M(79, 73) * x(73)
      temp = temp + M(79, 74) * x(74)
      temp = temp + M(79, 75) * x(75)
      temp = temp + M(79, 76) * x(76)
      temp = temp + M(79, 77) * x(77)
      temp = temp + M(79, 78) * x(78)
      x(79) = ( x(79) - temp ) / M(79, 79)

      temp = M(80, 14) * x(14)
      temp = temp + M(80, 23) * x(23)
      temp = temp + M(80, 32) * x(32)
      temp = temp + M(80, 35) * x(35)
      temp = temp + M(80, 36) * x(36)
      temp = temp + M(80, 37) * x(37)
      temp = temp + M(80, 38) * x(38)
      temp = temp + M(80, 39) * x(39)
      temp = temp + M(80, 40) * x(40)
      temp = temp + M(80, 41) * x(41)
      temp = temp + M(80, 42) * x(42)
      temp = temp + M(80, 43) * x(43)
      temp = temp + M(80, 44) * x(44)
      temp = temp + M(80, 46) * x(46)
      temp = temp + M(80, 47) * x(47)
      temp = temp + M(80, 48) * x(48)
      temp = temp + M(80, 49) * x(49)
      temp = temp + M(80, 50) * x(50)
      temp = temp + M(80, 51) * x(51)
      temp = temp + M(80, 54) * x(54)
      temp = temp + M(80, 55) * x(55)
      temp = temp + M(80, 56) * x(56)
      temp = temp + M(80, 57) * x(57)
      temp = temp + M(80, 58) * x(58)
      temp = temp + M(80, 59) * x(59)
      temp = temp + M(80, 60) * x(60)
      temp = temp + M(80, 63) * x(63)
      temp = temp + M(80, 64) * x(64)
      temp = temp + M(80, 66) * x(66)
      temp = temp + M(80, 69) * x(69)
      temp = temp + M(80, 73) * x(73)
      temp = temp + M(80, 74) * x(74)
      temp = temp + M(80, 75) * x(75)
      temp = temp + M(80, 76) * x(76)
      temp = temp + M(80, 77) * x(77)
      temp = temp + M(80, 78) * x(78)
      temp = temp + M(80, 79) * x(79)
      x(80) = ( x(80) - temp ) / M(80, 80)

      temp = M(81, 15) * x(15)
      temp = temp + M(81, 17) * x(17)
      temp = temp + M(81, 18) * x(18)
      temp = temp + M(81, 23) * x(23)
      temp = temp + M(81, 26) * x(26)
      temp = temp + M(81, 32) * x(32)
      temp = temp + M(81, 35) * x(35)
      temp = temp + M(81, 36) * x(36)
      temp = temp + M(81, 37) * x(37)
      temp = temp + M(81, 38) * x(38)
      temp = temp + M(81, 39) * x(39)
      temp = temp + M(81, 40) * x(40)
      temp = temp + M(81, 41) * x(41)
      temp = temp + M(81, 42) * x(42)
      temp = temp + M(81, 43) * x(43)
      temp = temp + M(81, 44) * x(44)
      temp = temp + M(81, 46) * x(46)
      temp = temp + M(81, 47) * x(47)
      temp = temp + M(81, 48) * x(48)
      temp = temp + M(81, 49) * x(49)
      temp = temp + M(81, 50) * x(50)
      temp = temp + M(81, 51) * x(51)
      temp = temp + M(81, 53) * x(53)
      temp = temp + M(81, 54) * x(54)
      temp = temp + M(81, 55) * x(55)
      temp = temp + M(81, 56) * x(56)
      temp = temp + M(81, 57) * x(57)
      temp = temp + M(81, 58) * x(58)
      temp = temp + M(81, 59) * x(59)
      temp = temp + M(81, 60) * x(60)
      temp = temp + M(81, 61) * x(61)
      temp = temp + M(81, 63) * x(63)
      temp = temp + M(81, 64) * x(64)
      temp = temp + M(81, 66) * x(66)
      temp = temp + M(81, 69) * x(69)
      temp = temp + M(81, 72) * x(72)
      temp = temp + M(81, 73) * x(73)
      temp = temp + M(81, 74) * x(74)
      temp = temp + M(81, 75) * x(75)
      temp = temp + M(81, 76) * x(76)
      temp = temp + M(81, 77) * x(77)
      temp = temp + M(81, 78) * x(78)
      temp = temp + M(81, 79) * x(79)
      temp = temp + M(81, 80) * x(80)
      x(81) = ( x(81) - temp ) / M(81, 81)

      temp = M(82, 26) * x(26)
      temp = temp + M(82, 28) * x(28)
      temp = temp + M(82, 30) * x(30)
      temp = temp + M(82, 35) * x(35)
      temp = temp + M(82, 36) * x(36)
      temp = temp + M(82, 37) * x(37)
      temp = temp + M(82, 38) * x(38)
      temp = temp + M(82, 39) * x(39)
      temp = temp + M(82, 40) * x(40)
      temp = temp + M(82, 41) * x(41)
      temp = temp + M(82, 42) * x(42)
      temp = temp + M(82, 43) * x(43)
      temp = temp + M(82, 44) * x(44)
      temp = temp + M(82, 46) * x(46)
      temp = temp + M(82, 47) * x(47)
      temp = temp + M(82, 48) * x(48)
      temp = temp + M(82, 49) * x(49)
      temp = temp + M(82, 51) * x(51)
      temp = temp + M(82, 53) * x(53)
      temp = temp + M(82, 54) * x(54)
      temp = temp + M(82, 55) * x(55)
      temp = temp + M(82, 56) * x(56)
      temp = temp + M(82, 57) * x(57)
      temp = temp + M(82, 58) * x(58)
      temp = temp + M(82, 59) * x(59)
      temp = temp + M(82, 60) * x(60)
      temp = temp + M(82, 62) * x(62)
      temp = temp + M(82, 63) * x(63)
      temp = temp + M(82, 64) * x(64)
      temp = temp + M(82, 66) * x(66)
      temp = temp + M(82, 67) * x(67)
      temp = temp + M(82, 69) * x(69)
      temp = temp + M(82, 70) * x(70)
      temp = temp + M(82, 73) * x(73)
      temp = temp + M(82, 74) * x(74)
      temp = temp + M(82, 75) * x(75)
      temp = temp + M(82, 76) * x(76)
      temp = temp + M(82, 77) * x(77)
      temp = temp + M(82, 78) * x(78)
      temp = temp + M(82, 79) * x(79)
      temp = temp + M(82, 80) * x(80)
      temp = temp + M(82, 81) * x(81)
      x(82) = ( x(82) - temp ) / M(82, 82)


C     Backward substitution.

      temp = M(81, 82) * x(82)
      x(81) = x(81) - temp

      temp = M(80, 81) * x(81)
      temp = temp + M(80, 82) * x(82)
      x(80) = x(80) - temp

      temp = M(79, 80) * x(80)
      temp = temp + M(79, 81) * x(81)
      temp = temp + M(79, 82) * x(82)
      x(79) = x(79) - temp

      temp = M(78, 79) * x(79)
      temp = temp + M(78, 80) * x(80)
      temp = temp + M(78, 81) * x(81)
      temp = temp + M(78, 82) * x(82)
      x(78) = x(78) - temp

      temp = M(77, 78) * x(78)
      temp = temp + M(77, 79) * x(79)
      temp = temp + M(77, 80) * x(80)
      temp = temp + M(77, 81) * x(81)
      temp = temp + M(77, 82) * x(82)
      x(77) = x(77) - temp

      temp = M(76, 77) * x(77)
      temp = temp + M(76, 78) * x(78)
      temp = temp + M(76, 79) * x(79)
      temp = temp + M(76, 80) * x(80)
      temp = temp + M(76, 81) * x(81)
      temp = temp + M(76, 82) * x(82)
      x(76) = x(76) - temp

      temp = M(75, 76) * x(76)
      temp = temp + M(75, 77) * x(77)
      temp = temp + M(75, 78) * x(78)
      temp = temp + M(75, 79) * x(79)
      temp = temp + M(75, 80) * x(80)
      temp = temp + M(75, 81) * x(81)
      temp = temp + M(75, 82) * x(82)
      x(75) = x(75) - temp

      temp = M(74, 75) * x(75)
      temp = temp + M(74, 77) * x(77)
      temp = temp + M(74, 78) * x(78)
      temp = temp + M(74, 79) * x(79)
      temp = temp + M(74, 80) * x(80)
      temp = temp + M(74, 81) * x(81)
      temp = temp + M(74, 82) * x(82)
      x(74) = x(74) - temp

      temp = M(73, 74) * x(74)
      temp = temp + M(73, 75) * x(75)
      temp = temp + M(73, 77) * x(77)
      temp = temp + M(73, 78) * x(78)
      temp = temp + M(73, 79) * x(79)
      temp = temp + M(73, 80) * x(80)
      temp = temp + M(73, 81) * x(81)
      temp = temp + M(73, 82) * x(82)
      x(73) = x(73) - temp

      temp = M(72, 73) * x(73)
      temp = temp + M(72, 74) * x(74)
      temp = temp + M(72, 75) * x(75)
      temp = temp + M(72, 77) * x(77)
      temp = temp + M(72, 78) * x(78)
      temp = temp + M(72, 79) * x(79)
      temp = temp + M(72, 80) * x(80)
      temp = temp + M(72, 81) * x(81)
      temp = temp + M(72, 82) * x(82)
      x(72) = x(72) - temp

      temp = M(71, 73) * x(73)
      temp = temp + M(71, 75) * x(75)
      temp = temp + M(71, 77) * x(77)
      temp = temp + M(71, 78) * x(78)
      temp = temp + M(71, 79) * x(79)
      temp = temp + M(71, 80) * x(80)
      temp = temp + M(71, 81) * x(81)
      temp = temp + M(71, 82) * x(82)
      x(71) = x(71) - temp

      temp = M(70, 73) * x(73)
      temp = temp + M(70, 75) * x(75)
      temp = temp + M(70, 77) * x(77)
      temp = temp + M(70, 78) * x(78)
      temp = temp + M(70, 79) * x(79)
      temp = temp + M(70, 80) * x(80)
      temp = temp + M(70, 81) * x(81)
      temp = temp + M(70, 82) * x(82)
      x(70) = x(70) - temp

      temp = M(69, 73) * x(73)
      temp = temp + M(69, 75) * x(75)
      temp = temp + M(69, 77) * x(77)
      temp = temp + M(69, 78) * x(78)
      temp = temp + M(69, 79) * x(79)
      temp = temp + M(69, 80) * x(80)
      temp = temp + M(69, 81) * x(81)
      temp = temp + M(69, 82) * x(82)
      x(69) = x(69) - temp

      temp = M(68, 69) * x(69)
      temp = temp + M(68, 73) * x(73)
      temp = temp + M(68, 75) * x(75)
      temp = temp + M(68, 77) * x(77)
      temp = temp + M(68, 78) * x(78)
      temp = temp + M(68, 79) * x(79)
      temp = temp + M(68, 80) * x(80)
      temp = temp + M(68, 81) * x(81)
      temp = temp + M(68, 82) * x(82)
      x(68) = x(68) - temp

      temp = M(67, 69) * x(69)
      temp = temp + M(67, 73) * x(73)
      temp = temp + M(67, 75) * x(75)
      temp = temp + M(67, 77) * x(77)
      temp = temp + M(67, 78) * x(78)
      temp = temp + M(67, 79) * x(79)
      temp = temp + M(67, 80) * x(80)
      temp = temp + M(67, 81) * x(81)
      temp = temp + M(67, 82) * x(82)
      x(67) = x(67) - temp

      temp = M(66, 69) * x(69)
      temp = temp + M(66, 73) * x(73)
      temp = temp + M(66, 75) * x(75)
      temp = temp + M(66, 77) * x(77)
      temp = temp + M(66, 78) * x(78)
      temp = temp + M(66, 79) * x(79)
      temp = temp + M(66, 80) * x(80)
      temp = temp + M(66, 81) * x(81)
      temp = temp + M(66, 82) * x(82)
      x(66) = x(66) - temp

      temp = M(65, 66) * x(66)
      temp = temp + M(65, 69) * x(69)
      temp = temp + M(65, 73) * x(73)
      temp = temp + M(65, 75) * x(75)
      temp = temp + M(65, 77) * x(77)
      temp = temp + M(65, 78) * x(78)
      temp = temp + M(65, 79) * x(79)
      temp = temp + M(65, 80) * x(80)
      temp = temp + M(65, 81) * x(81)
      temp = temp + M(65, 82) * x(82)
      x(65) = x(65) - temp

      temp = M(64, 66) * x(66)
      temp = temp + M(64, 69) * x(69)
      temp = temp + M(64, 73) * x(73)
      temp = temp + M(64, 75) * x(75)
      temp = temp + M(64, 79) * x(79)
      temp = temp + M(64, 80) * x(80)
      temp = temp + M(64, 81) * x(81)
      temp = temp + M(64, 82) * x(82)
      x(64) = x(64) - temp

      temp = M(63, 66) * x(66)
      temp = temp + M(63, 69) * x(69)
      temp = temp + M(63, 73) * x(73)
      temp = temp + M(63, 75) * x(75)
      temp = temp + M(63, 79) * x(79)
      temp = temp + M(63, 80) * x(80)
      temp = temp + M(63, 81) * x(81)
      temp = temp + M(63, 82) * x(82)
      x(63) = x(63) - temp

      temp = M(62, 66) * x(66)
      temp = temp + M(62, 69) * x(69)
      temp = temp + M(62, 73) * x(73)
      temp = temp + M(62, 75) * x(75)
      temp = temp + M(62, 79) * x(79)
      temp = temp + M(62, 80) * x(80)
      temp = temp + M(62, 81) * x(81)
      temp = temp + M(62, 82) * x(82)
      x(62) = x(62) - temp

      temp = M(61, 66) * x(66)
      temp = temp + M(61, 69) * x(69)
      temp = temp + M(61, 73) * x(73)
      temp = temp + M(61, 75) * x(75)
      temp = temp + M(61, 79) * x(79)
      temp = temp + M(61, 80) * x(80)
      temp = temp + M(61, 81) * x(81)
      temp = temp + M(61, 82) * x(82)
      x(61) = x(61) - temp

      temp = M(60, 69) * x(69)
      temp = temp + M(60, 73) * x(73)
      temp = temp + M(60, 75) * x(75)
      temp = temp + M(60, 79) * x(79)
      temp = temp + M(60, 80) * x(80)
      temp = temp + M(60, 81) * x(81)
      temp = temp + M(60, 82) * x(82)
      x(60) = x(60) - temp

      temp = M(59, 69) * x(69)
      temp = temp + M(59, 73) * x(73)
      temp = temp + M(59, 75) * x(75)
      temp = temp + M(59, 79) * x(79)
      temp = temp + M(59, 80) * x(80)
      temp = temp + M(59, 81) * x(81)
      temp = temp + M(59, 82) * x(82)
      x(59) = x(59) - temp

      temp = M(58, 59) * x(59)
      temp = temp + M(58, 69) * x(69)
      temp = temp + M(58, 73) * x(73)
      temp = temp + M(58, 75) * x(75)
      temp = temp + M(58, 79) * x(79)
      temp = temp + M(58, 80) * x(80)
      temp = temp + M(58, 81) * x(81)
      temp = temp + M(58, 82) * x(82)
      x(58) = x(58) - temp

      temp = M(57, 58) * x(58)
      temp = temp + M(57, 69) * x(69)
      temp = temp + M(57, 73) * x(73)
      temp = temp + M(57, 75) * x(75)
      temp = temp + M(57, 79) * x(79)
      temp = temp + M(57, 80) * x(80)
      temp = temp + M(57, 82) * x(82)
      x(57) = x(57) - temp

      temp = M(56, 58) * x(58)
      temp = temp + M(56, 69) * x(69)
      temp = temp + M(56, 73) * x(73)
      temp = temp + M(56, 75) * x(75)
      temp = temp + M(56, 79) * x(79)
      temp = temp + M(56, 80) * x(80)
      temp = temp + M(56, 82) * x(82)
      x(56) = x(56) - temp

      temp = M(55, 58) * x(58)
      temp = temp + M(55, 69) * x(69)
      temp = temp + M(55, 73) * x(73)
      temp = temp + M(55, 75) * x(75)
      temp = temp + M(55, 79) * x(79)
      temp = temp + M(55, 80) * x(80)
      temp = temp + M(55, 82) * x(82)
      x(55) = x(55) - temp

      temp = M(54, 59) * x(59)
      temp = temp + M(54, 69) * x(69)
      temp = temp + M(54, 75) * x(75)
      temp = temp + M(54, 79) * x(79)
      temp = temp + M(54, 80) * x(80)
      temp = temp + M(54, 82) * x(82)
      x(54) = x(54) - temp

      temp = M(53, 69) * x(69)
      temp = temp + M(53, 73) * x(73)
      temp = temp + M(53, 75) * x(75)
      temp = temp + M(53, 79) * x(79)
      temp = temp + M(53, 81) * x(81)
      temp = temp + M(53, 82) * x(82)
      x(53) = x(53) - temp

      temp = M(52, 57) * x(57)
      temp = temp + M(52, 58) * x(58)
      temp = temp + M(52, 69) * x(69)
      temp = temp + M(52, 73) * x(73)
      temp = temp + M(52, 75) * x(75)
      temp = temp + M(52, 79) * x(79)
      temp = temp + M(52, 80) * x(80)
      temp = temp + M(52, 82) * x(82)
      x(52) = x(52) - temp

      temp = M(51, 57) * x(57)
      temp = temp + M(51, 58) * x(58)
      temp = temp + M(51, 73) * x(73)
      temp = temp + M(51, 75) * x(75)
      temp = temp + M(51, 79) * x(79)
      temp = temp + M(51, 80) * x(80)
      x(51) = x(51) - temp

      temp = M(50, 51) * x(51)
      temp = temp + M(50, 57) * x(57)
      temp = temp + M(50, 58) * x(58)
      temp = temp + M(50, 73) * x(73)
      temp = temp + M(50, 75) * x(75)
      temp = temp + M(50, 79) * x(79)
      temp = temp + M(50, 80) * x(80)
      x(50) = x(50) - temp

      temp = M(49, 51) * x(51)
      temp = temp + M(49, 57) * x(57)
      temp = temp + M(49, 58) * x(58)
      temp = temp + M(49, 73) * x(73)
      temp = temp + M(49, 75) * x(75)
      temp = temp + M(49, 79) * x(79)
      temp = temp + M(49, 80) * x(80)
      x(49) = x(49) - temp

      temp = M(48, 69) * x(69)
      temp = temp + M(48, 75) * x(75)
      temp = temp + M(48, 79) * x(79)
      temp = temp + M(48, 80) * x(80)
      temp = temp + M(48, 82) * x(82)
      x(48) = x(48) - temp

      temp = M(47, 69) * x(69)
      temp = temp + M(47, 75) * x(75)
      temp = temp + M(47, 79) * x(79)
      temp = temp + M(47, 80) * x(80)
      temp = temp + M(47, 82) * x(82)
      x(47) = x(47) - temp

      temp = M(46, 49) * x(49)
      temp = temp + M(46, 51) * x(51)
      temp = temp + M(46, 58) * x(58)
      temp = temp + M(46, 69) * x(69)
      temp = temp + M(46, 73) * x(73)
      temp = temp + M(46, 75) * x(75)
      temp = temp + M(46, 79) * x(79)
      temp = temp + M(46, 80) * x(80)
      temp = temp + M(46, 82) * x(82)
      x(46) = x(46) - temp

      temp = M(45, 49) * x(49)
      temp = temp + M(45, 51) * x(51)
      temp = temp + M(45, 58) * x(58)
      temp = temp + M(45, 73) * x(73)
      temp = temp + M(45, 75) * x(75)
      temp = temp + M(45, 79) * x(79)
      temp = temp + M(45, 80) * x(80)
      x(45) = x(45) - temp

      temp = M(44, 49) * x(49)
      temp = temp + M(44, 51) * x(51)
      temp = temp + M(44, 58) * x(58)
      temp = temp + M(44, 73) * x(73)
      temp = temp + M(44, 75) * x(75)
      temp = temp + M(44, 79) * x(79)
      temp = temp + M(44, 80) * x(80)
      x(44) = x(44) - temp

      temp = M(43, 58) * x(58)
      temp = temp + M(43, 69) * x(69)
      temp = temp + M(43, 73) * x(73)
      temp = temp + M(43, 75) * x(75)
      temp = temp + M(43, 79) * x(79)
      temp = temp + M(43, 80) * x(80)
      temp = temp + M(43, 82) * x(82)
      x(43) = x(43) - temp

      temp = M(42, 58) * x(58)
      temp = temp + M(42, 69) * x(69)
      temp = temp + M(42, 73) * x(73)
      temp = temp + M(42, 75) * x(75)
      temp = temp + M(42, 79) * x(79)
      temp = temp + M(42, 80) * x(80)
      temp = temp + M(42, 82) * x(82)
      x(42) = x(42) - temp

      temp = M(41, 58) * x(58)
      temp = temp + M(41, 69) * x(69)
      temp = temp + M(41, 73) * x(73)
      temp = temp + M(41, 75) * x(75)
      temp = temp + M(41, 79) * x(79)
      temp = temp + M(41, 80) * x(80)
      temp = temp + M(41, 82) * x(82)
      x(41) = x(41) - temp

      temp = M(40, 69) * x(69)
      temp = temp + M(40, 75) * x(75)
      temp = temp + M(40, 79) * x(79)
      temp = temp + M(40, 80) * x(80)
      temp = temp + M(40, 82) * x(82)
      x(40) = x(40) - temp

      temp = M(39, 69) * x(69)
      temp = temp + M(39, 75) * x(75)
      temp = temp + M(39, 79) * x(79)
      temp = temp + M(39, 80) * x(80)
      temp = temp + M(39, 82) * x(82)
      x(39) = x(39) - temp

      temp = M(38, 69) * x(69)
      temp = temp + M(38, 75) * x(75)
      temp = temp + M(38, 79) * x(79)
      temp = temp + M(38, 80) * x(80)
      temp = temp + M(38, 82) * x(82)
      x(38) = x(38) - temp

      temp = M(37, 69) * x(69)
      temp = temp + M(37, 75) * x(75)
      temp = temp + M(37, 79) * x(79)
      temp = temp + M(37, 80) * x(80)
      temp = temp + M(37, 82) * x(82)
      x(37) = x(37) - temp

      temp = M(36, 69) * x(69)
      temp = temp + M(36, 75) * x(75)
      temp = temp + M(36, 79) * x(79)
      temp = temp + M(36, 80) * x(80)
      temp = temp + M(36, 82) * x(82)
      x(36) = x(36) - temp

      temp = M(35, 69) * x(69)
      temp = temp + M(35, 75) * x(75)
      temp = temp + M(35, 79) * x(79)
      temp = temp + M(35, 80) * x(80)
      temp = temp + M(35, 82) * x(82)
      x(35) = x(35) - temp

      temp = M(34, 45) * x(45)
      temp = temp + M(34, 50) * x(50)
      temp = temp + M(34, 57) * x(57)
      temp = temp + M(34, 58) * x(58)
      temp = temp + M(34, 59) * x(59)
      temp = temp + M(34, 73) * x(73)
      temp = temp + M(34, 75) * x(75)
      x(34) = x(34) - temp

      temp = M(33, 41) * x(41)
      temp = temp + M(33, 44) * x(44)
      temp = temp + M(33, 51) * x(51)
      temp = temp + M(33, 75) * x(75)
      temp = temp + M(33, 80) * x(80)
      x(33) = x(33) - temp

      temp = M(32, 50) * x(50)
      temp = temp + M(32, 57) * x(57)
      temp = temp + M(32, 58) * x(58)
      temp = temp + M(32, 73) * x(73)
      temp = temp + M(32, 75) * x(75)
      temp = temp + M(32, 81) * x(81)
      x(32) = x(32) - temp

      temp = M(31, 45) * x(45)
      temp = temp + M(31, 58) * x(58)
      temp = temp + M(31, 59) * x(59)
      temp = temp + M(31, 75) * x(75)
      x(31) = x(31) - temp

      temp = M(30, 44) * x(44)
      temp = temp + M(30, 49) * x(49)
      temp = temp + M(30, 75) * x(75)
      temp = temp + M(30, 80) * x(80)
      x(30) = x(30) - temp

      temp = M(29, 58) * x(58)
      temp = temp + M(29, 73) * x(73)
      temp = temp + M(29, 75) * x(75)
      temp = temp + M(29, 79) * x(79)
      x(29) = x(29) - temp

      temp = M(28, 75) * x(75)
      temp = temp + M(28, 79) * x(79)
      temp = temp + M(28, 82) * x(82)
      x(28) = x(28) - temp

      temp = M(27, 69) * x(69)
      temp = temp + M(27, 75) * x(75)
      temp = temp + M(27, 79) * x(79)
      x(27) = x(27) - temp

      temp = M(26, 75) * x(75)
      temp = temp + M(26, 81) * x(81)
      temp = temp + M(26, 82) * x(82)
      x(26) = x(26) - temp

      temp = M(25, 58) * x(58)
      temp = temp + M(25, 73) * x(73)
      temp = temp + M(25, 75) * x(75)
      x(25) = x(25) - temp

      temp = M(24, 58) * x(58)
      temp = temp + M(24, 73) * x(73)
      temp = temp + M(24, 75) * x(75)
      x(24) = x(24) - temp

      temp = M(23, 58) * x(58)
      temp = temp + M(23, 73) * x(73)
      temp = temp + M(23, 75) * x(75)
      temp = temp + M(23, 80) * x(80)
      x(23) = x(23) - temp

      temp = M(22, 58) * x(58)
      temp = temp + M(22, 73) * x(73)
      temp = temp + M(22, 75) * x(75)
      x(22) = x(22) - temp

      temp = M(21, 58) * x(58)
      temp = temp + M(21, 73) * x(73)
      temp = temp + M(21, 75) * x(75)
      x(21) = x(21) - temp

      temp = M(20, 58) * x(58)
      temp = temp + M(20, 73) * x(73)
      temp = temp + M(20, 75) * x(75)
      x(20) = x(20) - temp

      temp = M(19, 58) * x(58)
      temp = temp + M(19, 73) * x(73)
      temp = temp + M(19, 75) * x(75)
      x(19) = x(19) - temp

      temp = M(18, 75) * x(75)
      temp = temp + M(18, 79) * x(79)
      temp = temp + M(18, 81) * x(81)
      x(18) = x(18) - temp

      temp = M(17, 77) * x(77)
      temp = temp + M(17, 81) * x(81)
      x(17) = x(17) - temp

      temp = M(16, 73) * x(73)
      temp = temp + M(16, 75) * x(75)
      x(16) = x(16) - temp

      temp = M(15, 73) * x(73)
      temp = temp + M(15, 81) * x(81)
      x(15) = x(15) - temp

      temp = M(14, 75) * x(75)
      temp = temp + M(14, 80) * x(80)
      x(14) = x(14) - temp

      temp = M(13, 75) * x(75)
      x(13) = x(13) - temp

      temp = M(12, 75) * x(75)
      x(12) = x(12) - temp

      temp = M(11, 75) * x(75)
      x(11) = x(11) - temp

      temp = M(10, 75) * x(75)
      x(10) = x(10) - temp

      temp = M(9, 75) * x(75)
      x(9) = x(9) - temp

      temp = M(8, 75) * x(75)
      x(8) = x(8) - temp

      temp = M(7, 75) * x(75)
      x(7) = x(7) - temp

      temp = M(6, 75) * x(75)
      x(6) = x(6) - temp

      temp = M(5, 75) * x(75)
      x(5) = x(5) - temp

      temp = M(4, 75) * x(75)
      x(4) = x(4) - temp

      temp = M(3, 58) * x(58)
      x(3) = x(3) - temp

      temp = M(2, 75) * x(75)
      x(2) = x(2) - temp

      temp = M(1, 75) * x(75)
      x(1) = x(1) - temp


      END
