      subroutine fexchem(y,rk,ZCsourc,chem)
      
C------------------------------------------------------------------------
C     
C     -- DESCRIPTION
C     
C     This routine computes the chemical production term.
C     This routine is automatically generated by SPACK.
C     Mechanism: EURORADM            
C     Species: _ciEURORADM         
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     ZCSOURC: volumic emissions.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     CHEM: array of chemical production terms.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     SPACK.
C     
C------------------------------------------------------------------------
      
      implicit none
      
C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of chemical arrays.
C     COMUSE: flags and parameters for numerics.
C     PARADOM: parameters for all forced fields.
      
      include 'PARACHEM.INC' 
      include 'COMUSE.INC' 
      INCLUDE 'PARADOM.INC'  
      
      double precision w(nr),rk(nr),y(nesp),chem(nesp),ZCsourc(nesp)
      integer i
      
      do i=1,nesp
         chem(i)=0.d0
      enddo
      
C     Compute reaction rates.
      
      call rates(rk,y,w)
      
C     Chemical production terms.
      
      chem( 32) = chem( 32) + w(  1)
      chem( 80) = chem( 80) + w(  1)
      chem( 81) = chem( 81) - w(  1)
      chem(  3) = chem(  3) + w(  2)
      chem( 58) = chem( 58) - w(  2)
      chem( 32) = chem( 32) + w(  3)
      chem( 58) = chem( 58) - w(  3)
      chem( 14) = chem( 14) - w(  4)
      chem( 75) = chem( 75) + w(  4)
      chem( 80) = chem( 80) + w(  4)
      chem( 72) = chem( 72) - w(  5)
      chem( 75) = chem( 75) + w(  5)
      chem( 81) = chem( 81) + w(  5)
      chem( 18) = chem( 18) - w(  6)
      chem( 73) = chem( 73) +  0.3500000000000000D+00 * w(  6)
      chem( 75) = chem( 75) +  0.3500000000000000D+00 * w(  6)
      chem( 79) = chem( 79) +  0.6500000000000000D+00 * w(  6)
      chem( 81) = chem( 81) +  0.6500000000000000D+00 * w(  6)
      chem( 73) = chem( 73) - w(  7)
      chem( 80) = chem( 80) + w(  7)
      chem( 32) = chem( 32) + w(  8)
      chem( 73) = chem( 73) - w(  8)
      chem( 81) = chem( 81) + w(  8)
      chem( 29) = chem( 29) - w(  9)
      chem( 75) = chem( 75) +  0.2000000000000000D+01 * w(  9)
      chem( 74) = chem( 74) - w( 10)
      chem( 76) = chem( 76) + w( 10)
      chem( 74) = chem( 74) - w( 11)
      chem( 76) = chem( 76) + w( 11)
      chem( 79) = chem( 79) +  0.2000000000000000D+01 * w( 11)
      chem( 67) = chem( 67) - w( 12)
      chem( 69) = chem( 69) + w( 12)
      chem( 76) = chem( 76) + w( 12)
      chem( 79) = chem( 79) + w( 12)
      chem( 27) = chem( 27) - w( 13)
      chem( 74) = chem( 74) + w( 13)
      chem( 75) = chem( 75) + w( 13)
      chem( 79) = chem( 79) + w( 13)
      chem( 65) = chem( 65) - w( 14)
      chem( 67) = chem( 67) + w( 14)
      chem( 75) = chem( 75) + w( 14)
      chem( 79) = chem( 79) + w( 14)
      chem( 28) = chem( 28) - w( 15)
      chem( 69) = chem( 69) + w( 15)
      chem( 75) = chem( 75) + w( 15)
      chem( 62) = chem( 62) - w( 16)
      chem( 63) = chem( 63) + w( 16)
      chem( 82) = chem( 82) + w( 16)
      chem( 71) = chem( 71) - w( 17)
      chem( 74) = chem( 74) +  0.1300000000000000D+00 * w( 17)
      chem( 76) = chem( 76) +  0.1870000000000000D+01 * w( 17)
      chem( 71) = chem( 71) - w( 18)
      chem( 74) = chem( 74) +  0.4500000000000000D+00 * w( 18)
      chem( 76) = chem( 76) +  0.1550000000000000D+01 * w( 18)
      chem( 79) = chem( 79) +  0.8000000000000000D+00 * w( 18)
      chem( 70) = chem( 70) - w( 19)
      chem( 76) = chem( 76) + w( 19)
      chem( 79) = chem( 79) + w( 19)
      chem( 82) = chem( 82) + w( 19)
      chem( 52) = chem( 52) - w( 20)
      chem( 77) = chem( 77) + w( 20)
      chem( 79) = chem( 79) + w( 20)
      chem( 61) = chem( 61) - w( 21)
      chem( 62) = chem( 62) +  0.8000000000000000D+00 * w( 21)
      chem( 67) = chem( 67) +  0.2000000000000000D+00 * w( 21)
      chem( 79) = chem( 79) + w( 21)
      chem( 81) = chem( 81) + w( 21)
      chem( 33) = chem( 33) - w( 22)
      chem( 74) = chem( 74) + w( 22)
      chem( 76) = chem( 76) + w( 22)
      chem( 79) = chem( 79) +  0.2000000000000000D+01 * w( 22)
      chem( 30) = chem( 30) - w( 23)
      chem( 74) = chem( 74) + w( 23)
      chem( 79) = chem( 79) + w( 23)
      chem( 82) = chem( 82) + w( 23)
      chem( 32) = chem( 32) - w( 24)
      chem( 58) = chem( 58) + w( 24)
      chem( 32) = chem( 32) - w( 25)
      chem( 80) = chem( 80) + w( 25)
      chem( 81) = chem( 81) - w( 25)
      chem(  3) = chem(  3) - w( 26)
      chem( 32) = chem( 32) + w( 26)
      chem(  3) = chem(  3) - w( 27)
      chem( 32) = chem( 32) + w( 27)
      chem(  3) = chem(  3) - w( 28)
      chem( 75) = chem( 75) +  0.2000000000000000D+01 * w( 28)
      chem( 58) = chem( 58) - w( 29)
      chem( 80) = chem( 80) - w( 29)
      chem( 81) = chem( 81) + w( 29)
      chem( 58) = chem( 58) - w( 30)
      chem( 75) = chem( 75) - w( 30)
      chem( 79) = chem( 79) + w( 30)
      chem( 58) = chem( 58) - w( 31)
      chem( 75) = chem( 75) + w( 31)
      chem( 79) = chem( 79) - w( 31)
      chem( 75) = chem( 75) + w( 32)
      chem( 79) = chem( 79) - w( 32)
      chem( 80) = chem( 80) - w( 32)
      chem( 81) = chem( 81) + w( 32)
      chem( 18) = chem( 18) + w( 33)
      chem( 79) = chem( 79) - w( 33)
      chem( 81) = chem( 81) - w( 33)
      chem( 18) = chem( 18) - w( 34)
      chem( 79) = chem( 79) + w( 34)
      chem( 81) = chem( 81) + w( 34)
      chem( 29) = chem( 29) + w( 35)
      chem( 79) = chem( 79) -  0.2000000000000000D+01 * w( 35)
      chem( 29) = chem( 29) + w( 36)
      chem( 79) = chem( 79) -  0.2000000000000000D+01 * w( 36)
      chem( 29) = chem( 29) - w( 37)
      chem( 75) = chem( 75) - w( 37)
      chem( 79) = chem( 79) + w( 37)
      chem( 14) = chem( 14) + w( 38)
      chem( 75) = chem( 75) - w( 38)
      chem( 80) = chem( 80) - w( 38)
      chem( 80) = chem( 80) -  0.2000000000000000D+01 * w( 39)
      chem( 81) = chem( 81) +  0.2000000000000000D+01 * w( 39)
      chem( 58) = chem( 58) - w( 40)
      chem( 73) = chem( 73) + w( 40)
      chem( 81) = chem( 81) - w( 40)
      chem( 73) = chem( 73) - w( 41)
      chem( 80) = chem( 80) - w( 41)
      chem( 81) = chem( 81) +  0.2000000000000000D+01 * w( 41)
      chem( 73) = chem( 73) - w( 42)
      chem( 80) = chem( 80) + w( 42)
      chem( 72) = chem( 72) + w( 43)
      chem( 73) = chem( 73) - w( 43)
      chem( 79) = chem( 79) - w( 43)
      chem( 15) = chem( 15) + w( 44)
      chem( 73) = chem( 73) - w( 44)
      chem( 81) = chem( 81) - w( 44)
      chem( 15) = chem( 15) - w( 45)
      chem( 73) = chem( 73) + w( 45)
      chem( 81) = chem( 81) + w( 45)
      chem( 72) = chem( 72) + w( 46)
      chem( 75) = chem( 75) - w( 46)
      chem( 81) = chem( 81) - w( 46)
      chem( 72) = chem( 72) - w( 47)
      chem( 73) = chem( 73) + w( 47)
      chem( 75) = chem( 75) - w( 47)
      chem( 18) = chem( 18) - w( 48)
      chem( 75) = chem( 75) - w( 48)
      chem( 81) = chem( 81) + w( 48)
      chem( 75) = chem( 75) - w( 49)
      chem( 79) = chem( 79) - w( 49)
      chem(  1) = chem(  1) - w( 50)
      chem(  2) = chem(  2) + w( 50)
      chem( 75) = chem( 75) - w( 50)
      chem( 79) = chem( 79) + w( 50)
      chem( 75) = chem( 75) - w( 51)
      chem( 76) = chem( 76) - w( 51)
      chem( 79) = chem( 79) + w( 51)
      chem( 31) = chem( 31) - w( 52)
      chem( 69) = chem( 69) + w( 52)
      chem( 75) = chem( 75) - w( 52)
      chem(  4) = chem(  4) - w( 53)
      chem( 63) = chem( 63) + w( 53)
      chem( 75) = chem( 75) - w( 53)
      chem(  5) = chem(  5) - w( 54)
      chem( 66) = chem( 66) + w( 54)
      chem( 75) = chem( 75) - w( 54)
      chem(  6) = chem(  6) - w( 55)
      chem( 35) = chem( 35) + w( 55)
      chem( 75) = chem( 75) - w( 55)
      chem( 78) = chem( 78) +  0.3970000000000000D+00 * w( 55)
      chem( 10) = chem( 10) - w( 56)
      chem( 39) = chem( 39) + w( 56)
      chem( 75) = chem( 75) - w( 56)
      chem( 78) = chem( 78) +  0.7500000000000000D+00 * w( 56)
      chem( 19) = chem( 19) - w( 57)
      chem( 41) = chem( 41) + w( 57)
      chem( 75) = chem( 75) - w( 57)
      chem( 45) = chem( 45) - w( 58)
      chem( 46) = chem( 46) + w( 58)
      chem( 75) = chem( 75) - w( 58)
      chem( 54) = chem( 54) + w( 59)
      chem( 59) = chem( 59) - w( 59)
      chem( 75) = chem( 75) - w( 59)
      chem( 12) = chem( 12) - w( 60)
      chem( 16) = chem( 16) +  0.2500000000000000D+00 * w( 60)
      chem( 47) = chem( 47) +  0.7500000000000000D+00 * w( 60)
      chem( 75) = chem( 75) - w( 60)
      chem( 79) = chem( 79) +  0.2500000000000000D+00 * w( 60)
      chem( 13) = chem( 13) - w( 61)
      chem( 16) = chem( 16) +  0.1700000000000000D+00 * w( 61)
      chem( 48) = chem( 48) +  0.8300000000000000D+00 * w( 61)
      chem( 75) = chem( 75) - w( 61)
      chem( 79) = chem( 79) +  0.1700000000000000D+00 * w( 61)
      chem( 16) = chem( 16) - w( 62)
      chem( 75) = chem( 75) - w( 62)
      chem( 77) = chem( 77) +  0.9000000000000000D+00 * w( 62)
      chem( 78) = chem( 78) +  0.9000000000000000D+00 * w( 62)
      chem( 79) = chem( 79) +  0.1000000000000000D+00 * w( 62)
      chem( 75) = chem( 75) - w( 63)
      chem( 74) = chem( 74) - w( 64)
      chem( 75) = chem( 75) - w( 64)
      chem( 76) = chem( 76) + w( 64)
      chem( 79) = chem( 79) + w( 64)
      chem( 67) = chem( 67) - w( 65)
      chem( 75) = chem( 75) - w( 65)
      chem( 82) = chem( 82) + w( 65)
      chem( 62) = chem( 62) - w( 66)
      chem( 64) = chem( 64) + w( 66)
      chem( 75) = chem( 75) - w( 66)
      chem( 71) = chem( 71) - w( 67)
      chem( 75) = chem( 75) - w( 67)
      chem( 76) = chem( 76) +  0.2000000000000000D+01 * w( 67)
      chem( 79) = chem( 79) + w( 67)
      chem( 70) = chem( 70) - w( 68)
      chem( 75) = chem( 75) - w( 68)
      chem( 76) = chem( 76) + w( 68)
      chem( 82) = chem( 82) + w( 68)
      chem( 52) = chem( 52) - w( 69)
      chem( 75) = chem( 75) - w( 69)
      chem( 77) = chem( 77) + w( 69)
      chem( 27) = chem( 27) - w( 70)
      chem( 69) = chem( 69) +  0.5000000000000000D+00 * w( 70)
      chem( 74) = chem( 74) +  0.5000000000000000D+00 * w( 70)
      chem( 75) = chem( 75) -  0.5000000000000000D+00 * w( 70)
      chem( 65) = chem( 65) - w( 71)
      chem( 66) = chem( 66) +  0.5000000000000000D+00 * w( 71)
      chem( 67) = chem( 67) +  0.5000000000000000D+00 * w( 71)
      chem( 75) = chem( 75) -  0.5000000000000000D+00 * w( 71)
      chem( 28) = chem( 28) - w( 72)
      chem( 75) = chem( 75) - w( 72)
      chem( 82) = chem( 82) + w( 72)
      chem( 26) = chem( 26) - w( 73)
      chem( 73) = chem( 73) + w( 73)
      chem( 74) = chem( 74) + w( 73)
      chem( 75) = chem( 75) - w( 73)
      chem( 78) = chem( 78) + w( 73)
      chem( 61) = chem( 61) - w( 74)
      chem( 66) = chem( 66) + w( 74)
      chem( 75) = chem( 75) - w( 74)
      chem( 81) = chem( 81) + w( 74)
      chem( 22) = chem( 22) - w( 75)
      chem( 44) = chem( 44) + w( 75)
      chem( 75) = chem( 75) - w( 75)
      chem( 26) = chem( 26) + w( 76)
      chem( 81) = chem( 81) - w( 76)
      chem( 82) = chem( 82) - w( 76)
      chem( 26) = chem( 26) - w( 77)
      chem( 81) = chem( 81) + w( 77)
      chem( 82) = chem( 82) + w( 77)
      chem( 17) = chem( 17) + w( 78)
      chem( 77) = chem( 77) - w( 78)
      chem( 81) = chem( 81) - w( 78)
      chem( 17) = chem( 17) - w( 79)
      chem( 77) = chem( 77) + w( 79)
      chem( 81) = chem( 81) + w( 79)
      chem( 69) = chem( 69) - w( 80)
      chem( 74) = chem( 74) + w( 80)
      chem( 79) = chem( 79) + w( 80)
      chem( 80) = chem( 80) - w( 80)
      chem( 81) = chem( 81) + w( 80)
      chem( 61) = chem( 61) +  0.3900000000000000D-01 * w( 81)
      chem( 62) = chem( 62) +  0.6580000000000000D+00 * w( 81)
      chem( 66) = chem( 66) - w( 81)
      chem( 67) = chem( 67) +  0.3000000000000000D+00 * w( 81)
      chem( 79) = chem( 79) +  0.9610000000000000D+00 * w( 81)
      chem( 80) = chem( 80) - w( 81)
      chem( 81) = chem( 81) +  0.9610000000000000D+00 * w( 81)
      chem( 35) = chem( 35) - w( 82)
      chem( 61) = chem( 61) +  0.8000000000000000D-01 * w( 82)
      chem( 62) = chem( 62) +  0.5330000000000000D+00 * w( 82)
      chem( 67) = chem( 67) +  0.7110000000000000D+00 * w( 82)
      chem( 74) = chem( 74) +  0.1000000000000000D-02 * w( 82)
      chem( 79) = chem( 79) +  0.9240000000000000D+00 * w( 82)
      chem( 80) = chem( 80) - w( 82)
      chem( 81) = chem( 81) +  0.9240000000000000D+00 * w( 82)
      chem( 39) = chem( 39) - w( 83)
      chem( 61) = chem( 61) +  0.2400000000000000D+00 * w( 83)
      chem( 62) = chem( 62) +  0.1060000000000000D+01 * w( 83)
      chem( 67) = chem( 67) +  0.3500000000000000D+00 * w( 83)
      chem( 74) = chem( 74) +  0.4000000000000000D-01 * w( 83)
      chem( 79) = chem( 79) +  0.7600000000000000D+00 * w( 83)
      chem( 80) = chem( 80) - w( 83)
      chem( 81) = chem( 81) +  0.7600000000000000D+00 * w( 83)
      chem( 33) = chem( 33) +  0.2000000000000000D+00 * w( 84)
      chem( 41) = chem( 41) - w( 84)
      chem( 74) = chem( 74) +  0.1600000000000000D+01 * w( 84)
      chem( 79) = chem( 79) + w( 84)
      chem( 80) = chem( 80) - w( 84)
      chem( 81) = chem( 81) + w( 84)
      chem( 46) = chem( 46) - w( 85)
      chem( 67) = chem( 67) + w( 85)
      chem( 74) = chem( 74) + w( 85)
      chem( 79) = chem( 79) + w( 85)
      chem( 80) = chem( 80) - w( 85)
      chem( 81) = chem( 81) + w( 85)
      chem( 54) = chem( 54) - w( 86)
      chem( 62) = chem( 62) +  0.1000000000000000D+00 * w( 86)
      chem( 67) = chem( 67) +  0.1450000000000000D+01 * w( 86)
      chem( 74) = chem( 74) +  0.2800000000000000D+00 * w( 86)
      chem( 79) = chem( 79) + w( 86)
      chem( 80) = chem( 80) - w( 86)
      chem( 81) = chem( 81) + w( 86)
      chem( 69) = chem( 69) + w( 87)
      chem( 80) = chem( 80) - w( 87)
      chem( 81) = chem( 81) + w( 87)
      chem( 82) = chem( 82) - w( 87)
      chem( 70) = chem( 70) +  0.1100000000000000D+00 * w( 88)
      chem( 71) = chem( 71) +  0.8900000000000000D+00 * w( 88)
      chem( 76) = chem( 76) +  0.9500000000000000D+00 * w( 88)
      chem( 77) = chem( 77) - w( 88)
      chem( 78) = chem( 78) +  0.2000000000000000D+01 * w( 88)
      chem( 79) = chem( 79) +  0.9200000000000000D+00 * w( 88)
      chem( 80) = chem( 80) - w( 88)
      chem( 81) = chem( 81) + w( 88)
      chem( 82) = chem( 82) +  0.5000000000000000D-01 * w( 88)
      chem( 47) = chem( 47) - w( 89)
      chem( 52) = chem( 52) +  0.7000000000000000D+00 * w( 89)
      chem( 70) = chem( 70) +  0.1700000000000000D+00 * w( 89)
      chem( 71) = chem( 71) +  0.1600000000000000D+00 * w( 89)
      chem( 79) = chem( 79) + w( 89)
      chem( 80) = chem( 80) - w( 89)
      chem( 81) = chem( 81) + w( 89)
      chem( 48) = chem( 48) - w( 90)
      chem( 52) = chem( 52) +  0.8060000000000000D+00 * w( 90)
      chem( 70) = chem( 70) +  0.4500000000000000D+00 * w( 90)
      chem( 79) = chem( 79) + w( 90)
      chem( 80) = chem( 80) - w( 90)
      chem( 81) = chem( 81) + w( 90)
      chem( 63) = chem( 63) - w( 91)
      chem( 67) = chem( 67) + w( 91)
      chem( 79) = chem( 79) + w( 91)
      chem( 80) = chem( 80) - w( 91)
      chem( 81) = chem( 81) + w( 91)
      chem( 64) = chem( 64) - w( 92)
      chem( 70) = chem( 70) + w( 92)
      chem( 79) = chem( 79) + w( 92)
      chem( 80) = chem( 80) - w( 92)
      chem( 81) = chem( 81) + w( 92)
      chem( 60) = chem( 60) - w( 93)
      chem( 67) = chem( 67) + w( 93)
      chem( 74) = chem( 74) + w( 93)
      chem( 80) = chem( 80) - w( 93)
      chem( 81) = chem( 81) +  0.2000000000000000D+01 * w( 93)
      chem( 72) = chem( 72) + w( 94)
      chem( 73) = chem( 73) - w( 94)
      chem( 74) = chem( 74) - w( 94)
      chem( 76) = chem( 76) + w( 94)
      chem( 79) = chem( 79) + w( 94)
      chem( 67) = chem( 67) - w( 95)
      chem( 72) = chem( 72) + w( 95)
      chem( 73) = chem( 73) - w( 95)
      chem( 82) = chem( 82) + w( 95)
      chem( 71) = chem( 71) - w( 96)
      chem( 72) = chem( 72) + w( 96)
      chem( 73) = chem( 73) - w( 96)
      chem( 76) = chem( 76) +  0.2000000000000000D+01 * w( 96)
      chem( 79) = chem( 79) + w( 96)
      chem( 70) = chem( 70) - w( 97)
      chem( 72) = chem( 72) + w( 97)
      chem( 73) = chem( 73) - w( 97)
      chem( 76) = chem( 76) + w( 97)
      chem( 82) = chem( 82) + w( 97)
      chem( 52) = chem( 52) - w( 98)
      chem( 72) = chem( 72) + w( 98)
      chem( 73) = chem( 73) - w( 98)
      chem( 77) = chem( 77) + w( 98)
      chem( 16) = chem( 16) -  0.5000000000000000D+00 * w( 99)
      chem( 53) = chem( 53) + w( 99)
      chem( 72) = chem( 72) + w( 99)
      chem( 73) = chem( 73) - w( 99)
      chem( 19) = chem( 19) - w(100)
      chem( 60) = chem( 60) + w(100)
      chem( 73) = chem( 73) - w(100)
      chem( 45) = chem( 45) - w(101)
      chem( 60) = chem( 60) + w(101)
      chem( 73) = chem( 73) - w(101)
      chem( 59) = chem( 59) - w(102)
      chem( 60) = chem( 60) + w(102)
      chem( 73) = chem( 73) - w(102)
      chem( 22) = chem( 22) - w(103)
      chem( 23) = chem( 23) + w(103)
      chem( 73) = chem( 73) - w(103)
      chem( 19) = chem( 19) - w(104)
      chem( 34) = chem( 34) +  0.4000000000000000D+00 * w(104)
      chem( 58) = chem( 58) - w(104)
      chem( 74) = chem( 74) + w(104)
      chem( 76) = chem( 76) +  0.4200000000000000D+00 * w(104)
      chem( 79) = chem( 79) +  0.1200000000000000D+00 * w(104)
      chem( 31) = chem( 31) +  0.6000000000000000D-01 * w(105)
      chem( 34) = chem( 34) +  0.2000000000000000D+00 * w(105)
      chem( 45) = chem( 45) - w(105)
      chem( 58) = chem( 58) - w(105)
      chem( 67) = chem( 67) +  0.5000000000000000D+00 * w(105)
      chem( 68) = chem( 68) +  0.2000000000000000D+00 * w(105)
      chem( 69) = chem( 69) +  0.2200000000000000D+00 * w(105)
      chem( 74) = chem( 74) +  0.5300000000000000D+00 * w(105)
      chem( 75) = chem( 75) +  0.1000000000000000D+00 * w(105)
      chem( 76) = chem( 76) +  0.3300000000000000D+00 * w(105)
      chem( 79) = chem( 79) +  0.2300000000000000D+00 * w(105)
      chem( 31) = chem( 31) +  0.9000000000000000D-01 * w(106)
      chem( 34) = chem( 34) +  0.6000000000000000D-01 * w(106)
      chem( 58) = chem( 58) - w(106)
      chem( 59) = chem( 59) - w(106)
      chem( 62) = chem( 62) +  0.1000000000000000D+00 * w(106)
      chem( 67) = chem( 67) +  0.7200000000000000D+00 * w(106)
      chem( 68) = chem( 68) +  0.2900000000000000D+00 * w(106)
      chem( 69) = chem( 69) +  0.3100000000000000D+00 * w(106)
      chem( 74) = chem( 74) +  0.1800000000000000D+00 * w(106)
      chem( 75) = chem( 75) +  0.1400000000000000D+00 * w(106)
      chem( 76) = chem( 76) +  0.2300000000000000D+00 * w(106)
      chem( 79) = chem( 79) +  0.2600000000000000D+00 * w(106)
      chem( 22) = chem( 22) - w(107)
      chem( 32) = chem( 32) +  0.3000000000000000D+00 * w(107)
      chem( 34) = chem( 34) +  0.7000000000000001D-01 * w(107)
      chem( 45) = chem( 45) +  0.7000000000000001D-01 * w(107)
      chem( 50) = chem( 50) +  0.2100000000000000D+00 * w(107)
      chem( 57) = chem( 57) +  0.5500000000000000D+00 * w(107)
      chem( 58) = chem( 58) - w(107)
      chem( 68) = chem( 68) +  0.1500000000000000D+00 * w(107)
      chem( 69) = chem( 69) +  0.9000000000000000D-01 * w(107)
      chem( 71) = chem( 71) +  0.1000000000000000D-01 * w(107)
      chem( 74) = chem( 74) +  0.8000000000000000D+00 * w(107)
      chem( 75) = chem( 75) +  0.5000000000000000D+00 * w(107)
      chem( 76) = chem( 76) +  0.1800000000000000D+00 * w(107)
      chem( 79) = chem( 79) +  0.1100000000000000D+00 * w(107)
      chem( 27) = chem( 27) + w(108)
      chem( 69) = chem( 69) - w(108)
      chem( 79) = chem( 79) - w(108)
      chem( 63) = chem( 63) - w(109)
      chem( 65) = chem( 65) + w(109)
      chem( 79) = chem( 79) - w(109)
      chem( 65) = chem( 65) + w(110)
      chem( 66) = chem( 66) - w(110)
      chem( 79) = chem( 79) - w(110)
      chem( 35) = chem( 35) - w(111)
      chem( 65) = chem( 65) + w(111)
      chem( 79) = chem( 79) - w(111)
      chem( 39) = chem( 39) - w(112)
      chem( 65) = chem( 65) + w(112)
      chem( 79) = chem( 79) - w(112)
      chem( 41) = chem( 41) - w(113)
      chem( 65) = chem( 65) + w(113)
      chem( 79) = chem( 79) - w(113)
      chem( 46) = chem( 46) - w(114)
      chem( 65) = chem( 65) + w(114)
      chem( 79) = chem( 79) - w(114)
      chem( 54) = chem( 54) - w(115)
      chem( 65) = chem( 65) + w(115)
      chem( 79) = chem( 79) - w(115)
      chem( 64) = chem( 64) - w(116)
      chem( 65) = chem( 65) + w(116)
      chem( 79) = chem( 79) - w(116)
      chem( 28) = chem( 28) + w(117)
      chem( 79) = chem( 79) - w(117)
      chem( 82) = chem( 82) - w(117)
      chem( 47) = chem( 47) - w(118)
      chem( 65) = chem( 65) + w(118)
      chem( 79) = chem( 79) - w(118)
      chem( 48) = chem( 48) - w(119)
      chem( 65) = chem( 65) + w(119)
      chem( 79) = chem( 79) - w(119)
      chem( 65) = chem( 65) + w(120)
      chem( 77) = chem( 77) - w(120)
      chem( 79) = chem( 79) - w(120)
      chem( 60) = chem( 60) - w(121)
      chem( 61) = chem( 61) + w(121)
      chem( 79) = chem( 79) - w(121)
      chem( 69) = chem( 69) -  0.2000000000000000D+01 * w(122)
      chem( 74) = chem( 74) +  0.1500000000000000D+01 * w(122)
      chem( 79) = chem( 79) + w(122)
      chem( 63) = chem( 63) - w(123)
      chem( 67) = chem( 67) +  0.7500000000000000D+00 * w(123)
      chem( 69) = chem( 69) - w(123)
      chem( 74) = chem( 74) +  0.7500000000000000D+00 * w(123)
      chem( 79) = chem( 79) + w(123)
      chem( 62) = chem( 62) +  0.5140000000000000D+00 * w(124)
      chem( 66) = chem( 66) - w(124)
      chem( 67) = chem( 67) +  0.2360000000000000D+00 * w(124)
      chem( 69) = chem( 69) - w(124)
      chem( 74) = chem( 74) +  0.7500000000000000D+00 * w(124)
      chem( 79) = chem( 79) + w(124)
      chem( 35) = chem( 35) - w(125)
      chem( 62) = chem( 62) +  0.4330000000000000D+00 * w(125)
      chem( 67) = chem( 67) +  0.5770000000000000D+00 * w(125)
      chem( 69) = chem( 69) - w(125)
      chem( 74) = chem( 74) +  0.7510000000000000D+00 * w(125)
      chem( 79) = chem( 79) + w(125)
      chem( 39) = chem( 39) - w(126)
      chem( 62) = chem( 62) +  0.1050000000000000D+01 * w(126)
      chem( 67) = chem( 67) +  0.3500000000000000D+00 * w(126)
      chem( 69) = chem( 69) - w(126)
      chem( 74) = chem( 74) +  0.7900000000000000D+00 * w(126)
      chem( 79) = chem( 79) + w(126)
      chem( 41) = chem( 41) - w(127)
      chem( 67) = chem( 67) +  0.1500000000000000D+00 * w(127)
      chem( 69) = chem( 69) - w(127)
      chem( 74) = chem( 74) +  0.1950000000000000D+01 * w(127)
      chem( 79) = chem( 79) + w(127)
      chem( 46) = chem( 46) - w(128)
      chem( 67) = chem( 67) +  0.7500000000000000D+00 * w(128)
      chem( 69) = chem( 69) - w(128)
      chem( 74) = chem( 74) +  0.1250000000000000D+01 * w(128)
      chem( 79) = chem( 79) + w(128)
      chem( 54) = chem( 54) - w(129)
      chem( 62) = chem( 62) +  0.5500000000000000D+00 * w(129)
      chem( 67) = chem( 67) +  0.7250000000000000D+00 * w(129)
      chem( 69) = chem( 69) - w(129)
      chem( 74) = chem( 74) +  0.8900000000000000D+00 * w(129)
      chem( 79) = chem( 79) + w(129)
      chem( 64) = chem( 64) - w(130)
      chem( 69) = chem( 69) - w(130)
      chem( 70) = chem( 70) +  0.7500000000000000D+00 * w(130)
      chem( 74) = chem( 74) +  0.7500000000000000D+00 * w(130)
      chem( 79) = chem( 79) + w(130)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(131)
      chem( 69) = chem( 69) -  0.5000000000000000D+00 * w(131)
      chem( 74) = chem( 74) + w(131)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w(131)
      chem( 82) = chem( 82) - w(131)
      chem( 47) = chem( 47) - w(132)
      chem( 52) = chem( 52) +  0.7000000000000000D+00 * w(132)
      chem( 69) = chem( 69) - w(132)
      chem( 70) = chem( 70) +  0.1700000000000000D+00 * w(132)
      chem( 71) = chem( 71) +  0.1600000000000000D+00 * w(132)
      chem( 74) = chem( 74) + w(132)
      chem( 79) = chem( 79) +  0.2000000000000000D+01 * w(132)
      chem( 48) = chem( 48) - w(133)
      chem( 52) = chem( 52) +  0.8060000000000000D+00 * w(133)
      chem( 69) = chem( 69) - w(133)
      chem( 70) = chem( 70) +  0.4500000000000000D+00 * w(133)
      chem( 74) = chem( 74) + w(133)
      chem( 79) = chem( 79) +  0.2000000000000000D+01 * w(133)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(134)
      chem( 69) = chem( 69) - w(134)
      chem( 70) = chem( 70) +  0.5500000000000000D-01 * w(134)
      chem( 71) = chem( 71) +  0.4450000000000000D+00 * w(134)
      chem( 74) = chem( 74) +  0.5000000000000000D+00 * w(134)
      chem( 76) = chem( 76) +  0.4750000000000000D+00 * w(134)
      chem( 77) = chem( 77) - w(134)
      chem( 78) = chem( 78) + w(134)
      chem( 79) = chem( 79) +  0.4600000000000000D+00 * w(134)
      chem( 82) = chem( 82) +  0.2500000000000000D-01 * w(134)
      chem( 63) = chem( 63) - w(135)
      chem( 67) = chem( 67) + w(135)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(135)
      chem( 69) = chem( 69) +  0.5000000000000000D+00 * w(135)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w(135)
      chem( 82) = chem( 82) - w(135)
      chem( 62) = chem( 62) +  0.6850000000000001D+00 * w(136)
      chem( 66) = chem( 66) - w(136)
      chem( 67) = chem( 67) +  0.3150000000000000D+00 * w(136)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(136)
      chem( 69) = chem( 69) +  0.5000000000000000D+00 * w(136)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w(136)
      chem( 82) = chem( 82) - w(136)
      chem( 35) = chem( 35) - w(137)
      chem( 62) = chem( 62) +  0.5770000000000000D+00 * w(137)
      chem( 67) = chem( 67) +  0.7690000000000000D+00 * w(137)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(137)
      chem( 69) = chem( 69) +  0.5000000000000000D+00 * w(137)
      chem( 74) = chem( 74) +  0.1000000000000000D-02 * w(137)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w(137)
      chem( 82) = chem( 82) - w(137)
      chem( 39) = chem( 39) - w(138)
      chem( 62) = chem( 62) +  0.1400000000000000D+01 * w(138)
      chem( 67) = chem( 67) +  0.4600000000000000D+00 * w(138)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(138)
      chem( 69) = chem( 69) +  0.5000000000000000D+00 * w(138)
      chem( 74) = chem( 74) +  0.5300000000000000D-01 * w(138)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w(138)
      chem( 82) = chem( 82) - w(138)
      chem( 41) = chem( 41) - w(139)
      chem( 67) = chem( 67) +  0.2000000000000000D+00 * w(139)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(139)
      chem( 69) = chem( 69) +  0.5000000000000000D+00 * w(139)
      chem( 74) = chem( 74) +  0.1600000000000000D+01 * w(139)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w(139)
      chem( 82) = chem( 82) - w(139)
      chem( 46) = chem( 46) - w(140)
      chem( 67) = chem( 67) + w(140)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(140)
      chem( 69) = chem( 69) +  0.5000000000000000D+00 * w(140)
      chem( 74) = chem( 74) +  0.5000000000000000D+00 * w(140)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w(140)
      chem( 82) = chem( 82) - w(140)
      chem( 54) = chem( 54) - w(141)
      chem( 62) = chem( 62) +  0.5500000000000000D+00 * w(141)
      chem( 67) = chem( 67) +  0.7250000000000000D+00 * w(141)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(141)
      chem( 69) = chem( 69) +  0.5000000000000000D+00 * w(141)
      chem( 74) = chem( 74) +  0.1400000000000000D+00 * w(141)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w(141)
      chem( 82) = chem( 82) - w(141)
      chem( 64) = chem( 64) - w(142)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(142)
      chem( 69) = chem( 69) +  0.5000000000000000D+00 * w(142)
      chem( 70) = chem( 70) + w(142)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w(142)
      chem( 82) = chem( 82) - w(142)
      chem( 69) = chem( 69) +  0.2000000000000000D+01 * w(143)
      chem( 82) = chem( 82) -  0.2000000000000000D+01 * w(143)
      chem( 47) = chem( 47) - w(144)
      chem( 52) = chem( 52) +  0.7000000000000000D+00 * w(144)
      chem( 69) = chem( 69) + w(144)
      chem( 70) = chem( 70) +  0.1700000000000000D+00 * w(144)
      chem( 71) = chem( 71) +  0.1600000000000000D+00 * w(144)
      chem( 79) = chem( 79) + w(144)
      chem( 82) = chem( 82) - w(144)
      chem( 48) = chem( 48) - w(145)
      chem( 52) = chem( 52) +  0.8060000000000000D+00 * w(145)
      chem( 69) = chem( 69) + w(145)
      chem( 70) = chem( 70) +  0.4500000000000000D+00 * w(145)
      chem( 79) = chem( 79) + w(145)
      chem( 82) = chem( 82) - w(145)
      chem( 69) = chem( 69) + w(146)
      chem( 70) = chem( 70) +  0.1100000000000000D+00 * w(146)
      chem( 71) = chem( 71) +  0.8900000000000000D+00 * w(146)
      chem( 76) = chem( 76) +  0.9500000000000000D+00 * w(146)
      chem( 77) = chem( 77) - w(146)
      chem( 78) = chem( 78) +  0.2000000000000000D+01 * w(146)
      chem( 79) = chem( 79) +  0.9200000000000000D+00 * w(146)
      chem( 82) = chem( 82) -  0.9500000000000000D+00 * w(146)
      chem( 65) = chem( 65) + w(147)
      chem( 78) = chem( 78) - w(147)
      chem( 79) = chem( 79) - w(147)
      chem( 69) = chem( 69) - w(148)
      chem( 74) = chem( 74) + w(148)
      chem( 78) = chem( 78) - w(148)
      chem( 79) = chem( 79) + w(148)
      chem( 69) = chem( 69) + w(149)
      chem( 78) = chem( 78) - w(149)
      chem( 82) = chem( 82) - w(149)
      chem( 78) = chem( 78) -  0.2000000000000000D+01 * w(150)
      chem( 78) = chem( 78) - w(151)
      chem( 80) = chem( 80) - w(151)
      chem( 81) = chem( 81) + w(151)
      chem( 53) = chem( 53) - w(152)
      chem( 61) = chem( 61) + w(152)
      chem( 81) = chem( 81) - w(152)
      chem( 53) = chem( 53) - w(153)
      chem( 65) = chem( 65) + w(153)
      chem( 79) = chem( 79) - w(153)
      chem( 53) = chem( 53) - w(154)
      chem( 69) = chem( 69) - w(154)
      chem( 74) = chem( 74) + w(154)
      chem( 79) = chem( 79) + w(154)
      chem( 53) = chem( 53) - w(155)
      chem( 69) = chem( 69) + w(155)
      chem( 82) = chem( 82) - w(155)
      chem( 53) = chem( 53) -  0.2000000000000000D+01 * w(156)
      chem( 60) = chem( 60) - w(157)
      chem( 67) = chem( 67) + w(157)
      chem( 69) = chem( 69) - w(157)
      chem( 74) = chem( 74) +  0.1750000000000000D+01 * w(157)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w(157)
      chem( 81) = chem( 81) + w(157)
      chem( 60) = chem( 60) - w(158)
      chem( 67) = chem( 67) + w(158)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(158)
      chem( 69) = chem( 69) +  0.5000000000000000D+00 * w(158)
      chem( 74) = chem( 74) + w(158)
      chem( 81) = chem( 81) + w(158)
      chem( 82) = chem( 82) - w(158)
      chem( 60) = chem( 60) -  0.2000000000000000D+01 * w(159)
      chem( 67) = chem( 67) +  0.2000000000000000D+01 * w(159)
      chem( 74) = chem( 74) +  0.2000000000000000D+01 * w(159)
      chem( 81) = chem( 81) +  0.2000000000000000D+01 * w(159)
      chem( 49) = chem( 49) +  0.6000000000000000D+00 * w(160)
      chem( 57) = chem( 57) - w(160)
      chem( 74) = chem( 74) +  0.4000000000000000D+00 * w(160)
      chem( 75) = chem( 75) - w(160)
      chem( 82) = chem( 82) +  0.4000000000000000D+00 * w(160)
      chem( 50) = chem( 50) - w(161)
      chem( 51) = chem( 51) + w(161)
      chem( 75) = chem( 75) - w(161)
      chem( 33) = chem( 33) - w(162)
      chem( 69) = chem( 69) +  0.4000000000000000D+00 * w(162)
      chem( 71) = chem( 71) + w(162)
      chem( 75) = chem( 75) - w(162)
      chem( 79) = chem( 79) +  0.6000000000000000D+00 * w(162)
      chem( 30) = chem( 30) - w(163)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(163)
      chem( 69) = chem( 69) +  0.9000000000000000D+00 * w(163)
      chem( 74) = chem( 74) +  0.5000000000000000D+00 * w(163)
      chem( 75) = chem( 75) - w(163)
      chem( 79) = chem( 79) +  0.1000000000000000D+00 * w(163)
      chem( 32) = chem( 32) +  0.4400000000000000D+00 * w(164)
      chem( 34) = chem( 34) +  0.7000000000000001D-01 * w(164)
      chem( 57) = chem( 57) - w(164)
      chem( 58) = chem( 58) - w(164)
      chem( 68) = chem( 68) +  0.9000000000000000D-01 * w(164)
      chem( 70) = chem( 70) +  0.9100000000000000D+00 * w(164)
      chem( 74) = chem( 74) +  0.8000000000000000D+00 * w(164)
      chem( 75) = chem( 75) +  0.5400000000000000D+00 * w(164)
      chem( 32) = chem( 32) +  0.4400000000000000D+00 * w(165)
      chem( 34) = chem( 34) +  0.7000000000000001D-01 * w(165)
      chem( 50) = chem( 50) - w(165)
      chem( 58) = chem( 58) - w(165)
      chem( 67) = chem( 67) +  0.8000000000000000D-01 * w(165)
      chem( 68) = chem( 68) +  0.7000000000000001D-01 * w(165)
      chem( 70) = chem( 70) +  0.8500000000000000D+00 * w(165)
      chem( 74) = chem( 74) +  0.8000000000000000D+00 * w(165)
      chem( 75) = chem( 75) +  0.4200000000000000D+00 * w(165)
      chem( 30) = chem( 30) +  0.1200000000000000D+00 * w(166)
      chem( 33) = chem( 33) +  0.9000000000000000D-01 * w(166)
      chem( 44) = chem( 44) - w(166)
      chem( 50) = chem( 50) +  0.3800000000000000D+00 * w(166)
      chem( 57) = chem( 57) +  0.2800000000000000D+00 * w(166)
      chem( 61) = chem( 61) +  0.1200000000000000D+00 * w(166)
      chem( 68) = chem( 68) +  0.2000000000000000D-01 * w(166)
      chem( 70) = chem( 70) +  0.9000000000000000D-01 * w(166)
      chem( 71) = chem( 71) +  0.1000000000000000D+00 * w(166)
      chem( 74) = chem( 74) +  0.6200000000000000D+00 * w(166)
      chem( 75) = chem( 75) +  0.1100000000000000D+00 * w(166)
      chem( 79) = chem( 79) +  0.8800000000000000D+00 * w(166)
      chem( 80) = chem( 80) - w(166)
      chem( 81) = chem( 81) +  0.8800000000000000D+00 * w(166)
      chem( 30) = chem( 30) +  0.8000000000000000D+00 * w(167)
      chem( 49) = chem( 49) - w(167)
      chem( 70) = chem( 70) +  0.2000000000000000D+00 * w(167)
      chem( 74) = chem( 74) +  0.2000000000000000D+00 * w(167)
      chem( 79) = chem( 79) + w(167)
      chem( 80) = chem( 80) - w(167)
      chem( 81) = chem( 81) + w(167)
      chem( 33) = chem( 33) +  0.8000000000000000D+00 * w(168)
      chem( 51) = chem( 51) - w(168)
      chem( 70) = chem( 70) +  0.3000000000000000D+00 * w(168)
      chem( 74) = chem( 74) +  0.3000000000000000D+00 * w(168)
      chem( 79) = chem( 79) +  0.3000000000000000D+00 * w(168)
      chem( 80) = chem( 80) - w(168)
      chem( 81) = chem( 81) + w(168)
      chem( 82) = chem( 82) +  0.7000000000000000D+00 * w(168)
      chem( 23) = chem( 23) - w(169)
      chem( 50) = chem( 50) +  0.5000000000000000D+00 * w(169)
      chem( 57) = chem( 57) +  0.5000000000000000D+00 * w(169)
      chem( 74) = chem( 74) + w(169)
      chem( 80) = chem( 80) - w(169)
      chem( 81) = chem( 81) +  0.2000000000000000D+01 * w(169)
      chem( 44) = chem( 44) - w(170)
      chem( 65) = chem( 65) + w(170)
      chem( 79) = chem( 79) - w(170)
      chem( 49) = chem( 49) - w(171)
      chem( 65) = chem( 65) + w(171)
      chem( 79) = chem( 79) - w(171)
      chem( 51) = chem( 51) - w(172)
      chem( 65) = chem( 65) + w(172)
      chem( 79) = chem( 79) - w(172)
      chem( 30) = chem( 30) +  0.2200000000000000D+00 * w(173)
      chem( 33) = chem( 33) +  0.1600000000000000D+00 * w(173)
      chem( 44) = chem( 44) -  0.2000000000000000D+01 * w(173)
      chem( 45) = chem( 45) +  0.3000000000000000D+00 * w(173)
      chem( 50) = chem( 50) +  0.5000000000000000D+00 * w(173)
      chem( 52) = chem( 52) +  0.6000000000000000D-01 * w(173)
      chem( 57) = chem( 57) +  0.3700000000000000D+00 * w(173)
      chem( 59) = chem( 59) +  0.1000000000000000D+00 * w(173)
      chem( 68) = chem( 68) +  0.4000000000000000D-01 * w(173)
      chem( 70) = chem( 70) +  0.1600000000000000D+00 * w(173)
      chem( 71) = chem( 71) +  0.1800000000000000D+00 * w(173)
      chem( 74) = chem( 74) +  0.5000000000000000D+00 * w(173)
      chem( 75) = chem( 75) +  0.2000000000000000D+00 * w(173)
      chem( 79) = chem( 79) +  0.1600000000000000D+01 * w(173)
      chem( 50) = chem( 50) - w(174)
      chem( 51) = chem( 51) + w(174)
      chem( 73) = chem( 73) - w(174)
      chem( 81) = chem( 81) + w(174)
      chem( 49) = chem( 49) +  0.7000000000000000D+00 * w(175)
      chem( 57) = chem( 57) - w(175)
      chem( 72) = chem( 72) +  0.3000000000000000D+00 * w(175)
      chem( 73) = chem( 73) - w(175)
      chem( 77) = chem( 77) +  0.3000000000000000D+00 * w(175)
      chem( 81) = chem( 81) +  0.7000000000000000D+00 * w(175)
      chem( 44) = chem( 44) - w(176)
      chem( 45) = chem( 45) +  0.4000000000000000D+00 * w(176)
      chem( 50) = chem( 50) +  0.3000000000000000D+00 * w(176)
      chem( 51) = chem( 51) - w(176)
      chem( 52) = chem( 52) +  0.1000000000000000D+00 * w(176)
      chem( 57) = chem( 57) +  0.3000000000000000D+00 * w(176)
      chem( 59) = chem( 59) +  0.3000000000000000D+00 * w(176)
      chem( 70) = chem( 70) +  0.6000000000000000D+00 * w(176)
      chem( 74) = chem( 74) + w(176)
      chem( 79) = chem( 79) +  0.1200000000000000D+01 * w(176)
      chem( 44) = chem( 44) - w(177)
      chem( 45) = chem( 45) +  0.4000000000000000D+00 * w(177)
      chem( 49) = chem( 49) - w(177)
      chem( 50) = chem( 50) +  0.3000000000000000D+00 * w(177)
      chem( 52) = chem( 52) +  0.1000000000000000D+00 * w(177)
      chem( 57) = chem( 57) +  0.3000000000000000D+00 * w(177)
      chem( 59) = chem( 59) +  0.3000000000000000D+00 * w(177)
      chem( 70) = chem( 70) +  0.6000000000000000D+00 * w(177)
      chem( 74) = chem( 74) + w(177)
      chem( 79) = chem( 79) +  0.1200000000000000D+01 * w(177)
      chem(  7) = chem(  7) - w(178)
      chem( 36) = chem( 36) + w(178)
      chem( 75) = chem( 75) - w(178)
      chem( 78) = chem( 78) +  0.7440000000000000D+00 * w(178)
      chem(  8) = chem(  8) - w(179)
      chem( 37) = chem( 37) + w(179)
      chem( 75) = chem( 75) - w(179)
      chem( 78) = chem( 78) +  0.5440000000000000D+00 * w(179)
      chem(  9) = chem(  9) - w(180)
      chem( 38) = chem( 38) + w(180)
      chem( 75) = chem( 75) - w(180)
      chem( 78) = chem( 78) +  0.7340000000000000D+00 * w(180)
      chem( 11) = chem( 11) - w(181)
      chem( 40) = chem( 40) +  0.7000000000000000D+00 * w(181)
      chem( 75) = chem( 75) - w(181)
      chem( 79) = chem( 79) +  0.3000000000000000D+00 * w(181)
      chem( 20) = chem( 20) - w(182)
      chem( 42) = chem( 42) + w(182)
      chem( 75) = chem( 75) - w(182)
      chem( 21) = chem( 21) - w(183)
      chem( 43) = chem( 43) + w(183)
      chem( 75) = chem( 75) - w(183)
      chem( 36) = chem( 36) - w(184)
      chem( 61) = chem( 61) +  0.2700000000000000D-01 * w(184)
      chem( 62) = chem( 62) +  0.7440000000000000D+00 * w(184)
      chem( 67) = chem( 67) +  0.2990000000000000D+00 * w(184)
      chem( 74) = chem( 74) +  0.7440000000000000D+00 * w(184)
      chem( 79) = chem( 79) +  0.9730000000000000D+00 * w(184)
      chem( 80) = chem( 80) - w(184)
      chem( 81) = chem( 81) +  0.9730000000000000D+00 * w(184)
      chem( 37) = chem( 37) - w(185)
      chem( 61) = chem( 61) +  0.2700000000000000D-01 * w(185)
      chem( 62) = chem( 62) +  0.9290000000000000D+00 * w(185)
      chem( 67) = chem( 67) +  0.2520000000000000D+00 * w(185)
      chem( 74) = chem( 74) +  0.7000000000000000D-02 * w(185)
      chem( 79) = chem( 79) +  0.8800000000000000D+00 * w(185)
      chem( 80) = chem( 80) - w(185)
      chem( 81) = chem( 81) +  0.8800000000000000D+00 * w(185)
      chem( 38) = chem( 38) - w(186)
      chem( 61) = chem( 61) +  0.1200000000000000D+00 * w(186)
      chem( 62) = chem( 62) +  0.9140000000000000D+00 * w(186)
      chem( 67) = chem( 67) +  0.7470000000000000D+00 * w(186)
      chem( 79) = chem( 79) +  0.9330000000000001D+00 * w(186)
      chem( 80) = chem( 80) - w(186)
      chem( 81) = chem( 81) +  0.8800000000000000D+00 * w(186)
      chem( 40) = chem( 40) - w(187)
      chem( 71) = chem( 71) + w(187)
      chem( 79) = chem( 79) + w(187)
      chem( 80) = chem( 80) - w(187)
      chem( 81) = chem( 81) + w(187)
      chem( 42) = chem( 42) - w(188)
      chem( 67) = chem( 67) + w(188)
      chem( 74) = chem( 74) + w(188)
      chem( 79) = chem( 79) + w(188)
      chem( 80) = chem( 80) - w(188)
      chem( 81) = chem( 81) + w(188)
      chem( 43) = chem( 43) - w(189)
      chem( 67) = chem( 67) + w(189)
      chem( 74) = chem( 74) + w(189)
      chem( 79) = chem( 79) + w(189)
      chem( 80) = chem( 80) - w(189)
      chem( 81) = chem( 81) + w(189)
      chem( 20) = chem( 20) - w(190)
      chem( 60) = chem( 60) + w(190)
      chem( 73) = chem( 73) - w(190)
      chem( 21) = chem( 21) - w(191)
      chem( 60) = chem( 60) + w(191)
      chem( 73) = chem( 73) - w(191)
      chem( 20) = chem( 20) - w(192)
      chem( 34) = chem( 34) +  0.1430000000000000D+00 * w(192)
      chem( 58) = chem( 58) - w(192)
      chem( 62) = chem( 62) +  0.1400000000000000D+00 * w(192)
      chem( 67) = chem( 67) +  0.5000000000000000D+00 * w(192)
      chem( 68) = chem( 68) +  0.1430000000000000D+00 * w(192)
      chem( 69) = chem( 69) +  0.1350000000000000D+00 * w(192)
      chem( 74) = chem( 74) +  0.6500000000000000D+00 * w(192)
      chem( 75) = chem( 75) +  0.6000000000000000D-01 * w(192)
      chem( 76) = chem( 76) +  0.2950000000000000D+00 * w(192)
      chem( 79) = chem( 79) +  0.1650000000000000D+00 * w(192)
      chem( 21) = chem( 21) - w(193)
      chem( 34) = chem( 34) +  0.1430000000000000D+00 * w(193)
      chem( 58) = chem( 58) - w(193)
      chem( 62) = chem( 62) +  0.2100000000000000D+00 * w(193)
      chem( 67) = chem( 67) +  0.6500000000000000D+00 * w(193)
      chem( 68) = chem( 68) +  0.1430000000000000D+00 * w(193)
      chem( 69) = chem( 69) +  0.1350000000000000D+00 * w(193)
      chem( 74) = chem( 74) +  0.5000000000000000D+00 * w(193)
      chem( 75) = chem( 75) +  0.6000000000000000D-01 * w(193)
      chem( 76) = chem( 76) +  0.2950000000000000D+00 * w(193)
      chem( 79) = chem( 79) +  0.1650000000000000D+00 * w(193)
      chem( 36) = chem( 36) - w(194)
      chem( 65) = chem( 65) + w(194)
      chem( 79) = chem( 79) - w(194)
      chem( 37) = chem( 37) - w(195)
      chem( 65) = chem( 65) + w(195)
      chem( 79) = chem( 79) - w(195)
      chem( 38) = chem( 38) - w(196)
      chem( 65) = chem( 65) + w(196)
      chem( 79) = chem( 79) - w(196)
      chem( 40) = chem( 40) - w(197)
      chem( 65) = chem( 65) + w(197)
      chem( 79) = chem( 79) - w(197)
      chem( 42) = chem( 42) - w(198)
      chem( 65) = chem( 65) + w(198)
      chem( 79) = chem( 79) - w(198)
      chem( 43) = chem( 43) - w(199)
      chem( 65) = chem( 65) + w(199)
      chem( 79) = chem( 79) - w(199)
      chem( 36) = chem( 36) - w(200)
      chem( 62) = chem( 62) +  0.7650000000000000D+00 * w(200)
      chem( 67) = chem( 67) +  0.1760000000000000D+00 * w(200)
      chem( 69) = chem( 69) - w(200)
      chem( 74) = chem( 74) +  0.1320000000000000D+01 * w(200)
      chem( 79) = chem( 79) + w(200)
      chem( 37) = chem( 37) - w(201)
      chem( 62) = chem( 62) +  0.7920000000000000D+00 * w(201)
      chem( 67) = chem( 67) +  0.2150000000000000D+00 * w(201)
      chem( 69) = chem( 69) - w(201)
      chem( 74) = chem( 74) +  0.7650000000000000D+00 * w(201)
      chem( 79) = chem( 79) + w(201)
      chem( 38) = chem( 38) - w(202)
      chem( 62) = chem( 62) +  0.7350000000000000D+00 * w(202)
      chem( 67) = chem( 67) +  0.6010000000000000D+00 * w(202)
      chem( 69) = chem( 69) - w(202)
      chem( 74) = chem( 74) +  0.7500000000000000D+00 * w(202)
      chem( 79) = chem( 79) + w(202)
      chem( 40) = chem( 40) - w(203)
      chem( 69) = chem( 69) - w(203)
      chem( 71) = chem( 71) +  0.7500000000000000D+00 * w(203)
      chem( 74) = chem( 74) +  0.7500000000000000D+00 * w(203)
      chem( 79) = chem( 79) + w(203)
      chem( 42) = chem( 42) - w(204)
      chem( 67) = chem( 67) +  0.7500000000000000D+00 * w(204)
      chem( 69) = chem( 69) - w(204)
      chem( 74) = chem( 74) +  0.1500000000000000D+01 * w(204)
      chem( 79) = chem( 79) + w(204)
      chem( 43) = chem( 43) - w(205)
      chem( 67) = chem( 67) +  0.7500000000000000D+00 * w(205)
      chem( 69) = chem( 69) - w(205)
      chem( 74) = chem( 74) +  0.1500000000000000D+01 * w(205)
      chem( 79) = chem( 79) + w(205)
      chem( 36) = chem( 36) - w(206)
      chem( 62) = chem( 62) +  0.7650000000000000D+00 * w(206)
      chem( 67) = chem( 67) +  0.2350000000000000D+00 * w(206)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(206)
      chem( 69) = chem( 69) +  0.5000000000000000D+00 * w(206)
      chem( 74) = chem( 74) +  0.7650000000000000D+00 * w(206)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w(206)
      chem( 82) = chem( 82) - w(206)
      chem( 37) = chem( 37) - w(207)
      chem( 62) = chem( 62) +  0.1060000000000000D+00 * w(207)
      chem( 67) = chem( 67) +  0.2860000000000000D+00 * w(207)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(207)
      chem( 69) = chem( 69) +  0.5000000000000000D+00 * w(207)
      chem( 74) = chem( 74) +  0.8000000000000000D-02 * w(207)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w(207)
      chem( 82) = chem( 82) - w(207)
      chem( 38) = chem( 38) - w(208)
      chem( 62) = chem( 62) +  0.9860000000000000D+00 * w(208)
      chem( 67) = chem( 67) +  0.8010000000000000D+00 * w(208)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(208)
      chem( 69) = chem( 69) +  0.5000000000000000D+00 * w(208)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w(208)
      chem( 82) = chem( 82) - w(208)
      chem( 40) = chem( 40) - w(209)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(209)
      chem( 69) = chem( 69) +  0.5000000000000000D+00 * w(209)
      chem( 71) = chem( 71) + w(209)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w(209)
      chem( 82) = chem( 82) - w(209)
      chem( 42) = chem( 42) - w(210)
      chem( 67) = chem( 67) + w(210)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(210)
      chem( 69) = chem( 69) +  0.5000000000000000D+00 * w(210)
      chem( 74) = chem( 74) + w(210)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w(210)
      chem( 82) = chem( 82) - w(210)
      chem( 43) = chem( 43) - w(211)
      chem( 67) = chem( 67) + w(211)
      chem( 68) = chem( 68) +  0.5000000000000000D+00 * w(211)
      chem( 69) = chem( 69) +  0.5000000000000000D+00 * w(211)
      chem( 74) = chem( 74) + w(211)
      chem( 79) = chem( 79) +  0.5000000000000000D+00 * w(211)
      chem( 82) = chem( 82) - w(211)
      chem( 24) = chem( 24) - w(212)
      chem( 55) = chem( 55) + w(212)
      chem( 75) = chem( 75) - w(212)
      chem( 24) = chem( 24) - w(213)
      chem( 60) = chem( 60) + w(213)
      chem( 73) = chem( 73) - w(213)
      chem( 24) = chem( 24) - w(214)
      chem( 29) = chem( 29) +  0.2000000000000000D-01 * w(214)
      chem( 58) = chem( 58) - w(214)
      chem( 62) = chem( 62) +  0.5300000000000000D+00 * w(214)
      chem( 63) = chem( 63) +  0.2000000000000000D+00 * w(214)
      chem( 64) = chem( 64) +  0.4200000000000000D+00 * w(214)
      chem( 67) = chem( 67) +  0.6500000000000000D+00 * w(214)
      chem( 75) = chem( 75) +  0.8500000000000000D+00 * w(214)
      chem( 76) = chem( 76) +  0.1400000000000000D+00 * w(214)
      chem( 79) = chem( 79) +  0.1000000000000000D+00 * w(214)
      chem( 55) = chem( 55) - w(215)
      chem( 61) = chem( 61) +  0.2000000000000000D+00 * w(215)
      chem( 62) = chem( 62) +  0.8000000000000000D+00 * w(215)
      chem( 67) = chem( 67) +  0.8000000000000000D+00 * w(215)
      chem( 79) = chem( 79) +  0.8000000000000000D+00 * w(215)
      chem( 80) = chem( 80) - w(215)
      chem( 81) = chem( 81) +  0.8000000000000000D+00 * w(215)
      chem( 55) = chem( 55) - w(216)
      chem( 65) = chem( 65) + w(216)
      chem( 79) = chem( 79) - w(216)
      chem( 55) = chem( 55) - w(217)
      chem( 62) = chem( 62) + w(217)
      chem( 67) = chem( 67) + w(217)
      chem( 69) = chem( 69) - w(217)
      chem( 74) = chem( 74) + w(217)
      chem( 79) = chem( 79) +  0.2000000000000000D+01 * w(217)
      chem( 55) = chem( 55) - w(218)
      chem( 62) = chem( 62) + w(218)
      chem( 67) = chem( 67) + w(218)
      chem( 69) = chem( 69) + w(218)
      chem( 79) = chem( 79) + w(218)
      chem( 82) = chem( 82) - w(218)
      chem( 55) = chem( 55) - w(219)
      chem( 62) = chem( 62) + w(219)
      chem( 67) = chem( 67) + w(219)
      chem( 73) = chem( 73) - w(219)
      chem( 79) = chem( 79) + w(219)
      chem( 81) = chem( 81) + w(219)
      chem( 25) = chem( 25) - w(220)
      chem( 56) = chem( 56) + w(220)
      chem( 75) = chem( 75) - w(220)
      chem( 25) = chem( 25) - w(221)
      chem( 60) = chem( 60) + w(221)
      chem( 73) = chem( 73) - w(221)
      chem( 25) = chem( 25) - w(222)
      chem( 29) = chem( 29) +  0.2000000000000000D-01 * w(222)
      chem( 34) = chem( 34) +  0.1000000000000000D-01 * w(222)
      chem( 45) = chem( 45) +  0.4600000000000000D+00 * w(222)
      chem( 57) = chem( 57) +  0.7900000000000000D+00 * w(222)
      chem( 58) = chem( 58) - w(222)
      chem( 63) = chem( 63) +  0.1600000000000000D+00 * w(222)
      chem( 64) = chem( 64) +  0.4200000000000000D+00 * w(222)
      chem( 68) = chem( 68) +  0.7000000000000001D-01 * w(222)
      chem( 74) = chem( 74) +  0.4000000000000000D-01 * w(222)
      chem( 75) = chem( 75) +  0.8500000000000000D+00 * w(222)
      chem( 76) = chem( 76) +  0.1400000000000000D+00 * w(222)
      chem( 79) = chem( 79) +  0.1000000000000000D+00 * w(222)
      chem( 56) = chem( 56) - w(223)
      chem( 57) = chem( 57) +  0.4000000000000000D+00 * w(223)
      chem( 59) = chem( 59) +  0.2500000000000000D+00 * w(223)
      chem( 61) = chem( 61) +  0.3500000000000000D+00 * w(223)
      chem( 74) = chem( 74) +  0.2500000000000000D+00 * w(223)
      chem( 79) = chem( 79) +  0.6500000000000000D+00 * w(223)
      chem( 80) = chem( 80) - w(223)
      chem( 81) = chem( 81) +  0.6500000000000000D+00 * w(223)
      chem( 56) = chem( 56) - w(224)
      chem( 65) = chem( 65) + w(224)
      chem( 79) = chem( 79) - w(224)
      chem( 56) = chem( 56) - w(225)
      chem( 57) = chem( 57) +  0.6000000000000000D+00 * w(225)
      chem( 59) = chem( 59) +  0.4000000000000000D+00 * w(225)
      chem( 69) = chem( 69) - w(225)
      chem( 74) = chem( 74) +  0.1400000000000000D+01 * w(225)
      chem( 79) = chem( 79) +  0.2000000000000000D+01 * w(225)
      chem( 56) = chem( 56) - w(226)
      chem( 57) = chem( 57) +  0.6000000000000000D+00 * w(226)
      chem( 59) = chem( 59) +  0.4000000000000000D+00 * w(226)
      chem( 69) = chem( 69) + w(226)
      chem( 74) = chem( 74) +  0.4000000000000000D+00 * w(226)
      chem( 79) = chem( 79) + w(226)
      chem( 82) = chem( 82) - w(226)
      chem( 56) = chem( 56) - w(227)
      chem( 57) = chem( 57) +  0.6000000000000000D+00 * w(227)
      chem( 59) = chem( 59) +  0.4000000000000000D+00 * w(227)
      chem( 73) = chem( 73) - w(227)
      chem( 74) = chem( 74) +  0.4000000000000000D+00 * w(227)
      chem( 79) = chem( 79) + w(227)
      chem( 81) = chem( 81) + w(227)
      chem( 58) = chem( 58) + w(228)
      chem( 68) = chem( 68) + w(228)
      chem( 79) = chem( 79) - w(228)
      chem( 82) = chem( 82) - w(228)
      
C     Volumic source terms.
      
      IF(LSOURC)THEN
         do i=1,nesp
            chem(i)=chem(i)+ZCsourc(i)
         enddo
      endif
      
      RETURN
      END
      
