      subroutine kinetic(rk,temp,xlw,Press,azi,att)
      
C------------------------------------------------------------------------
C     
C     -- DESCRIPTION
C     
C     This routine computes the kinetic rates for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: EURORADM            
C     Species: _ciEURORADM         
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     TEMP: temperature ([K]).
C     XLW: water massic fraction.
C     PRESS: pressure ([Pa]).
C     AZI: zenithal angle ([degree]).
C     ATT: attenuation variable.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     RK: kinetic rates.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     SPACK.
C     
C------------------------------------------------------------------------
      
      implicit none
      
C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of chemical arrays.
C     COMUSE: flags and parameters for numerics.
C     COMDATA: global variables for chemicaldata (e.g. molar mass).
C     COMCHEM: global variables for chemical species.
      
      include 'PARACHEM.INC' 
      include 'COMUSE.INC' 
      INCLUDE 'PARADOM.INC'  
      include 'COMDATA.INC' 
      include 'COMCHEM.INC' 
      
      double precision rk(nr),temp,xlw,Press
      double precision Effko,Rapk,facteur,SumM,Fcent,azi,att
      double precision YlH2O,VO2,VN2,VH2O
      integer j,k
      
C     Compute third body.
C     Conversion = Avogadro*1d-6/Perfect gas constant.
C     PRESS in Pascal, SUMM in molecules/cm3, TEMP in Kelvin
      
      SumM = Press * 7.243D16 / temp
      
C     Number of water molecules computed from the massic fraction
C     (absolute humidity)
      
      YlH2O = 29.d0*SumM*xlw/(18.d0+11.d0*xlw)
      
C     For the zenithal angle at tropics
      
      azi=abs(azi)
      
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk(  1)=-0.1302720567168785D-07
         rk(  1)=-0.7822279432831320D-06+(azi- 0.00D+00) * rk(  1)
         rk(  1)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  1)
         rk(  1)= 0.9310260000000001D-02+(azi- 0.00D+00) * rk(  1)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk(  1)= 0.3771617015066826D-08
         rk(  1)=-0.1173044113433767D-05+(azi- 0.10D+02) * rk(  1)
         rk(  1)=-0.1955272056716900D-04+(azi- 0.10D+02) * rk(  1)
         rk(  1)= 0.9219010000000000D-02+(azi- 0.10D+02) * rk(  1)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk(  1)=-0.5859262388581099D-08
         rk(  1)=-0.1059895602981763D-05+(azi- 0.20D+02) * rk(  1)
         rk(  1)=-0.4188211773132430D-04+(azi- 0.20D+02) * rk(  1)
         rk(  1)= 0.8909950000000000D-02+(azi- 0.20D+02) * rk(  1)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk(  1)=-0.7024567460740303D-08
         rk(  1)=-0.1235673474639197D-05+(azi- 0.30D+02) * rk(  1)
         rk(  1)=-0.6483780850753389D-04+(azi- 0.30D+02) * rk(  1)
         rk(  1)= 0.8379279999999999D-02+(azi- 0.30D+02) * rk(  1)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk(  1)=-0.9202467768460965D-08
         rk(  1)=-0.1446410498461400D-05+(azi- 0.40D+02) * rk(  1)
         rk(  1)=-0.9165864823853991D-04+(azi- 0.40D+02) * rk(  1)
         rk(  1)= 0.7600310000000000D-02+(azi- 0.40D+02) * rk(  1)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk(  1)=-0.1612556146542510D-07
         rk(  1)=-0.1722484531515181D-05+(azi- 0.50D+02) * rk(  1)
         rk(  1)=-0.1233475985383055D-03+(azi- 0.50D+02) * rk(  1)
         rk(  1)= 0.6529880000000000D-02+(azi- 0.50D+02) * rk(  1)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(  1)= 0.3226471363014276D-07
         rk(  1)=-0.2206251375477955D-05+(azi- 0.60D+02) * rk(  1)
         rk(  1)=-0.1626349576082373D-03+(azi- 0.60D+02) * rk(  1)
         rk(  1)= 0.5108030000000000D-02+(azi- 0.60D+02) * rk(  1)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk(  1)= 0.2027078243960827D-06
         rk(  1)=-0.1238309966573864D-05+(azi- 0.70D+02) * rk(  1)
         rk(  1)=-0.1970805710287607D-03+(azi- 0.70D+02) * rk(  1)
         rk(  1)= 0.3293320000000000D-02+(azi- 0.70D+02) * rk(  1)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk(  1)=-0.7448311471156531D-07
         rk(  1)= 0.3626677818929516D-05+(azi- 0.78D+02) * rk(  1)
         rk(  1)=-0.1779736282098987D-03+(azi- 0.78D+02) * rk(  1)
         rk(  1)= 0.1741210000000000D-02+(azi- 0.78D+02) * rk(  1)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk(  1)= 0.2490309929267534D-05
         rk(  1)= 0.1839083065848481D-05+(azi- 0.86D+02) * rk(  1)
         rk(  1)=-0.1342475411317025D-03+(azi- 0.86D+02) * rk(  1)
         rk(  1)= 0.5113930000000000D-03+(azi- 0.86D+02) * rk(  1)
      elseif(azi.ge.90.D0)then
         rk(  1)= 0.1632080000000000D-03
      endif
      if(att.lt.0.99999) rk(  1) = rk(  1) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk(  2)=-0.8776629099833271D-10
         rk(  2)=-0.1165033709001663D-07+(azi- 0.00D+00) * rk(  2)
         rk(  2)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  2)
         rk(  2)= 0.3523480000000000D-04+(azi- 0.00D+00) * rk(  2)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk(  2)= 0.1474988729949854D-09
         rk(  2)=-0.1428332581996661D-07+(azi- 0.10D+02) * rk(  2)
         rk(  2)=-0.2593366290998325D-06+(azi- 0.10D+02) * rk(  2)
         rk(  2)= 0.3398200000000000D-04+(azi- 0.10D+02) * rk(  2)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk(  2)= 0.1300707990183978D-09
         rk(  2)=-0.9858359630117046D-08+(azi- 0.20D+02) * rk(  2)
         rk(  2)=-0.5007534836006691D-06+(azi- 0.20D+02) * rk(  2)
         rk(  2)= 0.3010780000000000D-04+(azi- 0.20D+02) * rk(  2)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk(  2)= 0.1988179309314352D-09
         rk(  2)=-0.5956235659565153D-08+(azi- 0.30D+02) * rk(  2)
         rk(  2)=-0.6588994364974914D-06+(azi- 0.30D+02) * rk(  2)
         rk(  2)= 0.2424450000000000D-04+(azi- 0.30D+02) * rk(  2)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk(  2)= 0.2219574772558567D-09
         rk(  2)= 0.8302268377970103D-11+(azi- 0.40D+02) * rk(  2)
         rk(  2)=-0.7183787704093629D-06+(azi- 0.40D+02) * rk(  2)
         rk(  2)= 0.1725870000000000D-04+(azi- 0.40D+02) * rk(  2)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk(  2)= 0.1913521600450560D-09
         rk(  2)= 0.6667026586053825D-08+(azi- 0.50D+02) * rk(  2)
         rk(  2)=-0.6516254818650434D-06+(azi- 0.50D+02) * rk(  2)
         rk(  2)= 0.1029770000000000D-04+(azi- 0.50D+02) * rk(  2)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(  2)= 0.1602388256383848D-10
         rk(  2)= 0.1240759138740537D-07+(azi- 0.60D+02) * rk(  2)
         rk(  2)=-0.4608793021304573D-06+(azi- 0.60D+02) * rk(  2)
         rk(  2)= 0.4639500000000000D-05+(azi- 0.60D+02) * rk(  2)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk(  2)=-0.3089359890843757D-09
         rk(  2)= 0.1288830786432081D-07+(azi- 0.70D+02) * rk(  2)
         rk(  2)=-0.2079203096132002D-06+(azi- 0.70D+02) * rk(  2)
         rk(  2)= 0.1287490000000000D-05+(azi- 0.70D+02) * rk(  2)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk(  2)=-0.2034952628526878D-09
         rk(  2)= 0.5473844126316121D-08+(azi- 0.78D+02) * rk(  2)
         rk(  2)=-0.6102309368822491D-07+(azi- 0.78D+02) * rk(  2)
         rk(  2)= 0.2908040000000000D-06+(azi- 0.78D+02) * rk(  2)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk(  2)= 0.1623544915387105D-09
         rk(  2)= 0.5899578177432198D-09+(azi- 0.86D+02) * rk(  2)
         rk(  2)=-0.1251267813553324D-07+(azi- 0.86D+02) * rk(  2)
         rk(  2)= 0.4875570000000000D-07+(azi- 0.86D+02) * rk(  2)
      elseif(azi.ge.90.D0)then
         rk(  2)= 0.1853500000000000D-07
      endif
      if(att.lt.0.99999) rk(  2) = rk(  2) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk(  3)=-0.5928286648808027D-09
         rk(  3)=-0.3096171335119276D-07+(azi- 0.00D+00) * rk(  3)
         rk(  3)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  3)
         rk(  3)= 0.4927580000000000D-03+(azi- 0.00D+00) * rk(  3)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk(  3)= 0.1444859946426994D-09
         rk(  3)=-0.4874657329761684D-07+(azi- 0.10D+02) * rk(  3)
         rk(  3)=-0.7970828664880959D-06+(azi- 0.10D+02) * rk(  3)
         rk(  3)= 0.4890690000000000D-03+(azi- 0.10D+02) * rk(  3)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk(  3)=-0.5511531369017539D-10
         rk(  3)=-0.4441199345833588D-07+(azi- 0.20D+02) * rk(  3)
         rk(  3)=-0.1728668534047623D-05+(azi- 0.20D+02) * rk(  3)
         rk(  3)= 0.4763680000000000D-03+(azi- 0.20D+02) * rk(  3)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk(  3)=-0.3000247398819817D-09
         rk(  3)=-0.4606545286904117D-07+(azi- 0.30D+02) * rk(  3)
         rk(  3)=-0.2633442997321394D-05+(azi- 0.30D+02) * rk(  3)
         rk(  3)= 0.4545850000000000D-03+(azi- 0.30D+02) * rk(  3)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk(  3)=-0.2397857267816865D-09
         rk(  3)=-0.5506619506550068D-07+(azi- 0.40D+02) * rk(  3)
         rk(  3)=-0.3644759476666812D-05+(azi- 0.40D+02) * rk(  3)
         rk(  3)= 0.4233440000000000D-03+(azi- 0.40D+02) * rk(  3)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk(  3)=-0.1844832352991595D-08
         rk(  3)=-0.6225976686895072D-07+(azi- 0.50D+02) * rk(  3)
         rk(  3)=-0.4818019096011311D-05+(azi- 0.50D+02) * rk(  3)
         rk(  3)= 0.3811500000000000D-03+(azi- 0.50D+02) * rk(  3)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(  3)= 0.1101151387472940D-09
         rk(  3)=-0.1176047374587006D-06+(azi- 0.60D+02) * rk(  3)
         rk(  3)=-0.6616664139287841D-05+(azi- 0.60D+02) * rk(  3)
         rk(  3)= 0.3248990000000000D-03+(azi- 0.60D+02) * rk(  3)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk(  3)=-0.1557211541862520D-07
         rk(  3)=-0.1143012832962748D-06+(azi- 0.70D+02) * rk(  3)
         rk(  3)=-0.8935724346837626D-05+(azi- 0.70D+02) * rk(  3)
         rk(  3)= 0.2470820000000000D-03+(azi- 0.70D+02) * rk(  3)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk(  3)= 0.4048472604219372D-07
         rk(  3)=-0.4880320533432526D-06+(azi- 0.78D+02) * rk(  3)
         rk(  3)=-0.1375439103995373D-04+(azi- 0.78D+02) * rk(  3)
         rk(  3)= 0.1603080000000000D-03+(azi- 0.78D+02) * rk(  3)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk(  3)= 0.2066880316665801D-06
         rk(  3)= 0.4836013716693967D-06+(azi- 0.86D+02) * rk(  3)
         rk(  3)=-0.1378983649334545D-04+(azi- 0.86D+02) * rk(  3)
         rk(  3)= 0.3976700000000000D-04+(azi- 0.86D+02) * rk(  3)
      elseif(azi.ge.90.D0)then
         rk(  3)= 0.5573310000000000D-05
      endif
      if(att.lt.0.99999) rk(  3) = rk(  3) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk(  4)=-0.2887225450832654D-08
         rk(  4)=-0.1810277454916759D-06+(azi- 0.00D+00) * rk(  4)
         rk(  4)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  4)
         rk(  4)= 0.2046710000000000D-02+(azi- 0.00D+00) * rk(  4)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk(  4)= 0.8216763524985581D-09
         rk(  4)=-0.2676445090166555D-06+(azi- 0.10D+02) * rk(  4)
         rk(  4)=-0.4486722545083315D-05+(azi- 0.10D+02) * rk(  4)
         rk(  4)= 0.2025720000000000D-02+(azi- 0.10D+02) * rk(  4)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk(  4)=-0.1309479959161411D-08
         rk(  4)=-0.2429942184416987D-06+(azi- 0.20D+02) * rk(  4)
         rk(  4)=-0.9593109819666857D-05+(azi- 0.20D+02) * rk(  4)
         rk(  4)= 0.1954910000000000D-02+(azi- 0.20D+02) * rk(  4)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk(  4)=-0.1523756515853306D-08
         rk(  4)=-0.2822786172165413D-06+(azi- 0.30D+02) * rk(  4)
         rk(  4)=-0.1484583817624925D-04+(azi- 0.30D+02) * rk(  4)
         rk(  4)= 0.1833370000000000D-02+(azi- 0.30D+02) * rk(  4)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk(  4)=-0.1745493977424805D-08
         rk(  4)=-0.3279913126921416D-06+(azi- 0.40D+02) * rk(  4)
         rk(  4)=-0.2094853747533607D-04+(azi- 0.40D+02) * rk(  4)
         rk(  4)= 0.1655160000000000D-02+(azi- 0.40D+02) * rk(  4)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk(  4)=-0.2754267574449666D-08
         rk(  4)=-0.3803561320148791D-06+(azi- 0.50D+02) * rk(  4)
         rk(  4)=-0.2803201192240627D-04+(azi- 0.50D+02) * rk(  4)
         rk(  4)= 0.1411130000000000D-02+(azi- 0.50D+02) * rk(  4)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(  4)= 0.1037656427521931D-07
         rk(  4)=-0.4629841592483614D-06+(azi- 0.60D+02) * rk(  4)
         rk(  4)=-0.3646541483503890D-04+(azi- 0.60D+02) * rk(  4)
         rk(  4)= 0.1090020000000000D-02+(azi- 0.60D+02) * rk(  4)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk(  4)= 0.4335158727146124D-07
         rk(  4)=-0.1516872309916836D-06+(azi- 0.70D+02) * rk(  4)
         rk(  4)=-0.4261212873744006D-04+(azi- 0.70D+02) * rk(  4)
         rk(  4)= 0.6894440000000000D-03+(azi- 0.70D+02) * rk(  4)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk(  4)=-0.2976581610929885D-07
         rk(  4)= 0.8887508635229522D-06+(azi- 0.78D+02) * rk(  4)
         rk(  4)=-0.3671561967719012D-04+(azi- 0.78D+02) * rk(  4)
         rk(  4)= 0.3610350000000000D-03+(azi- 0.78D+02) * rk(  4)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk(  4)= 0.5586598403868970D-06
         rk(  4)= 0.1743712769006476D-06+(azi- 0.86D+02) * rk(  4)
         rk(  4)=-0.2821064255380132D-04+(azi- 0.86D+02) * rk(  4)
         rk(  4)= 0.1089500000000000D-03+(azi- 0.86D+02) * rk(  4)
      elseif(azi.ge.90.D0)then
         rk(  4)= 0.3465160000000000D-04
      endif
      if(att.lt.0.99999) rk(  4) = rk(  4) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk(  5)=-0.1532025548735504D-11
         rk(  5)=-0.1605297445126456D-09+(azi- 0.00D+00) * rk(  5)
         rk(  5)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  5)
         rk(  5)= 0.7475310000000001D-06+(azi- 0.00D+00) * rk(  5)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk(  5)= 0.1499076646206673D-11
         rk(  5)=-0.2064905109747107D-09+(azi- 0.10D+02) * rk(  5)
         rk(  5)=-0.3670202554873562D-08+(azi- 0.10D+02) * rk(  5)
         rk(  5)= 0.7299460000000000D-06+(azi- 0.10D+02) * rk(  5)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk(  5)= 0.8827189639088217D-12
         rk(  5)=-0.1615182115885105D-09+(azi- 0.20D+02) * rk(  5)
         rk(  5)=-0.7350289780505773D-08+(azi- 0.20D+02) * rk(  5)
         rk(  5)= 0.6740940000000000D-06+(azi- 0.20D+02) * rk(  5)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk(  5)= 0.1742047498157866D-11
         rk(  5)=-0.1350366426712456D-09+(azi- 0.30D+02) * rk(  5)
         rk(  5)=-0.1031583832310333D-07+(azi- 0.30D+02) * rk(  5)
         rk(  5)= 0.5853220000000000D-06+(azi- 0.30D+02) * rk(  5)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk(  5)= 0.2513091043460236D-11
         rk(  5)=-0.8277521772650986D-10+(azi- 0.40D+02) * rk(  5)
         rk(  5)=-0.1249395692708090D-07+(azi- 0.40D+02) * rk(  5)
         rk(  5)= 0.4704020000000000D-06+(azi- 0.40D+02) * rk(  5)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk(  5)= 0.3194588327998947D-11
         rk(  5)=-0.7382486422695786D-11+(azi- 0.50D+02) * rk(  5)
         rk(  5)=-0.1339553396857292D-07+(azi- 0.50D+02) * rk(  5)
         rk(  5)= 0.3396980000000000D-06+(azi- 0.50D+02) * rk(  5)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(  5)= 0.5281855644532753D-11
         rk(  5)= 0.8845516341730926D-10+(azi- 0.60D+02) * rk(  5)
         rk(  5)=-0.1258480719862703D-07+(azi- 0.60D+02) * rk(  5)
         rk(  5)= 0.2081990000000000D-06+(azi- 0.60D+02) * rk(  5)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk(  5)=-0.2756160172825952D-12
         rk(  5)= 0.2469108327533722D-09+(azi- 0.70D+02) * rk(  5)
         rk(  5)=-0.9231147236921398D-08+(azi- 0.70D+02) * rk(  5)
         rk(  5)= 0.9647830000000000D-07+(azi- 0.70D+02) * rk(  5)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk(  5)=-0.5270116383010849D-11
         rk(  5)= 0.2402960483381663D-09+(azi- 0.78D+02) * rk(  5)
         rk(  5)=-0.5333492188188506D-08+(azi- 0.78D+02) * rk(  5)
         rk(  5)= 0.3829030000000000D-07+(azi- 0.78D+02) * rk(  5)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk(  5)= 0.3312732748139775D-10
         rk(  5)= 0.1138132551480241D-09+(azi- 0.86D+02) * rk(  5)
         rk(  5)=-0.2500617760302373D-08+(azi- 0.86D+02) * rk(  5)
         rk(  5)= 0.8303010000000000D-08+(azi- 0.86D+02) * rk(  5)
      elseif(azi.ge.90.D0)then
         rk(  5)= 0.2241700000000000D-08
      endif
      if(att.lt.0.99999) rk(  5) = rk(  5) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk(  6)=-0.1022637521258297D-10
         rk(  6)=-0.1047636247874169D-08+(azi- 0.00D+00) * rk(  6)
         rk(  6)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  6)
         rk(  6)= 0.5038360000000000D-05+(azi- 0.00D+00) * rk(  6)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk(  6)= 0.9289125637748417D-11
         rk(  6)=-0.1354427504251658D-08+(azi- 0.10D+02) * rk(  6)
         rk(  6)=-0.2402063752125827D-07+(azi- 0.10D+02) * rk(  6)
         rk(  6)= 0.4923370000000000D-05+(azi- 0.10D+02) * rk(  6)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk(  6)= 0.4979872661590548D-11
         rk(  6)=-0.1075753735119206D-08+(azi- 0.20D+02) * rk(  6)
         rk(  6)=-0.4832244991496691D-07+(azi- 0.20D+02) * rk(  6)
         rk(  6)= 0.4557010000000000D-05+(azi- 0.20D+02) * rk(  6)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk(  6)= 0.1055138371588769D-10
         rk(  6)=-0.9263575552714919D-09+(azi- 0.30D+02) * rk(  6)
         rk(  6)=-0.6834356281887387D-07+(azi- 0.30D+02) * rk(  6)
         rk(  6)= 0.3971190000000000D-05+(azi- 0.30D+02) * rk(  6)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk(  6)= 0.1620459247486260D-10
         rk(  6)=-0.6098160437948575D-09+(azi- 0.40D+02) * rk(  6)
         rk(  6)=-0.8370529880953742D-07+(azi- 0.40D+02) * rk(  6)
         rk(  6)= 0.3205670000000000D-05+(azi- 0.40D+02) * rk(  6)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk(  6)= 0.2215024638465413D-10
         rk(  6)=-0.1236782695489542D-09+(azi- 0.50D+02) * rk(  6)
         rk(  6)=-0.9104024194297523D-07+(azi- 0.50D+02) * rk(  6)
         rk(  6)= 0.2323840000000000D-05+(azi- 0.50D+02) * rk(  6)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(  6)= 0.3999042198649142D-10
         rk(  6)= 0.5408291219906615D-09+(azi- 0.60D+02) * rk(  6)
         rk(  6)=-0.8686873341855832D-07+(azi- 0.60D+02) * rk(  6)
         rk(  6)= 0.1423220000000000D-05+(azi- 0.60D+02) * rk(  6)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk(  6)=-0.2067341717177852D-11
         rk(  6)= 0.1740541781586059D-08+(azi- 0.70D+02) * rk(  6)
         rk(  6)=-0.6405502438279355D-07+(azi- 0.70D+02) * rk(  6)
         rk(  6)= 0.6486060000000000D-06+(azi- 0.70D+02) * rk(  6)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk(  6)=-0.2916729149813073D-10
         rk(  6)= 0.1690925580372944D-08+(azi- 0.78D+02) * rk(  6)
         rk(  6)=-0.3660328548711093D-07+(azi- 0.78D+02) * rk(  6)
         rk(  6)= 0.2465020000000000D-06+(azi- 0.78D+02) * rk(  6)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk(  6)= 0.1504439894468502D-09
         rk(  6)= 0.9909105844178033D-09+(azi- 0.86D+02) * rk(  6)
         rk(  6)=-0.1514859616879851D-07+(azi- 0.86D+02) * rk(  6)
         rk(  6)= 0.4696130000000000D-07+(azi- 0.86D+02) * rk(  6)
      elseif(azi.ge.90.D0)then
         rk(  6)= 0.1184990000000000D-07
      endif
      if(att.lt.0.99999) rk(  6) = rk(  6) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk(  7)=-0.3691161034363458D-07
         rk(  7)=-0.1177883896563626D-05+(azi- 0.00D+00) * rk(  7)
         rk(  7)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  7)
         rk(  7)= 0.2656490000000000D-01+(azi- 0.00D+00) * rk(  7)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk(  7)= 0.1703483103089457D-07
         rk(  7)=-0.2285232206872663D-05+(azi- 0.10D+02) * rk(  7)
         rk(  7)=-0.3463116103436289D-04+(azi- 0.10D+02) * rk(  7)
         rk(  7)= 0.2641020000000000D-01+(azi- 0.10D+02) * rk(  7)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk(  7)=-0.1532771377994111D-07
         rk(  7)=-0.1774187275945826D-05+(azi- 0.20D+02) * rk(  7)
         rk(  7)=-0.7522535586254778D-04+(azi- 0.20D+02) * rk(  7)
         rk(  7)= 0.2585240000000000D-01+(azi- 0.20D+02) * rk(  7)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk(  7)=-0.1372397591112909D-07
         rk(  7)=-0.2234018689344059D-05+(azi- 0.30D+02) * rk(  7)
         rk(  7)=-0.1153074155154466D-03+(azi- 0.30D+02) * rk(  7)
         rk(  7)= 0.2490740000000000D-01+(azi- 0.30D+02) * rk(  7)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk(  7)=-0.2747638257553896D-07
         rk(  7)=-0.2645737966677928D-05+(azi- 0.40D+02) * rk(  7)
         rk(  7)=-0.1641049820756666D-03+(azi- 0.40D+02) * rk(  7)
         rk(  7)= 0.2351720000000000D-01+(azi- 0.40D+02) * rk(  7)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk(  7)=-0.1322704937867268D-06
         rk(  7)=-0.3470029443944055D-05+(azi- 0.50D+02) * rk(  7)
         rk(  7)=-0.2252626561818860D-03+(azi- 0.50D+02) * rk(  7)
         rk(  7)= 0.2158410000000000D-01+(azi- 0.50D+02) * rk(  7)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(  7)=-0.2304164227761627D-07
         rk(  7)=-0.7438144257545701D-05+(azi- 0.60D+02) * rk(  7)
         rk(  7)=-0.3343443931967854D-03+(azi- 0.60D+02) * rk(  7)
         rk(  7)= 0.1885220000000000D-01+(azi- 0.60D+02) * rk(  7)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk(  7)=-0.1151055949406665D-05
         rk(  7)=-0.8129393525873554D-05+(azi- 0.70D+02) * rk(  7)
         rk(  7)=-0.4900197710309803D-03+(azi- 0.70D+02) * rk(  7)
         rk(  7)= 0.1474190000000000D-01+(azi- 0.70D+02) * rk(  7)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk(  7)= 0.3051007034751954D-05
         rk(  7)=-0.3575473631163524D-04+(azi- 0.78D+02) * rk(  7)
         rk(  7)=-0.8410928097310395D-03+(azi- 0.78D+02) * rk(  7)
         rk(  7)= 0.9712119999999999D-02+(azi- 0.78D+02) * rk(  7)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk(  7)= 0.1099207874720238D-04
         rk(  7)= 0.3746943252240472D-04+(azi- 0.86D+02) * rk(  7)
         rk(  7)=-0.8273752400448559D-03+(azi- 0.86D+02) * rk(  7)
         rk(  7)= 0.2257190000000000D-02+(azi- 0.86D+02) * rk(  7)
      elseif(azi.ge.90.D0)then
         rk(  7)= 0.2506930000000000D-03
      endif
      if(att.lt.0.99999) rk(  7) = rk(  7) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk(  8)=-0.1926445199576590D-06
         rk(  8)=-0.1114355480042344D-04+(azi- 0.00D+00) * rk(  8)
         rk(  8)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  8)
         rk(  8)= 0.2129960000000000D+00+(azi- 0.00D+00) * rk(  8)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk(  8)=-0.3806644012700089D-07
         rk(  8)=-0.1692289039915320D-04+(azi- 0.10D+02) * rk(  8)
         rk(  8)=-0.2806644519957664D-03+(azi- 0.10D+02) * rk(  8)
         rk(  8)= 0.2116890000000000D+00+(azi- 0.10D+02) * rk(  8)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk(  8)= 0.3591028046562971D-07
         rk(  8)=-0.1806488360296323D-04+(azi- 0.20D+02) * rk(  8)
         rk(  8)=-0.6305421920169308D-03+(azi- 0.20D+02) * rk(  8)
         rk(  8)= 0.2071520000000000D+00+(azi- 0.20D+02) * rk(  8)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk(  8)=-0.2185746817355207D-06
         rk(  8)=-0.1698757518899435D-04+(azi- 0.30D+02) * rk(  8)
         rk(  8)=-0.9810667799365058D-03+(azi- 0.30D+02) * rk(  8)
         rk(  8)= 0.1990760000000000D+00+(azi- 0.30D+02) * rk(  8)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk(  8)=-0.2006115535234723D-06
         rk(  8)=-0.2354481564106007D-04+(azi- 0.40D+02) * rk(  8)
         rk(  8)=-0.1386390688237050D-02+(azi- 0.40D+02) * rk(  8)
         rk(  8)= 0.1873480000000000D+00+(azi- 0.40D+02) * rk(  8)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk(  8)=-0.1055979104170515D-05
         rk(  8)=-0.2956316224676458D-04+(azi- 0.50D+02) * rk(  8)
         rk(  8)=-0.1917470467115294D-02+(azi- 0.50D+02) * rk(  8)
         rk(  8)= 0.1709290000000000D+00+(azi- 0.50D+02) * rk(  8)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(  8)=-0.3204720297944544D-06
         rk(  8)=-0.6124253537188041D-04+(azi- 0.60D+02) * rk(  8)
         rk(  8)=-0.2825527443301754D-02+(azi- 0.60D+02) * rk(  8)
         rk(  8)= 0.1477420000000000D+00+(azi- 0.60D+02) * rk(  8)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk(  8)=-0.6785572971821480D-05
         rk(  8)=-0.7085669626571215D-04+(azi- 0.70D+02) * rk(  8)
         rk(  8)=-0.4146519759677717D-02+(azi- 0.70D+02) * rk(  8)
         rk(  8)= 0.1130420000000000D+00+(azi- 0.70D+02) * rk(  8)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk(  8)= 0.2349184361303900D-04
         rk(  8)=-0.2337104475894554D-03+(azi- 0.78D+02) * rk(  8)
         rk(  8)=-0.6583056910518905D-02+(azi- 0.78D+02) * rk(  8)
         rk(  8)= 0.7186080000000000D-01+(azi- 0.78D+02) * rk(  8)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk(  8)= 0.6606749385954785D-04
         rk(  8)= 0.3300937991235361D-03+(azi- 0.86D+02) * rk(  8)
         rk(  8)=-0.5811990098247148D-02+(azi- 0.86D+02) * rk(  8)
         rk(  8)= 0.1626670000000000D-01+(azi- 0.86D+02) * rk(  8)
      elseif(azi.ge.90.D0)then
         rk(  8)= 0.2528560000000000D-02
      endif
      if(att.lt.0.99999) rk(  8) = rk(  8) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk(  9)=-0.1441479345432038D-10
         rk(  9)=-0.1242452065456794D-08+(azi- 0.00D+00) * rk(  9)
         rk(  9)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  9)
         rk(  9)= 0.8394580000000000D-05+(azi- 0.00D+00) * rk(  9)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk(  9)= 0.8244380362960485D-11
         rk(  9)=-0.1674895869086405D-08+(azi- 0.10D+02) * rk(  9)
         rk(  9)=-0.2917347934543199D-07+(azi- 0.10D+02) * rk(  9)
         rk(  9)= 0.8255920000000000D-05+(azi- 0.10D+02) * rk(  9)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk(  9)= 0.1172720024785529D-12
         rk(  9)=-0.1427564458197591D-08+(azi- 0.20D+02) * rk(  9)
         rk(  9)=-0.6019808261827194D-07+(azi- 0.20D+02) * rk(  9)
         rk(  9)= 0.7804940000000000D-05+(azi- 0.20D+02) * rk(  9)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk(  9)= 0.4506531627126526D-11
         rk(  9)=-0.1424046298123237D-08+(azi- 0.30D+02) * rk(  9)
         rk(  9)=-0.8871419018148017D-07+(azi- 0.30D+02) * rk(  9)
         rk(  9)= 0.7060320000000000D-05+(azi- 0.30D+02) * rk(  9)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk(  9)= 0.1086660148901081D-10
         rk(  9)=-0.1288850349309429D-08+(azi- 0.40D+02) * rk(  9)
         rk(  9)=-0.1158431566558069D-06+(azi- 0.40D+02) * rk(  9)
         rk(  9)= 0.6035280000000000D-05+(azi- 0.40D+02) * rk(  9)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk(  9)= 0.1803706241683296D-10
         rk(  9)=-0.9628523046390888D-09+(azi- 0.50D+02) * rk(  9)
         rk(  9)=-0.1383601831952917D-06+(azi- 0.50D+02) * rk(  9)
         rk(  9)= 0.4758830000000000D-05+(azi- 0.50D+02) * rk(  9)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(  9)= 0.7329514884360326D-10
         rk(  9)=-0.4217404321338086D-09+(azi- 0.60D+02) * rk(  9)
         rk(  9)=-0.1522061105630235D-06+(azi- 0.60D+02) * rk(  9)
         rk(  9)= 0.3296980000000000D-05+(azi- 0.60D+02) * rk(  9)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk(  9)= 0.6172011386290993D-10
         rk(  9)= 0.1777114033174925D-08+(azi- 0.70D+02) * rk(  9)
         rk(  9)=-0.1386523745526208D-06+(azi- 0.70D+02) * rk(  9)
         rk(  9)= 0.1806040000000000D-05+(azi- 0.70D+02) * rk(  9)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk(  9)=-0.8279704635832541D-10
         rk(  9)= 0.3258396765884765D-08+(azi- 0.78D+02) * rk(  9)
         rk(  9)=-0.9836828816015230D-07+(azi- 0.78D+02) * rk(  9)
         rk(  9)= 0.8421570000000000D-06+(azi- 0.78D+02) * rk(  9)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk(  9)= 0.1082517324592100D-08
         rk(  9)= 0.1271267653291731D-08+(azi- 0.86D+02) * rk(  9)
         rk(  9)=-0.6213097280668617D-07+(azi- 0.86D+02) * rk(  9)
         rk(  9)= 0.2213560000000000D-06+(azi- 0.86D+02) * rk(  9)
      elseif(azi.ge.90.D0)then
         rk(  9)= 0.6245350000000000D-07
      endif
      if(att.lt.0.99999) rk(  9) = rk(  9) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 10)=-0.7261045436751536D-10
         rk( 10)=-0.5576895456324843D-08+(azi- 0.00D+00) * rk( 10)
         rk( 10)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 10)
         rk( 10)= 0.4669460000000000D-04+(azi- 0.00D+00) * rk( 10)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 10)= 0.2853136310254380D-10
         rk( 10)=-0.7755209087350300D-08+(azi- 0.10D+02) * rk( 10)
         rk( 10)=-0.1333210454367515D-06+(azi- 0.10D+02) * rk( 10)
         rk( 10)= 0.4606430000000000D-04+(azi- 0.10D+02) * rk( 10)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 10)=-0.1901499804265908D-10
         rk( 10)=-0.6899268194273983D-08+(azi- 0.20D+02) * rk( 10)
         rk( 10)=-0.2798658182529943D-06+(azi- 0.20D+02) * rk( 10)
         rk( 10)= 0.4398410000000000D-04+(azi- 0.20D+02) * rk( 10)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 10)=-0.9471370931901177D-11
         rk( 10)=-0.7469718135553756D-08+(azi- 0.30D+02) * rk( 10)
         rk( 10)=-0.4235556815512716D-06+(azi- 0.30D+02) * rk( 10)
         rk( 10)= 0.4047650000000000D-04+(azi- 0.30D+02) * rk( 10)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 10)= 0.1440048177026605D-10
         rk( 10)=-0.7753859263510771D-08+(azi- 0.40D+02) * rk( 10)
         rk( 10)=-0.5757914555419167D-06+(azi- 0.40D+02) * rk( 10)
         rk( 10)= 0.3548450000000000D-04+(azi- 0.40D+02) * rk( 10)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 10)= 0.3856944385086320D-10
         rk( 10)=-0.7321844810402955D-08+(azi- 0.50D+02) * rk( 10)
         rk( 10)=-0.7265484962810528D-06+(azi- 0.50D+02) * rk( 10)
         rk( 10)= 0.2896560000000000D-04+(azi- 0.50D+02) * rk( 10)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 10)= 0.4136217428260806D-09
         rk( 10)=-0.6164761494876927D-08+(azi- 0.60D+02) * rk( 10)
         rk( 10)=-0.8614145593338610D-06+(azi- 0.60D+02) * rk( 10)
         rk( 10)= 0.2100650000000000D-04+(azi- 0.60D+02) * rk( 10)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 10)= 0.5376701572550642D-09
         rk( 10)= 0.6243890789907289D-08+(azi- 0.70D+02) * rk( 10)
         rk( 10)=-0.8606232663835828D-06+(azi- 0.70D+02) * rk( 10)
         rk( 10)= 0.1218950000000000D-04+(azi- 0.70D+02) * rk( 10)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 10)=-0.5508273899998801D-09
         rk( 10)= 0.1914797456402205D-07+(azi- 0.78D+02) * rk( 10)
         rk( 10)=-0.6574883435521547D-06+(azi- 0.78D+02) * rk( 10)
         rk( 10)= 0.5979410000000000D-05+(azi- 0.78D+02) * rk( 10)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 10)= 0.8530305661981016D-08
         rk( 10)= 0.5928117204024931D-08+(azi- 0.86D+02) * rk( 10)
         rk( 10)=-0.4568796094078873D-06+(azi- 0.86D+02) * rk( 10)
         rk( 10)= 0.1662950000000000D-05+(azi- 0.86D+02) * rk( 10)
      elseif(azi.ge.90.D0)then
         rk( 10)= 0.4762210000000000D-06
      endif
      if(att.lt.0.99999) rk( 10) = rk( 10) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 11)=-0.5816837387219510D-10
         rk( 11)=-0.5184316261278088D-08+(azi- 0.00D+00) * rk( 11)
         rk( 11)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 11)
         rk( 11)= 0.3220560000000000D-04+(azi- 0.00D+00) * rk( 11)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 11)= 0.3450512161659960D-10
         rk( 11)=-0.6929367477443939D-08+(azi- 0.10D+02) * rk( 11)
         rk( 11)=-0.1211368373872202D-06+(azi- 0.10D+02) * rk( 11)
         rk( 11)= 0.3162900000000000D-04+(azi- 0.10D+02) * rk( 11)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 11)= 0.3647887405786855D-11
         rk( 11)=-0.5894213828945953D-08+(azi- 0.20D+02) * rk( 11)
         rk( 11)=-0.2493726504511192D-06+(azi- 0.20D+02) * rk( 11)
         rk( 11)= 0.2975920000000000D-04+(azi- 0.20D+02) * rk( 11)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 11)= 0.2530332876026024D-10
         rk( 11)=-0.5784777206772373D-08+(azi- 0.30D+02) * rk( 11)
         rk( 11)=-0.3661625608083023D-06+(azi- 0.30D+02) * rk( 11)
         rk( 11)= 0.2667970000000000D-04+(azi- 0.30D+02) * rk( 11)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 11)= 0.6013879755318127D-10
         rk( 11)=-0.5025677343964567D-08+(azi- 0.40D+02) * rk( 11)
         rk( 11)=-0.4742671063156718D-06+(azi- 0.40D+02) * rk( 11)
         rk( 11)= 0.2246490000000000D-04+(azi- 0.40D+02) * rk( 11)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 11)= 0.1004414810269849D-09
         rk( 11)=-0.3221513417369090D-08+(azi- 0.50D+02) * rk( 11)
         rk( 11)=-0.5567390139290057D-06+(azi- 0.50D+02) * rk( 11)
         rk( 11)= 0.1727980000000000D-04+(azi- 0.50D+02) * rk( 11)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 11)= 0.3107352783389149D-09
         rk( 11)=-0.2082689865602761D-09+(azi- 0.60D+02) * rk( 11)
         rk( 11)=-0.5910368379683005D-06+(azi- 0.60D+02) * rk( 11)
         rk( 11)= 0.1149070000000000D-04+(azi- 0.60D+02) * rk( 11)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 11)= 0.1345128013885966D-09
         rk( 11)= 0.9113789363611865D-08+(azi- 0.70D+02) * rk( 11)
         rk( 11)=-0.5019816341978055D-06+(azi- 0.70D+02) * rk( 11)
         rk( 11)= 0.5870240000000000D-05+(azi- 0.70D+02) * rk( 11)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 11)=-0.1960445509686722D-09
         rk( 11)= 0.1234209659693818D-07+(azi- 0.78D+02) * rk( 11)
         rk( 11)=-0.3303345465133592D-06+(azi- 0.78D+02) * rk( 11)
         rk( 11)= 0.2506540000000000D-05+(azi- 0.78D+02) * rk( 11)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 11)= 0.2279277828334194D-08
         rk( 11)= 0.7637027373690048D-08+(azi- 0.86D+02) * rk( 11)
         rk( 11)=-0.1705015547483333D-06+(azi- 0.86D+02) * rk( 11)
         rk( 11)= 0.5533830000000000D-06+(azi- 0.86D+02) * rk( 11)
      elseif(azi.ge.90.D0)then
         rk( 11)= 0.1394430000000000D-06
      endif
      if(att.lt.0.99999) rk( 11) = rk( 11) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 12)=-0.1292568102250472D-10
         rk( 12)=-0.1349143189774952D-08+(azi- 0.00D+00) * rk( 12)
         rk( 12)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 12)
         rk( 12)= 0.6105070000000000D-05+(azi- 0.00D+00) * rk( 12)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 12)= 0.1221704306751370D-10
         rk( 12)=-0.1736913620450094D-08+(azi- 0.10D+02) * rk( 12)
         rk( 12)=-0.3086056810225046D-07+(azi- 0.10D+02) * rk( 12)
         rk( 12)= 0.5957230000000000D-05+(azi- 0.10D+02) * rk( 12)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 12)= 0.7227508752451053D-11
         rk( 12)=-0.1370402328424683D-08+(azi- 0.20D+02) * rk( 12)
         rk( 12)=-0.6193372759099821D-07+(azi- 0.20D+02) * rk( 12)
         rk( 12)= 0.5487150000000000D-05+(azi- 0.20D+02) * rk( 12)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 12)= 0.1521292192268116D-10
         rk( 12)=-0.1153577065851154D-08+(azi- 0.30D+02) * rk( 12)
         rk( 12)=-0.8717352153375659D-07+(azi- 0.30D+02) * rk( 12)
         rk( 12)= 0.4738000000000000D-05+(azi- 0.30D+02) * rk( 12)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 12)= 0.2301080355682754D-10
         rk( 12)=-0.6971894081707150D-09+(azi- 0.40D+02) * rk( 12)
         rk( 12)=-0.1056811862739752D-06+(azi- 0.40D+02) * rk( 12)
         rk( 12)= 0.3766120000000000D-05+(azi- 0.40D+02) * rk( 12)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 12)= 0.3106386384999196D-10
         rk( 12)=-0.6865301465851467D-11+(azi- 0.50D+02) * rk( 12)
         rk( 12)=-0.1127217333703403D-06+(azi- 0.50D+02) * rk( 12)
         rk( 12)= 0.2662600000000000D-05+(azi- 0.50D+02) * rk( 12)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 12)= 0.4531874104320491D-10
         rk( 12)= 0.9250506140339120D-09+(azi- 0.60D+02) * rk( 12)
         rk( 12)=-0.1035398802446603D-06+(azi- 0.60D+02) * rk( 12)
         rk( 12)= 0.1565760000000000D-05+(azi- 0.60D+02) * rk( 12)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 12)=-0.1303761111901561D-10
         rk( 12)= 0.2284612845330078D-08+(azi- 0.70D+02) * rk( 12)
         rk( 12)=-0.7144324565102197D-07+(azi- 0.70D+02) * rk( 12)
         rk( 12)= 0.6681850000000000D-06+(azi- 0.70D+02) * rk( 12)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 12)=-0.4077238229876006D-10
         rk( 12)= 0.1971710178468621D-08+(azi- 0.78D+02) * rk( 12)
         rk( 12)=-0.3739266146061392D-07+(azi- 0.78D+02) * rk( 12)
         rk( 12)= 0.2361790000000000D-06+(azi- 0.78D+02) * rk( 12)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 12)= 0.1193377495830152D-09
         rk( 12)= 0.9931730032983793D-09+(azi- 0.86D+02) * rk( 12)
         rk( 12)=-0.1367359600650506D-07+(azi- 0.86D+02) * rk( 12)
         rk( 12)= 0.4235170000000000D-07+(azi- 0.86D+02) * rk( 12)
      elseif(azi.ge.90.D0)then
         rk( 12)= 0.1118570000000000D-07
      endif
      if(att.lt.0.99999) rk( 12) = rk( 12) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 13)=-0.9639086891432885D-11
         rk( 13)=-0.8144091310856726D-09+(azi- 0.00D+00) * rk( 13)
         rk( 13)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 13)
         rk( 13)= 0.5704620000000000D-05+(azi- 0.00D+00) * rk( 13)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 13)= 0.5287260674298930D-11
         rk( 13)=-0.1103581737828659D-08+(azi- 0.10D+02) * rk( 13)
         rk( 13)=-0.1917990868914331D-07+(azi- 0.10D+02) * rk( 13)
         rk( 13)= 0.5613540000000000D-05+(azi- 0.10D+02) * rk( 13)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 13)=-0.2699558057626279D-12
         rk( 13)=-0.9449639175996907D-09+(azi- 0.20D+02) * rk( 13)
         rk( 13)=-0.3966536524342681D-07+(azi- 0.20D+02) * rk( 13)
         rk( 13)= 0.5316670000000000D-05+(azi- 0.20D+02) * rk( 13)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 13)= 0.2382562548751788D-11
         rk( 13)=-0.9530625917725730D-09+(azi- 0.30D+02) * rk( 13)
         rk( 13)=-0.5864563033714944D-07+(azi- 0.30D+02) * rk( 13)
         rk( 13)= 0.4825250000000000D-05+(azi- 0.30D+02) * rk( 13)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 13)= 0.6319705610755386D-11
         rk( 13)=-0.8815857153100197D-09+(azi- 0.40D+02) * rk( 13)
         rk( 13)=-0.7699211340797530D-07+(azi- 0.40D+02) * rk( 13)
         rk( 13)= 0.4145870000000000D-05+(azi- 0.40D+02) * rk( 13)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 13)= 0.1056861500823120D-10
         rk( 13)=-0.6919945469873768D-09+(azi- 0.50D+02) * rk( 13)
         rk( 13)=-0.9272791603094922D-07+(azi- 0.50D+02) * rk( 13)
         rk( 13)= 0.3294110000000000D-05+(azi- 0.50D+02) * rk( 13)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 13)= 0.4850583435626295D-10
         rk( 13)=-0.3749360967401678D-09+(azi- 0.60D+02) * rk( 13)
         rk( 13)=-0.1033972224682260D-06+(azi- 0.60D+02) * rk( 13)
         rk( 13)= 0.2308200000000000D-05+(azi- 0.60D+02) * rk( 13)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 13)= 0.4863918163385332D-10
         rk( 13)= 0.1080238933947648D-08+(azi- 0.70D+02) * rk( 13)
         rk( 13)=-0.9634419409615171D-07+(azi- 0.70D+02) * rk( 13)
         rk( 13)= 0.1285240000000000D-05+(azi- 0.70D+02) * rk( 13)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 13)=-0.6023611040592816D-10
         rk( 13)= 0.2247579293159280D-08+(azi- 0.78D+02) * rk( 13)
         rk( 13)=-0.6972164827929671D-07+(azi- 0.78D+02) * rk( 13)
         rk( 13)= 0.6085250000000000D-06+(azi- 0.78D+02) * rk( 13)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 13)= 0.8106335758210396D-09
         rk( 13)= 0.8019126434102249D-09+(azi- 0.86D+02) * rk( 13)
         rk( 13)=-0.4532571278674064D-07+(azi- 0.86D+02) * rk( 13)
         rk( 13)= 0.1637560000000000D-06+(azi- 0.86D+02) * rk( 13)
      elseif(azi.ge.90.D0)then
         rk( 13)= 0.4716430000000000D-07
      endif
      if(att.lt.0.99999) rk( 13) = rk( 13) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 14)=-0.9639086891432885D-11
         rk( 14)=-0.8144091310856726D-09+(azi- 0.00D+00) * rk( 14)
         rk( 14)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 14)
         rk( 14)= 0.5704620000000000D-05+(azi- 0.00D+00) * rk( 14)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 14)= 0.5287260674298930D-11
         rk( 14)=-0.1103581737828659D-08+(azi- 0.10D+02) * rk( 14)
         rk( 14)=-0.1917990868914331D-07+(azi- 0.10D+02) * rk( 14)
         rk( 14)= 0.5613540000000000D-05+(azi- 0.10D+02) * rk( 14)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 14)=-0.2699558057626279D-12
         rk( 14)=-0.9449639175996907D-09+(azi- 0.20D+02) * rk( 14)
         rk( 14)=-0.3966536524342681D-07+(azi- 0.20D+02) * rk( 14)
         rk( 14)= 0.5316670000000000D-05+(azi- 0.20D+02) * rk( 14)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 14)= 0.2382562548751788D-11
         rk( 14)=-0.9530625917725730D-09+(azi- 0.30D+02) * rk( 14)
         rk( 14)=-0.5864563033714944D-07+(azi- 0.30D+02) * rk( 14)
         rk( 14)= 0.4825250000000000D-05+(azi- 0.30D+02) * rk( 14)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 14)= 0.6319705610755386D-11
         rk( 14)=-0.8815857153100197D-09+(azi- 0.40D+02) * rk( 14)
         rk( 14)=-0.7699211340797530D-07+(azi- 0.40D+02) * rk( 14)
         rk( 14)= 0.4145870000000000D-05+(azi- 0.40D+02) * rk( 14)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 14)= 0.1056861500823120D-10
         rk( 14)=-0.6919945469873768D-09+(azi- 0.50D+02) * rk( 14)
         rk( 14)=-0.9272791603094922D-07+(azi- 0.50D+02) * rk( 14)
         rk( 14)= 0.3294110000000000D-05+(azi- 0.50D+02) * rk( 14)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 14)= 0.4850583435626295D-10
         rk( 14)=-0.3749360967401678D-09+(azi- 0.60D+02) * rk( 14)
         rk( 14)=-0.1033972224682260D-06+(azi- 0.60D+02) * rk( 14)
         rk( 14)= 0.2308200000000000D-05+(azi- 0.60D+02) * rk( 14)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 14)= 0.4863918163385332D-10
         rk( 14)= 0.1080238933947648D-08+(azi- 0.70D+02) * rk( 14)
         rk( 14)=-0.9634419409615171D-07+(azi- 0.70D+02) * rk( 14)
         rk( 14)= 0.1285240000000000D-05+(azi- 0.70D+02) * rk( 14)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 14)=-0.6023611040592816D-10
         rk( 14)= 0.2247579293159280D-08+(azi- 0.78D+02) * rk( 14)
         rk( 14)=-0.6972164827929671D-07+(azi- 0.78D+02) * rk( 14)
         rk( 14)= 0.6085250000000000D-06+(azi- 0.78D+02) * rk( 14)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 14)= 0.8106335758210396D-09
         rk( 14)= 0.8019126434102249D-09+(azi- 0.86D+02) * rk( 14)
         rk( 14)=-0.4532571278674064D-07+(azi- 0.86D+02) * rk( 14)
         rk( 14)= 0.1637560000000000D-06+(azi- 0.86D+02) * rk( 14)
      elseif(azi.ge.90.D0)then
         rk( 14)= 0.4716430000000000D-07
      endif
      if(att.lt.0.99999) rk( 14) = rk( 14) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 15)=-0.3832057510941279D-11
         rk( 15)=-0.3311794248905843D-09+(azi- 0.00D+00) * rk( 15)
         rk( 15)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 15)
         rk( 15)= 0.2224430000000000D-05+(azi- 0.00D+00) * rk( 15)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 15)= 0.2216172532823076D-11
         rk( 15)=-0.4461411502188226D-09+(azi- 0.10D+02) * rk( 15)
         rk( 15)=-0.7773205751094070D-08+(azi- 0.10D+02) * rk( 15)
         rk( 15)= 0.2187480000000000D-05+(azi- 0.10D+02) * rk( 15)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 15)= 0.5736737964886529D-13
         rk( 15)=-0.3796559742341305D-09+(azi- 0.20D+02) * rk( 15)
         rk( 15)=-0.1603117699562360D-07+(azi- 0.20D+02) * rk( 15)
         rk( 15)= 0.2067350000000000D-05+(azi- 0.20D+02) * rk( 15)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 15)= 0.1254357948582340D-11
         rk( 15)=-0.3779349528446666D-09+(azi- 0.30D+02) * rk( 15)
         rk( 15)=-0.2360708626641156D-07+(azi- 0.30D+02) * rk( 15)
         rk( 15)= 0.1869130000000000D-05+(azi- 0.30D+02) * rk( 15)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 15)= 0.2935200826022499D-11
         rk( 15)=-0.3403042143871993D-09+(azi- 0.40D+02) * rk( 15)
         rk( 15)=-0.3078947793873023D-07+(azi- 0.40D+02) * rk( 15)
         rk( 15)= 0.1596520000000000D-05+(azi- 0.40D+02) * rk( 15)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 15)= 0.4861838747323474D-11
         rk( 15)=-0.2522481896065036D-09+(azi- 0.50D+02) * rk( 15)
         rk( 15)=-0.3671500197866727D-07+(azi- 0.50D+02) * rk( 15)
         rk( 15)= 0.1257530000000000D-05+(azi- 0.50D+02) * rk( 15)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 15)= 0.1939344418468631D-10
         rk( 15)=-0.1063930271867588D-09+(azi- 0.60D+02) * rk( 15)
         rk( 15)=-0.4030141414660076D-07+(azi- 0.60D+02) * rk( 15)
         rk( 15)= 0.8700170000000000D-06+(azi- 0.60D+02) * rk( 15)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 15)= 0.1609506325150023D-10
         rk( 15)= 0.4754102983539929D-09+(azi- 0.70D+02) * rk( 15)
         rk( 15)=-0.3661124143492975D-07+(azi- 0.70D+02) * rk( 15)
         rk( 15)= 0.4757570000000000D-06+(azi- 0.70D+02) * rk( 15)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 15)=-0.2188667990866934D-10
         rk( 15)= 0.8616918163904216D-09+(azi- 0.78D+02) * rk( 15)
         rk( 15)=-0.2591442451697153D-07+(azi- 0.78D+02) * rk( 15)
         rk( 15)= 0.2215340000000000D-06+(azi- 0.78D+02) * rk( 15)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 15)= 0.2841313751764769D-09
         rk( 15)= 0.3364114985848984D-09+(azi- 0.86D+02) * rk( 15)
         rk( 15)=-0.1632959799717574D-07+(azi- 0.86D+02) * rk( 15)
         rk( 15)= 0.5816090000000000D-07+(azi- 0.86D+02) * rk( 15)
      elseif(azi.ge.90.D0)then
         rk( 15)= 0.1640950000000000D-07
      endif
      if(att.lt.0.99999) rk( 15) = rk( 15) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 16)=-0.2139600241835119D-11
         rk( 16)=-0.2151039975816486D-09+(azi- 0.00D+00) * rk( 16)
         rk( 16)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 16)
         rk( 16)= 0.1065630000000000D-05+(azi- 0.00D+00) * rk( 16)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 16)= 0.1813800725505305D-11
         rk( 16)=-0.2792920048367021D-09+(azi- 0.10D+02) * rk( 16)
         rk( 16)=-0.4943960024183507D-08+(azi- 0.10D+02) * rk( 16)
         rk( 16)= 0.1041980000000000D-05+(azi- 0.10D+02) * rk( 16)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 16)= 0.9033973398139053D-12
         rk( 16)=-0.2248779830715429D-09+(azi- 0.20D+02) * rk( 16)
         rk( 16)=-0.9985659903265959D-08+(azi- 0.20D+02) * rk( 16)
         rk( 16)= 0.9664250000000000D-06+(azi- 0.20D+02) * rk( 16)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 16)= 0.2075609915239216D-11
         rk( 16)=-0.1977760628771271D-09+(azi- 0.30D+02) * rk( 16)
         rk( 16)=-0.1421220036275265D-07+(azi- 0.30D+02) * rk( 16)
         rk( 16)= 0.8449840000000000D-06+(azi- 0.30D+02) * rk( 16)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 16)= 0.3345162999229720D-11
         rk( 16)=-0.1355077654199492D-09+(azi- 0.40D+02) * rk( 16)
         rk( 16)=-0.1754503864572343D-07+(azi- 0.40D+02) * rk( 16)
         rk( 16)= 0.6851600000000000D-06+(azi- 0.40D+02) * rk( 16)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 16)= 0.4733738087840769D-11
         rk( 16)=-0.3515287544305134D-10+(azi- 0.50D+02) * rk( 16)
         rk( 16)=-0.1925164505435348D-07+(azi- 0.50D+02) * rk( 16)
         rk( 16)= 0.4995040000000001D-06+(azi- 0.50D+02) * rk( 16)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 16)= 0.8639884649395565D-11
         rk( 16)= 0.1068592671922140D-09+(azi- 0.60D+02) * rk( 16)
         rk( 16)=-0.1853458113686210D-07+(azi- 0.60D+02) * rk( 16)
         rk( 16)= 0.3082060000000000D-06+(azi- 0.60D+02) * rk( 16)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 16)=-0.6489929988116252D-13
         rk( 16)= 0.3660558066739854D-09+(azi- 0.70D+02) * rk( 16)
         rk( 16)=-0.1380543039820027D-07+(azi- 0.70D+02) * rk( 16)
         rk( 16)= 0.1421860000000000D-06+(azi- 0.70D+02) * rk( 16)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 16)=-0.7060744231570133D-11
         rk( 16)= 0.3644982234768375D-09+(azi- 0.78D+02) * rk( 16)
         rk( 16)=-0.7960998156992907D-08+(azi- 0.78D+02) * rk( 16)
         rk( 16)= 0.5513690000000000D-07+(azi- 0.78D+02) * rk( 16)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 16)= 0.4009097038578255D-10
         rk( 16)= 0.1950403619166119D-09+(azi- 0.86D+02) * rk( 16)
         rk( 16)=-0.3484689473838533D-08+(azi- 0.86D+02) * rk( 16)
         rk( 16)= 0.1116170000000000D-07+(azi- 0.86D+02) * rk( 16)
      elseif(azi.ge.90.D0)then
         rk( 16)= 0.2909410000000000D-08
      endif
      if(att.lt.0.99999) rk( 16) = rk( 16) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 17)=-0.9030422964083281D-10
         rk( 17)=-0.4134957703591605D-08+(azi- 0.00D+00) * rk( 17)
         rk( 17)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 17)
         rk( 17)= 0.6803410000000000D-04+(azi- 0.00D+00) * rk( 17)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 17)= 0.2671268892247770D-10
         rk( 17)=-0.6844084592816589D-08+(azi- 0.10D+02) * rk( 17)
         rk( 17)=-0.1097904229640819D-06+(azi- 0.10D+02) * rk( 17)
         rk( 17)= 0.6753030000000001D-04+(azi- 0.10D+02) * rk( 17)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 17)=-0.4184652604907337D-10
         rk( 17)=-0.6042703925142255D-08+(azi- 0.20D+02) * rk( 17)
         rk( 17)=-0.2386583081436704D-06+(azi- 0.20D+02) * rk( 17)
         rk( 17)= 0.6577470000000001D-04+(azi- 0.20D+02) * rk( 17)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 17)=-0.5902658472617613D-10
         rk( 17)=-0.7298099706614461D-08+(azi- 0.30D+02) * rk( 17)
         rk( 17)=-0.3720663444612375D-06+(azi- 0.30D+02) * rk( 17)
         rk( 17)= 0.6274200000000000D-04+(azi- 0.30D+02) * rk( 17)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 17)=-0.1000471350462304D-09
         rk( 17)=-0.9068897248399723D-08+(azi- 0.40D+02) * rk( 17)
         rk( 17)=-0.5357363140113791D-06+(azi- 0.40D+02) * rk( 17)
         rk( 17)= 0.5823250000000000D-04+(azi- 0.40D+02) * rk( 17)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 17)=-0.2435848750889002D-09
         rk( 17)=-0.1207031129978659D-07+(azi- 0.50D+02) * rk( 17)
         rk( 17)=-0.7471283994932429D-06+(azi- 0.50D+02) * rk( 17)
         rk( 17)= 0.5186820000000000D-04+(azi- 0.50D+02) * rk( 17)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 17)=-0.1549133645981479D-09
         rk( 17)=-0.1937785755245395D-07+(azi- 0.60D+02) * rk( 17)
         rk( 17)=-0.1061610088015651D-05+(azi- 0.60D+02) * rk( 17)
         rk( 17)= 0.4294630000000000D-04+(azi- 0.60D+02) * rk( 17)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 17)= 0.8239190057393872D-09
         rk( 17)=-0.2402525849039683D-07+(azi- 0.70D+02) * rk( 17)
         rk( 17)=-0.1495641248444166D-05+(azi- 0.70D+02) * rk( 17)
         rk( 17)= 0.3023750000000000D-04+(azi- 0.70D+02) * rk( 17)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 17)= 0.2660899281402167D-08
         rk( 17)=-0.4251202352641377D-08+(azi- 0.78D+02) * rk( 17)
         rk( 17)=-0.1721852935188484D-05+(azi- 0.78D+02) * rk( 17)
         rk( 17)= 0.1715660000000000D-04+(azi- 0.78D+02) * rk( 17)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 17)= 0.1671034307483684D-07
         rk( 17)= 0.5961038040102419D-07+(azi- 0.86D+02) * rk( 17)
         rk( 17)=-0.1278979510801584D-05+(azi- 0.86D+02) * rk( 17)
         rk( 17)= 0.4472080000000000D-05+(azi- 0.86D+02) * rk( 17)
      elseif(azi.ge.90.D0)then
         rk( 17)= 0.1379390000000000D-05
      endif
      if(att.lt.0.99999) rk( 17) = rk( 17) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 18)=-0.4649884923986659D-10
         rk( 18)=-0.3874011507601327D-08+(azi- 0.00D+00) * rk( 18)
         rk( 18)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 18)
         rk( 18)= 0.2781010000000000D-04+(azi- 0.00D+00) * rk( 18)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 18)= 0.2349654771959617D-10
         rk( 18)=-0.5268976984797324D-08+(azi- 0.10D+02) * rk( 18)
         rk( 18)=-0.9142988492398653D-07+(azi- 0.10D+02) * rk( 18)
         rk( 18)= 0.2737620000000000D-04+(azi- 0.10D+02) * rk( 18)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 18)=-0.4087341638514865D-11
         rk( 18)=-0.4564080553209436D-08+(azi- 0.20D+02) * rk( 18)
         rk( 18)=-0.1897604603040542D-06+(azi- 0.20D+02) * rk( 18)
         rk( 18)= 0.2595850000000000D-04+(azi- 0.20D+02) * rk( 18)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 18)= 0.8252818834464185D-11
         rk( 18)=-0.4686700802364881D-08+(azi- 0.30D+02) * rk( 18)
         rk( 18)=-0.2822682738597972D-06+(azi- 0.30D+02) * rk( 18)
         rk( 18)= 0.2360040000000000D-04+(azi- 0.30D+02) * rk( 18)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 18)= 0.2837606630065219D-10
         rk( 18)=-0.4439116237330941D-08+(azi- 0.40D+02) * rk( 18)
         rk( 18)=-0.3735264442567555D-06+(azi- 0.40D+02) * rk( 18)
         rk( 18)= 0.2031730000000000D-04+(azi- 0.40D+02) * rk( 18)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 18)= 0.5284291596291778D-10
         rk( 18)=-0.3587834248311254D-08+(azi- 0.50D+02) * rk( 18)
         rk( 18)=-0.4537959491131773D-06+(azi- 0.50D+02) * rk( 18)
         rk( 18)= 0.1616650000000000D-04+(azi- 0.50D+02) * rk( 18)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 18)= 0.2535522698475817D-09
         rk( 18)=-0.2002546769423132D-08+(azi- 0.60D+02) * rk( 18)
         rk( 18)=-0.5096997592905311D-06+(azi- 0.60D+02) * rk( 18)
         rk( 18)= 0.1132260000000000D-04+(azi- 0.60D+02) * rk( 18)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 18)= 0.2218412986971257D-09
         rk( 18)= 0.5604021326007098D-08+(azi- 0.70D+02) * rk( 18)
         rk( 18)=-0.4736850137246986D-06+(azi- 0.70D+02) * rk( 18)
         rk( 18)= 0.6278900000000000D-05+(azi- 0.70D+02) * rk( 18)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 18)=-0.2840497156138616D-09
         rk( 18)= 0.1092821249474490D-07+(azi- 0.78D+02) * rk( 18)
         rk( 18)=-0.3414271431586551D-06+(azi- 0.78D+02) * rk( 18)
         rk( 18)= 0.2961660000000000D-05+(azi- 0.78D+02) * rk( 18)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 18)= 0.3921356960025574D-08
         rk( 18)= 0.4111019320025769D-08+(azi- 0.86D+02) * rk( 18)
         rk( 18)=-0.2211132886406525D-06+(azi- 0.86D+02) * rk( 18)
         rk( 18)= 0.7842150000000000D-06+(azi- 0.86D+02) * rk( 18)
      elseif(azi.ge.90.D0)then
         rk( 18)= 0.2165050000000000D-06
      endif
      if(att.lt.0.99999) rk( 18) = rk( 18) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 19)=-0.1826021023809210D-09
         rk( 19)=-0.1228397897619083D-07+(azi- 0.00D+00) * rk( 19)
         rk( 19)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 19)
         rk( 19)= 0.1204770000000000D-03+(azi- 0.00D+00) * rk( 19)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 19)= 0.7680630714277428D-10
         rk( 19)=-0.1776204204761846D-07+(azi- 0.10D+02) * rk( 19)
         rk( 19)=-0.3004602102380929D-06+(azi- 0.10D+02) * rk( 19)
         rk( 19)= 0.1190660000000000D-03+(azi- 0.10D+02) * rk( 19)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 19)=-0.4662312619018003D-10
         rk( 19)=-0.1545785283333524D-07+(azi- 0.20D+02) * rk( 19)
         rk( 19)=-0.6326591590476300D-06+(azi- 0.20D+02) * rk( 19)
         rk( 19)= 0.1143620000000000D-03+(azi- 0.20D+02) * rk( 19)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 19)=-0.3391380238202962D-10
         rk( 19)=-0.1685654661904070D-07+(azi- 0.30D+02) * rk( 19)
         rk( 19)=-0.9558031535713891D-06+(azi- 0.30D+02) * rk( 19)
         rk( 19)= 0.1064430000000000D-03+(azi- 0.30D+02) * rk( 19)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 19)=-0.3482166428168610D-10
         rk( 19)=-0.1787396069050171D-07+(azi- 0.40D+02) * rk( 19)
         rk( 19)=-0.1303108226666813D-05+(azi- 0.40D+02) * rk( 19)
         rk( 19)= 0.9516540000000000D-04+(azi- 0.40D+02) * rk( 19)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 19)=-0.9419954049141070D-10
         rk( 19)=-0.1891861061895139D-07+(azi- 0.50D+02) * rk( 19)
         rk( 19)=-0.1671033939761346D-05+(azi- 0.50D+02) * rk( 19)
         rk( 19)= 0.8031210000000001D-04+(azi- 0.50D+02) * rk( 19)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 19)= 0.4307198262475603D-09
         rk( 19)=-0.2174459683369594D-07+(azi- 0.60D+02) * rk( 19)
         rk( 19)=-0.2077666014287819D-05+(azi- 0.60D+02) * rk( 19)
         rk( 19)= 0.6161569999999999D-04+(azi- 0.60D+02) * rk( 19)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 19)= 0.1932828429020804D-08
         rk( 19)=-0.8823002046251790D-08+(azi- 0.70D+02) * rk( 19)
         rk( 19)=-0.2383342003087370D-05+(azi- 0.70D+02) * rk( 19)
         rk( 19)= 0.3909530000000000D-04+(azi- 0.70D+02) * rk( 19)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 19)= 0.7078805395703406D-10
         rk( 19)= 0.3756488025027462D-07+(azi- 0.78D+02) * rk( 19)
         rk( 19)=-0.2153406977455360D-05+(azi- 0.78D+02) * rk( 19)
         rk( 19)= 0.2045350000000000D-04+(azi- 0.78D+02) * rk( 19)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 19)= 0.2551390080691808D-07
         rk( 19)= 0.3926379354513499D-07+(azi- 0.86D+02) * rk( 19)
         rk( 19)=-0.1538777587091867D-05+(azi- 0.86D+02) * rk( 19)
         rk( 19)= 0.5666640000000000D-05+(azi- 0.86D+02) * rk( 19)
      elseif(azi.ge.90.D0)then
         rk( 19)= 0.1772640000000000D-05
      endif
      if(att.lt.0.99999) rk( 19) = rk( 19) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 20)=-0.8584948998100682D-09
         rk( 20)=-0.6414505100189955D-07+(azi- 0.00D+00) * rk( 20)
         rk( 20)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 20)
         rk( 20)= 0.5609260000000000D-03+(azi- 0.00D+00) * rk( 20)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 20)= 0.3254846994303396D-09
         rk( 20)=-0.8989989799620159D-07+(azi- 0.10D+02) * rk( 20)
         rk( 20)=-0.1540449489981011D-05+(azi- 0.10D+02) * rk( 20)
         rk( 20)= 0.5536530000000000D-03+(azi- 0.10D+02) * rk( 20)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 20)=-0.2454438979115427D-09
         rk( 20)=-0.8013535701329142D-07+(azi- 0.20D+02) * rk( 20)
         rk( 20)=-0.3240802040075941D-05+(azi- 0.20D+02) * rk( 20)
         rk( 20)= 0.5295840000000000D-03+(azi- 0.20D+02) * rk( 20)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 20)=-0.1557091077838690D-09
         rk( 20)=-0.8749867395063758D-07+(azi- 0.30D+02) * rk( 20)
         rk( 20)=-0.4917142349715231D-05+(azi- 0.30D+02) * rk( 20)
         rk( 20)= 0.4889170000000000D-03+(azi- 0.30D+02) * rk( 20)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 20)= 0.5928032904712242D-10
         rk( 20)=-0.9216994718415395D-07+(azi- 0.40D+02) * rk( 20)
         rk( 20)=-0.6713828561063149D-05+(azi- 0.40D+02) * rk( 20)
         rk( 20)= 0.4308400000000000D-03+(azi- 0.40D+02) * rk( 20)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 20)= 0.2595877915946566D-09
         rk( 20)=-0.9039153731273745D-07+(azi- 0.50D+02) * rk( 20)
         rk( 20)=-0.8539443406032075D-05+(azi- 0.50D+02) * rk( 20)
         rk( 20)= 0.3545440000000000D-03+(azi- 0.50D+02) * rk( 20)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 20)= 0.4590368504576727D-08
         rk( 20)=-0.8260390356489925D-07+(azi- 0.60D+02) * rk( 20)
         rk( 20)=-0.1026939781480862D-04+(azi- 0.60D+02) * rk( 20)
         rk( 20)= 0.2603700000000000D-03+(azi- 0.60D+02) * rk( 20)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 20)= 0.7530009721151624D-08
         rk( 20)= 0.5510715157242705D-07+(azi- 0.70D+02) * rk( 20)
         rk( 20)=-0.1054436533473341D-04+(azi- 0.70D+02) * rk( 20)
         rk( 20)= 0.1540060000000000D-03+(azi- 0.70D+02) * rk( 20)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 20)=-0.7917656811329901D-08
         rk( 20)= 0.2358273848799034D-06+(azi- 0.78D+02) * rk( 20)
         rk( 20)=-0.8216889043114103D-05+(azi- 0.78D+02) * rk( 20)
         rk( 20)= 0.7703330000000000D-04+(azi- 0.78D+02) * rk( 20)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 20)= 0.1166127504488929D-06
         rk( 20)= 0.4580362140798608D-07+(azi- 0.86D+02) * rk( 20)
         rk( 20)=-0.5963840992810121D-05+(azi- 0.86D+02) * rk( 20)
         rk( 20)= 0.2233730000000000D-04+(azi- 0.86D+02) * rk( 20)
      elseif(azi.ge.90.D0)then
         rk( 20)= 0.6678010000000000D-05
      endif
      if(att.lt.0.99999) rk( 20) = rk( 20) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 21)=-0.6650705923705501D-11
         rk( 21)=-0.6611929407629448D-09+(azi- 0.00D+00) * rk( 21)
         rk( 21)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 21)
         rk( 21)= 0.3379090000000000D-05+(azi- 0.00D+00) * rk( 21)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 21)= 0.5602117771116336D-11
         rk( 21)=-0.8607141184741093D-09+(azi- 0.10D+02) * rk( 21)
         rk( 21)=-0.1521907059237054D-07+(azi- 0.10D+02) * rk( 21)
         rk( 21)= 0.3306320000000000D-05+(azi- 0.10D+02) * rk( 21)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 21)= 0.2622234839240057D-11
         rk( 21)=-0.6926505853406192D-09+(azi- 0.20D+02) * rk( 21)
         rk( 21)=-0.3075271763051782D-07+(azi- 0.20D+02) * rk( 21)
         rk( 21)= 0.3073660000000000D-05+(azi- 0.20D+02) * rk( 21)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 21)= 0.6018942871923531D-11
         rk( 21)=-0.6139835401634149D-09+(azi- 0.30D+02) * rk( 21)
         rk( 21)=-0.4381905888555817D-07+(azi- 0.30D+02) * rk( 21)
         rk( 21)= 0.2699490000000000D-05+(azi- 0.30D+02) * rk( 21)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 21)= 0.9631993673065927D-11
         rk( 21)=-0.4334152540057025D-09+(azi- 0.40D+02) * rk( 21)
         rk( 21)=-0.5429304682724942D-07+(azi- 0.40D+02) * rk( 21)
         rk( 21)= 0.2205920000000000D-05+(azi- 0.40D+02) * rk( 21)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 21)= 0.1346308243580085D-10
         rk( 21)=-0.1444554438136832D-09+(azi- 0.50D+02) * rk( 21)
         rk( 21)=-0.6007175380544338D-07+(azi- 0.50D+02) * rk( 21)
         rk( 21)= 0.1629280000000000D-05+(azi- 0.50D+02) * rk( 21)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 21)= 0.2754267658374655D-10
         rk( 21)= 0.2594370292602514D-09+(azi- 0.60D+02) * rk( 21)
         rk( 21)=-0.5892193795097818D-07+(azi- 0.60D+02) * rk( 21)
         rk( 21)= 0.1027580000000000D-05+(azi- 0.60D+02) * rk( 21)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 21)= 0.3078605882291204D-11
         rk( 21)= 0.1085717326772708D-08+(azi- 0.70D+02) * rk( 21)
         rk( 21)=-0.4547039439065166D-07+(azi- 0.70D+02) * rk( 21)
         rk( 21)= 0.4918470000000000D-06+(azi- 0.70D+02) * rk( 21)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 21)=-0.2153154079260804D-10
         rk( 21)= 0.1159603867948544D-08+(azi- 0.78D+02) * rk( 21)
         rk( 21)=-0.2750782483287924D-07+(azi- 0.78D+02) * rk( 21)
         rk( 21)= 0.1991460000000000D-06+(azi- 0.78D+02) * rk( 21)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 21)= 0.1655300763857872D-09
         rk( 21)= 0.6428468889259512D-09+(azi- 0.86D+02) * rk( 21)
         rk( 21)=-0.1308821877788330D-07+(azi- 0.86D+02) * rk( 21)
         rk( 21)= 0.4227390000000000D-07+(azi- 0.86D+02) * rk( 21)
      elseif(azi.ge.90.D0)then
         rk( 21)= 0.1080050000000000D-07
      endif
      if(att.lt.0.99999) rk( 21) = rk( 21) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 22)=-0.2585136204500944D-10
         rk( 22)=-0.2698286379549904D-08+(azi- 0.00D+00) * rk( 22)
         rk( 22)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 22)
         rk( 22)= 0.1221014000000000D-04+(azi- 0.00D+00) * rk( 22)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 22)= 0.2443408613502741D-10
         rk( 22)=-0.3473827240900187D-08+(azi- 0.10D+02) * rk( 22)
         rk( 22)=-0.6172113620450092D-07+(azi- 0.10D+02) * rk( 22)
         rk( 22)= 0.1191446000000000D-04+(azi- 0.10D+02) * rk( 22)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 22)= 0.1445501750490211D-10
         rk( 22)=-0.2740804656849367D-08+(azi- 0.20D+02) * rk( 22)
         rk( 22)=-0.1238674551819964D-06+(azi- 0.20D+02) * rk( 22)
         rk( 22)= 0.1097430000000000D-04+(azi- 0.20D+02) * rk( 22)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 22)= 0.3042584384536232D-10
         rk( 22)=-0.2307154131702309D-08+(azi- 0.30D+02) * rk( 22)
         rk( 22)=-0.1743470430675132D-06+(azi- 0.30D+02) * rk( 22)
         rk( 22)= 0.9476000000000000D-05+(azi- 0.30D+02) * rk( 22)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 22)= 0.4602160711365508D-10
         rk( 22)=-0.1394378816341430D-08+(azi- 0.40D+02) * rk( 22)
         rk( 22)=-0.2113623725479505D-06+(azi- 0.40D+02) * rk( 22)
         rk( 22)= 0.7532240000000000D-05+(azi- 0.40D+02) * rk( 22)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 22)= 0.6212772769998392D-10
         rk( 22)=-0.1373060293170293D-10+(azi- 0.50D+02) * rk( 22)
         rk( 22)=-0.2254434667406807D-06+(azi- 0.50D+02) * rk( 22)
         rk( 22)= 0.5325200000000000D-05+(azi- 0.50D+02) * rk( 22)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 22)= 0.9063748208640981D-10
         rk( 22)= 0.1850101228067824D-08+(azi- 0.60D+02) * rk( 22)
         rk( 22)=-0.2070797604893206D-06+(azi- 0.60D+02) * rk( 22)
         rk( 22)= 0.3131520000000000D-05+(azi- 0.60D+02) * rk( 22)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 22)=-0.2607522223803122D-10
         rk( 22)= 0.4569225690660155D-08+(azi- 0.70D+02) * rk( 22)
         rk( 22)=-0.1428864913020439D-06+(azi- 0.70D+02) * rk( 22)
         rk( 22)= 0.1336370000000000D-05+(azi- 0.70D+02) * rk( 22)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 22)=-0.8154476459752011D-10
         rk( 22)= 0.3943420356937241D-08+(azi- 0.78D+02) * rk( 22)
         rk( 22)=-0.7478532292122784D-07+(azi- 0.78D+02) * rk( 22)
         rk( 22)= 0.4723580000000000D-06+(azi- 0.78D+02) * rk( 22)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 22)= 0.2386754991660304D-09
         rk( 22)= 0.1986346006596759D-08+(azi- 0.86D+02) * rk( 22)
         rk( 22)=-0.2734719201301013D-07+(azi- 0.86D+02) * rk( 22)
         rk( 22)= 0.8470340000000000D-07+(azi- 0.86D+02) * rk( 22)
      elseif(azi.ge.90.D0)then
         rk( 22)= 0.2237140000000000D-07
      endif
      if(att.lt.0.99999) rk( 22) = rk( 22) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 23)=-0.2139600241835119D-11
         rk( 23)=-0.2151039975816486D-09+(azi- 0.00D+00) * rk( 23)
         rk( 23)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 23)
         rk( 23)= 0.1065630000000000D-05+(azi- 0.00D+00) * rk( 23)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 23)= 0.1813800725505305D-11
         rk( 23)=-0.2792920048367021D-09+(azi- 0.10D+02) * rk( 23)
         rk( 23)=-0.4943960024183507D-08+(azi- 0.10D+02) * rk( 23)
         rk( 23)= 0.1041980000000000D-05+(azi- 0.10D+02) * rk( 23)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 23)= 0.9033973398139053D-12
         rk( 23)=-0.2248779830715429D-09+(azi- 0.20D+02) * rk( 23)
         rk( 23)=-0.9985659903265959D-08+(azi- 0.20D+02) * rk( 23)
         rk( 23)= 0.9664250000000000D-06+(azi- 0.20D+02) * rk( 23)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 23)= 0.2075609915239216D-11
         rk( 23)=-0.1977760628771271D-09+(azi- 0.30D+02) * rk( 23)
         rk( 23)=-0.1421220036275265D-07+(azi- 0.30D+02) * rk( 23)
         rk( 23)= 0.8449840000000000D-06+(azi- 0.30D+02) * rk( 23)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 23)= 0.3345162999229720D-11
         rk( 23)=-0.1355077654199492D-09+(azi- 0.40D+02) * rk( 23)
         rk( 23)=-0.1754503864572343D-07+(azi- 0.40D+02) * rk( 23)
         rk( 23)= 0.6851600000000000D-06+(azi- 0.40D+02) * rk( 23)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 23)= 0.4733738087840769D-11
         rk( 23)=-0.3515287544305134D-10+(azi- 0.50D+02) * rk( 23)
         rk( 23)=-0.1925164505435348D-07+(azi- 0.50D+02) * rk( 23)
         rk( 23)= 0.4995040000000001D-06+(azi- 0.50D+02) * rk( 23)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 23)= 0.8639884649395565D-11
         rk( 23)= 0.1068592671922140D-09+(azi- 0.60D+02) * rk( 23)
         rk( 23)=-0.1853458113686210D-07+(azi- 0.60D+02) * rk( 23)
         rk( 23)= 0.3082060000000000D-06+(azi- 0.60D+02) * rk( 23)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 23)=-0.6489929988116252D-13
         rk( 23)= 0.3660558066739854D-09+(azi- 0.70D+02) * rk( 23)
         rk( 23)=-0.1380543039820027D-07+(azi- 0.70D+02) * rk( 23)
         rk( 23)= 0.1421860000000000D-06+(azi- 0.70D+02) * rk( 23)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 23)=-0.7060744231570133D-11
         rk( 23)= 0.3644982234768375D-09+(azi- 0.78D+02) * rk( 23)
         rk( 23)=-0.7960998156992907D-08+(azi- 0.78D+02) * rk( 23)
         rk( 23)= 0.5513690000000000D-07+(azi- 0.78D+02) * rk( 23)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 23)= 0.4009097038578255D-10
         rk( 23)= 0.1950403619166119D-09+(azi- 0.86D+02) * rk( 23)
         rk( 23)=-0.3484689473838533D-08+(azi- 0.86D+02) * rk( 23)
         rk( 23)= 0.1116170000000000D-07+(azi- 0.86D+02) * rk( 23)
      elseif(azi.ge.90.D0)then
         rk( 23)= 0.2909410000000000D-08
      endif
      if(att.lt.0.99999) rk( 23) = rk( 23) * att
C     
      rk( 24) = SumM * 6.0d-34 * (temp/3.d2) ** (-2.3d0)
      rk( 24) = rk( 24) * SumM * 0.2d0
      rk( 25) =  DEXP(-0.2575921893902696D+02
     &     - ( -0.1200000000000000D+03 )/temp)
      rk( 26) =  DEXP(-0.2474064935803238D+02
     &     - ( -0.1100000000000000D+03 )/temp)
      rk( 26) = rk( 26) * SumM * 0.8d0
      rk( 27) =  DEXP(-0.2416528521312882D+02
     &     - ( -0.7000000000000000D+02 )/temp)
      rk( 27) = rk( 27) * SumM * 0.2d0
      rk( 28) =  0.2200000000000000D-09
      rk( 28) = rk( 28) * YlH2O
      rk( 29) =  DEXP(-0.2693787393536860D+02
     &     - (  0.1400000000000000D+04 )/temp)
      rk( 30) =  DEXP(-0.2716101748668281D+02
     &     - (  0.9400000000000000D+03 )/temp)
      rk( 31) =  DEXP(-0.3214088112211231D+02
     &     - (  0.5000000000000000D+03 )/temp)
      rk( 32) =  DEXP(-0.2632268829627837D+02
     &     - ( -0.2400000000000000D+03 )/temp)
      Effko =  0.1800000000000000D-30* (temp / 3.d2)
     &     **(- ( 0.3200000000000000D+01))
      Rapk =  0.4700000000000000D-11* (temp / 3.d2)
     &     **(- ( 0.1400000000000000D+01))
      rk( 33) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.6000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk( 34) =  DEXP( 0.6142746008608852D+02
     &     - (  0.1090000000000000D+05 )/temp)
      Effko =  0.1800000000000000D-30* (temp / 3.d2)
     &     **(- ( 0.3200000000000000D+01))
      Rapk =  0.4700000000000000D-11* (temp / 3.d2)
     &     **(- ( 0.1400000000000000D+01))
      facteur = (Effko * SumM / ( 1.0d0 + Effko * SumM / 
     &     Rapk)) * 0.6d0 ** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk( 34) = facteur * rk( 34)
      rk( 35) = 2.2d-13 * dexp(620.0d0 / temp)
     &     + 1.9d-33* SumM * dexp(980.0d0 / temp)
      rk( 36) = 3.08d-34 * dexp(2820.0d0 / temp) + 
     &     2.66d-54 * SumM * dexp(3180.0d0 / temp)
      rk( 36) = rk( 36) * YlH2O
      rk( 37) =  DEXP(-0.2643709864745611D+02
     &     - (  0.2000000000000000D+03 )/temp)
      Effko =  0.7000000000000000D-30* (temp / 3.d2)
     &     **(- ( 0.2600000000000000D+01))
      Rapk =  0.1500000000000000D-10* (temp / 3.d2)
     &     **(- ( 0.5000000000000000D+00))
      rk( 38) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.6000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk( 39) =  DEXP(-0.8860689615829534D+02
     &     - ( -0.5300000000000000D+03 )/temp)
      rk( 39) = rk( 39) * SumM * 0.2d0
      rk( 40) =  DEXP(-0.2959713397230138D+02
     &     - (  0.2500000000000000D+04 )/temp)
      rk( 41) =  DEXP(-0.2479780777187233D+02
     &     - ( -0.1500000000000000D+03 )/temp)
      rk( 42) =  DEXP(-0.3131990057004248D+02
     &     - (  0.1230000000000000D+04 )/temp)
      rk( 43) =  0.2500000000000000D-11
      Effko =  0.2200000000000000D-29* (temp / 3.d2)
     &     **(- ( 0.3900000000000000D+01))
      Rapk =  0.1500000000000000D-11* (temp / 3.d2)
     &     **(- ( 0.7000000000000000D+00))
      rk( 44) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.6000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk( 45) =  DEXP( 0.6207438732603458D+02
     &     - (  0.1120000000000000D+05 )/temp)
      Effko =  0.2200000000000000D-29* (temp / 3.d2)
     &     **(- ( 0.4300000000000000D+01))
      Rapk =  0.1500000000000000D-11* (temp / 3.d2)
     &     **(- ( 0.5000000000000000D+00))
      facteur = (Effko * SumM / ( 1.0d0 + Effko * SumM / 
     &     Rapk)) * 0.6d0 ** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk( 45) = facteur * rk( 45)
      Effko =  0.2600000000000000D-29* (temp / 3.d2)
     &     **(- ( 0.3200000000000000D+01))
      Rapk =  0.2400000000000000D-10* (temp / 3.d2)
     &     **(- ( 0.1300000000000000D+01))
      rk( 46) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.6000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      Effko = 7.2d-15 * dexp(785.0d0 / temp)
      Rapk = 4.1d-16 * dexp(1440.0d0 / temp)
      facteur =1.9d-33 * dexp(725.0d0 / temp) * SumM
      rk( 47) = Effko + facteur/(1.0d0 + facteur / Rapk)
      rk( 48) =  DEXP(-0.2736865685146106D+02
     &     - ( -0.3800000000000000D+03 )/temp)
      rk( 49) =  DEXP(-0.2380237971943945D+02
     &     - ( -0.2300000000000000D+03 )/temp)
      Effko =  0.3000000000000000D-30* (temp / 3.d2)
     &     **(- ( 0.3300000000000000D+01))
      Rapk =  0.1500000000000000D-11* (temp / 3.d2)
     &     **(- ( 0.0000000000000000D+00))
      rk( 50) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.6000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk( 51) = 1.5d-13 * (1.0d0 + 2.439d-20 * SumM)
      rk( 52) =  DEXP(-0.3950779001431612D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     -  0.1280000000000000D+04/temp)
      rk( 53) =  DEXP(-0.3882913584105874D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     -  0.4440000000000000D+03/temp)
      rk( 54) =  DEXP(-0.2484600987369021D+02
     &     - (  0.7700000000000000D+03 )/temp)
      rk( 55) =  DEXP(-0.2487736040357429D+02
     &     - (  0.5400000000000000D+03 )/temp)
      rk( 56) =  DEXP(-0.2403645234128585D+02
     &     - (  0.3800000000000000D+03 )/temp)
      rk( 57) =  DEXP(-0.2686555327378898D+02
     &     - ( -0.4110000000000000D+03 )/temp)
      rk( 58) =  DEXP(-0.2595954781257500D+02
     &     - ( -0.5040000000000000D+03 )/temp)
      rk( 59) =  DEXP(-0.2526077737446069D+02
     &     - ( -0.5490000000000000D+03 )/temp)
      rk( 60) =  DEXP(-0.2688908377119917D+02
     &     - ( -0.3220000000000000D+03 )/temp)
      rk( 61) =  DEXP(-0.2469185919386295D+02
     &     - ( -0.1160000000000000D+03 )/temp)
      rk( 62) =  0.4000000000000000D-10
      rk( 63) =  0.3600000000000000D-10
      rk( 64) =  0.9000000000000000D-11
      rk( 65) =  DEXP(-0.2570385700969429D+02
     &     - ( -0.2560000000000000D+03 )/temp)
      rk( 66) =  DEXP(-0.2514611446614055D+02
     &     - (  0.7450000000000000D+03 )/temp)
      rk( 67) =  0.1150000000000000D-10
      rk( 68) =  0.1700000000000000D-10
      rk( 69) =  0.2800000000000000D-10
      rk( 70) =  0.9999999999999999D-11
      rk( 71) =  0.9999999999999999D-11
      rk( 72) =  0.9999999999999999D-11
      rk( 73) =  DEXP(-0.3952228302161869D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     -  0.4440000000000000D+03/temp)
      rk( 74) =  DEXP(-0.2596142928067470D+02
     &     - (  0.2600000000000000D+03 )/temp)
      rk( 75) =  DEXP(-0.2439234266376417D+02
     &     - ( -0.4090000000000000D+03 )/temp)
      Effko =  0.9700000000000000D-28* (temp / 3.d2)
     &     **(- ( 0.5600000000000000D+01))
      Rapk =  0.9300000000000000D-11* (temp / 3.d2)
     &     **(- ( 0.1500000000000000D+01))
      rk( 76) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.6000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk( 77) =  DEXP( 0.6462080260895155D+02
     &     - (  0.1395400000000000D+05 )/temp)
      Effko =  0.9700000000000000D-28* (temp / 3.d2)
     &     **(- ( 0.5600000000000000D+01))
      Rapk =  0.9300000000000000D-11* (temp / 3.d2)
     &     **(- ( 0.1500000000000000D+01))
      facteur = (Effko * SumM / ( 1.0d0 + Effko * SumM / 
     &     Rapk)) * 0.6d0 ** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk( 77) = facteur * rk( 77)
      Effko =  0.9700000000000000D-28* (temp / 3.d2)
     &     **(- ( 0.5600000000000000D+01))
      Rapk =  0.9300000000000000D-11* (temp / 3.d2)
     &     **(- ( 0.1500000000000000D+01))
      rk( 78) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.6000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk( 79) =  DEXP( 0.6462080260895155D+02
     &     - (  0.1395400000000000D+05 )/temp)
      Effko =  0.9700000000000000D-28* (temp / 3.d2)
     &     **(- ( 0.5600000000000000D+01))
      Rapk =  0.9300000000000000D-11* (temp / 3.d2)
     &     **(- ( 0.1500000000000000D+01))
      facteur = (Effko * SumM / ( 1.0d0 + Effko * SumM / 
     &     Rapk)) * 0.6d0 ** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk( 79) = facteur * rk( 79)
      rk( 80) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 81) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 82) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 83) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 84) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 85) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 86) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 87) =  0.2000000000000000D-10
      rk( 88) =  0.2000000000000000D-10
      rk( 89) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 90) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 91) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 92) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 93) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 94) =  DEXP(-0.2814184673969454D+02
     &     - (  0.2058000000000000D+04 )/temp)
      rk( 95) =  DEXP(-0.2729454887930734D+02
     &     - (  0.1900000000000000D+04 )/temp)
      rk( 96) =  DEXP(-0.2814184673969454D+02
     &     - (  0.2058000000000000D+04 )/temp)
      rk( 97) =  DEXP(-0.2729454887930734D+02
     &     - (  0.1900000000000000D+04 )/temp)
      rk( 98) =  DEXP(-0.2729454887930734D+02
     &     - (  0.1900000000000000D+04 )/temp)
      rk( 99) =  0.2200000000000000D-10
      rk(100) =  DEXP(-0.2693787393536860D+02
     &     - (  0.2923000000000000D+04 )/temp)
      rk(101) =  DEXP(-0.2532843602293450D+02
     &     - (  0.1895000000000000D+04 )/temp)
      rk(102) =  DEXP(-0.2415595388569994D+02
     &     - (  0.9750000000000000D+03 )/temp)
      rk(103) =  DEXP(-0.2624472675480866D+02
     &     - (  0.4460000000000000D+03 )/temp)
      rk(104) =  DEXP(-0.3205386974512268D+02
     &     - (  0.2633000000000000D+04 )/temp)
      rk(105) =  DEXP(-0.3195855956531836D+02
     &     - (  0.2105000000000000D+04 )/temp)
      rk(106) =  DEXP(-0.3255227284889012D+02
     &     - (  0.1136000000000000D+04 )/temp)
      rk(107) =  DEXP(-0.3202917713253231D+02
     &     - (  0.2013000000000000D+04 )/temp)
      rk(108) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(109) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(110) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(111) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(112) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(113) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(114) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(115) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(116) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(117) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(118) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(119) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(120) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(121) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(122) =  DEXP(-0.2929175232275020D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(123) =  DEXP(-0.2959713397230138D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(124) =  DEXP(-0.3051342470417553D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(125) =  DEXP(-0.3007286827625610D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(126) =  DEXP(-0.3117148056492421D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(127) =  DEXP(-0.2959713397230138D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(128) =  DEXP(-0.2959713397230138D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(129) =  DEXP(-0.3170556305085447D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(130) =  DEXP(-0.3170556305085447D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(131) =  DEXP(-0.2767184311044880D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(132) =  DEXP(-0.3170556305085447D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(133) =  DEXP(-0.3170556305085447D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(134) =  DEXP(-0.2767184311044880D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(135) =  DEXP(-0.2870983077730048D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(136) =  DEXP(-0.2952814110081443D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(137) =  DEXP(-0.2880220409743149D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(138) =  DEXP(-0.2924045902836265D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(139) =  DEXP(-0.2870983077730048D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(140) =  DEXP(-0.2870983077730048D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(141) =  DEXP(-0.3080110677662732D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(142) =  DEXP(-0.3080110677662732D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(143) =  DEXP(-0.2745706780880511D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(144) =  DEXP(-0.3080110677662732D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(145) =  DEXP(-0.3080110677662732D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(146) =  DEXP(-0.2745706780880511D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(147) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(148) =  DEXP(-0.3170556305085447D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(149) =  DEXP(-0.3080110677662732D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(150) =  DEXP(-0.3556042764244267D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(151) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk(152) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk(153) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(154) =  DEXP(-0.3170556305085447D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(155) =  DEXP(-0.3080110677662732D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(156) =  DEXP(-0.3556042764244267D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(157) =  DEXP(-0.3170556305085447D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(158) =  DEXP(-0.3080110677662732D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(159) =  DEXP(-0.3556042764244267D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(160) =  DEXP(-0.2470785953520939D+02
     &     - ( -0.1750000000000000D+03 )/temp)
      rk(161) =  DEXP(-0.2621274370895561D+02
     &     - ( -0.4520000000000000D+03 )/temp)
      rk(162) =  DEXP(-0.2570385700969429D+02
     &     - ( -0.2560000000000000D+03 )/temp)
      rk(163) =  0.3000000000000000D-11
      rk(164) =  DEXP(-0.3305717185398647D+02
     &     - (  0.2500000000000000D+04 )/temp)
      rk(165) =  DEXP(-0.3315248203379080D+02
     &     - (  0.2000000000000000D+04 )/temp)
      rk(166) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk(167) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk(168) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk(169) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk(170) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(171) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(172) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(173) =  0.1000000000000000D-12
      rk(174) =  0.6000000000000000D-13
      rk(175) =  0.1000000000000000D-13
      rk(176) =  0.5000000000000000D-13
      rk(177) =  0.5000000000000000D-13
      rk(178) =  DEXP(-0.3918685408191006D+02
     &     - ( -0.3050000000000000D+03 )/temp)
      rk(179) =  DEXP(-0.2497777915132133D+02
     &     - (  0.3800000000000000D+03 )/temp)
      rk(180) =  DEXP(-0.2497777915132133D+02
     &     - (  0.3800000000000000D+03 )/temp)
      rk(181) =  DEXP(-0.2710039286486638D+02
     &     - (  0.2330000000000000D+03 )/temp)
      rk(182) =  DEXP(-0.2605204241097915D+02
     &     - ( -0.5040000000000000D+03 )/temp)
      rk(183) =  DEXP(-0.2575155606628139D+02
     &     - ( -0.4670000000000000D+03 )/temp)
      rk(184) =  DEXP(-0.2624472675480866D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk(185) =  DEXP(-0.2624472675480866D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk(186) =  DEXP(-0.2624472675480866D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk(187) =  DEXP(-0.2624472675480866D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk(188) =  DEXP(-0.2624472675480866D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk(189) =  DEXP(-0.2624472675480866D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk(190) =  0.4850000000000000D+01
      rk(191) =  DEXP(-0.2575155606628139D+02
     &     - (  0.1878000000000000D+04 )/temp)
      rk(192) =  DEXP(-0.3195855956531836D+02
     &     - (  0.2104000000000000D+04 )/temp)
      rk(193) =  DEXP(-0.3329750780584105D+02
     &     - (  0.1712000000000000D+04 )/temp)
      rk(194) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(195) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(196) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(197) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(198) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(199) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(200) =  DEXP(-0.3071013499842159D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(201) =  DEXP(-0.3077293589966062D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(202) =  DEXP(-0.3025795226574597D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(203) =  DEXP(-0.2959713397230138D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(204) =  DEXP(-0.2959713397230138D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(205) =  DEXP(-0.2959713397230138D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(206) =  DEXP(-0.2973475535017743D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(207) =  DEXP(-0.2959713397230138D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(208) =  DEXP(-0.2878938340900243D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(209) =  DEXP(-0.2870983077730048D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(210) =  DEXP(-0.2870983077730048D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(211) =  DEXP(-0.2870983077730048D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(212) =  DEXP(-0.2513781566332585D+02
     &     - ( -0.4440000000000000D+03 )/temp)
      rk(213) =  DEXP(-0.2745706780880511D+02
     &     - ( -0.4900000000000000D+03 )/temp)
      rk(214) =  DEXP(-0.3452882606405752D+02
     &     - (  0.7360000000000000D+03 )/temp)
      rk(215) =  0.4000000000000000D-11
      rk(216) =  0.1500000000000000D-10
      rk(217) =  DEXP(-0.3096643075705270D+02
     &     - ( -0.7080000000000000D+03 )/temp)
      rk(218) =  DEXP(-0.2793212620871247D+02
     &     - ( -0.7650000000000000D+03 )/temp)
      rk(219) =  0.1200000000000000D-11
      rk(220) =  0.1700000000000000D-09
      rk(221) =  0.1220000000000000D-10
      rk(222) =  0.2000000000000000D-15
      rk(223) =  0.4000000000000000D-11
      rk(224) =  0.1500000000000000D-10
      rk(225) =  DEXP(-0.3096643075705270D+02
     &     - ( -0.7080000000000000D+03 )/temp)
      rk(226) =  DEXP(-0.2793212620871247D+02
     &     - ( -0.7650000000000000D+03 )/temp)
      rk(227) =  0.1200000000000000D-11
      rk(228) =  DEXP(-0.2858293902544585D+02
     &     - ( -0.2640000000000000D+04 )/temp)
      
      RETURN
      END
      
