C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE LU_decompose (M)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes an LU factorization of M.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     M: on entry, an invertible matrix. On exit, an LU factorization
C     of M.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of 'chemical' arrays.

      INCLUDE 'PARACHEM.INC'

      DOUBLE PRECISION M(Nesp,Nesp)
      DOUBLE PRECISION temp


C     Upper part.
      M(1, 33) = M(1, 33) / M(1, 1)

C     Upper part.
      M(2, 33) = M(2, 33) / M(2, 2)

C     Upper part.
      M(3, 33) = M(3, 33) / M(3, 3)

C     Upper part.
      temp = M(4, 3) * M(3, 33)
      M(4, 33) = ( M(4, 33) - temp ) / M(4, 4)

C     Upper part.
      temp = M(5, 4) * M(4, 33)
      M(5, 33) = ( M(5, 33) - temp ) / M(5, 5)

C     Upper part.
      M(6, 28) = M(6, 28) / M(6, 6)
C     Upper part.
      M(6, 33) = M(6, 33) / M(6, 6)

C     Upper part.
      M(7, 33) = M(7, 33) / M(7, 7)
C     Upper part.
      M(7, 44) = M(7, 44) / M(7, 7)

C     Upper part.
      M(8, 41) = M(8, 41) / M(8, 8)
C     Upper part.
      M(8, 42) = M(8, 42) / M(8, 8)

C     Upper part.
      M(9, 33) = M(9, 33) / M(9, 9)
C     Upper part.
      M(9, 37) = M(9, 37) / M(9, 9)

C     Upper part.
      M(10, 33) = M(10, 33) / M(10, 10)
C     Upper part.
      M(10, 37) = M(10, 37) / M(10, 10)
C     Upper part.
      M(10, 39) = M(10, 39) / M(10, 10)

C     Upper part.
      M(11, 15) = M(11, 15) / M(11, 11)
C     Upper part.
      M(11, 33) = M(11, 33) / M(11, 11)
C     Upper part.
      M(11, 34) = M(11, 34) / M(11, 11)

C     Upper part.
      M(12, 33) = M(12, 33) / M(12, 12)
C     Upper part.
      M(12, 34) = M(12, 34) / M(12, 12)
C     Upper part.
      M(12, 41) = M(12, 41) / M(12, 12)

C     Upper part.
      M(13, 33) = M(13, 33) / M(13, 13)
C     Upper part.
      M(13, 39) = M(13, 39) / M(13, 13)
C     Upper part.
      M(13, 41) = M(13, 41) / M(13, 13)

C     Upper part.
      temp = M(14, 12) * M(12, 33)
      M(14, 33) = ( M(14, 33) - temp ) / M(14, 14)
C     Upper part.
      temp = M(14, 12) * M(12, 34)
      M(14, 34) = ( M(14, 34) - temp ) / M(14, 14)
C     Upper part.
      temp = M(14, 12) * M(12, 41)
      M(14, 41) = ( M(14, 41) - temp ) / M(14, 14)

C     Lower part.
      temp = M(33, 11) * M(11, 15)
      M(33, 15) = M(33, 15) - temp
C     Lower part.
      temp = M(37, 11) * M(11, 15)
      M(37, 15) = M(37, 15) - temp
C     Upper part.
      temp = M(15, 12) * M(12, 33)
      M(15, 33) = ( M(15, 33) - temp ) / M(15, 15)
C     Upper part.
      temp = M(15, 12) * M(12, 34)
      M(15, 34) = ( M(15, 34) - temp ) / M(15, 15)
C     Upper part.
      temp = M(15, 12) * M(12, 41)
      M(15, 41) = ( M(15, 41) - temp ) / M(15, 15)

C     Upper part.
      M(16, 19) = M(16, 19) / M(16, 16)
C     Upper part.
      temp = M(16, 15) * M(15, 33)
      M(16, 33) = ( M(16, 33) - temp ) / M(16, 16)
C     Upper part.
      temp = M(16, 15) * M(15, 34)
      M(16, 34) = ( M(16, 34) - temp ) / M(16, 16)
C     Upper part.
      temp = M(16, 15) * M(15, 41)
      M(16, 41) = ( M(16, 41) - temp ) / M(16, 16)

C     Upper part.
      temp = M(17, 4) * M(4, 33)
      temp = temp + M(17, 12) * M(12, 33)
      M(17, 33) = ( M(17, 33) - temp ) / M(17, 17)
C     Upper part.
      temp = M(17, 12) * M(12, 34)
      M(17, 34) = ( M(17, 34) - temp ) / M(17, 17)
C     Upper part.
      temp = M(17, 12) * M(12, 41)
      M(17, 41) = ( M(17, 41) - temp ) / M(17, 17)

C     Upper part.
      M(18, 27) = M(18, 27) / M(18, 18)
C     Upper part.
      temp = M(18, 3) * M(3, 33)
      temp = temp + M(18, 4) * M(4, 33)
      temp = temp + M(18, 14) * M(14, 33)
      temp = temp + M(18, 17) * M(17, 33)
      M(18, 33) = ( M(18, 33) - temp ) / M(18, 18)
C     Upper part.
      temp = M(18, 14) * M(14, 34)
      temp = temp + M(18, 17) * M(17, 34)
      M(18, 34) = ( M(18, 34) - temp ) / M(18, 18)
C     Upper part.
      temp = M(18, 14) * M(14, 41)
      temp = temp + M(18, 17) * M(17, 41)
      M(18, 41) = ( M(18, 41) - temp ) / M(18, 18)

C     Lower part.
      temp = M(29, 16) * M(16, 19)
      M(29, 19) = M(29, 19) - temp
C     Lower part.
      temp = M(31, 16) * M(16, 19)
      M(31, 19) = M(31, 19) - temp
C     Lower part.
      temp = M(33, 16) * M(16, 19)
      M(33, 19) = M(33, 19) - temp
C     Lower part.
      temp = M(42, 16) * M(16, 19)
      M(42, 19) = M(42, 19) - temp
C     Upper part.
      M(19, 33) = M(19, 33) / M(19, 19)
C     Upper part.
      M(19, 34) = M(19, 34) / M(19, 19)
C     Upper part.
      M(19, 41) = M(19, 41) / M(19, 19)

C     Upper part.
      M(20, 33) = M(20, 33) / M(20, 20)
C     Upper part.
      M(20, 36) = M(20, 36) / M(20, 20)
C     Upper part.
      M(20, 39) = M(20, 39) / M(20, 20)

C     Upper part.
      M(21, 33) = M(21, 33) / M(21, 21)
C     Upper part.
      M(21, 35) = M(21, 35) / M(21, 21)
C     Upper part.
      M(21, 39) = M(21, 39) / M(21, 21)

C     Upper part.
      M(22, 33) = M(22, 33) / M(22, 22)
C     Upper part.
      M(22, 34) = M(22, 34) / M(22, 22)
C     Upper part.
      M(22, 41) = M(22, 41) / M(22, 22)

C     Upper part.
      M(23, 33) = M(23, 33) / M(23, 23)
C     Upper part.
      M(23, 42) = M(23, 42) / M(23, 23)
C     Upper part.
      M(23, 43) = M(23, 43) / M(23, 23)

C     Upper part.
      M(24, 33) = M(24, 33) / M(24, 24)
C     Upper part.
      M(24, 39) = M(24, 39) / M(24, 24)
C     Upper part.
      M(24, 40) = M(24, 40) / M(24, 24)

C     Upper part.
      M(25, 33) = M(25, 33) / M(25, 25)
C     Upper part.
      M(25, 39) = M(25, 39) / M(25, 25)
C     Upper part.
      M(25, 43) = M(25, 43) / M(25, 25)

C     Upper part.
      M(26, 33) = M(26, 33) / M(26, 26)
C     Upper part.
      M(26, 40) = M(26, 40) / M(26, 26)
C     Upper part.
      M(26, 42) = M(26, 42) / M(26, 26)

C     Lower part.
      temp = M(31, 18) * M(18, 27)
      M(31, 27) = M(31, 27) - temp
C     Lower part.
      temp = M(33, 18) * M(18, 27)
      M(33, 27) = M(33, 27) - temp
C     Lower part.
      temp = M(39, 18) * M(18, 27)
      M(39, 27) = M(39, 27) - temp
C     Lower part.
      temp = M(43, 18) * M(18, 27)
      M(43, 27) = M(43, 27) - temp
C     Upper part.
      temp = M(27, 12) * M(12, 33)
      temp = temp + M(27, 17) * M(17, 33)
      M(27, 33) = ( M(27, 33) - temp ) / M(27, 27)
C     Upper part.
      temp = M(27, 12) * M(12, 34)
      temp = temp + M(27, 17) * M(17, 34)
      M(27, 34) = ( M(27, 34) - temp ) / M(27, 27)
C     Upper part.
      M(27, 36) = M(27, 36) / M(27, 27)
C     Upper part.
      temp = M(27, 12) * M(12, 41)
      temp = temp + M(27, 17) * M(17, 41)
      M(27, 41) = ( M(27, 41) - temp ) / M(27, 27)
C     Upper part.
      M(27, 44) = M(27, 44) / M(27, 27)

C     Lower part.
      temp = M(43, 6) * M(6, 28)
      M(43, 28) = M(43, 28) - temp
C     Upper part.
      temp = M(28, 2) * M(2, 33)
      temp = temp + M(28, 14) * M(14, 33)
      temp = temp + M(28, 22) * M(22, 33)
      temp = temp + M(28, 27) * M(27, 33)
      M(28, 33) = ( M(28, 33) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 14) * M(14, 34)
      temp = temp + M(28, 22) * M(22, 34)
      temp = temp + M(28, 27) * M(27, 34)
      M(28, 34) = ( M(28, 34) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 27) * M(27, 36)
      M(28, 36) = ( M(28, 36) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 14) * M(14, 41)
      temp = temp + M(28, 22) * M(22, 41)
      temp = temp + M(28, 27) * M(27, 41)
      M(28, 41) = ( M(28, 41) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 27) * M(27, 44)
      M(28, 44) = ( M(28, 44) - temp ) / M(28, 28)

C     Upper part.
      temp = M(29, 1) * M(1, 33)
      temp = temp + M(29, 2) * M(2, 33)
      temp = temp + M(29, 15) * M(15, 33)
      temp = temp + M(29, 16) * M(16, 33)
      temp = temp + M(29, 17) * M(17, 33)
      temp = temp + M(29, 19) * M(19, 33)
      temp = temp + M(29, 22) * M(22, 33)
      temp = temp + M(29, 27) * M(27, 33)
      temp = temp + M(29, 28) * M(28, 33)
      M(29, 33) = ( M(29, 33) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 15) * M(15, 34)
      temp = temp + M(29, 16) * M(16, 34)
      temp = temp + M(29, 17) * M(17, 34)
      temp = temp + M(29, 19) * M(19, 34)
      temp = temp + M(29, 22) * M(22, 34)
      temp = temp + M(29, 27) * M(27, 34)
      temp = temp + M(29, 28) * M(28, 34)
      M(29, 34) = ( M(29, 34) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 27) * M(27, 36)
      temp = temp + M(29, 28) * M(28, 36)
      M(29, 36) = ( M(29, 36) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 15) * M(15, 41)
      temp = temp + M(29, 16) * M(16, 41)
      temp = temp + M(29, 17) * M(17, 41)
      temp = temp + M(29, 19) * M(19, 41)
      temp = temp + M(29, 22) * M(22, 41)
      temp = temp + M(29, 27) * M(27, 41)
      temp = temp + M(29, 28) * M(28, 41)
      M(29, 41) = ( M(29, 41) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 27) * M(27, 44)
      temp = temp + M(29, 28) * M(28, 44)
      M(29, 44) = ( M(29, 44) - temp ) / M(29, 29)

C     Upper part.
      temp = M(30, 12) * M(12, 33)
      temp = temp + M(30, 15) * M(15, 33)
      temp = temp + M(30, 19) * M(19, 33)
      temp = temp + M(30, 22) * M(22, 33)
      temp = temp + M(30, 27) * M(27, 33)
      M(30, 33) = ( M(30, 33) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 12) * M(12, 34)
      temp = temp + M(30, 15) * M(15, 34)
      temp = temp + M(30, 19) * M(19, 34)
      temp = temp + M(30, 22) * M(22, 34)
      temp = temp + M(30, 27) * M(27, 34)
      M(30, 34) = ( M(30, 34) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 27) * M(27, 36)
      M(30, 36) = ( M(30, 36) - temp ) / M(30, 30)
C     Upper part.
      M(30, 39) = M(30, 39) / M(30, 30)
C     Upper part.
      temp = M(30, 12) * M(12, 41)
      temp = temp + M(30, 15) * M(15, 41)
      temp = temp + M(30, 19) * M(19, 41)
      temp = temp + M(30, 22) * M(22, 41)
      temp = temp + M(30, 27) * M(27, 41)
      M(30, 41) = ( M(30, 41) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 27) * M(27, 44)
      M(30, 44) = ( M(30, 44) - temp ) / M(30, 30)

C     Upper part.
      temp = M(31, 5) * M(5, 33)
      temp = temp + M(31, 12) * M(12, 33)
      temp = temp + M(31, 14) * M(14, 33)
      temp = temp + M(31, 15) * M(15, 33)
      temp = temp + M(31, 16) * M(16, 33)
      temp = temp + M(31, 17) * M(17, 33)
      temp = temp + M(31, 18) * M(18, 33)
      temp = temp + M(31, 19) * M(19, 33)
      temp = temp + M(31, 22) * M(22, 33)
      temp = temp + M(31, 27) * M(27, 33)
      temp = temp + M(31, 29) * M(29, 33)
      M(31, 33) = ( M(31, 33) - temp ) / M(31, 31)
C     Upper part.
      temp = M(31, 12) * M(12, 34)
      temp = temp + M(31, 14) * M(14, 34)
      temp = temp + M(31, 15) * M(15, 34)
      temp = temp + M(31, 16) * M(16, 34)
      temp = temp + M(31, 17) * M(17, 34)
      temp = temp + M(31, 18) * M(18, 34)
      temp = temp + M(31, 19) * M(19, 34)
      temp = temp + M(31, 22) * M(22, 34)
      temp = temp + M(31, 27) * M(27, 34)
      temp = temp + M(31, 29) * M(29, 34)
      M(31, 34) = ( M(31, 34) - temp ) / M(31, 31)
C     Upper part.
      temp = M(31, 27) * M(27, 36)
      temp = temp + M(31, 29) * M(29, 36)
      M(31, 36) = ( M(31, 36) - temp ) / M(31, 31)
C     Upper part.
      M(31, 38) = M(31, 38) / M(31, 31)
C     Upper part.
      temp = M(31, 12) * M(12, 41)
      temp = temp + M(31, 14) * M(14, 41)
      temp = temp + M(31, 15) * M(15, 41)
      temp = temp + M(31, 16) * M(16, 41)
      temp = temp + M(31, 17) * M(17, 41)
      temp = temp + M(31, 18) * M(18, 41)
      temp = temp + M(31, 19) * M(19, 41)
      temp = temp + M(31, 22) * M(22, 41)
      temp = temp + M(31, 27) * M(27, 41)
      temp = temp + M(31, 29) * M(29, 41)
      M(31, 41) = ( M(31, 41) - temp ) / M(31, 31)
C     Upper part.
      temp = M(31, 27) * M(27, 44)
      temp = temp + M(31, 29) * M(29, 44)
      M(31, 44) = ( M(31, 44) - temp ) / M(31, 31)

C     Upper part.
      temp = M(32, 13) * M(13, 33)
      temp = temp + M(32, 29) * M(29, 33)
      M(32, 33) = ( M(32, 33) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 29) * M(29, 34)
      M(32, 34) = ( M(32, 34) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 29) * M(29, 36)
      M(32, 36) = ( M(32, 36) - temp ) / M(32, 32)
C     Upper part.
      M(32, 38) = M(32, 38) / M(32, 32)
C     Upper part.
      temp = M(32, 13) * M(13, 39)
      M(32, 39) = ( M(32, 39) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 8) * M(8, 41)
      temp = temp + M(32, 13) * M(13, 41)
      temp = temp + M(32, 29) * M(29, 41)
      M(32, 41) = ( M(32, 41) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 8) * M(8, 42)
      M(32, 42) = ( M(32, 42) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 29) * M(29, 44)
      M(32, 44) = ( M(32, 44) - temp ) / M(32, 32)

C     Lower part.
      temp = M(33, 1) * M(1, 33)
      temp = temp + M(33, 2) * M(2, 33)
      temp = temp + M(33, 3) * M(3, 33)
      temp = temp + M(33, 4) * M(4, 33)
      temp = temp + M(33, 5) * M(5, 33)
      temp = temp + M(33, 7) * M(7, 33)
      temp = temp + M(33, 9) * M(9, 33)
      temp = temp + M(33, 10) * M(10, 33)
      temp = temp + M(33, 11) * M(11, 33)
      temp = temp + M(33, 12) * M(12, 33)
      temp = temp + M(33, 13) * M(13, 33)
      temp = temp + M(33, 14) * M(14, 33)
      temp = temp + M(33, 15) * M(15, 33)
      temp = temp + M(33, 16) * M(16, 33)
      temp = temp + M(33, 17) * M(17, 33)
      temp = temp + M(33, 18) * M(18, 33)
      temp = temp + M(33, 19) * M(19, 33)
      temp = temp + M(33, 20) * M(20, 33)
      temp = temp + M(33, 21) * M(21, 33)
      temp = temp + M(33, 22) * M(22, 33)
      temp = temp + M(33, 23) * M(23, 33)
      temp = temp + M(33, 24) * M(24, 33)
      temp = temp + M(33, 25) * M(25, 33)
      temp = temp + M(33, 26) * M(26, 33)
      temp = temp + M(33, 27) * M(27, 33)
      temp = temp + M(33, 28) * M(28, 33)
      temp = temp + M(33, 29) * M(29, 33)
      temp = temp + M(33, 31) * M(31, 33)
      temp = temp + M(33, 32) * M(32, 33)
      M(33, 33) = M(33, 33) - temp
C     Lower part.
      temp = M(34, 12) * M(12, 33)
      temp = temp + M(34, 14) * M(14, 33)
      temp = temp + M(34, 15) * M(15, 33)
      temp = temp + M(34, 17) * M(17, 33)
      temp = temp + M(34, 19) * M(19, 33)
      temp = temp + M(34, 22) * M(22, 33)
      M(34, 33) = M(34, 33) - temp
C     Lower part.
      temp = M(35, 1) * M(1, 33)
      temp = temp + M(35, 2) * M(2, 33)
      temp = temp + M(35, 3) * M(3, 33)
      temp = temp + M(35, 4) * M(4, 33)
      temp = temp + M(35, 15) * M(15, 33)
      temp = temp + M(35, 17) * M(17, 33)
      temp = temp + M(35, 19) * M(19, 33)
      temp = temp + M(35, 21) * M(21, 33)
      temp = temp + M(35, 22) * M(22, 33)
      temp = temp + M(35, 28) * M(28, 33)
      M(35, 33) = M(35, 33) - temp
C     Lower part.
      temp = M(36, 12) * M(12, 33)
      temp = temp + M(36, 22) * M(22, 33)
      M(36, 33) = M(36, 33) - temp
C     Lower part.
      temp = M(37, 9) * M(9, 33)
      temp = temp + M(37, 10) * M(10, 33)
      temp = temp + M(37, 11) * M(11, 33)
      temp = temp + M(37, 15) * M(15, 33)
      temp = temp + M(37, 25) * M(25, 33)
      temp = temp + M(37, 29) * M(29, 33)
      M(37, 33) = M(37, 33) - temp
C     Lower part.
      temp = M(38, 4) * M(4, 33)
      temp = temp + M(38, 9) * M(9, 33)
      temp = temp + M(38, 10) * M(10, 33)
      temp = temp + M(38, 12) * M(12, 33)
      temp = temp + M(38, 14) * M(14, 33)
      temp = temp + M(38, 15) * M(15, 33)
      temp = temp + M(38, 17) * M(17, 33)
      temp = temp + M(38, 19) * M(19, 33)
      temp = temp + M(38, 22) * M(22, 33)
      temp = temp + M(38, 23) * M(23, 33)
      M(38, 33) = M(38, 33) - temp
C     Lower part.
      temp = M(39, 4) * M(4, 33)
      temp = temp + M(39, 5) * M(5, 33)
      temp = temp + M(39, 9) * M(9, 33)
      temp = temp + M(39, 10) * M(10, 33)
      temp = temp + M(39, 12) * M(12, 33)
      temp = temp + M(39, 13) * M(13, 33)
      temp = temp + M(39, 14) * M(14, 33)
      temp = temp + M(39, 15) * M(15, 33)
      temp = temp + M(39, 17) * M(17, 33)
      temp = temp + M(39, 18) * M(18, 33)
      temp = temp + M(39, 19) * M(19, 33)
      temp = temp + M(39, 20) * M(20, 33)
      temp = temp + M(39, 21) * M(21, 33)
      temp = temp + M(39, 22) * M(22, 33)
      temp = temp + M(39, 24) * M(24, 33)
      temp = temp + M(39, 27) * M(27, 33)
      temp = temp + M(39, 29) * M(29, 33)
      temp = temp + M(39, 30) * M(30, 33)
      temp = temp + M(39, 31) * M(31, 33)
      M(39, 33) = M(39, 33) - temp
C     Lower part.
      temp = M(40, 4) * M(4, 33)
      temp = temp + M(40, 14) * M(14, 33)
      temp = temp + M(40, 24) * M(24, 33)
      temp = temp + M(40, 26) * M(26, 33)
      M(40, 33) = M(40, 33) - temp
C     Lower part.
      temp = M(41, 12) * M(12, 33)
      temp = temp + M(41, 13) * M(13, 33)
      temp = temp + M(41, 15) * M(15, 33)
      temp = temp + M(41, 19) * M(19, 33)
      temp = temp + M(41, 22) * M(22, 33)
      temp = temp + M(41, 23) * M(23, 33)
      temp = temp + M(41, 26) * M(26, 33)
      temp = temp + M(41, 29) * M(29, 33)
      temp = temp + M(41, 30) * M(30, 33)
      temp = temp + M(41, 32) * M(32, 33)
      M(41, 33) = M(41, 33) - temp
C     Lower part.
      temp = M(42, 7) * M(7, 33)
      temp = temp + M(42, 16) * M(16, 33)
      temp = temp + M(42, 19) * M(19, 33)
      temp = temp + M(42, 23) * M(23, 33)
      temp = temp + M(42, 26) * M(26, 33)
      temp = temp + M(42, 30) * M(30, 33)
      temp = temp + M(42, 32) * M(32, 33)
      M(42, 33) = M(42, 33) - temp
C     Lower part.
      temp = M(43, 2) * M(2, 33)
      temp = temp + M(43, 6) * M(6, 33)
      temp = temp + M(43, 17) * M(17, 33)
      temp = temp + M(43, 18) * M(18, 33)
      temp = temp + M(43, 23) * M(23, 33)
      temp = temp + M(43, 25) * M(25, 33)
      temp = temp + M(43, 27) * M(27, 33)
      temp = temp + M(43, 28) * M(28, 33)
      temp = temp + M(43, 29) * M(29, 33)
      M(43, 33) = M(43, 33) - temp
C     Lower part.
      temp = M(44, 7) * M(7, 33)
      temp = temp + M(44, 30) * M(30, 33)
      M(44, 33) = M(44, 33) - temp
C     Upper part.
      temp = M(33, 11) * M(11, 34)
      temp = temp + M(33, 12) * M(12, 34)
      temp = temp + M(33, 14) * M(14, 34)
      temp = temp + M(33, 15) * M(15, 34)
      temp = temp + M(33, 16) * M(16, 34)
      temp = temp + M(33, 17) * M(17, 34)
      temp = temp + M(33, 18) * M(18, 34)
      temp = temp + M(33, 19) * M(19, 34)
      temp = temp + M(33, 22) * M(22, 34)
      temp = temp + M(33, 27) * M(27, 34)
      temp = temp + M(33, 28) * M(28, 34)
      temp = temp + M(33, 29) * M(29, 34)
      temp = temp + M(33, 31) * M(31, 34)
      temp = temp + M(33, 32) * M(32, 34)
      M(33, 34) = ( M(33, 34) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 21) * M(21, 35)
      M(33, 35) = ( M(33, 35) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 20) * M(20, 36)
      temp = temp + M(33, 27) * M(27, 36)
      temp = temp + M(33, 28) * M(28, 36)
      temp = temp + M(33, 29) * M(29, 36)
      temp = temp + M(33, 31) * M(31, 36)
      temp = temp + M(33, 32) * M(32, 36)
      M(33, 36) = ( M(33, 36) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 9) * M(9, 37)
      temp = temp + M(33, 10) * M(10, 37)
      M(33, 37) = ( M(33, 37) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 31) * M(31, 38)
      temp = temp + M(33, 32) * M(32, 38)
      M(33, 38) = ( M(33, 38) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 10) * M(10, 39)
      temp = temp + M(33, 13) * M(13, 39)
      temp = temp + M(33, 20) * M(20, 39)
      temp = temp + M(33, 21) * M(21, 39)
      temp = temp + M(33, 24) * M(24, 39)
      temp = temp + M(33, 25) * M(25, 39)
      temp = temp + M(33, 32) * M(32, 39)
      M(33, 39) = ( M(33, 39) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 24) * M(24, 40)
      temp = temp + M(33, 26) * M(26, 40)
      M(33, 40) = ( M(33, 40) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 12) * M(12, 41)
      temp = temp + M(33, 13) * M(13, 41)
      temp = temp + M(33, 14) * M(14, 41)
      temp = temp + M(33, 15) * M(15, 41)
      temp = temp + M(33, 16) * M(16, 41)
      temp = temp + M(33, 17) * M(17, 41)
      temp = temp + M(33, 18) * M(18, 41)
      temp = temp + M(33, 19) * M(19, 41)
      temp = temp + M(33, 22) * M(22, 41)
      temp = temp + M(33, 27) * M(27, 41)
      temp = temp + M(33, 28) * M(28, 41)
      temp = temp + M(33, 29) * M(29, 41)
      temp = temp + M(33, 31) * M(31, 41)
      temp = temp + M(33, 32) * M(32, 41)
      M(33, 41) = ( M(33, 41) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 23) * M(23, 42)
      temp = temp + M(33, 26) * M(26, 42)
      temp = temp + M(33, 32) * M(32, 42)
      M(33, 42) = ( M(33, 42) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 23) * M(23, 43)
      temp = temp + M(33, 25) * M(25, 43)
      M(33, 43) = ( M(33, 43) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 7) * M(7, 44)
      temp = temp + M(33, 27) * M(27, 44)
      temp = temp + M(33, 28) * M(28, 44)
      temp = temp + M(33, 29) * M(29, 44)
      temp = temp + M(33, 31) * M(31, 44)
      temp = temp + M(33, 32) * M(32, 44)
      M(33, 44) = ( M(33, 44) - temp ) / M(33, 33)

C     Lower part.
      temp = M(34, 12) * M(12, 34)
      temp = temp + M(34, 14) * M(14, 34)
      temp = temp + M(34, 15) * M(15, 34)
      temp = temp + M(34, 17) * M(17, 34)
      temp = temp + M(34, 19) * M(19, 34)
      temp = temp + M(34, 22) * M(22, 34)
      temp = temp + M(34, 33) * M(33, 34)
      M(34, 34) = M(34, 34) - temp
C     Lower part.
      temp = M(35, 15) * M(15, 34)
      temp = temp + M(35, 17) * M(17, 34)
      temp = temp + M(35, 19) * M(19, 34)
      temp = temp + M(35, 22) * M(22, 34)
      temp = temp + M(35, 28) * M(28, 34)
      temp = temp + M(35, 33) * M(33, 34)
      M(35, 34) = M(35, 34) - temp
C     Lower part.
      temp = M(36, 12) * M(12, 34)
      temp = temp + M(36, 22) * M(22, 34)
      temp = temp + M(36, 33) * M(33, 34)
      M(36, 34) = M(36, 34) - temp
C     Lower part.
      temp = M(37, 11) * M(11, 34)
      temp = temp + M(37, 15) * M(15, 34)
      temp = temp + M(37, 29) * M(29, 34)
      temp = temp + M(37, 33) * M(33, 34)
      M(37, 34) = M(37, 34) - temp
C     Lower part.
      temp = M(38, 12) * M(12, 34)
      temp = temp + M(38, 14) * M(14, 34)
      temp = temp + M(38, 15) * M(15, 34)
      temp = temp + M(38, 17) * M(17, 34)
      temp = temp + M(38, 19) * M(19, 34)
      temp = temp + M(38, 22) * M(22, 34)
      temp = temp + M(38, 33) * M(33, 34)
      M(38, 34) = M(38, 34) - temp
C     Lower part.
      temp = M(39, 12) * M(12, 34)
      temp = temp + M(39, 14) * M(14, 34)
      temp = temp + M(39, 15) * M(15, 34)
      temp = temp + M(39, 17) * M(17, 34)
      temp = temp + M(39, 18) * M(18, 34)
      temp = temp + M(39, 19) * M(19, 34)
      temp = temp + M(39, 22) * M(22, 34)
      temp = temp + M(39, 27) * M(27, 34)
      temp = temp + M(39, 29) * M(29, 34)
      temp = temp + M(39, 30) * M(30, 34)
      temp = temp + M(39, 31) * M(31, 34)
      temp = temp + M(39, 33) * M(33, 34)
      M(39, 34) = M(39, 34) - temp
C     Lower part.
      temp = M(40, 14) * M(14, 34)
      temp = temp + M(40, 33) * M(33, 34)
      M(40, 34) = M(40, 34) - temp
C     Lower part.
      temp = M(41, 12) * M(12, 34)
      temp = temp + M(41, 15) * M(15, 34)
      temp = temp + M(41, 19) * M(19, 34)
      temp = temp + M(41, 22) * M(22, 34)
      temp = temp + M(41, 29) * M(29, 34)
      temp = temp + M(41, 30) * M(30, 34)
      temp = temp + M(41, 32) * M(32, 34)
      temp = temp + M(41, 33) * M(33, 34)
      M(41, 34) = M(41, 34) - temp
C     Lower part.
      temp = M(42, 16) * M(16, 34)
      temp = temp + M(42, 19) * M(19, 34)
      temp = temp + M(42, 30) * M(30, 34)
      temp = temp + M(42, 32) * M(32, 34)
      temp = temp + M(42, 33) * M(33, 34)
      M(42, 34) = M(42, 34) - temp
C     Lower part.
      temp = M(43, 17) * M(17, 34)
      temp = temp + M(43, 18) * M(18, 34)
      temp = temp + M(43, 27) * M(27, 34)
      temp = temp + M(43, 28) * M(28, 34)
      temp = temp + M(43, 29) * M(29, 34)
      temp = temp + M(43, 33) * M(33, 34)
      M(43, 34) = M(43, 34) - temp
C     Lower part.
      temp = M(44, 30) * M(30, 34)
      temp = temp + M(44, 33) * M(33, 34)
      M(44, 34) = M(44, 34) - temp
C     Upper part.
      temp = M(34, 33) * M(33, 35)
      M(34, 35) = ( M(34, 35) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 33) * M(33, 36)
      M(34, 36) = ( M(34, 36) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 33) * M(33, 37)
      M(34, 37) = ( M(34, 37) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 33) * M(33, 38)
      M(34, 38) = ( M(34, 38) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 33) * M(33, 39)
      M(34, 39) = ( M(34, 39) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 33) * M(33, 40)
      M(34, 40) = ( M(34, 40) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 12) * M(12, 41)
      temp = temp + M(34, 14) * M(14, 41)
      temp = temp + M(34, 15) * M(15, 41)
      temp = temp + M(34, 17) * M(17, 41)
      temp = temp + M(34, 19) * M(19, 41)
      temp = temp + M(34, 22) * M(22, 41)
      temp = temp + M(34, 33) * M(33, 41)
      M(34, 41) = ( M(34, 41) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 33) * M(33, 42)
      M(34, 42) = ( M(34, 42) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 33) * M(33, 43)
      M(34, 43) = ( M(34, 43) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 33) * M(33, 44)
      M(34, 44) = ( M(34, 44) - temp ) / M(34, 34)

C     Lower part.
      temp = M(35, 21) * M(21, 35)
      temp = temp + M(35, 33) * M(33, 35)
      temp = temp + M(35, 34) * M(34, 35)
      M(35, 35) = M(35, 35) - temp
C     Lower part.
      temp = M(36, 33) * M(33, 35)
      temp = temp + M(36, 34) * M(34, 35)
      M(36, 35) = M(36, 35) - temp
C     Lower part.
      temp = M(37, 33) * M(33, 35)
      temp = temp + M(37, 34) * M(34, 35)
      M(37, 35) = M(37, 35) - temp
C     Lower part.
      temp = M(38, 33) * M(33, 35)
      temp = temp + M(38, 34) * M(34, 35)
      M(38, 35) = M(38, 35) - temp
C     Lower part.
      temp = M(39, 21) * M(21, 35)
      temp = temp + M(39, 33) * M(33, 35)
      temp = temp + M(39, 34) * M(34, 35)
      M(39, 35) = M(39, 35) - temp
C     Lower part.
      temp = M(40, 33) * M(33, 35)
      temp = temp + M(40, 34) * M(34, 35)
      M(40, 35) = M(40, 35) - temp
C     Lower part.
      temp = M(41, 33) * M(33, 35)
      temp = temp + M(41, 34) * M(34, 35)
      M(41, 35) = M(41, 35) - temp
C     Lower part.
      temp = M(42, 33) * M(33, 35)
      temp = temp + M(42, 34) * M(34, 35)
      M(42, 35) = M(42, 35) - temp
C     Lower part.
      temp = M(43, 33) * M(33, 35)
      temp = temp + M(43, 34) * M(34, 35)
      M(43, 35) = M(43, 35) - temp
C     Lower part.
      temp = M(44, 33) * M(33, 35)
      temp = temp + M(44, 34) * M(34, 35)
      M(44, 35) = M(44, 35) - temp
C     Upper part.
      temp = M(35, 28) * M(28, 36)
      temp = temp + M(35, 33) * M(33, 36)
      temp = temp + M(35, 34) * M(34, 36)
      M(35, 36) = ( M(35, 36) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 33) * M(33, 37)
      temp = temp + M(35, 34) * M(34, 37)
      M(35, 37) = ( M(35, 37) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 33) * M(33, 38)
      temp = temp + M(35, 34) * M(34, 38)
      M(35, 38) = ( M(35, 38) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 21) * M(21, 39)
      temp = temp + M(35, 33) * M(33, 39)
      temp = temp + M(35, 34) * M(34, 39)
      M(35, 39) = ( M(35, 39) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 33) * M(33, 40)
      temp = temp + M(35, 34) * M(34, 40)
      M(35, 40) = ( M(35, 40) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 15) * M(15, 41)
      temp = temp + M(35, 17) * M(17, 41)
      temp = temp + M(35, 19) * M(19, 41)
      temp = temp + M(35, 22) * M(22, 41)
      temp = temp + M(35, 28) * M(28, 41)
      temp = temp + M(35, 33) * M(33, 41)
      temp = temp + M(35, 34) * M(34, 41)
      M(35, 41) = ( M(35, 41) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 33) * M(33, 42)
      temp = temp + M(35, 34) * M(34, 42)
      M(35, 42) = ( M(35, 42) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 33) * M(33, 43)
      temp = temp + M(35, 34) * M(34, 43)
      M(35, 43) = ( M(35, 43) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 28) * M(28, 44)
      temp = temp + M(35, 33) * M(33, 44)
      temp = temp + M(35, 34) * M(34, 44)
      M(35, 44) = ( M(35, 44) - temp ) / M(35, 35)

C     Lower part.
      temp = M(36, 33) * M(33, 36)
      temp = temp + M(36, 34) * M(34, 36)
      temp = temp + M(36, 35) * M(35, 36)
      M(36, 36) = M(36, 36) - temp
C     Lower part.
      temp = M(37, 29) * M(29, 36)
      temp = temp + M(37, 33) * M(33, 36)
      temp = temp + M(37, 34) * M(34, 36)
      temp = temp + M(37, 35) * M(35, 36)
      M(37, 36) = M(37, 36) - temp
C     Lower part.
      temp = M(38, 33) * M(33, 36)
      temp = temp + M(38, 34) * M(34, 36)
      temp = temp + M(38, 35) * M(35, 36)
      M(38, 36) = M(38, 36) - temp
C     Lower part.
      temp = M(39, 20) * M(20, 36)
      temp = temp + M(39, 27) * M(27, 36)
      temp = temp + M(39, 29) * M(29, 36)
      temp = temp + M(39, 30) * M(30, 36)
      temp = temp + M(39, 31) * M(31, 36)
      temp = temp + M(39, 33) * M(33, 36)
      temp = temp + M(39, 34) * M(34, 36)
      temp = temp + M(39, 35) * M(35, 36)
      M(39, 36) = M(39, 36) - temp
C     Lower part.
      temp = M(40, 33) * M(33, 36)
      temp = temp + M(40, 34) * M(34, 36)
      temp = temp + M(40, 35) * M(35, 36)
      M(40, 36) = M(40, 36) - temp
C     Lower part.
      temp = M(41, 29) * M(29, 36)
      temp = temp + M(41, 30) * M(30, 36)
      temp = temp + M(41, 32) * M(32, 36)
      temp = temp + M(41, 33) * M(33, 36)
      temp = temp + M(41, 34) * M(34, 36)
      temp = temp + M(41, 35) * M(35, 36)
      M(41, 36) = M(41, 36) - temp
C     Lower part.
      temp = M(42, 30) * M(30, 36)
      temp = temp + M(42, 32) * M(32, 36)
      temp = temp + M(42, 33) * M(33, 36)
      temp = temp + M(42, 34) * M(34, 36)
      temp = temp + M(42, 35) * M(35, 36)
      M(42, 36) = M(42, 36) - temp
C     Lower part.
      temp = M(43, 27) * M(27, 36)
      temp = temp + M(43, 28) * M(28, 36)
      temp = temp + M(43, 29) * M(29, 36)
      temp = temp + M(43, 33) * M(33, 36)
      temp = temp + M(43, 34) * M(34, 36)
      temp = temp + M(43, 35) * M(35, 36)
      M(43, 36) = M(43, 36) - temp
C     Lower part.
      temp = M(44, 30) * M(30, 36)
      temp = temp + M(44, 33) * M(33, 36)
      temp = temp + M(44, 34) * M(34, 36)
      temp = temp + M(44, 35) * M(35, 36)
      M(44, 36) = M(44, 36) - temp
C     Upper part.
      temp = M(36, 33) * M(33, 37)
      temp = temp + M(36, 34) * M(34, 37)
      temp = temp + M(36, 35) * M(35, 37)
      M(36, 37) = ( M(36, 37) - temp ) / M(36, 36)
C     Upper part.
      temp = M(36, 33) * M(33, 38)
      temp = temp + M(36, 34) * M(34, 38)
      temp = temp + M(36, 35) * M(35, 38)
      M(36, 38) = ( M(36, 38) - temp ) / M(36, 36)
C     Upper part.
      temp = M(36, 33) * M(33, 39)
      temp = temp + M(36, 34) * M(34, 39)
      temp = temp + M(36, 35) * M(35, 39)
      M(36, 39) = ( M(36, 39) - temp ) / M(36, 36)
C     Upper part.
      temp = M(36, 33) * M(33, 40)
      temp = temp + M(36, 34) * M(34, 40)
      temp = temp + M(36, 35) * M(35, 40)
      M(36, 40) = ( M(36, 40) - temp ) / M(36, 36)
C     Upper part.
      temp = M(36, 12) * M(12, 41)
      temp = temp + M(36, 22) * M(22, 41)
      temp = temp + M(36, 33) * M(33, 41)
      temp = temp + M(36, 34) * M(34, 41)
      temp = temp + M(36, 35) * M(35, 41)
      M(36, 41) = ( M(36, 41) - temp ) / M(36, 36)
C     Upper part.
      temp = M(36, 33) * M(33, 42)
      temp = temp + M(36, 34) * M(34, 42)
      temp = temp + M(36, 35) * M(35, 42)
      M(36, 42) = ( M(36, 42) - temp ) / M(36, 36)
C     Upper part.
      temp = M(36, 33) * M(33, 43)
      temp = temp + M(36, 34) * M(34, 43)
      temp = temp + M(36, 35) * M(35, 43)
      M(36, 43) = ( M(36, 43) - temp ) / M(36, 36)
C     Upper part.
      temp = M(36, 33) * M(33, 44)
      temp = temp + M(36, 34) * M(34, 44)
      temp = temp + M(36, 35) * M(35, 44)
      M(36, 44) = ( M(36, 44) - temp ) / M(36, 36)

C     Lower part.
      temp = M(37, 9) * M(9, 37)
      temp = temp + M(37, 10) * M(10, 37)
      temp = temp + M(37, 33) * M(33, 37)
      temp = temp + M(37, 34) * M(34, 37)
      temp = temp + M(37, 35) * M(35, 37)
      temp = temp + M(37, 36) * M(36, 37)
      M(37, 37) = M(37, 37) - temp
C     Lower part.
      temp = M(38, 9) * M(9, 37)
      temp = temp + M(38, 10) * M(10, 37)
      temp = temp + M(38, 33) * M(33, 37)
      temp = temp + M(38, 34) * M(34, 37)
      temp = temp + M(38, 35) * M(35, 37)
      temp = temp + M(38, 36) * M(36, 37)
      M(38, 37) = M(38, 37) - temp
C     Lower part.
      temp = M(39, 9) * M(9, 37)
      temp = temp + M(39, 10) * M(10, 37)
      temp = temp + M(39, 33) * M(33, 37)
      temp = temp + M(39, 34) * M(34, 37)
      temp = temp + M(39, 35) * M(35, 37)
      temp = temp + M(39, 36) * M(36, 37)
      M(39, 37) = M(39, 37) - temp
C     Lower part.
      temp = M(40, 33) * M(33, 37)
      temp = temp + M(40, 34) * M(34, 37)
      temp = temp + M(40, 35) * M(35, 37)
      temp = temp + M(40, 36) * M(36, 37)
      M(40, 37) = M(40, 37) - temp
C     Lower part.
      temp = M(41, 33) * M(33, 37)
      temp = temp + M(41, 34) * M(34, 37)
      temp = temp + M(41, 35) * M(35, 37)
      temp = temp + M(41, 36) * M(36, 37)
      M(41, 37) = M(41, 37) - temp
C     Lower part.
      temp = M(42, 33) * M(33, 37)
      temp = temp + M(42, 34) * M(34, 37)
      temp = temp + M(42, 35) * M(35, 37)
      temp = temp + M(42, 36) * M(36, 37)
      M(42, 37) = M(42, 37) - temp
C     Lower part.
      temp = M(43, 33) * M(33, 37)
      temp = temp + M(43, 34) * M(34, 37)
      temp = temp + M(43, 35) * M(35, 37)
      temp = temp + M(43, 36) * M(36, 37)
      M(43, 37) = M(43, 37) - temp
C     Lower part.
      temp = M(44, 33) * M(33, 37)
      temp = temp + M(44, 34) * M(34, 37)
      temp = temp + M(44, 35) * M(35, 37)
      temp = temp + M(44, 36) * M(36, 37)
      M(44, 37) = M(44, 37) - temp
C     Upper part.
      temp = M(37, 33) * M(33, 38)
      temp = temp + M(37, 34) * M(34, 38)
      temp = temp + M(37, 35) * M(35, 38)
      temp = temp + M(37, 36) * M(36, 38)
      M(37, 38) = ( M(37, 38) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 10) * M(10, 39)
      temp = temp + M(37, 25) * M(25, 39)
      temp = temp + M(37, 33) * M(33, 39)
      temp = temp + M(37, 34) * M(34, 39)
      temp = temp + M(37, 35) * M(35, 39)
      temp = temp + M(37, 36) * M(36, 39)
      M(37, 39) = ( M(37, 39) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 33) * M(33, 40)
      temp = temp + M(37, 34) * M(34, 40)
      temp = temp + M(37, 35) * M(35, 40)
      temp = temp + M(37, 36) * M(36, 40)
      M(37, 40) = ( M(37, 40) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 15) * M(15, 41)
      temp = temp + M(37, 29) * M(29, 41)
      temp = temp + M(37, 33) * M(33, 41)
      temp = temp + M(37, 34) * M(34, 41)
      temp = temp + M(37, 35) * M(35, 41)
      temp = temp + M(37, 36) * M(36, 41)
      M(37, 41) = ( M(37, 41) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 33) * M(33, 42)
      temp = temp + M(37, 34) * M(34, 42)
      temp = temp + M(37, 35) * M(35, 42)
      temp = temp + M(37, 36) * M(36, 42)
      M(37, 42) = ( M(37, 42) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 25) * M(25, 43)
      temp = temp + M(37, 33) * M(33, 43)
      temp = temp + M(37, 34) * M(34, 43)
      temp = temp + M(37, 35) * M(35, 43)
      temp = temp + M(37, 36) * M(36, 43)
      M(37, 43) = ( M(37, 43) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 29) * M(29, 44)
      temp = temp + M(37, 33) * M(33, 44)
      temp = temp + M(37, 34) * M(34, 44)
      temp = temp + M(37, 35) * M(35, 44)
      temp = temp + M(37, 36) * M(36, 44)
      M(37, 44) = ( M(37, 44) - temp ) / M(37, 37)

C     Lower part.
      temp = M(38, 33) * M(33, 38)
      temp = temp + M(38, 34) * M(34, 38)
      temp = temp + M(38, 35) * M(35, 38)
      temp = temp + M(38, 36) * M(36, 38)
      temp = temp + M(38, 37) * M(37, 38)
      M(38, 38) = M(38, 38) - temp
C     Lower part.
      temp = M(39, 31) * M(31, 38)
      temp = temp + M(39, 33) * M(33, 38)
      temp = temp + M(39, 34) * M(34, 38)
      temp = temp + M(39, 35) * M(35, 38)
      temp = temp + M(39, 36) * M(36, 38)
      temp = temp + M(39, 37) * M(37, 38)
      M(39, 38) = M(39, 38) - temp
C     Lower part.
      temp = M(40, 33) * M(33, 38)
      temp = temp + M(40, 34) * M(34, 38)
      temp = temp + M(40, 35) * M(35, 38)
      temp = temp + M(40, 36) * M(36, 38)
      temp = temp + M(40, 37) * M(37, 38)
      M(40, 38) = M(40, 38) - temp
C     Lower part.
      temp = M(41, 32) * M(32, 38)
      temp = temp + M(41, 33) * M(33, 38)
      temp = temp + M(41, 34) * M(34, 38)
      temp = temp + M(41, 35) * M(35, 38)
      temp = temp + M(41, 36) * M(36, 38)
      temp = temp + M(41, 37) * M(37, 38)
      M(41, 38) = M(41, 38) - temp
C     Lower part.
      temp = M(42, 32) * M(32, 38)
      temp = temp + M(42, 33) * M(33, 38)
      temp = temp + M(42, 34) * M(34, 38)
      temp = temp + M(42, 35) * M(35, 38)
      temp = temp + M(42, 36) * M(36, 38)
      temp = temp + M(42, 37) * M(37, 38)
      M(42, 38) = M(42, 38) - temp
C     Lower part.
      temp = M(43, 33) * M(33, 38)
      temp = temp + M(43, 34) * M(34, 38)
      temp = temp + M(43, 35) * M(35, 38)
      temp = temp + M(43, 36) * M(36, 38)
      temp = temp + M(43, 37) * M(37, 38)
      M(43, 38) = M(43, 38) - temp
C     Lower part.
      temp = M(44, 33) * M(33, 38)
      temp = temp + M(44, 34) * M(34, 38)
      temp = temp + M(44, 35) * M(35, 38)
      temp = temp + M(44, 36) * M(36, 38)
      temp = temp + M(44, 37) * M(37, 38)
      M(44, 38) = M(44, 38) - temp
C     Upper part.
      temp = M(38, 10) * M(10, 39)
      temp = temp + M(38, 33) * M(33, 39)
      temp = temp + M(38, 34) * M(34, 39)
      temp = temp + M(38, 35) * M(35, 39)
      temp = temp + M(38, 36) * M(36, 39)
      temp = temp + M(38, 37) * M(37, 39)
      M(38, 39) = ( M(38, 39) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 33) * M(33, 40)
      temp = temp + M(38, 34) * M(34, 40)
      temp = temp + M(38, 35) * M(35, 40)
      temp = temp + M(38, 36) * M(36, 40)
      temp = temp + M(38, 37) * M(37, 40)
      M(38, 40) = ( M(38, 40) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 12) * M(12, 41)
      temp = temp + M(38, 14) * M(14, 41)
      temp = temp + M(38, 15) * M(15, 41)
      temp = temp + M(38, 17) * M(17, 41)
      temp = temp + M(38, 19) * M(19, 41)
      temp = temp + M(38, 22) * M(22, 41)
      temp = temp + M(38, 33) * M(33, 41)
      temp = temp + M(38, 34) * M(34, 41)
      temp = temp + M(38, 35) * M(35, 41)
      temp = temp + M(38, 36) * M(36, 41)
      temp = temp + M(38, 37) * M(37, 41)
      M(38, 41) = ( M(38, 41) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 23) * M(23, 42)
      temp = temp + M(38, 33) * M(33, 42)
      temp = temp + M(38, 34) * M(34, 42)
      temp = temp + M(38, 35) * M(35, 42)
      temp = temp + M(38, 36) * M(36, 42)
      temp = temp + M(38, 37) * M(37, 42)
      M(38, 42) = ( M(38, 42) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 23) * M(23, 43)
      temp = temp + M(38, 33) * M(33, 43)
      temp = temp + M(38, 34) * M(34, 43)
      temp = temp + M(38, 35) * M(35, 43)
      temp = temp + M(38, 36) * M(36, 43)
      temp = temp + M(38, 37) * M(37, 43)
      M(38, 43) = ( M(38, 43) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 33) * M(33, 44)
      temp = temp + M(38, 34) * M(34, 44)
      temp = temp + M(38, 35) * M(35, 44)
      temp = temp + M(38, 36) * M(36, 44)
      temp = temp + M(38, 37) * M(37, 44)
      M(38, 44) = ( M(38, 44) - temp ) / M(38, 38)

C     Lower part.
      temp = M(39, 10) * M(10, 39)
      temp = temp + M(39, 13) * M(13, 39)
      temp = temp + M(39, 20) * M(20, 39)
      temp = temp + M(39, 21) * M(21, 39)
      temp = temp + M(39, 24) * M(24, 39)
      temp = temp + M(39, 30) * M(30, 39)
      temp = temp + M(39, 33) * M(33, 39)
      temp = temp + M(39, 34) * M(34, 39)
      temp = temp + M(39, 35) * M(35, 39)
      temp = temp + M(39, 36) * M(36, 39)
      temp = temp + M(39, 37) * M(37, 39)
      temp = temp + M(39, 38) * M(38, 39)
      M(39, 39) = M(39, 39) - temp
C     Lower part.
      temp = M(40, 24) * M(24, 39)
      temp = temp + M(40, 33) * M(33, 39)
      temp = temp + M(40, 34) * M(34, 39)
      temp = temp + M(40, 35) * M(35, 39)
      temp = temp + M(40, 36) * M(36, 39)
      temp = temp + M(40, 37) * M(37, 39)
      temp = temp + M(40, 38) * M(38, 39)
      M(40, 39) = M(40, 39) - temp
C     Lower part.
      temp = M(41, 13) * M(13, 39)
      temp = temp + M(41, 30) * M(30, 39)
      temp = temp + M(41, 32) * M(32, 39)
      temp = temp + M(41, 33) * M(33, 39)
      temp = temp + M(41, 34) * M(34, 39)
      temp = temp + M(41, 35) * M(35, 39)
      temp = temp + M(41, 36) * M(36, 39)
      temp = temp + M(41, 37) * M(37, 39)
      temp = temp + M(41, 38) * M(38, 39)
      M(41, 39) = M(41, 39) - temp
C     Lower part.
      temp = M(42, 30) * M(30, 39)
      temp = temp + M(42, 32) * M(32, 39)
      temp = temp + M(42, 33) * M(33, 39)
      temp = temp + M(42, 34) * M(34, 39)
      temp = temp + M(42, 35) * M(35, 39)
      temp = temp + M(42, 36) * M(36, 39)
      temp = temp + M(42, 37) * M(37, 39)
      temp = temp + M(42, 38) * M(38, 39)
      M(42, 39) = M(42, 39) - temp
C     Lower part.
      temp = M(43, 25) * M(25, 39)
      temp = temp + M(43, 33) * M(33, 39)
      temp = temp + M(43, 34) * M(34, 39)
      temp = temp + M(43, 35) * M(35, 39)
      temp = temp + M(43, 36) * M(36, 39)
      temp = temp + M(43, 37) * M(37, 39)
      temp = temp + M(43, 38) * M(38, 39)
      M(43, 39) = M(43, 39) - temp
C     Lower part.
      temp = M(44, 30) * M(30, 39)
      temp = temp + M(44, 33) * M(33, 39)
      temp = temp + M(44, 34) * M(34, 39)
      temp = temp + M(44, 35) * M(35, 39)
      temp = temp + M(44, 36) * M(36, 39)
      temp = temp + M(44, 37) * M(37, 39)
      temp = temp + M(44, 38) * M(38, 39)
      M(44, 39) = M(44, 39) - temp
C     Upper part.
      temp = M(39, 24) * M(24, 40)
      temp = temp + M(39, 33) * M(33, 40)
      temp = temp + M(39, 34) * M(34, 40)
      temp = temp + M(39, 35) * M(35, 40)
      temp = temp + M(39, 36) * M(36, 40)
      temp = temp + M(39, 37) * M(37, 40)
      temp = temp + M(39, 38) * M(38, 40)
      M(39, 40) = ( M(39, 40) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 12) * M(12, 41)
      temp = temp + M(39, 13) * M(13, 41)
      temp = temp + M(39, 14) * M(14, 41)
      temp = temp + M(39, 15) * M(15, 41)
      temp = temp + M(39, 17) * M(17, 41)
      temp = temp + M(39, 18) * M(18, 41)
      temp = temp + M(39, 19) * M(19, 41)
      temp = temp + M(39, 22) * M(22, 41)
      temp = temp + M(39, 27) * M(27, 41)
      temp = temp + M(39, 29) * M(29, 41)
      temp = temp + M(39, 30) * M(30, 41)
      temp = temp + M(39, 31) * M(31, 41)
      temp = temp + M(39, 33) * M(33, 41)
      temp = temp + M(39, 34) * M(34, 41)
      temp = temp + M(39, 35) * M(35, 41)
      temp = temp + M(39, 36) * M(36, 41)
      temp = temp + M(39, 37) * M(37, 41)
      temp = temp + M(39, 38) * M(38, 41)
      M(39, 41) = ( M(39, 41) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 33) * M(33, 42)
      temp = temp + M(39, 34) * M(34, 42)
      temp = temp + M(39, 35) * M(35, 42)
      temp = temp + M(39, 36) * M(36, 42)
      temp = temp + M(39, 37) * M(37, 42)
      temp = temp + M(39, 38) * M(38, 42)
      M(39, 42) = ( M(39, 42) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 33) * M(33, 43)
      temp = temp + M(39, 34) * M(34, 43)
      temp = temp + M(39, 35) * M(35, 43)
      temp = temp + M(39, 36) * M(36, 43)
      temp = temp + M(39, 37) * M(37, 43)
      temp = temp + M(39, 38) * M(38, 43)
      M(39, 43) = ( M(39, 43) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 27) * M(27, 44)
      temp = temp + M(39, 29) * M(29, 44)
      temp = temp + M(39, 30) * M(30, 44)
      temp = temp + M(39, 31) * M(31, 44)
      temp = temp + M(39, 33) * M(33, 44)
      temp = temp + M(39, 34) * M(34, 44)
      temp = temp + M(39, 35) * M(35, 44)
      temp = temp + M(39, 36) * M(36, 44)
      temp = temp + M(39, 37) * M(37, 44)
      temp = temp + M(39, 38) * M(38, 44)
      M(39, 44) = ( M(39, 44) - temp ) / M(39, 39)

C     Lower part.
      temp = M(40, 24) * M(24, 40)
      temp = temp + M(40, 26) * M(26, 40)
      temp = temp + M(40, 33) * M(33, 40)
      temp = temp + M(40, 34) * M(34, 40)
      temp = temp + M(40, 35) * M(35, 40)
      temp = temp + M(40, 36) * M(36, 40)
      temp = temp + M(40, 37) * M(37, 40)
      temp = temp + M(40, 38) * M(38, 40)
      temp = temp + M(40, 39) * M(39, 40)
      M(40, 40) = M(40, 40) - temp
C     Lower part.
      temp = M(41, 26) * M(26, 40)
      temp = temp + M(41, 33) * M(33, 40)
      temp = temp + M(41, 34) * M(34, 40)
      temp = temp + M(41, 35) * M(35, 40)
      temp = temp + M(41, 36) * M(36, 40)
      temp = temp + M(41, 37) * M(37, 40)
      temp = temp + M(41, 38) * M(38, 40)
      temp = temp + M(41, 39) * M(39, 40)
      M(41, 40) = M(41, 40) - temp
C     Lower part.
      temp = M(42, 26) * M(26, 40)
      temp = temp + M(42, 33) * M(33, 40)
      temp = temp + M(42, 34) * M(34, 40)
      temp = temp + M(42, 35) * M(35, 40)
      temp = temp + M(42, 36) * M(36, 40)
      temp = temp + M(42, 37) * M(37, 40)
      temp = temp + M(42, 38) * M(38, 40)
      temp = temp + M(42, 39) * M(39, 40)
      M(42, 40) = M(42, 40) - temp
C     Lower part.
      temp = M(43, 33) * M(33, 40)
      temp = temp + M(43, 34) * M(34, 40)
      temp = temp + M(43, 35) * M(35, 40)
      temp = temp + M(43, 36) * M(36, 40)
      temp = temp + M(43, 37) * M(37, 40)
      temp = temp + M(43, 38) * M(38, 40)
      temp = temp + M(43, 39) * M(39, 40)
      M(43, 40) = M(43, 40) - temp
C     Lower part.
      temp = M(44, 33) * M(33, 40)
      temp = temp + M(44, 34) * M(34, 40)
      temp = temp + M(44, 35) * M(35, 40)
      temp = temp + M(44, 36) * M(36, 40)
      temp = temp + M(44, 37) * M(37, 40)
      temp = temp + M(44, 38) * M(38, 40)
      temp = temp + M(44, 39) * M(39, 40)
      M(44, 40) = M(44, 40) - temp
C     Upper part.
      temp = M(40, 14) * M(14, 41)
      temp = temp + M(40, 33) * M(33, 41)
      temp = temp + M(40, 34) * M(34, 41)
      temp = temp + M(40, 35) * M(35, 41)
      temp = temp + M(40, 36) * M(36, 41)
      temp = temp + M(40, 37) * M(37, 41)
      temp = temp + M(40, 38) * M(38, 41)
      temp = temp + M(40, 39) * M(39, 41)
      M(40, 41) = ( M(40, 41) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 26) * M(26, 42)
      temp = temp + M(40, 33) * M(33, 42)
      temp = temp + M(40, 34) * M(34, 42)
      temp = temp + M(40, 35) * M(35, 42)
      temp = temp + M(40, 36) * M(36, 42)
      temp = temp + M(40, 37) * M(37, 42)
      temp = temp + M(40, 38) * M(38, 42)
      temp = temp + M(40, 39) * M(39, 42)
      M(40, 42) = ( M(40, 42) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 33) * M(33, 43)
      temp = temp + M(40, 34) * M(34, 43)
      temp = temp + M(40, 35) * M(35, 43)
      temp = temp + M(40, 36) * M(36, 43)
      temp = temp + M(40, 37) * M(37, 43)
      temp = temp + M(40, 38) * M(38, 43)
      temp = temp + M(40, 39) * M(39, 43)
      M(40, 43) = ( M(40, 43) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 33) * M(33, 44)
      temp = temp + M(40, 34) * M(34, 44)
      temp = temp + M(40, 35) * M(35, 44)
      temp = temp + M(40, 36) * M(36, 44)
      temp = temp + M(40, 37) * M(37, 44)
      temp = temp + M(40, 38) * M(38, 44)
      temp = temp + M(40, 39) * M(39, 44)
      M(40, 44) = ( M(40, 44) - temp ) / M(40, 40)

C     Lower part.
      temp = M(41, 8) * M(8, 41)
      temp = temp + M(41, 12) * M(12, 41)
      temp = temp + M(41, 13) * M(13, 41)
      temp = temp + M(41, 15) * M(15, 41)
      temp = temp + M(41, 19) * M(19, 41)
      temp = temp + M(41, 22) * M(22, 41)
      temp = temp + M(41, 29) * M(29, 41)
      temp = temp + M(41, 30) * M(30, 41)
      temp = temp + M(41, 32) * M(32, 41)
      temp = temp + M(41, 33) * M(33, 41)
      temp = temp + M(41, 34) * M(34, 41)
      temp = temp + M(41, 35) * M(35, 41)
      temp = temp + M(41, 36) * M(36, 41)
      temp = temp + M(41, 37) * M(37, 41)
      temp = temp + M(41, 38) * M(38, 41)
      temp = temp + M(41, 39) * M(39, 41)
      temp = temp + M(41, 40) * M(40, 41)
      M(41, 41) = M(41, 41) - temp
C     Lower part.
      temp = M(42, 8) * M(8, 41)
      temp = temp + M(42, 16) * M(16, 41)
      temp = temp + M(42, 19) * M(19, 41)
      temp = temp + M(42, 30) * M(30, 41)
      temp = temp + M(42, 32) * M(32, 41)
      temp = temp + M(42, 33) * M(33, 41)
      temp = temp + M(42, 34) * M(34, 41)
      temp = temp + M(42, 35) * M(35, 41)
      temp = temp + M(42, 36) * M(36, 41)
      temp = temp + M(42, 37) * M(37, 41)
      temp = temp + M(42, 38) * M(38, 41)
      temp = temp + M(42, 39) * M(39, 41)
      temp = temp + M(42, 40) * M(40, 41)
      M(42, 41) = M(42, 41) - temp
C     Lower part.
      temp = M(43, 17) * M(17, 41)
      temp = temp + M(43, 18) * M(18, 41)
      temp = temp + M(43, 27) * M(27, 41)
      temp = temp + M(43, 28) * M(28, 41)
      temp = temp + M(43, 29) * M(29, 41)
      temp = temp + M(43, 33) * M(33, 41)
      temp = temp + M(43, 34) * M(34, 41)
      temp = temp + M(43, 35) * M(35, 41)
      temp = temp + M(43, 36) * M(36, 41)
      temp = temp + M(43, 37) * M(37, 41)
      temp = temp + M(43, 38) * M(38, 41)
      temp = temp + M(43, 39) * M(39, 41)
      temp = temp + M(43, 40) * M(40, 41)
      M(43, 41) = M(43, 41) - temp
C     Lower part.
      temp = M(44, 30) * M(30, 41)
      temp = temp + M(44, 33) * M(33, 41)
      temp = temp + M(44, 34) * M(34, 41)
      temp = temp + M(44, 35) * M(35, 41)
      temp = temp + M(44, 36) * M(36, 41)
      temp = temp + M(44, 37) * M(37, 41)
      temp = temp + M(44, 38) * M(38, 41)
      temp = temp + M(44, 39) * M(39, 41)
      temp = temp + M(44, 40) * M(40, 41)
      M(44, 41) = M(44, 41) - temp
C     Upper part.
      temp = M(41, 8) * M(8, 42)
      temp = temp + M(41, 23) * M(23, 42)
      temp = temp + M(41, 26) * M(26, 42)
      temp = temp + M(41, 32) * M(32, 42)
      temp = temp + M(41, 33) * M(33, 42)
      temp = temp + M(41, 34) * M(34, 42)
      temp = temp + M(41, 35) * M(35, 42)
      temp = temp + M(41, 36) * M(36, 42)
      temp = temp + M(41, 37) * M(37, 42)
      temp = temp + M(41, 38) * M(38, 42)
      temp = temp + M(41, 39) * M(39, 42)
      temp = temp + M(41, 40) * M(40, 42)
      M(41, 42) = ( M(41, 42) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 23) * M(23, 43)
      temp = temp + M(41, 33) * M(33, 43)
      temp = temp + M(41, 34) * M(34, 43)
      temp = temp + M(41, 35) * M(35, 43)
      temp = temp + M(41, 36) * M(36, 43)
      temp = temp + M(41, 37) * M(37, 43)
      temp = temp + M(41, 38) * M(38, 43)
      temp = temp + M(41, 39) * M(39, 43)
      temp = temp + M(41, 40) * M(40, 43)
      M(41, 43) = ( M(41, 43) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 29) * M(29, 44)
      temp = temp + M(41, 30) * M(30, 44)
      temp = temp + M(41, 32) * M(32, 44)
      temp = temp + M(41, 33) * M(33, 44)
      temp = temp + M(41, 34) * M(34, 44)
      temp = temp + M(41, 35) * M(35, 44)
      temp = temp + M(41, 36) * M(36, 44)
      temp = temp + M(41, 37) * M(37, 44)
      temp = temp + M(41, 38) * M(38, 44)
      temp = temp + M(41, 39) * M(39, 44)
      temp = temp + M(41, 40) * M(40, 44)
      M(41, 44) = ( M(41, 44) - temp ) / M(41, 41)

C     Lower part.
      temp = M(42, 8) * M(8, 42)
      temp = temp + M(42, 23) * M(23, 42)
      temp = temp + M(42, 26) * M(26, 42)
      temp = temp + M(42, 32) * M(32, 42)
      temp = temp + M(42, 33) * M(33, 42)
      temp = temp + M(42, 34) * M(34, 42)
      temp = temp + M(42, 35) * M(35, 42)
      temp = temp + M(42, 36) * M(36, 42)
      temp = temp + M(42, 37) * M(37, 42)
      temp = temp + M(42, 38) * M(38, 42)
      temp = temp + M(42, 39) * M(39, 42)
      temp = temp + M(42, 40) * M(40, 42)
      temp = temp + M(42, 41) * M(41, 42)
      M(42, 42) = M(42, 42) - temp
C     Lower part.
      temp = M(43, 23) * M(23, 42)
      temp = temp + M(43, 33) * M(33, 42)
      temp = temp + M(43, 34) * M(34, 42)
      temp = temp + M(43, 35) * M(35, 42)
      temp = temp + M(43, 36) * M(36, 42)
      temp = temp + M(43, 37) * M(37, 42)
      temp = temp + M(43, 38) * M(38, 42)
      temp = temp + M(43, 39) * M(39, 42)
      temp = temp + M(43, 40) * M(40, 42)
      temp = temp + M(43, 41) * M(41, 42)
      M(43, 42) = M(43, 42) - temp
C     Lower part.
      temp = M(44, 33) * M(33, 42)
      temp = temp + M(44, 34) * M(34, 42)
      temp = temp + M(44, 35) * M(35, 42)
      temp = temp + M(44, 36) * M(36, 42)
      temp = temp + M(44, 37) * M(37, 42)
      temp = temp + M(44, 38) * M(38, 42)
      temp = temp + M(44, 39) * M(39, 42)
      temp = temp + M(44, 40) * M(40, 42)
      temp = temp + M(44, 41) * M(41, 42)
      M(44, 42) = M(44, 42) - temp
C     Upper part.
      temp = M(42, 23) * M(23, 43)
      temp = temp + M(42, 33) * M(33, 43)
      temp = temp + M(42, 34) * M(34, 43)
      temp = temp + M(42, 35) * M(35, 43)
      temp = temp + M(42, 36) * M(36, 43)
      temp = temp + M(42, 37) * M(37, 43)
      temp = temp + M(42, 38) * M(38, 43)
      temp = temp + M(42, 39) * M(39, 43)
      temp = temp + M(42, 40) * M(40, 43)
      temp = temp + M(42, 41) * M(41, 43)
      M(42, 43) = ( M(42, 43) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 7) * M(7, 44)
      temp = temp + M(42, 30) * M(30, 44)
      temp = temp + M(42, 32) * M(32, 44)
      temp = temp + M(42, 33) * M(33, 44)
      temp = temp + M(42, 34) * M(34, 44)
      temp = temp + M(42, 35) * M(35, 44)
      temp = temp + M(42, 36) * M(36, 44)
      temp = temp + M(42, 37) * M(37, 44)
      temp = temp + M(42, 38) * M(38, 44)
      temp = temp + M(42, 39) * M(39, 44)
      temp = temp + M(42, 40) * M(40, 44)
      temp = temp + M(42, 41) * M(41, 44)
      M(42, 44) = ( M(42, 44) - temp ) / M(42, 42)

C     Lower part.
      temp = M(43, 23) * M(23, 43)
      temp = temp + M(43, 25) * M(25, 43)
      temp = temp + M(43, 33) * M(33, 43)
      temp = temp + M(43, 34) * M(34, 43)
      temp = temp + M(43, 35) * M(35, 43)
      temp = temp + M(43, 36) * M(36, 43)
      temp = temp + M(43, 37) * M(37, 43)
      temp = temp + M(43, 38) * M(38, 43)
      temp = temp + M(43, 39) * M(39, 43)
      temp = temp + M(43, 40) * M(40, 43)
      temp = temp + M(43, 41) * M(41, 43)
      temp = temp + M(43, 42) * M(42, 43)
      M(43, 43) = M(43, 43) - temp
C     Lower part.
      temp = M(44, 33) * M(33, 43)
      temp = temp + M(44, 34) * M(34, 43)
      temp = temp + M(44, 35) * M(35, 43)
      temp = temp + M(44, 36) * M(36, 43)
      temp = temp + M(44, 37) * M(37, 43)
      temp = temp + M(44, 38) * M(38, 43)
      temp = temp + M(44, 39) * M(39, 43)
      temp = temp + M(44, 40) * M(40, 43)
      temp = temp + M(44, 41) * M(41, 43)
      temp = temp + M(44, 42) * M(42, 43)
      M(44, 43) = M(44, 43) - temp
C     Upper part.
      temp = M(43, 27) * M(27, 44)
      temp = temp + M(43, 28) * M(28, 44)
      temp = temp + M(43, 29) * M(29, 44)
      temp = temp + M(43, 33) * M(33, 44)
      temp = temp + M(43, 34) * M(34, 44)
      temp = temp + M(43, 35) * M(35, 44)
      temp = temp + M(43, 36) * M(36, 44)
      temp = temp + M(43, 37) * M(37, 44)
      temp = temp + M(43, 38) * M(38, 44)
      temp = temp + M(43, 39) * M(39, 44)
      temp = temp + M(43, 40) * M(40, 44)
      temp = temp + M(43, 41) * M(41, 44)
      temp = temp + M(43, 42) * M(42, 44)
      M(43, 44) = ( M(43, 44) - temp ) / M(43, 43)

C     Lower part.
      temp = M(44, 7) * M(7, 44)
      temp = temp + M(44, 30) * M(30, 44)
      temp = temp + M(44, 33) * M(33, 44)
      temp = temp + M(44, 34) * M(34, 44)
      temp = temp + M(44, 35) * M(35, 44)
      temp = temp + M(44, 36) * M(36, 44)
      temp = temp + M(44, 37) * M(37, 44)
      temp = temp + M(44, 38) * M(38, 44)
      temp = temp + M(44, 39) * M(39, 44)
      temp = temp + M(44, 40) * M(40, 44)
      temp = temp + M(44, 41) * M(41, 44)
      temp = temp + M(44, 42) * M(42, 44)
      temp = temp + M(44, 43) * M(43, 44)
      M(44, 44) = M(44, 44) - temp


      END
