C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE LU_solve (M, x)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves M * y = x where M is an LU factorization
C     computed by LU_decompose.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     M: LU factorization computed by LU_decompose.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     x: on entry, the right-hand side of the equation. On exit,
C     the solution of the equation.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of 'chemical' arrays.

      INCLUDE 'PARACHEM.INC'

      DOUBLE PRECISION M(Nesp,Nesp)
      DOUBLE PRECISION x(Nesp)
      DOUBLE PRECISION temp


C     Forward substitution.

      x(1) = x(1) / M(1, 1)

      x(2) = x(2) / M(2, 2)

      x(3) = x(3) / M(3, 3)

      temp = M(4, 3) * x(3)
      x(4) = ( x(4) - temp ) / M(4, 4)

      temp = M(5, 4) * x(4)
      x(5) = ( x(5) - temp ) / M(5, 5)

      x(6) = x(6) / M(6, 6)

      x(7) = x(7) / M(7, 7)

      x(8) = x(8) / M(8, 8)

      x(9) = x(9) / M(9, 9)

      x(10) = x(10) / M(10, 10)

      x(11) = x(11) / M(11, 11)

      x(12) = x(12) / M(12, 12)

      x(13) = x(13) / M(13, 13)

      temp = M(14, 12) * x(12)
      x(14) = ( x(14) - temp ) / M(14, 14)

      temp = M(15, 12) * x(12)
      x(15) = ( x(15) - temp ) / M(15, 15)

      temp = M(16, 15) * x(15)
      x(16) = ( x(16) - temp ) / M(16, 16)

      temp = M(17, 4) * x(4)
      temp = temp + M(17, 12) * x(12)
      x(17) = ( x(17) - temp ) / M(17, 17)

      temp = M(18, 3) * x(3)
      temp = temp + M(18, 4) * x(4)
      temp = temp + M(18, 14) * x(14)
      temp = temp + M(18, 17) * x(17)
      x(18) = ( x(18) - temp ) / M(18, 18)

      x(19) = x(19) / M(19, 19)

      x(20) = x(20) / M(20, 20)

      x(21) = x(21) / M(21, 21)

      x(22) = x(22) / M(22, 22)

      x(23) = x(23) / M(23, 23)

      x(24) = x(24) / M(24, 24)

      x(25) = x(25) / M(25, 25)

      x(26) = x(26) / M(26, 26)

      temp = M(27, 12) * x(12)
      temp = temp + M(27, 17) * x(17)
      x(27) = ( x(27) - temp ) / M(27, 27)

      temp = M(28, 2) * x(2)
      temp = temp + M(28, 14) * x(14)
      temp = temp + M(28, 22) * x(22)
      temp = temp + M(28, 27) * x(27)
      x(28) = ( x(28) - temp ) / M(28, 28)

      temp = M(29, 1) * x(1)
      temp = temp + M(29, 2) * x(2)
      temp = temp + M(29, 15) * x(15)
      temp = temp + M(29, 16) * x(16)
      temp = temp + M(29, 17) * x(17)
      temp = temp + M(29, 19) * x(19)
      temp = temp + M(29, 22) * x(22)
      temp = temp + M(29, 27) * x(27)
      temp = temp + M(29, 28) * x(28)
      x(29) = ( x(29) - temp ) / M(29, 29)

      temp = M(30, 12) * x(12)
      temp = temp + M(30, 15) * x(15)
      temp = temp + M(30, 19) * x(19)
      temp = temp + M(30, 22) * x(22)
      temp = temp + M(30, 27) * x(27)
      x(30) = ( x(30) - temp ) / M(30, 30)

      temp = M(31, 5) * x(5)
      temp = temp + M(31, 12) * x(12)
      temp = temp + M(31, 14) * x(14)
      temp = temp + M(31, 15) * x(15)
      temp = temp + M(31, 16) * x(16)
      temp = temp + M(31, 17) * x(17)
      temp = temp + M(31, 18) * x(18)
      temp = temp + M(31, 19) * x(19)
      temp = temp + M(31, 22) * x(22)
      temp = temp + M(31, 27) * x(27)
      temp = temp + M(31, 29) * x(29)
      x(31) = ( x(31) - temp ) / M(31, 31)

      temp = M(32, 8) * x(8)
      temp = temp + M(32, 13) * x(13)
      temp = temp + M(32, 29) * x(29)
      x(32) = ( x(32) - temp ) / M(32, 32)

      temp = M(33, 1) * x(1)
      temp = temp + M(33, 2) * x(2)
      temp = temp + M(33, 3) * x(3)
      temp = temp + M(33, 4) * x(4)
      temp = temp + M(33, 5) * x(5)
      temp = temp + M(33, 7) * x(7)
      temp = temp + M(33, 9) * x(9)
      temp = temp + M(33, 10) * x(10)
      temp = temp + M(33, 11) * x(11)
      temp = temp + M(33, 12) * x(12)
      temp = temp + M(33, 13) * x(13)
      temp = temp + M(33, 14) * x(14)
      temp = temp + M(33, 15) * x(15)
      temp = temp + M(33, 16) * x(16)
      temp = temp + M(33, 17) * x(17)
      temp = temp + M(33, 18) * x(18)
      temp = temp + M(33, 19) * x(19)
      temp = temp + M(33, 20) * x(20)
      temp = temp + M(33, 21) * x(21)
      temp = temp + M(33, 22) * x(22)
      temp = temp + M(33, 23) * x(23)
      temp = temp + M(33, 24) * x(24)
      temp = temp + M(33, 25) * x(25)
      temp = temp + M(33, 26) * x(26)
      temp = temp + M(33, 27) * x(27)
      temp = temp + M(33, 28) * x(28)
      temp = temp + M(33, 29) * x(29)
      temp = temp + M(33, 31) * x(31)
      temp = temp + M(33, 32) * x(32)
      x(33) = ( x(33) - temp ) / M(33, 33)

      temp = M(34, 12) * x(12)
      temp = temp + M(34, 14) * x(14)
      temp = temp + M(34, 15) * x(15)
      temp = temp + M(34, 17) * x(17)
      temp = temp + M(34, 19) * x(19)
      temp = temp + M(34, 22) * x(22)
      temp = temp + M(34, 33) * x(33)
      x(34) = ( x(34) - temp ) / M(34, 34)

      temp = M(35, 1) * x(1)
      temp = temp + M(35, 2) * x(2)
      temp = temp + M(35, 3) * x(3)
      temp = temp + M(35, 4) * x(4)
      temp = temp + M(35, 15) * x(15)
      temp = temp + M(35, 17) * x(17)
      temp = temp + M(35, 19) * x(19)
      temp = temp + M(35, 21) * x(21)
      temp = temp + M(35, 22) * x(22)
      temp = temp + M(35, 28) * x(28)
      temp = temp + M(35, 33) * x(33)
      temp = temp + M(35, 34) * x(34)
      x(35) = ( x(35) - temp ) / M(35, 35)

      temp = M(36, 12) * x(12)
      temp = temp + M(36, 22) * x(22)
      temp = temp + M(36, 33) * x(33)
      temp = temp + M(36, 34) * x(34)
      temp = temp + M(36, 35) * x(35)
      x(36) = ( x(36) - temp ) / M(36, 36)

      temp = M(37, 9) * x(9)
      temp = temp + M(37, 10) * x(10)
      temp = temp + M(37, 11) * x(11)
      temp = temp + M(37, 15) * x(15)
      temp = temp + M(37, 25) * x(25)
      temp = temp + M(37, 29) * x(29)
      temp = temp + M(37, 33) * x(33)
      temp = temp + M(37, 34) * x(34)
      temp = temp + M(37, 35) * x(35)
      temp = temp + M(37, 36) * x(36)
      x(37) = ( x(37) - temp ) / M(37, 37)

      temp = M(38, 4) * x(4)
      temp = temp + M(38, 9) * x(9)
      temp = temp + M(38, 10) * x(10)
      temp = temp + M(38, 12) * x(12)
      temp = temp + M(38, 14) * x(14)
      temp = temp + M(38, 15) * x(15)
      temp = temp + M(38, 17) * x(17)
      temp = temp + M(38, 19) * x(19)
      temp = temp + M(38, 22) * x(22)
      temp = temp + M(38, 23) * x(23)
      temp = temp + M(38, 33) * x(33)
      temp = temp + M(38, 34) * x(34)
      temp = temp + M(38, 35) * x(35)
      temp = temp + M(38, 36) * x(36)
      temp = temp + M(38, 37) * x(37)
      x(38) = ( x(38) - temp ) / M(38, 38)

      temp = M(39, 4) * x(4)
      temp = temp + M(39, 5) * x(5)
      temp = temp + M(39, 9) * x(9)
      temp = temp + M(39, 10) * x(10)
      temp = temp + M(39, 12) * x(12)
      temp = temp + M(39, 13) * x(13)
      temp = temp + M(39, 14) * x(14)
      temp = temp + M(39, 15) * x(15)
      temp = temp + M(39, 17) * x(17)
      temp = temp + M(39, 18) * x(18)
      temp = temp + M(39, 19) * x(19)
      temp = temp + M(39, 20) * x(20)
      temp = temp + M(39, 21) * x(21)
      temp = temp + M(39, 22) * x(22)
      temp = temp + M(39, 24) * x(24)
      temp = temp + M(39, 27) * x(27)
      temp = temp + M(39, 29) * x(29)
      temp = temp + M(39, 30) * x(30)
      temp = temp + M(39, 31) * x(31)
      temp = temp + M(39, 33) * x(33)
      temp = temp + M(39, 34) * x(34)
      temp = temp + M(39, 35) * x(35)
      temp = temp + M(39, 36) * x(36)
      temp = temp + M(39, 37) * x(37)
      temp = temp + M(39, 38) * x(38)
      x(39) = ( x(39) - temp ) / M(39, 39)

      temp = M(40, 4) * x(4)
      temp = temp + M(40, 14) * x(14)
      temp = temp + M(40, 24) * x(24)
      temp = temp + M(40, 26) * x(26)
      temp = temp + M(40, 33) * x(33)
      temp = temp + M(40, 34) * x(34)
      temp = temp + M(40, 35) * x(35)
      temp = temp + M(40, 36) * x(36)
      temp = temp + M(40, 37) * x(37)
      temp = temp + M(40, 38) * x(38)
      temp = temp + M(40, 39) * x(39)
      x(40) = ( x(40) - temp ) / M(40, 40)

      temp = M(41, 8) * x(8)
      temp = temp + M(41, 12) * x(12)
      temp = temp + M(41, 13) * x(13)
      temp = temp + M(41, 15) * x(15)
      temp = temp + M(41, 19) * x(19)
      temp = temp + M(41, 22) * x(22)
      temp = temp + M(41, 23) * x(23)
      temp = temp + M(41, 26) * x(26)
      temp = temp + M(41, 29) * x(29)
      temp = temp + M(41, 30) * x(30)
      temp = temp + M(41, 32) * x(32)
      temp = temp + M(41, 33) * x(33)
      temp = temp + M(41, 34) * x(34)
      temp = temp + M(41, 35) * x(35)
      temp = temp + M(41, 36) * x(36)
      temp = temp + M(41, 37) * x(37)
      temp = temp + M(41, 38) * x(38)
      temp = temp + M(41, 39) * x(39)
      temp = temp + M(41, 40) * x(40)
      x(41) = ( x(41) - temp ) / M(41, 41)

      temp = M(42, 7) * x(7)
      temp = temp + M(42, 8) * x(8)
      temp = temp + M(42, 16) * x(16)
      temp = temp + M(42, 19) * x(19)
      temp = temp + M(42, 23) * x(23)
      temp = temp + M(42, 26) * x(26)
      temp = temp + M(42, 30) * x(30)
      temp = temp + M(42, 32) * x(32)
      temp = temp + M(42, 33) * x(33)
      temp = temp + M(42, 34) * x(34)
      temp = temp + M(42, 35) * x(35)
      temp = temp + M(42, 36) * x(36)
      temp = temp + M(42, 37) * x(37)
      temp = temp + M(42, 38) * x(38)
      temp = temp + M(42, 39) * x(39)
      temp = temp + M(42, 40) * x(40)
      temp = temp + M(42, 41) * x(41)
      x(42) = ( x(42) - temp ) / M(42, 42)

      temp = M(43, 2) * x(2)
      temp = temp + M(43, 6) * x(6)
      temp = temp + M(43, 17) * x(17)
      temp = temp + M(43, 18) * x(18)
      temp = temp + M(43, 23) * x(23)
      temp = temp + M(43, 25) * x(25)
      temp = temp + M(43, 27) * x(27)
      temp = temp + M(43, 28) * x(28)
      temp = temp + M(43, 29) * x(29)
      temp = temp + M(43, 33) * x(33)
      temp = temp + M(43, 34) * x(34)
      temp = temp + M(43, 35) * x(35)
      temp = temp + M(43, 36) * x(36)
      temp = temp + M(43, 37) * x(37)
      temp = temp + M(43, 38) * x(38)
      temp = temp + M(43, 39) * x(39)
      temp = temp + M(43, 40) * x(40)
      temp = temp + M(43, 41) * x(41)
      temp = temp + M(43, 42) * x(42)
      x(43) = ( x(43) - temp ) / M(43, 43)

      temp = M(44, 7) * x(7)
      temp = temp + M(44, 30) * x(30)
      temp = temp + M(44, 33) * x(33)
      temp = temp + M(44, 34) * x(34)
      temp = temp + M(44, 35) * x(35)
      temp = temp + M(44, 36) * x(36)
      temp = temp + M(44, 37) * x(37)
      temp = temp + M(44, 38) * x(38)
      temp = temp + M(44, 39) * x(39)
      temp = temp + M(44, 40) * x(40)
      temp = temp + M(44, 41) * x(41)
      temp = temp + M(44, 42) * x(42)
      temp = temp + M(44, 43) * x(43)
      x(44) = ( x(44) - temp ) / M(44, 44)


C     Backward substitution.

      temp = M(43, 44) * x(44)
      x(43) = x(43) - temp

      temp = M(42, 43) * x(43)
      temp = temp + M(42, 44) * x(44)
      x(42) = x(42) - temp

      temp = M(41, 42) * x(42)
      temp = temp + M(41, 43) * x(43)
      temp = temp + M(41, 44) * x(44)
      x(41) = x(41) - temp

      temp = M(40, 41) * x(41)
      temp = temp + M(40, 42) * x(42)
      temp = temp + M(40, 43) * x(43)
      temp = temp + M(40, 44) * x(44)
      x(40) = x(40) - temp

      temp = M(39, 40) * x(40)
      temp = temp + M(39, 41) * x(41)
      temp = temp + M(39, 42) * x(42)
      temp = temp + M(39, 43) * x(43)
      temp = temp + M(39, 44) * x(44)
      x(39) = x(39) - temp

      temp = M(38, 39) * x(39)
      temp = temp + M(38, 40) * x(40)
      temp = temp + M(38, 41) * x(41)
      temp = temp + M(38, 42) * x(42)
      temp = temp + M(38, 43) * x(43)
      temp = temp + M(38, 44) * x(44)
      x(38) = x(38) - temp

      temp = M(37, 38) * x(38)
      temp = temp + M(37, 39) * x(39)
      temp = temp + M(37, 40) * x(40)
      temp = temp + M(37, 41) * x(41)
      temp = temp + M(37, 42) * x(42)
      temp = temp + M(37, 43) * x(43)
      temp = temp + M(37, 44) * x(44)
      x(37) = x(37) - temp

      temp = M(36, 37) * x(37)
      temp = temp + M(36, 38) * x(38)
      temp = temp + M(36, 39) * x(39)
      temp = temp + M(36, 40) * x(40)
      temp = temp + M(36, 41) * x(41)
      temp = temp + M(36, 42) * x(42)
      temp = temp + M(36, 43) * x(43)
      temp = temp + M(36, 44) * x(44)
      x(36) = x(36) - temp

      temp = M(35, 36) * x(36)
      temp = temp + M(35, 37) * x(37)
      temp = temp + M(35, 38) * x(38)
      temp = temp + M(35, 39) * x(39)
      temp = temp + M(35, 40) * x(40)
      temp = temp + M(35, 41) * x(41)
      temp = temp + M(35, 42) * x(42)
      temp = temp + M(35, 43) * x(43)
      temp = temp + M(35, 44) * x(44)
      x(35) = x(35) - temp

      temp = M(34, 35) * x(35)
      temp = temp + M(34, 36) * x(36)
      temp = temp + M(34, 37) * x(37)
      temp = temp + M(34, 38) * x(38)
      temp = temp + M(34, 39) * x(39)
      temp = temp + M(34, 40) * x(40)
      temp = temp + M(34, 41) * x(41)
      temp = temp + M(34, 42) * x(42)
      temp = temp + M(34, 43) * x(43)
      temp = temp + M(34, 44) * x(44)
      x(34) = x(34) - temp

      temp = M(33, 34) * x(34)
      temp = temp + M(33, 35) * x(35)
      temp = temp + M(33, 36) * x(36)
      temp = temp + M(33, 37) * x(37)
      temp = temp + M(33, 38) * x(38)
      temp = temp + M(33, 39) * x(39)
      temp = temp + M(33, 40) * x(40)
      temp = temp + M(33, 41) * x(41)
      temp = temp + M(33, 42) * x(42)
      temp = temp + M(33, 43) * x(43)
      temp = temp + M(33, 44) * x(44)
      x(33) = x(33) - temp

      temp = M(32, 33) * x(33)
      temp = temp + M(32, 34) * x(34)
      temp = temp + M(32, 36) * x(36)
      temp = temp + M(32, 38) * x(38)
      temp = temp + M(32, 39) * x(39)
      temp = temp + M(32, 41) * x(41)
      temp = temp + M(32, 42) * x(42)
      temp = temp + M(32, 44) * x(44)
      x(32) = x(32) - temp

      temp = M(31, 33) * x(33)
      temp = temp + M(31, 34) * x(34)
      temp = temp + M(31, 36) * x(36)
      temp = temp + M(31, 38) * x(38)
      temp = temp + M(31, 41) * x(41)
      temp = temp + M(31, 44) * x(44)
      x(31) = x(31) - temp

      temp = M(30, 33) * x(33)
      temp = temp + M(30, 34) * x(34)
      temp = temp + M(30, 36) * x(36)
      temp = temp + M(30, 39) * x(39)
      temp = temp + M(30, 41) * x(41)
      temp = temp + M(30, 44) * x(44)
      x(30) = x(30) - temp

      temp = M(29, 33) * x(33)
      temp = temp + M(29, 34) * x(34)
      temp = temp + M(29, 36) * x(36)
      temp = temp + M(29, 41) * x(41)
      temp = temp + M(29, 44) * x(44)
      x(29) = x(29) - temp

      temp = M(28, 33) * x(33)
      temp = temp + M(28, 34) * x(34)
      temp = temp + M(28, 36) * x(36)
      temp = temp + M(28, 41) * x(41)
      temp = temp + M(28, 44) * x(44)
      x(28) = x(28) - temp

      temp = M(27, 33) * x(33)
      temp = temp + M(27, 34) * x(34)
      temp = temp + M(27, 36) * x(36)
      temp = temp + M(27, 41) * x(41)
      temp = temp + M(27, 44) * x(44)
      x(27) = x(27) - temp

      temp = M(26, 33) * x(33)
      temp = temp + M(26, 40) * x(40)
      temp = temp + M(26, 42) * x(42)
      x(26) = x(26) - temp

      temp = M(25, 33) * x(33)
      temp = temp + M(25, 39) * x(39)
      temp = temp + M(25, 43) * x(43)
      x(25) = x(25) - temp

      temp = M(24, 33) * x(33)
      temp = temp + M(24, 39) * x(39)
      temp = temp + M(24, 40) * x(40)
      x(24) = x(24) - temp

      temp = M(23, 33) * x(33)
      temp = temp + M(23, 42) * x(42)
      temp = temp + M(23, 43) * x(43)
      x(23) = x(23) - temp

      temp = M(22, 33) * x(33)
      temp = temp + M(22, 34) * x(34)
      temp = temp + M(22, 41) * x(41)
      x(22) = x(22) - temp

      temp = M(21, 33) * x(33)
      temp = temp + M(21, 35) * x(35)
      temp = temp + M(21, 39) * x(39)
      x(21) = x(21) - temp

      temp = M(20, 33) * x(33)
      temp = temp + M(20, 36) * x(36)
      temp = temp + M(20, 39) * x(39)
      x(20) = x(20) - temp

      temp = M(19, 33) * x(33)
      temp = temp + M(19, 34) * x(34)
      temp = temp + M(19, 41) * x(41)
      x(19) = x(19) - temp

      temp = M(18, 27) * x(27)
      temp = temp + M(18, 33) * x(33)
      temp = temp + M(18, 34) * x(34)
      temp = temp + M(18, 41) * x(41)
      x(18) = x(18) - temp

      temp = M(17, 33) * x(33)
      temp = temp + M(17, 34) * x(34)
      temp = temp + M(17, 41) * x(41)
      x(17) = x(17) - temp

      temp = M(16, 19) * x(19)
      temp = temp + M(16, 33) * x(33)
      temp = temp + M(16, 34) * x(34)
      temp = temp + M(16, 41) * x(41)
      x(16) = x(16) - temp

      temp = M(15, 33) * x(33)
      temp = temp + M(15, 34) * x(34)
      temp = temp + M(15, 41) * x(41)
      x(15) = x(15) - temp

      temp = M(14, 33) * x(33)
      temp = temp + M(14, 34) * x(34)
      temp = temp + M(14, 41) * x(41)
      x(14) = x(14) - temp

      temp = M(13, 33) * x(33)
      temp = temp + M(13, 39) * x(39)
      temp = temp + M(13, 41) * x(41)
      x(13) = x(13) - temp

      temp = M(12, 33) * x(33)
      temp = temp + M(12, 34) * x(34)
      temp = temp + M(12, 41) * x(41)
      x(12) = x(12) - temp

      temp = M(11, 15) * x(15)
      temp = temp + M(11, 33) * x(33)
      temp = temp + M(11, 34) * x(34)
      x(11) = x(11) - temp

      temp = M(10, 33) * x(33)
      temp = temp + M(10, 37) * x(37)
      temp = temp + M(10, 39) * x(39)
      x(10) = x(10) - temp

      temp = M(9, 33) * x(33)
      temp = temp + M(9, 37) * x(37)
      x(9) = x(9) - temp

      temp = M(8, 41) * x(41)
      temp = temp + M(8, 42) * x(42)
      x(8) = x(8) - temp

      temp = M(7, 33) * x(33)
      temp = temp + M(7, 44) * x(44)
      x(7) = x(7) - temp

      temp = M(6, 28) * x(28)
      temp = temp + M(6, 33) * x(33)
      x(6) = x(6) - temp

      temp = M(5, 33) * x(33)
      x(5) = x(5) - temp

      temp = M(4, 33) * x(33)
      x(4) = x(4) - temp

      temp = M(3, 33) * x(33)
      x(3) = x(3) - temp

      temp = M(2, 33) * x(33)
      x(2) = x(2) - temp

      temp = M(1, 33) * x(33)
      x(1) = x(1) - temp


      END
