      subroutine fexchem(y,rk,ZCsourc,chem)
      
C------------------------------------------------------------------------
C     
C     -- DESCRIPTION
C     
C     This routine computes the chemical production term.
C     This routine is automatically generated by SPACK.
C     Mechanism: MELCHIOR            
C     Species: _ciMELCHIOR         
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     ZCSOURC: volumic emissions.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     CHEM: array of chemical production terms.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     SPACK.
C     
C------------------------------------------------------------------------
      
      implicit none
      
C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of chemical arrays.
C     COMUSE: flags and parameters for numerics.
C     PARADOM: parameters for all forced fields.
      
      include 'PARACHEM.INC' 
      include 'COMUSE.INC' 
      INCLUDE 'PARADOM.INC'  
      
      double precision w(nr),rk(nr),y(nesp),chem(nesp),ZCsourc(nesp)
      integer i
      
      do i=1,nesp
         chem(i)=0.d0
      enddo
      
C     Compute reaction rates.
      
      call rates(rk,y,w)
      
C     Chemical production terms.
      
      chem( 34) = chem( 34) - w(  1)
      chem( 42) = chem( 42) + w(  1)
      chem( 44) = chem( 44) - w(  1)
      chem( 34) = chem( 34) - w(  2)
      chem( 41) = chem( 41) + w(  2)
      chem( 42) = chem( 42) - w(  2)
      chem( 33) = chem( 33) - w(  3)
      chem( 34) = chem( 34) - w(  3)
      chem( 39) = chem( 39) + w(  3)
      chem( 33) = chem( 33) + w(  4)
      chem( 34) = chem( 34) - w(  4)
      chem( 39) = chem( 39) - w(  4)
      chem( 33) = chem( 33) + w(  5)
      chem( 39) = chem( 39) - w(  5)
      chem( 42) = chem( 42) + w(  5)
      chem( 44) = chem( 44) - w(  5)
      chem( 32) = chem( 32) + w(  6)
      chem( 33) = chem( 33) - w(  6)
      chem( 42) = chem( 42) - w(  6)
      chem( 33) = chem( 33) - w(  7)
      chem( 39) = chem( 39) - w(  7)
      chem( 13) = chem( 13) - w(  8)
      chem( 33) = chem( 33) - w(  8)
      chem( 39) = chem( 39) + w(  8)
      chem( 32) = chem( 32) - w(  9)
      chem( 33) = chem( 33) - w(  9)
      chem( 41) = chem( 41) + w(  9)
      chem( 31) = chem( 31) - w( 10)
      chem( 33) = chem( 33) - w( 10)
      chem( 39) = chem( 39) + w( 10)
      chem( 13) = chem( 13) + w( 11)
      chem( 39) = chem( 39) -  0.2000000000000000D+01 * w( 11)
      chem( 13) = chem( 13) + w( 12)
      chem( 39) = chem( 39) -  0.2000000000000000D+01 * w( 12)
      chem( 33) = chem( 33) + w( 13)
      chem( 39) = chem( 39) - w( 13)
      chem( 41) = chem( 41) - w( 13)
      chem( 42) = chem( 42) + w( 13)
      chem( 13) = chem( 13) - w( 14)
      chem( 32) = chem( 32) + w( 14)
      chem( 39) = chem( 39) + w( 14)
      chem( 41) = chem( 41) - w( 14)
      chem( 41) = chem( 41) - w( 15)
      chem( 42) = chem( 42) +  0.2000000000000000D+01 * w( 15)
      chem( 44) = chem( 44) - w( 15)
      chem( 41) = chem( 41) - w( 16)
      chem( 44) = chem( 44) + w( 16)
      chem(  8) = chem(  8) + w( 17)
      chem( 41) = chem( 41) - w( 17)
      chem( 42) = chem( 42) - w( 17)
      chem(  8) = chem(  8) - w( 18)
      chem( 41) = chem( 41) + w( 18)
      chem( 42) = chem( 42) + w( 18)
      chem(  8) = chem(  8) - w( 19)
      chem( 32) = chem( 32) +  0.2000000000000000D+01 * w( 19)
      chem(  8) = chem(  8) - w( 20)
      chem( 32) = chem( 32) +  0.2000000000000000D+01 * w( 20)
      chem(  7) = chem(  7) + w( 21)
      chem( 33) = chem( 33) - w( 21)
      chem( 44) = chem( 44) - w( 21)
      chem(  7) = chem(  7) - w( 22)
      chem( 33) = chem( 33) - w( 22)
      chem( 42) = chem( 42) + w( 22)
      chem(  9) = chem(  9) - w( 23)
      chem( 37) = chem( 37) - w( 23)
      chem( 38) = chem( 38) + w( 23)
      chem( 39) = chem( 39) + w( 23)
      chem(  9) = chem(  9) - w( 24)
      chem( 33) = chem( 33) - w( 24)
      chem( 39) = chem( 39) + w( 24)
      chem( 27) = chem( 27) +  0.1400000000000000D+00 * w( 25)
      chem( 36) = chem( 36) - w( 25)
      chem( 39) = chem( 39) +  0.7800000000000000D+00 * w( 25)
      chem( 42) = chem( 42) +  0.8600000000000000D+00 * w( 25)
      chem( 44) = chem( 44) - w( 25)
      chem( 20) = chem( 20) + w( 26)
      chem( 36) = chem( 36) - w( 26)
      chem( 39) = chem( 39) - w( 26)
      chem( 36) = chem( 36) - w( 27)
      chem( 39) = chem( 39) + w( 27)
      chem( 41) = chem( 41) - w( 27)
      chem( 42) = chem( 42) + w( 27)
      chem( 36) = chem( 36) - w( 28)
      chem( 37) = chem( 37) - w( 28)
      chem( 38) = chem( 38) +  0.5000000000000000D+00 * w( 28)
      chem( 39) = chem( 39) +  0.8000000000000000D+00 * w( 28)
      chem( 36) = chem( 36) - w( 29)
      chem( 38) = chem( 38) +  0.5000000000000000D+00 * w( 29)
      chem( 39) = chem( 39) +  0.1500000000000000D+01 * w( 29)
      chem( 43) = chem( 43) - w( 29)
      chem( 20) = chem( 20) - w( 30)
      chem( 35) = chem( 35) - w( 31)
      chem( 39) = chem( 39) + w( 31)
      chem( 42) = chem( 42) + w( 31)
      chem( 44) = chem( 44) - w( 31)
      chem( 21) = chem( 21) + w( 32)
      chem( 35) = chem( 35) - w( 32)
      chem( 39) = chem( 39) - w( 32)
      chem( 35) = chem( 35) -  0.2000000000000000D+01 * w( 33)
      chem( 39) = chem( 39) +  0.1300000000000000D+01 * w( 33)
      chem( 35) = chem( 35) - w( 34)
      chem( 39) = chem( 39) + w( 34)
      chem( 41) = chem( 41) - w( 34)
      chem( 42) = chem( 42) + w( 34)
      chem( 35) = chem( 35) - w( 35)
      chem( 37) = chem( 37) - w( 35)
      chem( 38) = chem( 38) +  0.6500000000000000D+00 * w( 35)
      chem( 39) = chem( 39) +  0.8000000000000000D+00 * w( 35)
      chem( 35) = chem( 35) - w( 36)
      chem( 37) = chem( 37) +  0.8000000000000000D+00 * w( 36)
      chem( 39) = chem( 39) +  0.8000000000000000D+00 * w( 36)
      chem( 43) = chem( 43) - w( 36)
      chem( 21) = chem( 21) - w( 37)
      chem( 33) = chem( 33) -  0.2000000000000000D+00 * w( 37)
      chem( 35) = chem( 35) +  0.2000000000000000D+00 * w( 37)
      chem( 14) = chem( 14) - w( 38)
      chem( 28) = chem( 28) +  0.5000000000000000D+00 * w( 38)
      chem( 33) = chem( 33) - w( 38)
      chem( 40) = chem( 40) +  0.5000000000000000D+00 * w( 38)
      chem( 39) = chem( 39) + w( 39)
      chem( 40) = chem( 40) - w( 39)
      chem( 42) = chem( 42) + w( 39)
      chem( 44) = chem( 44) - w( 39)
      chem( 39) = chem( 39) + w( 40)
      chem( 40) = chem( 40) - w( 40)
      chem( 41) = chem( 41) - w( 40)
      chem( 42) = chem( 42) + w( 40)
      chem( 24) = chem( 24) + w( 41)
      chem( 39) = chem( 39) - w( 41)
      chem( 40) = chem( 40) - w( 41)
      chem( 24) = chem( 24) - w( 42)
      chem( 33) = chem( 33) - w( 42)
      chem( 40) = chem( 40) +  0.2000000000000000D+00 * w( 42)
      chem( 37) = chem( 37) - w( 43)
      chem( 38) = chem( 38) + w( 43)
      chem( 39) = chem( 39) +  0.5000000000000000D+00 * w( 43)
      chem( 40) = chem( 40) - w( 43)
      chem( 37) = chem( 37) + w( 44)
      chem( 39) = chem( 39) + w( 44)
      chem( 40) = chem( 40) - w( 44)
      chem( 43) = chem( 43) - w( 44)
      chem( 26) = chem( 26) + w( 45)
      chem( 40) = chem( 40) - w( 45)
      chem( 42) = chem( 42) - w( 45)
      chem( 26) = chem( 26) - w( 46)
      chem( 40) = chem( 40) + w( 46)
      chem( 42) = chem( 42) + w( 46)
      chem( 26) = chem( 26) - w( 47)
      chem( 33) = chem( 33) - w( 47)
      chem( 41) = chem( 41) + w( 47)
      chem( 16) = chem( 16) +  0.5000000000000000D+00 * w( 48)
      chem( 19) = chem( 19) - w( 48)
      chem( 30) = chem( 30) + w( 48)
      chem( 38) = chem( 38) + w( 48)
      chem( 41) = chem( 41) - w( 48)
      chem( 15) = chem( 15) - w( 49)
      chem( 16) = chem( 16) +  0.5000000000000000D+00 * w( 49)
      chem( 29) = chem( 29) +  0.5000000000000000D+00 * w( 49)
      chem( 30) = chem( 30) + w( 49)
      chem( 38) = chem( 38) +  0.1500000000000000D+01 * w( 49)
      chem( 39) = chem( 39) +  0.5000000000000000D+00 * w( 49)
      chem( 41) = chem( 41) - w( 49)
      chem( 22) = chem( 22) - w( 50)
      chem( 28) = chem( 28) + w( 50)
      chem( 29) = chem( 29) + w( 50)
      chem( 30) = chem( 30) + w( 50)
      chem( 41) = chem( 41) - w( 50)
      chem( 18) = chem( 18) +  0.4750000000000000D+00 * w( 51)
      chem( 27) = chem( 27) -  0.9500000000000000D+00 * w( 51)
      chem( 28) = chem( 28) +  0.4750000000000000D+00 * w( 51)
      chem( 29) = chem( 29) +  0.9500000000000000D+00 * w( 51)
      chem( 30) = chem( 30) + w( 51)
      chem( 33) = chem( 33) - w( 51)
      chem( 39) = chem( 39) +  0.5000000000000000D-01 * w( 51)
      chem( 12) = chem( 12) - w( 52)
      chem( 14) = chem( 14) +  0.1000000000000000D+00 * w( 52)
      chem( 17) = chem( 17) +  0.5000000000000000D-01 * w( 52)
      chem( 27) = chem( 27) +  0.8500000000000000D+00 * w( 52)
      chem( 30) = chem( 30) + w( 52)
      chem( 38) = chem( 38) +  0.1500000000000000D+00 * w( 52)
      chem( 39) = chem( 39) +  0.8000000000000000D+00 * w( 52)
      chem( 41) = chem( 41) - w( 52)
      chem( 30) = chem( 30) - w( 53)
      chem( 42) = chem( 42) +  0.1500000000000000D+01 * w( 53)
      chem( 44) = chem( 44) - w( 53)
      chem( 30) = chem( 30) - w( 54)
      chem( 41) = chem( 41) - w( 54)
      chem( 42) = chem( 42) +  0.1500000000000000D+01 * w( 54)
      chem( 30) = chem( 30) - w( 55)
      chem( 39) = chem( 39) - w( 55)
      chem( 11) = chem( 11) - w( 56)
      chem( 33) = chem( 33) - w( 56)
      chem( 37) = chem( 37) + w( 56)
      chem(  1) = chem(  1) - w( 57)
      chem( 29) = chem( 29) + w( 57)
      chem( 33) = chem( 33) - w( 57)
      chem( 35) = chem( 35) + w( 57)
      chem(  2) = chem(  2) - w( 58)
      chem( 28) = chem( 28) +  0.9000000000000000D+00 * w( 58)
      chem( 29) = chem( 29) +  0.1000000000000000D+00 * w( 58)
      chem( 33) = chem( 33) - w( 58)
      chem( 35) = chem( 35) +  0.9000000000000000D+00 * w( 58)
      chem( 43) = chem( 43) +  0.1000000000000000D+00 * w( 58)
      chem( 19) = chem( 19) - w( 59)
      chem( 33) = chem( 33) - w( 59)
      chem( 35) = chem( 35) + w( 59)
      chem( 38) = chem( 38) +  0.2000000000000000D+01 * w( 59)
      chem( 15) = chem( 15) - w( 60)
      chem( 29) = chem( 29) + w( 60)
      chem( 33) = chem( 33) - w( 60)
      chem( 35) = chem( 35) + w( 60)
      chem( 38) = chem( 38) + w( 60)
      chem(  3) = chem(  3) - w( 61)
      chem(  4) = chem(  4) + w( 61)
      chem( 18) = chem( 18) + w( 61)
      chem( 33) = chem( 33) - w( 61)
      chem( 35) = chem( 35) + w( 61)
      chem( 12) = chem( 12) - w( 62)
      chem( 14) = chem( 14) +  0.3200000000000000D+00 * w( 62)
      chem( 17) = chem( 17) +  0.4200000000000000D+00 * w( 62)
      chem( 33) = chem( 33) - w( 62)
      chem( 36) = chem( 36) + w( 62)
      chem( 38) = chem( 38) +  0.7400000000000000D+00 * w( 62)
      chem( 22) = chem( 22) - w( 63)
      chem( 28) = chem( 28) +  0.8000000000000000D+00 * w( 63)
      chem( 29) = chem( 29) +  0.8000000000000000D+00 * w( 63)
      chem( 33) = chem( 33) - w( 63)
      chem( 36) = chem( 36) + w( 63)
      chem( 31) = chem( 31) + w( 64)
      chem( 33) = chem( 33) - w( 64)
      chem( 38) = chem( 38) - w( 64)
      chem( 39) = chem( 39) + w( 64)
      chem( 29) = chem( 29) - w( 65)
      chem( 33) = chem( 33) - w( 65)
      chem( 43) = chem( 43) + w( 65)
      chem(  4) = chem(  4) - w( 66)
      chem(  5) = chem(  5) + w( 66)
      chem( 18) = chem( 18) + w( 66)
      chem( 33) = chem( 33) - w( 66)
      chem( 35) = chem( 35) + w( 66)
      chem(  6) = chem(  6) + w( 67)
      chem( 28) = chem( 28) - w( 67)
      chem( 33) = chem( 33) - w( 67)
      chem( 35) = chem( 35) + w( 67)
      chem(  5) = chem(  5) - w( 68)
      chem( 31) = chem( 31) +  0.2000000000000000D+01 * w( 68)
      chem( 33) = chem( 33) - w( 68)
      chem( 39) = chem( 39) + w( 68)
      chem( 18) = chem( 18) - w( 69)
      chem( 31) = chem( 31) + w( 69)
      chem( 33) = chem( 33) - w( 69)
      chem( 43) = chem( 43) + w( 69)
      chem( 17) = chem( 17) - w( 70)
      chem( 18) = chem( 18) +  0.2660000000000000D+00 * w( 70)
      chem( 27) = chem( 27) +  0.5000000000000000D-01 * w( 70)
      chem( 29) = chem( 29) +  0.6840000000000001D+00 * w( 70)
      chem( 33) = chem( 33) - w( 70)
      chem( 35) = chem( 35) +  0.9500000000000000D+00 * w( 70)
      chem( 38) = chem( 38) +  0.2660000000000000D+00 * w( 70)
      chem( 43) = chem( 43) +  0.6840000000000001D+00 * w( 70)
      chem( 10) = chem( 10) - w( 71)
      chem( 33) = chem( 33) - w( 71)
      chem( 37) = chem( 37) + w( 71)
      chem( 25) = chem( 25) - w( 72)
      chem( 33) = chem( 33) - w( 72)
      chem( 43) = chem( 43) + w( 72)
      chem( 10) = chem( 10) - w( 73)
      chem( 38) = chem( 38) + w( 73)
      chem( 31) = chem( 31) + w( 74)
      chem( 32) = chem( 32) + w( 74)
      chem( 38) = chem( 38) - w( 74)
      chem( 39) = chem( 39) + w( 74)
      chem( 41) = chem( 41) - w( 74)
      chem( 29) = chem( 29) - w( 75)
      chem( 32) = chem( 32) + w( 75)
      chem( 41) = chem( 41) - w( 75)
      chem( 43) = chem( 43) + w( 75)
      chem( 37) = chem( 37) - w( 76)
      chem( 38) = chem( 38) + w( 76)
      chem( 39) = chem( 39) + w( 76)
      chem( 41) = chem( 41) - w( 76)
      chem( 42) = chem( 42) + w( 76)
      chem( 37) = chem( 37) + w( 77)
      chem( 41) = chem( 41) - w( 77)
      chem( 42) = chem( 42) + w( 77)
      chem( 43) = chem( 43) - w( 77)
      chem( 19) = chem( 19) - w( 78)
      chem( 31) = chem( 31) +  0.4400000000000000D+00 * w( 78)
      chem( 34) = chem( 34) - w( 78)
      chem( 38) = chem( 38) + w( 78)
      chem( 39) = chem( 39) +  0.1200000000000000D+00 * w( 78)
      chem( 11) = chem( 11) +  0.7000000000000000D+00 * w( 79)
      chem( 15) = chem( 15) - w( 79)
      chem( 29) = chem( 29) +  0.5000000000000000D+00 * w( 79)
      chem( 31) = chem( 31) +  0.4000000000000000D+00 * w( 79)
      chem( 33) = chem( 33) +  0.1500000000000000D+00 * w( 79)
      chem( 34) = chem( 34) - w( 79)
      chem( 37) = chem( 37) +  0.3100000000000000D+00 * w( 79)
      chem( 38) = chem( 38) +  0.5300000000000000D+00 * w( 79)
      chem( 39) = chem( 39) +  0.2800000000000000D+00 * w( 79)
      chem( 12) = chem( 12) - w( 80)
      chem( 14) = chem( 14) +  0.6700000000000000D+00 * w( 80)
      chem( 15) = chem( 15) +  0.7000000000000001D-01 * w( 80)
      chem( 17) = chem( 17) +  0.2600000000000000D+00 * w( 80)
      chem( 31) = chem( 31) +  0.5000000000000000D-01 * w( 80)
      chem( 33) = chem( 33) +  0.5500000000000000D+00 * w( 80)
      chem( 34) = chem( 34) -  0.7000000000000000D+00 * w( 80)
      chem( 38) = chem( 38) +  0.8000000000000000D+00 * w( 80)
      chem( 39) = chem( 39) +  0.6000000000000000D-01 * w( 80)
      chem( 14) = chem( 14) - w( 81)
      chem( 18) = chem( 18) +  0.8000000000000000D+00 * w( 81)
      chem( 31) = chem( 31) +  0.2000000000000000D+00 * w( 81)
      chem( 33) = chem( 33) +  0.2150000000000000D+00 * w( 81)
      chem( 34) = chem( 34) -  0.8000000000000000D+00 * w( 81)
      chem( 38) = chem( 38) +  0.7000000000000000D+00 * w( 81)
      chem( 39) = chem( 39) +  0.2750000000000000D+00 * w( 81)
      chem( 17) = chem( 17) - w( 82)
      chem( 18) = chem( 18) +  0.8200000000000000D+00 * w( 82)
      chem( 29) = chem( 29) +  0.4000000000000000D-01 * w( 82)
      chem( 31) = chem( 31) +  0.5000000000000000D-01 * w( 82)
      chem( 33) = chem( 33) +  0.8000000000000000D-01 * w( 82)
      chem( 34) = chem( 34) -  0.8000000000000000D+00 * w( 82)
      chem( 38) = chem( 38) +  0.8000000000000000D+00 * w( 82)
      chem( 39) = chem( 39) +  0.6000000000000000D-01 * w( 82)
      chem( 22) = chem( 22) - w( 83)
      chem( 28) = chem( 28) +  0.5300000000000000D+00 * w( 83)
      chem( 29) = chem( 29) +  0.1270000000000000D+01 * w( 83)
      chem( 31) = chem( 31) +  0.1400000000000000D+00 * w( 83)
      chem( 33) = chem( 33) +  0.8500000000000000D+00 * w( 83)
      chem( 34) = chem( 34) - w( 83)
      chem( 35) = chem( 35) +  0.6200000000000000D+00 * w( 83)
      chem( 38) = chem( 38) +  0.4200000000000000D+00 * w( 83)
      chem( 39) = chem( 39) +  0.1000000000000000D+00 * w( 83)
      chem( 37) = chem( 37) - w( 84)
      chem( 38) = chem( 38) + w( 84)
      chem( 39) = chem( 39) + w( 84)
      chem( 42) = chem( 42) + w( 84)
      chem( 44) = chem( 44) - w( 84)
      chem( 37) = chem( 37) + w( 85)
      chem( 42) = chem( 42) + w( 85)
      chem( 43) = chem( 43) - w( 85)
      chem( 44) = chem( 44) - w( 85)
      chem( 10) = chem( 10) + w( 86)
      chem( 37) = chem( 37) - w( 86)
      chem( 39) = chem( 39) - w( 86)
      chem( 25) = chem( 25) +  0.6700000000000000D+00 * w( 87)
      chem( 34) = chem( 34) +  0.3300000000000000D+00 * w( 87)
      chem( 39) = chem( 39) - w( 87)
      chem( 43) = chem( 43) - w( 87)
      chem( 37) = chem( 37) -  0.2000000000000000D+01 * w( 88)
      chem( 38) = chem( 38) +  0.1350000000000000D+01 * w( 88)
      chem( 39) = chem( 39) +  0.7000000000000000D+00 * w( 88)
      chem( 37) = chem( 37) -  0.5000000000000000D+00 * w( 89)
      chem( 38) = chem( 38) + w( 89)
      chem( 39) = chem( 39) +  0.5000000000000000D+00 * w( 89)
      chem( 43) = chem( 43) - w( 89)
      chem( 37) = chem( 37) +  0.2000000000000000D+01 * w( 90)
      chem( 43) = chem( 43) -  0.2000000000000000D+01 * w( 90)
      chem( 23) = chem( 23) + w( 91)
      chem( 42) = chem( 42) - w( 91)
      chem( 43) = chem( 43) - w( 91)
      chem( 23) = chem( 23) - w( 92)
      chem( 42) = chem( 42) + w( 92)
      chem( 43) = chem( 43) + w( 92)
      chem( 23) = chem( 23) - w( 93)
      chem( 33) = chem( 33) - w( 93)
      chem( 38) = chem( 38) + w( 93)
      chem( 41) = chem( 41) + w( 93)
      chem( 16) = chem( 16) - w( 94)
      chem( 29) = chem( 29) + w( 94)
      chem( 31) = chem( 31) + w( 94)
      chem( 33) = chem( 33) - w( 94)
      chem( 42) = chem( 42) + w( 94)
      chem( 33) = chem( 33) +  0.2000000000000000D+01 * w( 95)
      chem( 34) = chem( 34) - w( 95)
      chem( 34) = chem( 34) + w( 96)
      chem( 42) = chem( 42) - w( 96)
      chem( 44) = chem( 44) + w( 96)
      chem( 41) = chem( 41) - w( 97)
      chem( 44) = chem( 44) + w( 97)
      chem( 34) = chem( 34) + w( 98)
      chem( 41) = chem( 41) - w( 98)
      chem( 42) = chem( 42) + w( 98)
      chem( 13) = chem( 13) - w( 99)
      chem( 33) = chem( 33) +  0.2000000000000000D+01 * w( 99)
      chem( 32) = chem( 32) - w(100)
      chem( 33) = chem( 33) + w(100)
      chem( 42) = chem( 42) + w(100)
      chem(  7) = chem(  7) - w(101)
      chem( 33) = chem( 33) + w(101)
      chem( 44) = chem( 44) + w(101)
      chem( 31) = chem( 31) + w(102)
      chem( 38) = chem( 38) - w(102)
      chem( 39) = chem( 39) +  0.2000000000000000D+01 * w(102)
      chem( 31) = chem( 31) + w(103)
      chem( 38) = chem( 38) - w(103)
      chem( 29) = chem( 29) - w(104)
      chem( 31) = chem( 31) + w(104)
      chem( 37) = chem( 37) + w(104)
      chem( 39) = chem( 39) + w(104)
      chem(  6) = chem(  6) - w(105)
      chem( 43) = chem( 43) +  0.2000000000000000D+01 * w(105)
      chem( 18) = chem( 18) - w(106)
      chem( 31) = chem( 31) + w(106)
      chem( 39) = chem( 39) + w(106)
      chem( 43) = chem( 43) + w(106)
      chem(  5) = chem(  5) - w(107)
      chem( 31) = chem( 31) +  0.2000000000000000D+01 * w(107)
      chem( 39) = chem( 39) +  0.6000000000000000D+00 * w(107)
      chem(  4) = chem(  4) - w(108)
      chem( 17) = chem( 17) +  0.5000000000000000D+00 * w(108)
      chem( 38) = chem( 38) +  0.5000000000000000D+00 * w(108)
      chem( 39) = chem( 39) +  0.5000000000000000D+00 * w(108)
      chem( 40) = chem( 40) +  0.5000000000000000D+00 * w(108)
      chem( 28) = chem( 28) - w(109)
      chem( 29) = chem( 29) + w(109)
      chem( 35) = chem( 35) + w(109)
      chem( 43) = chem( 43) + w(109)
      chem(  8) = chem(  8) - w(110)
      chem( 41) = chem( 41) + w(110)
      chem( 42) = chem( 42) + w(110)
      chem( 10) = chem( 10) - w(111)
      chem( 33) = chem( 33) + w(111)
      chem( 38) = chem( 38) + w(111)
      chem( 39) = chem( 39) + w(111)
      chem( 25) = chem( 25) - w(112)
      chem( 33) = chem( 33) + w(112)
      chem( 37) = chem( 37) + w(112)
      chem( 23) = chem( 23) - w(113)
      chem( 42) = chem( 42) + w(113)
      chem( 43) = chem( 43) + w(113)
      chem( 24) = chem( 24) - w(114)
      chem( 33) = chem( 33) + w(114)
      chem( 39) = chem( 39) + w(114)
      chem( 21) = chem( 21) - w(115)
      chem( 33) = chem( 33) + w(115)
      chem( 39) = chem( 39) + w(115)
      chem( 20) = chem( 20) - w(116)
      chem( 33) = chem( 33) + w(116)
      chem( 39) = chem( 39) + w(116)
      
C     Volumic source terms.
      
      IF(LSOURC)THEN
         do i=1,nesp
            chem(i)=chem(i)+ZCsourc(i)
         enddo
      endif
      
      RETURN
      END
      
