      subroutine jacdchemdc(y,rk,JacC)
      
C------------------------------------------------------------------------
C     
C     -- DESCRIPTION
C     
C     This routine computes the Jacobian matrix for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: MELCHIOR            
C     Species: _ciMELCHIOR         
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     JACC: Jacobian matrix.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C     The matrix JACC could be stored in a low-dimensional vector.
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     SPACK.
C     
C------------------------------------------------------------------------
      
      implicit none
      
C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of chemical arrays.
C     PARADOM: parameters for all forced fields.
      
      include 'PARACHEM.INC' 
      INCLUDE 'PARADOM.INC'  
      
      integer i,j
      double precision dw(nr,nesp),rk(nr),y(nesp),JacC(nesp,nesp)
      
      do j=1,nesp
         do i=1,nesp
            JacC(i,j)=0.d0
         enddo
      enddo
      
      call dratedc(rk,y,dw)
      
      JacC( 34, 34) = JacC( 34, 34) - dw(  1, 34)
      JacC( 34, 44) = JacC( 34, 44) - dw(  1, 44)
      JacC( 42, 34) = JacC( 42, 34) + dw(  1, 34)
      JacC( 42, 44) = JacC( 42, 44) + dw(  1, 44)
      JacC( 44, 34) = JacC( 44, 34) - dw(  1, 34)
      JacC( 44, 44) = JacC( 44, 44) - dw(  1, 44)
      JacC( 34, 34) = JacC( 34, 34) - dw(  2, 34)
      JacC( 34, 42) = JacC( 34, 42) - dw(  2, 42)
      JacC( 41, 34) = JacC( 41, 34) + dw(  2, 34)
      JacC( 41, 42) = JacC( 41, 42) + dw(  2, 42)
      JacC( 42, 34) = JacC( 42, 34) - dw(  2, 34)
      JacC( 42, 42) = JacC( 42, 42) - dw(  2, 42)
      JacC( 33, 34) = JacC( 33, 34) - dw(  3, 34)
      JacC( 33, 33) = JacC( 33, 33) - dw(  3, 33)
      JacC( 34, 34) = JacC( 34, 34) - dw(  3, 34)
      JacC( 34, 33) = JacC( 34, 33) - dw(  3, 33)
      JacC( 39, 34) = JacC( 39, 34) + dw(  3, 34)
      JacC( 39, 33) = JacC( 39, 33) + dw(  3, 33)
      JacC( 33, 34) = JacC( 33, 34) + dw(  4, 34)
      JacC( 33, 39) = JacC( 33, 39) + dw(  4, 39)
      JacC( 34, 34) = JacC( 34, 34) - dw(  4, 34)
      JacC( 34, 39) = JacC( 34, 39) - dw(  4, 39)
      JacC( 39, 34) = JacC( 39, 34) - dw(  4, 34)
      JacC( 39, 39) = JacC( 39, 39) - dw(  4, 39)
      JacC( 33, 44) = JacC( 33, 44) + dw(  5, 44)
      JacC( 33, 39) = JacC( 33, 39) + dw(  5, 39)
      JacC( 39, 44) = JacC( 39, 44) - dw(  5, 44)
      JacC( 39, 39) = JacC( 39, 39) - dw(  5, 39)
      JacC( 42, 44) = JacC( 42, 44) + dw(  5, 44)
      JacC( 42, 39) = JacC( 42, 39) + dw(  5, 39)
      JacC( 44, 44) = JacC( 44, 44) - dw(  5, 44)
      JacC( 44, 39) = JacC( 44, 39) - dw(  5, 39)
      JacC( 32, 42) = JacC( 32, 42) + dw(  6, 42)
      JacC( 32, 33) = JacC( 32, 33) + dw(  6, 33)
      JacC( 33, 42) = JacC( 33, 42) - dw(  6, 42)
      JacC( 33, 33) = JacC( 33, 33) - dw(  6, 33)
      JacC( 42, 42) = JacC( 42, 42) - dw(  6, 42)
      JacC( 42, 33) = JacC( 42, 33) - dw(  6, 33)
      JacC( 33, 39) = JacC( 33, 39) - dw(  7, 39)
      JacC( 33, 33) = JacC( 33, 33) - dw(  7, 33)
      JacC( 39, 39) = JacC( 39, 39) - dw(  7, 39)
      JacC( 39, 33) = JacC( 39, 33) - dw(  7, 33)
      JacC( 13, 13) = JacC( 13, 13) - dw(  8, 13)
      JacC( 13, 33) = JacC( 13, 33) - dw(  8, 33)
      JacC( 33, 13) = JacC( 33, 13) - dw(  8, 13)
      JacC( 33, 33) = JacC( 33, 33) - dw(  8, 33)
      JacC( 39, 13) = JacC( 39, 13) + dw(  8, 13)
      JacC( 39, 33) = JacC( 39, 33) + dw(  8, 33)
      JacC( 32, 32) = JacC( 32, 32) - dw(  9, 32)
      JacC( 32, 33) = JacC( 32, 33) - dw(  9, 33)
      JacC( 33, 32) = JacC( 33, 32) - dw(  9, 32)
      JacC( 33, 33) = JacC( 33, 33) - dw(  9, 33)
      JacC( 41, 32) = JacC( 41, 32) + dw(  9, 32)
      JacC( 41, 33) = JacC( 41, 33) + dw(  9, 33)
      JacC( 31, 31) = JacC( 31, 31) - dw( 10, 31)
      JacC( 31, 33) = JacC( 31, 33) - dw( 10, 33)
      JacC( 33, 31) = JacC( 33, 31) - dw( 10, 31)
      JacC( 33, 33) = JacC( 33, 33) - dw( 10, 33)
      JacC( 39, 31) = JacC( 39, 31) + dw( 10, 31)
      JacC( 39, 33) = JacC( 39, 33) + dw( 10, 33)
      JacC( 13, 39) = JacC( 13, 39) + dw( 11, 39)
      JacC( 13, 39) = JacC( 13, 39) + dw( 11, 39)
      JacC( 39, 39) = JacC( 39, 39)- 0.2000000000000000D+01*dw( 11, 39)
      JacC( 39, 39) = JacC( 39, 39)- 0.2000000000000000D+01*dw( 11, 39)
      JacC( 13, 39) = JacC( 13, 39) + dw( 12, 39)
      JacC( 13, 39) = JacC( 13, 39) + dw( 12, 39)
      JacC( 39, 39) = JacC( 39, 39)- 0.2000000000000000D+01*dw( 12, 39)
      JacC( 39, 39) = JacC( 39, 39)- 0.2000000000000000D+01*dw( 12, 39)
      JacC( 33, 41) = JacC( 33, 41) + dw( 13, 41)
      JacC( 33, 39) = JacC( 33, 39) + dw( 13, 39)
      JacC( 39, 41) = JacC( 39, 41) - dw( 13, 41)
      JacC( 39, 39) = JacC( 39, 39) - dw( 13, 39)
      JacC( 41, 41) = JacC( 41, 41) - dw( 13, 41)
      JacC( 41, 39) = JacC( 41, 39) - dw( 13, 39)
      JacC( 42, 41) = JacC( 42, 41) + dw( 13, 41)
      JacC( 42, 39) = JacC( 42, 39) + dw( 13, 39)
      JacC( 13, 41) = JacC( 13, 41) - dw( 14, 41)
      JacC( 13, 13) = JacC( 13, 13) - dw( 14, 13)
      JacC( 32, 41) = JacC( 32, 41) + dw( 14, 41)
      JacC( 32, 13) = JacC( 32, 13) + dw( 14, 13)
      JacC( 39, 41) = JacC( 39, 41) + dw( 14, 41)
      JacC( 39, 13) = JacC( 39, 13) + dw( 14, 13)
      JacC( 41, 41) = JacC( 41, 41) - dw( 14, 41)
      JacC( 41, 13) = JacC( 41, 13) - dw( 14, 13)
      JacC( 41, 41) = JacC( 41, 41) - dw( 15, 41)
      JacC( 41, 44) = JacC( 41, 44) - dw( 15, 44)
      JacC( 42, 41) = JacC( 42, 41)+ 0.2000000000000000D+01*dw( 15, 41)
      JacC( 42, 44) = JacC( 42, 44)+ 0.2000000000000000D+01*dw( 15, 44)
      JacC( 44, 41) = JacC( 44, 41) - dw( 15, 41)
      JacC( 44, 44) = JacC( 44, 44) - dw( 15, 44)
      JacC( 41, 42) = JacC( 41, 42) - dw( 16, 42)
      JacC( 41, 41) = JacC( 41, 41) - dw( 16, 41)
      JacC( 44, 42) = JacC( 44, 42) + dw( 16, 42)
      JacC( 44, 41) = JacC( 44, 41) + dw( 16, 41)
      JacC(  8, 41) = JacC(  8, 41) + dw( 17, 41)
      JacC(  8, 42) = JacC(  8, 42) + dw( 17, 42)
      JacC( 41, 41) = JacC( 41, 41) - dw( 17, 41)
      JacC( 41, 42) = JacC( 41, 42) - dw( 17, 42)
      JacC( 42, 41) = JacC( 42, 41) - dw( 17, 41)
      JacC( 42, 42) = JacC( 42, 42) - dw( 17, 42)
      JacC(  8,  8) = JacC(  8,  8) - dw( 18,  8)
      JacC( 41,  8) = JacC( 41,  8) + dw( 18,  8)
      JacC( 42,  8) = JacC( 42,  8) + dw( 18,  8)
      JacC(  8,  8) = JacC(  8,  8) - dw( 19,  8)
      JacC( 32,  8) = JacC( 32,  8)+ 0.2000000000000000D+01*dw( 19,  8)
      JacC(  8,  8) = JacC(  8,  8) - dw( 20,  8)
      JacC( 32,  8) = JacC( 32,  8)+ 0.2000000000000000D+01*dw( 20,  8)
      JacC(  7, 44) = JacC(  7, 44) + dw( 21, 44)
      JacC(  7, 33) = JacC(  7, 33) + dw( 21, 33)
      JacC( 33, 44) = JacC( 33, 44) - dw( 21, 44)
      JacC( 33, 33) = JacC( 33, 33) - dw( 21, 33)
      JacC( 44, 44) = JacC( 44, 44) - dw( 21, 44)
      JacC( 44, 33) = JacC( 44, 33) - dw( 21, 33)
      JacC(  7,  7) = JacC(  7,  7) - dw( 22,  7)
      JacC(  7, 33) = JacC(  7, 33) - dw( 22, 33)
      JacC( 33,  7) = JacC( 33,  7) - dw( 22,  7)
      JacC( 33, 33) = JacC( 33, 33) - dw( 22, 33)
      JacC( 42,  7) = JacC( 42,  7) + dw( 22,  7)
      JacC( 42, 33) = JacC( 42, 33) + dw( 22, 33)
      JacC(  9,  9) = JacC(  9,  9) - dw( 23,  9)
      JacC(  9, 37) = JacC(  9, 37) - dw( 23, 37)
      JacC( 37,  9) = JacC( 37,  9) - dw( 23,  9)
      JacC( 37, 37) = JacC( 37, 37) - dw( 23, 37)
      JacC( 38,  9) = JacC( 38,  9) + dw( 23,  9)
      JacC( 38, 37) = JacC( 38, 37) + dw( 23, 37)
      JacC( 39,  9) = JacC( 39,  9) + dw( 23,  9)
      JacC( 39, 37) = JacC( 39, 37) + dw( 23, 37)
      JacC(  9,  9) = JacC(  9,  9) - dw( 24,  9)
      JacC(  9, 33) = JacC(  9, 33) - dw( 24, 33)
      JacC( 33,  9) = JacC( 33,  9) - dw( 24,  9)
      JacC( 33, 33) = JacC( 33, 33) - dw( 24, 33)
      JacC( 39,  9) = JacC( 39,  9) + dw( 24,  9)
      JacC( 39, 33) = JacC( 39, 33) + dw( 24, 33)
      JacC( 27, 36) = JacC( 27, 36)+ 0.1400000000000000D+00*dw( 25, 36)
      JacC( 27, 44) = JacC( 27, 44)+ 0.1400000000000000D+00*dw( 25, 44)
      JacC( 36, 36) = JacC( 36, 36) - dw( 25, 36)
      JacC( 36, 44) = JacC( 36, 44) - dw( 25, 44)
      JacC( 39, 36) = JacC( 39, 36)+ 0.7800000000000000D+00*dw( 25, 36)
      JacC( 39, 44) = JacC( 39, 44)+ 0.7800000000000000D+00*dw( 25, 44)
      JacC( 42, 36) = JacC( 42, 36)+ 0.8600000000000000D+00*dw( 25, 36)
      JacC( 42, 44) = JacC( 42, 44)+ 0.8600000000000000D+00*dw( 25, 44)
      JacC( 44, 36) = JacC( 44, 36) - dw( 25, 36)
      JacC( 44, 44) = JacC( 44, 44) - dw( 25, 44)
      JacC( 20, 36) = JacC( 20, 36) + dw( 26, 36)
      JacC( 20, 39) = JacC( 20, 39) + dw( 26, 39)
      JacC( 36, 36) = JacC( 36, 36) - dw( 26, 36)
      JacC( 36, 39) = JacC( 36, 39) - dw( 26, 39)
      JacC( 39, 36) = JacC( 39, 36) - dw( 26, 36)
      JacC( 39, 39) = JacC( 39, 39) - dw( 26, 39)
      JacC( 36, 36) = JacC( 36, 36) - dw( 27, 36)
      JacC( 36, 41) = JacC( 36, 41) - dw( 27, 41)
      JacC( 39, 36) = JacC( 39, 36) + dw( 27, 36)
      JacC( 39, 41) = JacC( 39, 41) + dw( 27, 41)
      JacC( 41, 36) = JacC( 41, 36) - dw( 27, 36)
      JacC( 41, 41) = JacC( 41, 41) - dw( 27, 41)
      JacC( 42, 36) = JacC( 42, 36) + dw( 27, 36)
      JacC( 42, 41) = JacC( 42, 41) + dw( 27, 41)
      JacC( 36, 37) = JacC( 36, 37) - dw( 28, 37)
      JacC( 36, 36) = JacC( 36, 36) - dw( 28, 36)
      JacC( 37, 37) = JacC( 37, 37) - dw( 28, 37)
      JacC( 37, 36) = JacC( 37, 36) - dw( 28, 36)
      JacC( 38, 37) = JacC( 38, 37)+ 0.5000000000000000D+00*dw( 28, 37)
      JacC( 38, 36) = JacC( 38, 36)+ 0.5000000000000000D+00*dw( 28, 36)
      JacC( 39, 37) = JacC( 39, 37)+ 0.8000000000000000D+00*dw( 28, 37)
      JacC( 39, 36) = JacC( 39, 36)+ 0.8000000000000000D+00*dw( 28, 36)
      JacC( 36, 43) = JacC( 36, 43) - dw( 29, 43)
      JacC( 36, 36) = JacC( 36, 36) - dw( 29, 36)
      JacC( 38, 43) = JacC( 38, 43)+ 0.5000000000000000D+00*dw( 29, 43)
      JacC( 38, 36) = JacC( 38, 36)+ 0.5000000000000000D+00*dw( 29, 36)
      JacC( 39, 43) = JacC( 39, 43)+ 0.1500000000000000D+01*dw( 29, 43)
      JacC( 39, 36) = JacC( 39, 36)+ 0.1500000000000000D+01*dw( 29, 36)
      JacC( 43, 43) = JacC( 43, 43) - dw( 29, 43)
      JacC( 43, 36) = JacC( 43, 36) - dw( 29, 36)
      JacC( 20, 20) = JacC( 20, 20) - dw( 30, 20)
      JacC( 20, 33) = JacC( 20, 33) - dw( 30, 33)
      JacC( 35, 35) = JacC( 35, 35) - dw( 31, 35)
      JacC( 35, 44) = JacC( 35, 44) - dw( 31, 44)
      JacC( 39, 35) = JacC( 39, 35) + dw( 31, 35)
      JacC( 39, 44) = JacC( 39, 44) + dw( 31, 44)
      JacC( 42, 35) = JacC( 42, 35) + dw( 31, 35)
      JacC( 42, 44) = JacC( 42, 44) + dw( 31, 44)
      JacC( 44, 35) = JacC( 44, 35) - dw( 31, 35)
      JacC( 44, 44) = JacC( 44, 44) - dw( 31, 44)
      JacC( 21, 35) = JacC( 21, 35) + dw( 32, 35)
      JacC( 21, 39) = JacC( 21, 39) + dw( 32, 39)
      JacC( 35, 35) = JacC( 35, 35) - dw( 32, 35)
      JacC( 35, 39) = JacC( 35, 39) - dw( 32, 39)
      JacC( 39, 35) = JacC( 39, 35) - dw( 32, 35)
      JacC( 39, 39) = JacC( 39, 39) - dw( 32, 39)
      JacC( 35, 35) = JacC( 35, 35)- 0.2000000000000000D+01*dw( 33, 35)
      JacC( 35, 35) = JacC( 35, 35)- 0.2000000000000000D+01*dw( 33, 35)
      JacC( 39, 35) = JacC( 39, 35)+ 0.1300000000000000D+01*dw( 33, 35)
      JacC( 39, 35) = JacC( 39, 35)+ 0.1300000000000000D+01*dw( 33, 35)
      JacC( 35, 35) = JacC( 35, 35) - dw( 34, 35)
      JacC( 35, 41) = JacC( 35, 41) - dw( 34, 41)
      JacC( 39, 35) = JacC( 39, 35) + dw( 34, 35)
      JacC( 39, 41) = JacC( 39, 41) + dw( 34, 41)
      JacC( 41, 35) = JacC( 41, 35) - dw( 34, 35)
      JacC( 41, 41) = JacC( 41, 41) - dw( 34, 41)
      JacC( 42, 35) = JacC( 42, 35) + dw( 34, 35)
      JacC( 42, 41) = JacC( 42, 41) + dw( 34, 41)
      JacC( 35, 37) = JacC( 35, 37) - dw( 35, 37)
      JacC( 35, 35) = JacC( 35, 35) - dw( 35, 35)
      JacC( 37, 37) = JacC( 37, 37) - dw( 35, 37)
      JacC( 37, 35) = JacC( 37, 35) - dw( 35, 35)
      JacC( 38, 37) = JacC( 38, 37)+ 0.6500000000000000D+00*dw( 35, 37)
      JacC( 38, 35) = JacC( 38, 35)+ 0.6500000000000000D+00*dw( 35, 35)
      JacC( 39, 37) = JacC( 39, 37)+ 0.8000000000000000D+00*dw( 35, 37)
      JacC( 39, 35) = JacC( 39, 35)+ 0.8000000000000000D+00*dw( 35, 35)
      JacC( 35, 43) = JacC( 35, 43) - dw( 36, 43)
      JacC( 35, 35) = JacC( 35, 35) - dw( 36, 35)
      JacC( 37, 43) = JacC( 37, 43)+ 0.8000000000000000D+00*dw( 36, 43)
      JacC( 37, 35) = JacC( 37, 35)+ 0.8000000000000000D+00*dw( 36, 35)
      JacC( 39, 43) = JacC( 39, 43)+ 0.8000000000000000D+00*dw( 36, 43)
      JacC( 39, 35) = JacC( 39, 35)+ 0.8000000000000000D+00*dw( 36, 35)
      JacC( 43, 43) = JacC( 43, 43) - dw( 36, 43)
      JacC( 43, 35) = JacC( 43, 35) - dw( 36, 35)
      JacC( 21, 21) = JacC( 21, 21) - dw( 37, 21)
      JacC( 21, 33) = JacC( 21, 33) - dw( 37, 33)
      JacC( 33, 21) = JacC( 33, 21)- 0.2000000000000000D+00*dw( 37, 21)
      JacC( 33, 33) = JacC( 33, 33)- 0.2000000000000000D+00*dw( 37, 33)
      JacC( 35, 21) = JacC( 35, 21)+ 0.2000000000000000D+00*dw( 37, 21)
      JacC( 35, 33) = JacC( 35, 33)+ 0.2000000000000000D+00*dw( 37, 33)
      JacC( 14, 14) = JacC( 14, 14) - dw( 38, 14)
      JacC( 14, 33) = JacC( 14, 33) - dw( 38, 33)
      JacC( 28, 14) = JacC( 28, 14)+ 0.5000000000000000D+00*dw( 38, 14)
      JacC( 28, 33) = JacC( 28, 33)+ 0.5000000000000000D+00*dw( 38, 33)
      JacC( 33, 14) = JacC( 33, 14) - dw( 38, 14)
      JacC( 33, 33) = JacC( 33, 33) - dw( 38, 33)
      JacC( 40, 14) = JacC( 40, 14)+ 0.5000000000000000D+00*dw( 38, 14)
      JacC( 40, 33) = JacC( 40, 33)+ 0.5000000000000000D+00*dw( 38, 33)
      JacC( 39, 40) = JacC( 39, 40) + dw( 39, 40)
      JacC( 39, 44) = JacC( 39, 44) + dw( 39, 44)
      JacC( 40, 40) = JacC( 40, 40) - dw( 39, 40)
      JacC( 40, 44) = JacC( 40, 44) - dw( 39, 44)
      JacC( 42, 40) = JacC( 42, 40) + dw( 39, 40)
      JacC( 42, 44) = JacC( 42, 44) + dw( 39, 44)
      JacC( 44, 40) = JacC( 44, 40) - dw( 39, 40)
      JacC( 44, 44) = JacC( 44, 44) - dw( 39, 44)
      JacC( 39, 40) = JacC( 39, 40) + dw( 40, 40)
      JacC( 39, 41) = JacC( 39, 41) + dw( 40, 41)
      JacC( 40, 40) = JacC( 40, 40) - dw( 40, 40)
      JacC( 40, 41) = JacC( 40, 41) - dw( 40, 41)
      JacC( 41, 40) = JacC( 41, 40) - dw( 40, 40)
      JacC( 41, 41) = JacC( 41, 41) - dw( 40, 41)
      JacC( 42, 40) = JacC( 42, 40) + dw( 40, 40)
      JacC( 42, 41) = JacC( 42, 41) + dw( 40, 41)
      JacC( 24, 40) = JacC( 24, 40) + dw( 41, 40)
      JacC( 24, 39) = JacC( 24, 39) + dw( 41, 39)
      JacC( 39, 40) = JacC( 39, 40) - dw( 41, 40)
      JacC( 39, 39) = JacC( 39, 39) - dw( 41, 39)
      JacC( 40, 40) = JacC( 40, 40) - dw( 41, 40)
      JacC( 40, 39) = JacC( 40, 39) - dw( 41, 39)
      JacC( 24, 24) = JacC( 24, 24) - dw( 42, 24)
      JacC( 24, 33) = JacC( 24, 33) - dw( 42, 33)
      JacC( 33, 24) = JacC( 33, 24) - dw( 42, 24)
      JacC( 33, 33) = JacC( 33, 33) - dw( 42, 33)
      JacC( 40, 24) = JacC( 40, 24)+ 0.2000000000000000D+00*dw( 42, 24)
      JacC( 40, 33) = JacC( 40, 33)+ 0.2000000000000000D+00*dw( 42, 33)
      JacC( 37, 40) = JacC( 37, 40) - dw( 43, 40)
      JacC( 37, 37) = JacC( 37, 37) - dw( 43, 37)
      JacC( 38, 40) = JacC( 38, 40) + dw( 43, 40)
      JacC( 38, 37) = JacC( 38, 37) + dw( 43, 37)
      JacC( 39, 40) = JacC( 39, 40)+ 0.5000000000000000D+00*dw( 43, 40)
      JacC( 39, 37) = JacC( 39, 37)+ 0.5000000000000000D+00*dw( 43, 37)
      JacC( 40, 40) = JacC( 40, 40) - dw( 43, 40)
      JacC( 40, 37) = JacC( 40, 37) - dw( 43, 37)
      JacC( 37, 40) = JacC( 37, 40) + dw( 44, 40)
      JacC( 37, 43) = JacC( 37, 43) + dw( 44, 43)
      JacC( 39, 40) = JacC( 39, 40) + dw( 44, 40)
      JacC( 39, 43) = JacC( 39, 43) + dw( 44, 43)
      JacC( 40, 40) = JacC( 40, 40) - dw( 44, 40)
      JacC( 40, 43) = JacC( 40, 43) - dw( 44, 43)
      JacC( 43, 40) = JacC( 43, 40) - dw( 44, 40)
      JacC( 43, 43) = JacC( 43, 43) - dw( 44, 43)
      JacC( 26, 40) = JacC( 26, 40) + dw( 45, 40)
      JacC( 26, 42) = JacC( 26, 42) + dw( 45, 42)
      JacC( 40, 40) = JacC( 40, 40) - dw( 45, 40)
      JacC( 40, 42) = JacC( 40, 42) - dw( 45, 42)
      JacC( 42, 40) = JacC( 42, 40) - dw( 45, 40)
      JacC( 42, 42) = JacC( 42, 42) - dw( 45, 42)
      JacC( 26, 26) = JacC( 26, 26) - dw( 46, 26)
      JacC( 40, 26) = JacC( 40, 26) + dw( 46, 26)
      JacC( 42, 26) = JacC( 42, 26) + dw( 46, 26)
      JacC( 26, 26) = JacC( 26, 26) - dw( 47, 26)
      JacC( 26, 33) = JacC( 26, 33) - dw( 47, 33)
      JacC( 33, 26) = JacC( 33, 26) - dw( 47, 26)
      JacC( 33, 33) = JacC( 33, 33) - dw( 47, 33)
      JacC( 41, 26) = JacC( 41, 26) + dw( 47, 26)
      JacC( 41, 33) = JacC( 41, 33) + dw( 47, 33)
      JacC( 16, 19) = JacC( 16, 19)+ 0.5000000000000000D+00*dw( 48, 19)
      JacC( 16, 41) = JacC( 16, 41)+ 0.5000000000000000D+00*dw( 48, 41)
      JacC( 19, 19) = JacC( 19, 19) - dw( 48, 19)
      JacC( 19, 41) = JacC( 19, 41) - dw( 48, 41)
      JacC( 30, 19) = JacC( 30, 19) + dw( 48, 19)
      JacC( 30, 41) = JacC( 30, 41) + dw( 48, 41)
      JacC( 38, 19) = JacC( 38, 19) + dw( 48, 19)
      JacC( 38, 41) = JacC( 38, 41) + dw( 48, 41)
      JacC( 41, 19) = JacC( 41, 19) - dw( 48, 19)
      JacC( 41, 41) = JacC( 41, 41) - dw( 48, 41)
      JacC( 15, 15) = JacC( 15, 15) - dw( 49, 15)
      JacC( 15, 41) = JacC( 15, 41) - dw( 49, 41)
      JacC( 16, 15) = JacC( 16, 15)+ 0.5000000000000000D+00*dw( 49, 15)
      JacC( 16, 41) = JacC( 16, 41)+ 0.5000000000000000D+00*dw( 49, 41)
      JacC( 29, 15) = JacC( 29, 15)+ 0.5000000000000000D+00*dw( 49, 15)
      JacC( 29, 41) = JacC( 29, 41)+ 0.5000000000000000D+00*dw( 49, 41)
      JacC( 30, 15) = JacC( 30, 15) + dw( 49, 15)
      JacC( 30, 41) = JacC( 30, 41) + dw( 49, 41)
      JacC( 38, 15) = JacC( 38, 15)+ 0.1500000000000000D+01*dw( 49, 15)
      JacC( 38, 41) = JacC( 38, 41)+ 0.1500000000000000D+01*dw( 49, 41)
      JacC( 39, 15) = JacC( 39, 15)+ 0.5000000000000000D+00*dw( 49, 15)
      JacC( 39, 41) = JacC( 39, 41)+ 0.5000000000000000D+00*dw( 49, 41)
      JacC( 41, 15) = JacC( 41, 15) - dw( 49, 15)
      JacC( 41, 41) = JacC( 41, 41) - dw( 49, 41)
      JacC( 22, 22) = JacC( 22, 22) - dw( 50, 22)
      JacC( 22, 41) = JacC( 22, 41) - dw( 50, 41)
      JacC( 28, 22) = JacC( 28, 22) + dw( 50, 22)
      JacC( 28, 41) = JacC( 28, 41) + dw( 50, 41)
      JacC( 29, 22) = JacC( 29, 22) + dw( 50, 22)
      JacC( 29, 41) = JacC( 29, 41) + dw( 50, 41)
      JacC( 30, 22) = JacC( 30, 22) + dw( 50, 22)
      JacC( 30, 41) = JacC( 30, 41) + dw( 50, 41)
      JacC( 41, 22) = JacC( 41, 22) - dw( 50, 22)
      JacC( 41, 41) = JacC( 41, 41) - dw( 50, 41)
      JacC( 18, 27) = JacC( 18, 27)+ 0.4750000000000000D+00*dw( 51, 27)
      JacC( 18, 33) = JacC( 18, 33)+ 0.4750000000000000D+00*dw( 51, 33)
      JacC( 27, 27) = JacC( 27, 27)- 0.9500000000000000D+00*dw( 51, 27)
      JacC( 27, 33) = JacC( 27, 33)- 0.9500000000000000D+00*dw( 51, 33)
      JacC( 28, 27) = JacC( 28, 27)+ 0.4750000000000000D+00*dw( 51, 27)
      JacC( 28, 33) = JacC( 28, 33)+ 0.4750000000000000D+00*dw( 51, 33)
      JacC( 29, 27) = JacC( 29, 27)+ 0.9500000000000000D+00*dw( 51, 27)
      JacC( 29, 33) = JacC( 29, 33)+ 0.9500000000000000D+00*dw( 51, 33)
      JacC( 30, 27) = JacC( 30, 27) + dw( 51, 27)
      JacC( 30, 33) = JacC( 30, 33) + dw( 51, 33)
      JacC( 33, 27) = JacC( 33, 27) - dw( 51, 27)
      JacC( 33, 33) = JacC( 33, 33) - dw( 51, 33)
      JacC( 39, 27) = JacC( 39, 27)+ 0.5000000000000000D-01*dw( 51, 27)
      JacC( 39, 33) = JacC( 39, 33)+ 0.5000000000000000D-01*dw( 51, 33)
      JacC( 12, 12) = JacC( 12, 12) - dw( 52, 12)
      JacC( 12, 41) = JacC( 12, 41) - dw( 52, 41)
      JacC( 14, 12) = JacC( 14, 12)+ 0.1000000000000000D+00*dw( 52, 12)
      JacC( 14, 41) = JacC( 14, 41)+ 0.1000000000000000D+00*dw( 52, 41)
      JacC( 17, 12) = JacC( 17, 12)+ 0.5000000000000000D-01*dw( 52, 12)
      JacC( 17, 41) = JacC( 17, 41)+ 0.5000000000000000D-01*dw( 52, 41)
      JacC( 27, 12) = JacC( 27, 12)+ 0.8500000000000000D+00*dw( 52, 12)
      JacC( 27, 41) = JacC( 27, 41)+ 0.8500000000000000D+00*dw( 52, 41)
      JacC( 30, 12) = JacC( 30, 12) + dw( 52, 12)
      JacC( 30, 41) = JacC( 30, 41) + dw( 52, 41)
      JacC( 38, 12) = JacC( 38, 12)+ 0.1500000000000000D+00*dw( 52, 12)
      JacC( 38, 41) = JacC( 38, 41)+ 0.1500000000000000D+00*dw( 52, 41)
      JacC( 39, 12) = JacC( 39, 12)+ 0.8000000000000000D+00*dw( 52, 12)
      JacC( 39, 41) = JacC( 39, 41)+ 0.8000000000000000D+00*dw( 52, 41)
      JacC( 41, 12) = JacC( 41, 12) - dw( 52, 12)
      JacC( 41, 41) = JacC( 41, 41) - dw( 52, 41)
      JacC( 30, 30) = JacC( 30, 30) - dw( 53, 30)
      JacC( 30, 44) = JacC( 30, 44) - dw( 53, 44)
      JacC( 42, 30) = JacC( 42, 30)+ 0.1500000000000000D+01*dw( 53, 30)
      JacC( 42, 44) = JacC( 42, 44)+ 0.1500000000000000D+01*dw( 53, 44)
      JacC( 44, 30) = JacC( 44, 30) - dw( 53, 30)
      JacC( 44, 44) = JacC( 44, 44) - dw( 53, 44)
      JacC( 30, 30) = JacC( 30, 30) - dw( 54, 30)
      JacC( 30, 41) = JacC( 30, 41) - dw( 54, 41)
      JacC( 41, 30) = JacC( 41, 30) - dw( 54, 30)
      JacC( 41, 41) = JacC( 41, 41) - dw( 54, 41)
      JacC( 42, 30) = JacC( 42, 30)+ 0.1500000000000000D+01*dw( 54, 30)
      JacC( 42, 41) = JacC( 42, 41)+ 0.1500000000000000D+01*dw( 54, 41)
      JacC( 30, 30) = JacC( 30, 30) - dw( 55, 30)
      JacC( 30, 39) = JacC( 30, 39) - dw( 55, 39)
      JacC( 39, 30) = JacC( 39, 30) - dw( 55, 30)
      JacC( 39, 39) = JacC( 39, 39) - dw( 55, 39)
      JacC( 11, 11) = JacC( 11, 11) - dw( 56, 11)
      JacC( 11, 33) = JacC( 11, 33) - dw( 56, 33)
      JacC( 33, 11) = JacC( 33, 11) - dw( 56, 11)
      JacC( 33, 33) = JacC( 33, 33) - dw( 56, 33)
      JacC( 37, 11) = JacC( 37, 11) + dw( 56, 11)
      JacC( 37, 33) = JacC( 37, 33) + dw( 56, 33)
      JacC(  1,  1) = JacC(  1,  1) - dw( 57,  1)
      JacC(  1, 33) = JacC(  1, 33) - dw( 57, 33)
      JacC( 29,  1) = JacC( 29,  1) + dw( 57,  1)
      JacC( 29, 33) = JacC( 29, 33) + dw( 57, 33)
      JacC( 33,  1) = JacC( 33,  1) - dw( 57,  1)
      JacC( 33, 33) = JacC( 33, 33) - dw( 57, 33)
      JacC( 35,  1) = JacC( 35,  1) + dw( 57,  1)
      JacC( 35, 33) = JacC( 35, 33) + dw( 57, 33)
      JacC(  2,  2) = JacC(  2,  2) - dw( 58,  2)
      JacC(  2, 33) = JacC(  2, 33) - dw( 58, 33)
      JacC( 28,  2) = JacC( 28,  2)+ 0.9000000000000000D+00*dw( 58,  2)
      JacC( 28, 33) = JacC( 28, 33)+ 0.9000000000000000D+00*dw( 58, 33)
      JacC( 29,  2) = JacC( 29,  2)+ 0.1000000000000000D+00*dw( 58,  2)
      JacC( 29, 33) = JacC( 29, 33)+ 0.1000000000000000D+00*dw( 58, 33)
      JacC( 33,  2) = JacC( 33,  2) - dw( 58,  2)
      JacC( 33, 33) = JacC( 33, 33) - dw( 58, 33)
      JacC( 35,  2) = JacC( 35,  2)+ 0.9000000000000000D+00*dw( 58,  2)
      JacC( 35, 33) = JacC( 35, 33)+ 0.9000000000000000D+00*dw( 58, 33)
      JacC( 43,  2) = JacC( 43,  2)+ 0.1000000000000000D+00*dw( 58,  2)
      JacC( 43, 33) = JacC( 43, 33)+ 0.1000000000000000D+00*dw( 58, 33)
      JacC( 19, 19) = JacC( 19, 19) - dw( 59, 19)
      JacC( 19, 33) = JacC( 19, 33) - dw( 59, 33)
      JacC( 33, 19) = JacC( 33, 19) - dw( 59, 19)
      JacC( 33, 33) = JacC( 33, 33) - dw( 59, 33)
      JacC( 35, 19) = JacC( 35, 19) + dw( 59, 19)
      JacC( 35, 33) = JacC( 35, 33) + dw( 59, 33)
      JacC( 38, 19) = JacC( 38, 19)+ 0.2000000000000000D+01*dw( 59, 19)
      JacC( 38, 33) = JacC( 38, 33)+ 0.2000000000000000D+01*dw( 59, 33)
      JacC( 15, 15) = JacC( 15, 15) - dw( 60, 15)
      JacC( 15, 33) = JacC( 15, 33) - dw( 60, 33)
      JacC( 29, 15) = JacC( 29, 15) + dw( 60, 15)
      JacC( 29, 33) = JacC( 29, 33) + dw( 60, 33)
      JacC( 33, 15) = JacC( 33, 15) - dw( 60, 15)
      JacC( 33, 33) = JacC( 33, 33) - dw( 60, 33)
      JacC( 35, 15) = JacC( 35, 15) + dw( 60, 15)
      JacC( 35, 33) = JacC( 35, 33) + dw( 60, 33)
      JacC( 38, 15) = JacC( 38, 15) + dw( 60, 15)
      JacC( 38, 33) = JacC( 38, 33) + dw( 60, 33)
      JacC(  3,  3) = JacC(  3,  3) - dw( 61,  3)
      JacC(  3, 33) = JacC(  3, 33) - dw( 61, 33)
      JacC(  4,  3) = JacC(  4,  3) + dw( 61,  3)
      JacC(  4, 33) = JacC(  4, 33) + dw( 61, 33)
      JacC( 18,  3) = JacC( 18,  3) + dw( 61,  3)
      JacC( 18, 33) = JacC( 18, 33) + dw( 61, 33)
      JacC( 33,  3) = JacC( 33,  3) - dw( 61,  3)
      JacC( 33, 33) = JacC( 33, 33) - dw( 61, 33)
      JacC( 35,  3) = JacC( 35,  3) + dw( 61,  3)
      JacC( 35, 33) = JacC( 35, 33) + dw( 61, 33)
      JacC( 12, 12) = JacC( 12, 12) - dw( 62, 12)
      JacC( 12, 33) = JacC( 12, 33) - dw( 62, 33)
      JacC( 14, 12) = JacC( 14, 12)+ 0.3200000000000000D+00*dw( 62, 12)
      JacC( 14, 33) = JacC( 14, 33)+ 0.3200000000000000D+00*dw( 62, 33)
      JacC( 17, 12) = JacC( 17, 12)+ 0.4200000000000000D+00*dw( 62, 12)
      JacC( 17, 33) = JacC( 17, 33)+ 0.4200000000000000D+00*dw( 62, 33)
      JacC( 33, 12) = JacC( 33, 12) - dw( 62, 12)
      JacC( 33, 33) = JacC( 33, 33) - dw( 62, 33)
      JacC( 36, 12) = JacC( 36, 12) + dw( 62, 12)
      JacC( 36, 33) = JacC( 36, 33) + dw( 62, 33)
      JacC( 38, 12) = JacC( 38, 12)+ 0.7400000000000000D+00*dw( 62, 12)
      JacC( 38, 33) = JacC( 38, 33)+ 0.7400000000000000D+00*dw( 62, 33)
      JacC( 22, 22) = JacC( 22, 22) - dw( 63, 22)
      JacC( 22, 33) = JacC( 22, 33) - dw( 63, 33)
      JacC( 28, 22) = JacC( 28, 22)+ 0.8000000000000000D+00*dw( 63, 22)
      JacC( 28, 33) = JacC( 28, 33)+ 0.8000000000000000D+00*dw( 63, 33)
      JacC( 29, 22) = JacC( 29, 22)+ 0.8000000000000000D+00*dw( 63, 22)
      JacC( 29, 33) = JacC( 29, 33)+ 0.8000000000000000D+00*dw( 63, 33)
      JacC( 33, 22) = JacC( 33, 22) - dw( 63, 22)
      JacC( 33, 33) = JacC( 33, 33) - dw( 63, 33)
      JacC( 36, 22) = JacC( 36, 22) + dw( 63, 22)
      JacC( 36, 33) = JacC( 36, 33) + dw( 63, 33)
      JacC( 31, 38) = JacC( 31, 38) + dw( 64, 38)
      JacC( 31, 33) = JacC( 31, 33) + dw( 64, 33)
      JacC( 33, 38) = JacC( 33, 38) - dw( 64, 38)
      JacC( 33, 33) = JacC( 33, 33) - dw( 64, 33)
      JacC( 38, 38) = JacC( 38, 38) - dw( 64, 38)
      JacC( 38, 33) = JacC( 38, 33) - dw( 64, 33)
      JacC( 39, 38) = JacC( 39, 38) + dw( 64, 38)
      JacC( 39, 33) = JacC( 39, 33) + dw( 64, 33)
      JacC( 29, 29) = JacC( 29, 29) - dw( 65, 29)
      JacC( 29, 33) = JacC( 29, 33) - dw( 65, 33)
      JacC( 33, 29) = JacC( 33, 29) - dw( 65, 29)
      JacC( 33, 33) = JacC( 33, 33) - dw( 65, 33)
      JacC( 43, 29) = JacC( 43, 29) + dw( 65, 29)
      JacC( 43, 33) = JacC( 43, 33) + dw( 65, 33)
      JacC(  4,  4) = JacC(  4,  4) - dw( 66,  4)
      JacC(  4, 33) = JacC(  4, 33) - dw( 66, 33)
      JacC(  5,  4) = JacC(  5,  4) + dw( 66,  4)
      JacC(  5, 33) = JacC(  5, 33) + dw( 66, 33)
      JacC( 18,  4) = JacC( 18,  4) + dw( 66,  4)
      JacC( 18, 33) = JacC( 18, 33) + dw( 66, 33)
      JacC( 33,  4) = JacC( 33,  4) - dw( 66,  4)
      JacC( 33, 33) = JacC( 33, 33) - dw( 66, 33)
      JacC( 35,  4) = JacC( 35,  4) + dw( 66,  4)
      JacC( 35, 33) = JacC( 35, 33) + dw( 66, 33)
      JacC(  6, 28) = JacC(  6, 28) + dw( 67, 28)
      JacC(  6, 33) = JacC(  6, 33) + dw( 67, 33)
      JacC( 28, 28) = JacC( 28, 28) - dw( 67, 28)
      JacC( 28, 33) = JacC( 28, 33) - dw( 67, 33)
      JacC( 33, 28) = JacC( 33, 28) - dw( 67, 28)
      JacC( 33, 33) = JacC( 33, 33) - dw( 67, 33)
      JacC( 35, 28) = JacC( 35, 28) + dw( 67, 28)
      JacC( 35, 33) = JacC( 35, 33) + dw( 67, 33)
      JacC(  5,  5) = JacC(  5,  5) - dw( 68,  5)
      JacC(  5, 33) = JacC(  5, 33) - dw( 68, 33)
      JacC( 31,  5) = JacC( 31,  5)+ 0.2000000000000000D+01*dw( 68,  5)
      JacC( 31, 33) = JacC( 31, 33)+ 0.2000000000000000D+01*dw( 68, 33)
      JacC( 33,  5) = JacC( 33,  5) - dw( 68,  5)
      JacC( 33, 33) = JacC( 33, 33) - dw( 68, 33)
      JacC( 39,  5) = JacC( 39,  5) + dw( 68,  5)
      JacC( 39, 33) = JacC( 39, 33) + dw( 68, 33)
      JacC( 18, 18) = JacC( 18, 18) - dw( 69, 18)
      JacC( 18, 33) = JacC( 18, 33) - dw( 69, 33)
      JacC( 31, 18) = JacC( 31, 18) + dw( 69, 18)
      JacC( 31, 33) = JacC( 31, 33) + dw( 69, 33)
      JacC( 33, 18) = JacC( 33, 18) - dw( 69, 18)
      JacC( 33, 33) = JacC( 33, 33) - dw( 69, 33)
      JacC( 43, 18) = JacC( 43, 18) + dw( 69, 18)
      JacC( 43, 33) = JacC( 43, 33) + dw( 69, 33)
      JacC( 17, 17) = JacC( 17, 17) - dw( 70, 17)
      JacC( 17, 33) = JacC( 17, 33) - dw( 70, 33)
      JacC( 18, 17) = JacC( 18, 17)+ 0.2660000000000000D+00*dw( 70, 17)
      JacC( 18, 33) = JacC( 18, 33)+ 0.2660000000000000D+00*dw( 70, 33)
      JacC( 27, 17) = JacC( 27, 17)+ 0.5000000000000000D-01*dw( 70, 17)
      JacC( 27, 33) = JacC( 27, 33)+ 0.5000000000000000D-01*dw( 70, 33)
      JacC( 29, 17) = JacC( 29, 17)+ 0.6840000000000001D+00*dw( 70, 17)
      JacC( 29, 33) = JacC( 29, 33)+ 0.6840000000000001D+00*dw( 70, 33)
      JacC( 33, 17) = JacC( 33, 17) - dw( 70, 17)
      JacC( 33, 33) = JacC( 33, 33) - dw( 70, 33)
      JacC( 35, 17) = JacC( 35, 17)+ 0.9500000000000000D+00*dw( 70, 17)
      JacC( 35, 33) = JacC( 35, 33)+ 0.9500000000000000D+00*dw( 70, 33)
      JacC( 38, 17) = JacC( 38, 17)+ 0.2660000000000000D+00*dw( 70, 17)
      JacC( 38, 33) = JacC( 38, 33)+ 0.2660000000000000D+00*dw( 70, 33)
      JacC( 43, 17) = JacC( 43, 17)+ 0.6840000000000001D+00*dw( 70, 17)
      JacC( 43, 33) = JacC( 43, 33)+ 0.6840000000000001D+00*dw( 70, 33)
      JacC( 10, 10) = JacC( 10, 10) - dw( 71, 10)
      JacC( 10, 33) = JacC( 10, 33) - dw( 71, 33)
      JacC( 33, 10) = JacC( 33, 10) - dw( 71, 10)
      JacC( 33, 33) = JacC( 33, 33) - dw( 71, 33)
      JacC( 37, 10) = JacC( 37, 10) + dw( 71, 10)
      JacC( 37, 33) = JacC( 37, 33) + dw( 71, 33)
      JacC( 25, 25) = JacC( 25, 25) - dw( 72, 25)
      JacC( 25, 33) = JacC( 25, 33) - dw( 72, 33)
      JacC( 33, 25) = JacC( 33, 25) - dw( 72, 25)
      JacC( 33, 33) = JacC( 33, 33) - dw( 72, 33)
      JacC( 43, 25) = JacC( 43, 25) + dw( 72, 25)
      JacC( 43, 33) = JacC( 43, 33) + dw( 72, 33)
      JacC( 10, 10) = JacC( 10, 10) - dw( 73, 10)
      JacC( 10, 33) = JacC( 10, 33) - dw( 73, 33)
      JacC( 38, 10) = JacC( 38, 10) + dw( 73, 10)
      JacC( 38, 33) = JacC( 38, 33) + dw( 73, 33)
      JacC( 31, 38) = JacC( 31, 38) + dw( 74, 38)
      JacC( 31, 41) = JacC( 31, 41) + dw( 74, 41)
      JacC( 32, 38) = JacC( 32, 38) + dw( 74, 38)
      JacC( 32, 41) = JacC( 32, 41) + dw( 74, 41)
      JacC( 38, 38) = JacC( 38, 38) - dw( 74, 38)
      JacC( 38, 41) = JacC( 38, 41) - dw( 74, 41)
      JacC( 39, 38) = JacC( 39, 38) + dw( 74, 38)
      JacC( 39, 41) = JacC( 39, 41) + dw( 74, 41)
      JacC( 41, 38) = JacC( 41, 38) - dw( 74, 38)
      JacC( 41, 41) = JacC( 41, 41) - dw( 74, 41)
      JacC( 29, 29) = JacC( 29, 29) - dw( 75, 29)
      JacC( 29, 41) = JacC( 29, 41) - dw( 75, 41)
      JacC( 32, 29) = JacC( 32, 29) + dw( 75, 29)
      JacC( 32, 41) = JacC( 32, 41) + dw( 75, 41)
      JacC( 41, 29) = JacC( 41, 29) - dw( 75, 29)
      JacC( 41, 41) = JacC( 41, 41) - dw( 75, 41)
      JacC( 43, 29) = JacC( 43, 29) + dw( 75, 29)
      JacC( 43, 41) = JacC( 43, 41) + dw( 75, 41)
      JacC( 37, 37) = JacC( 37, 37) - dw( 76, 37)
      JacC( 37, 41) = JacC( 37, 41) - dw( 76, 41)
      JacC( 38, 37) = JacC( 38, 37) + dw( 76, 37)
      JacC( 38, 41) = JacC( 38, 41) + dw( 76, 41)
      JacC( 39, 37) = JacC( 39, 37) + dw( 76, 37)
      JacC( 39, 41) = JacC( 39, 41) + dw( 76, 41)
      JacC( 41, 37) = JacC( 41, 37) - dw( 76, 37)
      JacC( 41, 41) = JacC( 41, 41) - dw( 76, 41)
      JacC( 42, 37) = JacC( 42, 37) + dw( 76, 37)
      JacC( 42, 41) = JacC( 42, 41) + dw( 76, 41)
      JacC( 37, 43) = JacC( 37, 43) + dw( 77, 43)
      JacC( 37, 41) = JacC( 37, 41) + dw( 77, 41)
      JacC( 41, 43) = JacC( 41, 43) - dw( 77, 43)
      JacC( 41, 41) = JacC( 41, 41) - dw( 77, 41)
      JacC( 42, 43) = JacC( 42, 43) + dw( 77, 43)
      JacC( 42, 41) = JacC( 42, 41) + dw( 77, 41)
      JacC( 43, 43) = JacC( 43, 43) - dw( 77, 43)
      JacC( 43, 41) = JacC( 43, 41) - dw( 77, 41)
      JacC( 19, 19) = JacC( 19, 19) - dw( 78, 19)
      JacC( 19, 34) = JacC( 19, 34) - dw( 78, 34)
      JacC( 31, 19) = JacC( 31, 19)+ 0.4400000000000000D+00*dw( 78, 19)
      JacC( 31, 34) = JacC( 31, 34)+ 0.4400000000000000D+00*dw( 78, 34)
      JacC( 34, 19) = JacC( 34, 19) - dw( 78, 19)
      JacC( 34, 34) = JacC( 34, 34) - dw( 78, 34)
      JacC( 38, 19) = JacC( 38, 19) + dw( 78, 19)
      JacC( 38, 34) = JacC( 38, 34) + dw( 78, 34)
      JacC( 39, 19) = JacC( 39, 19)+ 0.1200000000000000D+00*dw( 78, 19)
      JacC( 39, 34) = JacC( 39, 34)+ 0.1200000000000000D+00*dw( 78, 34)
      JacC( 11, 15) = JacC( 11, 15)+ 0.7000000000000000D+00*dw( 79, 15)
      JacC( 11, 34) = JacC( 11, 34)+ 0.7000000000000000D+00*dw( 79, 34)
      JacC( 15, 15) = JacC( 15, 15) - dw( 79, 15)
      JacC( 15, 34) = JacC( 15, 34) - dw( 79, 34)
      JacC( 29, 15) = JacC( 29, 15)+ 0.5000000000000000D+00*dw( 79, 15)
      JacC( 29, 34) = JacC( 29, 34)+ 0.5000000000000000D+00*dw( 79, 34)
      JacC( 31, 15) = JacC( 31, 15)+ 0.4000000000000000D+00*dw( 79, 15)
      JacC( 31, 34) = JacC( 31, 34)+ 0.4000000000000000D+00*dw( 79, 34)
      JacC( 33, 15) = JacC( 33, 15)+ 0.1500000000000000D+00*dw( 79, 15)
      JacC( 33, 34) = JacC( 33, 34)+ 0.1500000000000000D+00*dw( 79, 34)
      JacC( 34, 15) = JacC( 34, 15) - dw( 79, 15)
      JacC( 34, 34) = JacC( 34, 34) - dw( 79, 34)
      JacC( 37, 15) = JacC( 37, 15)+ 0.3100000000000000D+00*dw( 79, 15)
      JacC( 37, 34) = JacC( 37, 34)+ 0.3100000000000000D+00*dw( 79, 34)
      JacC( 38, 15) = JacC( 38, 15)+ 0.5300000000000000D+00*dw( 79, 15)
      JacC( 38, 34) = JacC( 38, 34)+ 0.5300000000000000D+00*dw( 79, 34)
      JacC( 39, 15) = JacC( 39, 15)+ 0.2800000000000000D+00*dw( 79, 15)
      JacC( 39, 34) = JacC( 39, 34)+ 0.2800000000000000D+00*dw( 79, 34)
      JacC( 12, 12) = JacC( 12, 12) - dw( 80, 12)
      JacC( 12, 34) = JacC( 12, 34) - dw( 80, 34)
      JacC( 14, 12) = JacC( 14, 12)+ 0.6700000000000000D+00*dw( 80, 12)
      JacC( 14, 34) = JacC( 14, 34)+ 0.6700000000000000D+00*dw( 80, 34)
      JacC( 15, 12) = JacC( 15, 12)+ 0.7000000000000001D-01*dw( 80, 12)
      JacC( 15, 34) = JacC( 15, 34)+ 0.7000000000000001D-01*dw( 80, 34)
      JacC( 17, 12) = JacC( 17, 12)+ 0.2600000000000000D+00*dw( 80, 12)
      JacC( 17, 34) = JacC( 17, 34)+ 0.2600000000000000D+00*dw( 80, 34)
      JacC( 31, 12) = JacC( 31, 12)+ 0.5000000000000000D-01*dw( 80, 12)
      JacC( 31, 34) = JacC( 31, 34)+ 0.5000000000000000D-01*dw( 80, 34)
      JacC( 33, 12) = JacC( 33, 12)+ 0.5500000000000000D+00*dw( 80, 12)
      JacC( 33, 34) = JacC( 33, 34)+ 0.5500000000000000D+00*dw( 80, 34)
      JacC( 34, 12) = JacC( 34, 12)- 0.7000000000000000D+00*dw( 80, 12)
      JacC( 34, 34) = JacC( 34, 34)- 0.7000000000000000D+00*dw( 80, 34)
      JacC( 38, 12) = JacC( 38, 12)+ 0.8000000000000000D+00*dw( 80, 12)
      JacC( 38, 34) = JacC( 38, 34)+ 0.8000000000000000D+00*dw( 80, 34)
      JacC( 39, 12) = JacC( 39, 12)+ 0.6000000000000000D-01*dw( 80, 12)
      JacC( 39, 34) = JacC( 39, 34)+ 0.6000000000000000D-01*dw( 80, 34)
      JacC( 14, 14) = JacC( 14, 14) - dw( 81, 14)
      JacC( 14, 34) = JacC( 14, 34) - dw( 81, 34)
      JacC( 18, 14) = JacC( 18, 14)+ 0.8000000000000000D+00*dw( 81, 14)
      JacC( 18, 34) = JacC( 18, 34)+ 0.8000000000000000D+00*dw( 81, 34)
      JacC( 31, 14) = JacC( 31, 14)+ 0.2000000000000000D+00*dw( 81, 14)
      JacC( 31, 34) = JacC( 31, 34)+ 0.2000000000000000D+00*dw( 81, 34)
      JacC( 33, 14) = JacC( 33, 14)+ 0.2150000000000000D+00*dw( 81, 14)
      JacC( 33, 34) = JacC( 33, 34)+ 0.2150000000000000D+00*dw( 81, 34)
      JacC( 34, 14) = JacC( 34, 14)- 0.8000000000000000D+00*dw( 81, 14)
      JacC( 34, 34) = JacC( 34, 34)- 0.8000000000000000D+00*dw( 81, 34)
      JacC( 38, 14) = JacC( 38, 14)+ 0.7000000000000000D+00*dw( 81, 14)
      JacC( 38, 34) = JacC( 38, 34)+ 0.7000000000000000D+00*dw( 81, 34)
      JacC( 39, 14) = JacC( 39, 14)+ 0.2750000000000000D+00*dw( 81, 14)
      JacC( 39, 34) = JacC( 39, 34)+ 0.2750000000000000D+00*dw( 81, 34)
      JacC( 17, 17) = JacC( 17, 17) - dw( 82, 17)
      JacC( 17, 34) = JacC( 17, 34) - dw( 82, 34)
      JacC( 18, 17) = JacC( 18, 17)+ 0.8200000000000000D+00*dw( 82, 17)
      JacC( 18, 34) = JacC( 18, 34)+ 0.8200000000000000D+00*dw( 82, 34)
      JacC( 29, 17) = JacC( 29, 17)+ 0.4000000000000000D-01*dw( 82, 17)
      JacC( 29, 34) = JacC( 29, 34)+ 0.4000000000000000D-01*dw( 82, 34)
      JacC( 31, 17) = JacC( 31, 17)+ 0.5000000000000000D-01*dw( 82, 17)
      JacC( 31, 34) = JacC( 31, 34)+ 0.5000000000000000D-01*dw( 82, 34)
      JacC( 33, 17) = JacC( 33, 17)+ 0.8000000000000000D-01*dw( 82, 17)
      JacC( 33, 34) = JacC( 33, 34)+ 0.8000000000000000D-01*dw( 82, 34)
      JacC( 34, 17) = JacC( 34, 17)- 0.8000000000000000D+00*dw( 82, 17)
      JacC( 34, 34) = JacC( 34, 34)- 0.8000000000000000D+00*dw( 82, 34)
      JacC( 38, 17) = JacC( 38, 17)+ 0.8000000000000000D+00*dw( 82, 17)
      JacC( 38, 34) = JacC( 38, 34)+ 0.8000000000000000D+00*dw( 82, 34)
      JacC( 39, 17) = JacC( 39, 17)+ 0.6000000000000000D-01*dw( 82, 17)
      JacC( 39, 34) = JacC( 39, 34)+ 0.6000000000000000D-01*dw( 82, 34)
      JacC( 22, 22) = JacC( 22, 22) - dw( 83, 22)
      JacC( 22, 34) = JacC( 22, 34) - dw( 83, 34)
      JacC( 28, 22) = JacC( 28, 22)+ 0.5300000000000000D+00*dw( 83, 22)
      JacC( 28, 34) = JacC( 28, 34)+ 0.5300000000000000D+00*dw( 83, 34)
      JacC( 29, 22) = JacC( 29, 22)+ 0.1270000000000000D+01*dw( 83, 22)
      JacC( 29, 34) = JacC( 29, 34)+ 0.1270000000000000D+01*dw( 83, 34)
      JacC( 31, 22) = JacC( 31, 22)+ 0.1400000000000000D+00*dw( 83, 22)
      JacC( 31, 34) = JacC( 31, 34)+ 0.1400000000000000D+00*dw( 83, 34)
      JacC( 33, 22) = JacC( 33, 22)+ 0.8500000000000000D+00*dw( 83, 22)
      JacC( 33, 34) = JacC( 33, 34)+ 0.8500000000000000D+00*dw( 83, 34)
      JacC( 34, 22) = JacC( 34, 22) - dw( 83, 22)
      JacC( 34, 34) = JacC( 34, 34) - dw( 83, 34)
      JacC( 35, 22) = JacC( 35, 22)+ 0.6200000000000000D+00*dw( 83, 22)
      JacC( 35, 34) = JacC( 35, 34)+ 0.6200000000000000D+00*dw( 83, 34)
      JacC( 38, 22) = JacC( 38, 22)+ 0.4200000000000000D+00*dw( 83, 22)
      JacC( 38, 34) = JacC( 38, 34)+ 0.4200000000000000D+00*dw( 83, 34)
      JacC( 39, 22) = JacC( 39, 22)+ 0.1000000000000000D+00*dw( 83, 22)
      JacC( 39, 34) = JacC( 39, 34)+ 0.1000000000000000D+00*dw( 83, 34)
      JacC( 37, 37) = JacC( 37, 37) - dw( 84, 37)
      JacC( 37, 44) = JacC( 37, 44) - dw( 84, 44)
      JacC( 38, 37) = JacC( 38, 37) + dw( 84, 37)
      JacC( 38, 44) = JacC( 38, 44) + dw( 84, 44)
      JacC( 39, 37) = JacC( 39, 37) + dw( 84, 37)
      JacC( 39, 44) = JacC( 39, 44) + dw( 84, 44)
      JacC( 42, 37) = JacC( 42, 37) + dw( 84, 37)
      JacC( 42, 44) = JacC( 42, 44) + dw( 84, 44)
      JacC( 44, 37) = JacC( 44, 37) - dw( 84, 37)
      JacC( 44, 44) = JacC( 44, 44) - dw( 84, 44)
      JacC( 37, 43) = JacC( 37, 43) + dw( 85, 43)
      JacC( 37, 44) = JacC( 37, 44) + dw( 85, 44)
      JacC( 42, 43) = JacC( 42, 43) + dw( 85, 43)
      JacC( 42, 44) = JacC( 42, 44) + dw( 85, 44)
      JacC( 43, 43) = JacC( 43, 43) - dw( 85, 43)
      JacC( 43, 44) = JacC( 43, 44) - dw( 85, 44)
      JacC( 44, 43) = JacC( 44, 43) - dw( 85, 43)
      JacC( 44, 44) = JacC( 44, 44) - dw( 85, 44)
      JacC( 10, 37) = JacC( 10, 37) + dw( 86, 37)
      JacC( 10, 39) = JacC( 10, 39) + dw( 86, 39)
      JacC( 37, 37) = JacC( 37, 37) - dw( 86, 37)
      JacC( 37, 39) = JacC( 37, 39) - dw( 86, 39)
      JacC( 39, 37) = JacC( 39, 37) - dw( 86, 37)
      JacC( 39, 39) = JacC( 39, 39) - dw( 86, 39)
      JacC( 25, 43) = JacC( 25, 43)+ 0.6700000000000000D+00*dw( 87, 43)
      JacC( 25, 39) = JacC( 25, 39)+ 0.6700000000000000D+00*dw( 87, 39)
      JacC( 34, 43) = JacC( 34, 43)+ 0.3300000000000000D+00*dw( 87, 43)
      JacC( 34, 39) = JacC( 34, 39)+ 0.3300000000000000D+00*dw( 87, 39)
      JacC( 39, 43) = JacC( 39, 43) - dw( 87, 43)
      JacC( 39, 39) = JacC( 39, 39) - dw( 87, 39)
      JacC( 43, 43) = JacC( 43, 43) - dw( 87, 43)
      JacC( 43, 39) = JacC( 43, 39) - dw( 87, 39)
      JacC( 37, 37) = JacC( 37, 37)- 0.2000000000000000D+01*dw( 88, 37)
      JacC( 37, 37) = JacC( 37, 37)- 0.2000000000000000D+01*dw( 88, 37)
      JacC( 38, 37) = JacC( 38, 37)+ 0.1350000000000000D+01*dw( 88, 37)
      JacC( 38, 37) = JacC( 38, 37)+ 0.1350000000000000D+01*dw( 88, 37)
      JacC( 39, 37) = JacC( 39, 37)+ 0.7000000000000000D+00*dw( 88, 37)
      JacC( 39, 37) = JacC( 39, 37)+ 0.7000000000000000D+00*dw( 88, 37)
      JacC( 37, 43) = JacC( 37, 43)- 0.5000000000000000D+00*dw( 89, 43)
      JacC( 37, 37) = JacC( 37, 37)- 0.5000000000000000D+00*dw( 89, 37)
      JacC( 38, 43) = JacC( 38, 43) + dw( 89, 43)
      JacC( 38, 37) = JacC( 38, 37) + dw( 89, 37)
      JacC( 39, 43) = JacC( 39, 43)+ 0.5000000000000000D+00*dw( 89, 43)
      JacC( 39, 37) = JacC( 39, 37)+ 0.5000000000000000D+00*dw( 89, 37)
      JacC( 43, 43) = JacC( 43, 43) - dw( 89, 43)
      JacC( 43, 37) = JacC( 43, 37) - dw( 89, 37)
      JacC( 37, 43) = JacC( 37, 43)+ 0.2000000000000000D+01*dw( 90, 43)
      JacC( 37, 43) = JacC( 37, 43)+ 0.2000000000000000D+01*dw( 90, 43)
      JacC( 43, 43) = JacC( 43, 43)- 0.2000000000000000D+01*dw( 90, 43)
      JacC( 43, 43) = JacC( 43, 43)- 0.2000000000000000D+01*dw( 90, 43)
      JacC( 23, 43) = JacC( 23, 43) + dw( 91, 43)
      JacC( 23, 42) = JacC( 23, 42) + dw( 91, 42)
      JacC( 42, 43) = JacC( 42, 43) - dw( 91, 43)
      JacC( 42, 42) = JacC( 42, 42) - dw( 91, 42)
      JacC( 43, 43) = JacC( 43, 43) - dw( 91, 43)
      JacC( 43, 42) = JacC( 43, 42) - dw( 91, 42)
      JacC( 23, 23) = JacC( 23, 23) - dw( 92, 23)
      JacC( 42, 23) = JacC( 42, 23) + dw( 92, 23)
      JacC( 43, 23) = JacC( 43, 23) + dw( 92, 23)
      JacC( 23, 23) = JacC( 23, 23) - dw( 93, 23)
      JacC( 23, 33) = JacC( 23, 33) - dw( 93, 33)
      JacC( 33, 23) = JacC( 33, 23) - dw( 93, 23)
      JacC( 33, 33) = JacC( 33, 33) - dw( 93, 33)
      JacC( 38, 23) = JacC( 38, 23) + dw( 93, 23)
      JacC( 38, 33) = JacC( 38, 33) + dw( 93, 33)
      JacC( 41, 23) = JacC( 41, 23) + dw( 93, 23)
      JacC( 41, 33) = JacC( 41, 33) + dw( 93, 33)
      JacC( 16, 16) = JacC( 16, 16) - dw( 94, 16)
      JacC( 16, 33) = JacC( 16, 33) - dw( 94, 33)
      JacC( 29, 16) = JacC( 29, 16) + dw( 94, 16)
      JacC( 29, 33) = JacC( 29, 33) + dw( 94, 33)
      JacC( 31, 16) = JacC( 31, 16) + dw( 94, 16)
      JacC( 31, 33) = JacC( 31, 33) + dw( 94, 33)
      JacC( 33, 16) = JacC( 33, 16) - dw( 94, 16)
      JacC( 33, 33) = JacC( 33, 33) - dw( 94, 33)
      JacC( 42, 16) = JacC( 42, 16) + dw( 94, 16)
      JacC( 42, 33) = JacC( 42, 33) + dw( 94, 33)
      JacC( 33, 34) = JacC( 33, 34)+ 0.2000000000000000D+01*dw( 95, 34)
      JacC( 34, 34) = JacC( 34, 34) - dw( 95, 34)
      JacC( 34, 42) = JacC( 34, 42) + dw( 96, 42)
      JacC( 42, 42) = JacC( 42, 42) - dw( 96, 42)
      JacC( 44, 42) = JacC( 44, 42) + dw( 96, 42)
      JacC( 41, 41) = JacC( 41, 41) - dw( 97, 41)
      JacC( 44, 41) = JacC( 44, 41) + dw( 97, 41)
      JacC( 34, 41) = JacC( 34, 41) + dw( 98, 41)
      JacC( 41, 41) = JacC( 41, 41) - dw( 98, 41)
      JacC( 42, 41) = JacC( 42, 41) + dw( 98, 41)
      JacC( 13, 13) = JacC( 13, 13) - dw( 99, 13)
      JacC( 33, 13) = JacC( 33, 13)+ 0.2000000000000000D+01*dw( 99, 13)
      JacC( 32, 32) = JacC( 32, 32) - dw(100, 32)
      JacC( 33, 32) = JacC( 33, 32) + dw(100, 32)
      JacC( 42, 32) = JacC( 42, 32) + dw(100, 32)
      JacC(  7,  7) = JacC(  7,  7) - dw(101,  7)
      JacC( 33,  7) = JacC( 33,  7) + dw(101,  7)
      JacC( 44,  7) = JacC( 44,  7) + dw(101,  7)
      JacC( 31, 38) = JacC( 31, 38) + dw(102, 38)
      JacC( 38, 38) = JacC( 38, 38) - dw(102, 38)
      JacC( 39, 38) = JacC( 39, 38)+ 0.2000000000000000D+01*dw(102, 38)
      JacC( 31, 38) = JacC( 31, 38) + dw(103, 38)
      JacC( 38, 38) = JacC( 38, 38) - dw(103, 38)
      JacC( 29, 29) = JacC( 29, 29) - dw(104, 29)
      JacC( 31, 29) = JacC( 31, 29) + dw(104, 29)
      JacC( 37, 29) = JacC( 37, 29) + dw(104, 29)
      JacC( 39, 29) = JacC( 39, 29) + dw(104, 29)
      JacC(  6,  6) = JacC(  6,  6) - dw(105,  6)
      JacC( 43,  6) = JacC( 43,  6)+ 0.2000000000000000D+01*dw(105,  6)
      JacC( 18, 18) = JacC( 18, 18) - dw(106, 18)
      JacC( 31, 18) = JacC( 31, 18) + dw(106, 18)
      JacC( 39, 18) = JacC( 39, 18) + dw(106, 18)
      JacC( 43, 18) = JacC( 43, 18) + dw(106, 18)
      JacC(  5,  5) = JacC(  5,  5) - dw(107,  5)
      JacC( 31,  5) = JacC( 31,  5)+ 0.2000000000000000D+01*dw(107,  5)
      JacC( 39,  5) = JacC( 39,  5)+ 0.6000000000000000D+00*dw(107,  5)
      JacC(  4,  4) = JacC(  4,  4) - dw(108,  4)
      JacC( 17,  4) = JacC( 17,  4)+ 0.5000000000000000D+00*dw(108,  4)
      JacC( 38,  4) = JacC( 38,  4)+ 0.5000000000000000D+00*dw(108,  4)
      JacC( 39,  4) = JacC( 39,  4)+ 0.5000000000000000D+00*dw(108,  4)
      JacC( 40,  4) = JacC( 40,  4)+ 0.5000000000000000D+00*dw(108,  4)
      JacC( 28, 28) = JacC( 28, 28) - dw(109, 28)
      JacC( 29, 28) = JacC( 29, 28) + dw(109, 28)
      JacC( 35, 28) = JacC( 35, 28) + dw(109, 28)
      JacC( 43, 28) = JacC( 43, 28) + dw(109, 28)
      JacC(  8,  8) = JacC(  8,  8) - dw(110,  8)
      JacC( 41,  8) = JacC( 41,  8) + dw(110,  8)
      JacC( 42,  8) = JacC( 42,  8) + dw(110,  8)
      JacC( 10, 10) = JacC( 10, 10) - dw(111, 10)
      JacC( 33, 10) = JacC( 33, 10) + dw(111, 10)
      JacC( 38, 10) = JacC( 38, 10) + dw(111, 10)
      JacC( 39, 10) = JacC( 39, 10) + dw(111, 10)
      JacC( 25, 25) = JacC( 25, 25) - dw(112, 25)
      JacC( 33, 25) = JacC( 33, 25) + dw(112, 25)
      JacC( 37, 25) = JacC( 37, 25) + dw(112, 25)
      JacC( 23, 23) = JacC( 23, 23) - dw(113, 23)
      JacC( 42, 23) = JacC( 42, 23) + dw(113, 23)
      JacC( 43, 23) = JacC( 43, 23) + dw(113, 23)
      JacC( 24, 24) = JacC( 24, 24) - dw(114, 24)
      JacC( 33, 24) = JacC( 33, 24) + dw(114, 24)
      JacC( 39, 24) = JacC( 39, 24) + dw(114, 24)
      JacC( 21, 21) = JacC( 21, 21) - dw(115, 21)
      JacC( 33, 21) = JacC( 33, 21) + dw(115, 21)
      JacC( 39, 21) = JacC( 39, 21) + dw(115, 21)
      JacC( 20, 20) = JacC( 20, 20) - dw(116, 20)
      JacC( 33, 20) = JacC( 33, 20) + dw(116, 20)
      JacC( 39, 20) = JacC( 39, 20) + dw(116, 20)
      
      RETURN
      END
      
