      subroutine kinetic(rk,temp,xlw,Press,azi,att)
      
C------------------------------------------------------------------------
C     
C     -- DESCRIPTION
C     
C     This routine computes the kinetic rates for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: MELCHIOR            
C     Species: _ciMELCHIOR         
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     TEMP: temperature ([K]).
C     XLW: water massic fraction.
C     PRESS: pressure ([Pa]).
C     AZI: zenithal angle ([degree]).
C     ATT: attenuation variable.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     RK: kinetic rates.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     SPACK.
C     
C------------------------------------------------------------------------
      
      implicit none
      
C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of chemical arrays.
      
      include 'PARACHEM.INC' 
      INCLUDE 'PARADOM.INC'  
      
      double precision rk(nr),temp,xlw,Press
      double precision Effko,Rapk,SumM,azi,att
      double precision YlH2O,VO2,VN2,VH2O
      
C     Compute third body.
C     Conversion = Avogadro*1d-6/Perfect gas constant.
C     PRESS in Pascal, SUMM in molecules/cm3, TEMP in Kelvin
      
      SumM = Press * 7.243D16 / temp
      
C     Number of water molecules computed from the massic fraction
C     (absolute humidity)
      
      YlH2O = 29.d0*SumM*xlw/(18.d0+11.d0*xlw)
      
C     For the zenithal angle at tropics
      
      azi=abs(azi)
      
      rk(  1) =  DEXP(-0.2704323445102643D+02
     &     - (  0.1370000000000000D+04 )/temp)
      rk(  2) =  DEXP(-0.2975128465212864D+02
     &     - (  0.2450000000000000D+04 )/temp)
      rk(  3) =  DEXP(-0.2698916722975615D+02
     &     - (  0.1000000000000000D+04 )/temp)
      rk(  4) =  DEXP(-0.3189971906529543D+02
     &     - (  0.6000000000000000D+03 )/temp)
      rk(  5) =  DEXP(-0.2632268829627837D+02
     &     - ( -0.2400000000000000D+03 )/temp)
      Rapk = 3.4d-30 * (300.d0/temp)**(3.2d0)*SumM
      Effko = Rapk/(4.77D-11*(300.d0/temp)**1.4d0)
      rk(  6)=(Rapk/(1.d0+Effko))*0.3d0**
     &     (1.0d0/(1.0d0+ ((dlog10(Effko)-0.12d0)/1.2d0)**2))
      rk(  7) =  DEXP(-0.2375982010502066D+02
     &     - ( -0.2500000000000000D+03 )/temp)
      rk(  8) =  DEXP(-0.2656631037893612D+02
     &     - (  0.1600000000000000D+03 )/temp)
      rk(  9) =  DEXP(-0.3283402830267226D+02
     &     - ( -0.9850000000000000D+03 )/temp)
      rk( 10) =  DEXP(-0.2353667655370645D+02
     &     + (-0.1000000000000000D+01 * DLOG(temp)) ) 
      rk( 11) =  DEXP(-0.2914514884855832D+02
     &     - ( -0.7400000000000000D+03 )/temp)
      rk( 12) =  DEXP(-0.7677938116795342D+02
     &     - ( -0.2827000000000000D+04 )/temp)
      rk( 12) = rk( 12) * YlH2O
      rk( 13) =  0.4000000000000000D-11
      rk( 14) =  0.2000000000000000D-14
      rk( 15) =  DEXP(-0.2474064935803238D+02
     &     - ( -0.1100000000000000D+03 )/temp)
      rk( 16) =  DEXP(-0.3073211390514037D+02
     &     - (  0.1260000000000000D+04 )/temp)
      Effko =  0.2700000000000000D-29* (temp / 3.d2)
     &     **(- ( 0.3400000000000000D+01))
      Rapk =  0.2000000000000000D-11* (temp / 3.d2)
     &     **(- (-0.2000000000000000D+00))
      rk( 17) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.3300D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      Effko =  0.1000000000000000D-02* (temp / 3.d2)
     &     **(- ( 0.3500000000000000D+01))*
     &     dexp(- 0.1100000000000000D+05/temp)
      Rapk =  0.9700000000000000D+15* (temp / 3.d2)
     &     **(- (-0.1000000000000000D+00))*
     &     dexp(- 0.1108000000000000D+05/temp)
      rk( 18) = (Effko*SumM / ( 1.0d0 + Effko * SumM / 
     &     Rapk)) * 0.3300D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk( 19) =  0.2600000000000000D-21
      rk( 19) = rk( 19) * YlH2O
      rk( 20) = 2.0d-39 * YlH2O * YlH2O
      Effko =  0.7000000000000001D-29* (temp / 3.d2)
     &     **(- ( 0.2600000000000000D+01))
      Rapk =  0.1500000000000000D-10* (temp / 3.d2)
     &     **(- ( 0.5000000000000000D+00))
      rk( 21) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.6000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk( 22) =  DEXP(-0.2474064935803238D+02
     &     - (  0.3900000000000000D+03 )/temp)
      rk( 23) =  0.4000000000000000D-16
      Effko =  0.4000000000000000D-30* (temp / 3.d2)
     &     **(- ( 0.3300000000000000D+01))
      Rapk =  0.2000000000000000D-11* (temp / 3.d2)
     &     **(- ( 0.0000000000000000D+00))
      rk( 24) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.4500D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk( 25) =  DEXP(-0.2485843239368877D+02
     &     - (  0.1800000000000000D+03 )/temp)
      rk( 26) =  DEXP(-0.2894035443591231D+02
     &     - ( -0.1000000000000000D+04 )/temp)
      rk( 27) =  0.1200000000000000D-11
      rk( 28) =  DEXP(-0.2443643798362939D+02
     &     - (  0.2230000000000000D+03 )/temp)
      rk( 29) =  DEXP(-0.2516292158445693D+02
     &     - (  0.1270000000000000D+03 )/temp)
      rk( 30) =  0.8000000000000000D-10
      rk( 31) =  0.4000000000000000D-11
      rk( 32) =  DEXP(-0.2894035443591231D+02
     &     - ( -0.1000000000000000D+04 )/temp)
      rk( 33) =  0.6400000000000000D-13
      rk( 34) =  0.1200000000000000D-11
      rk( 35) =  DEXP(-0.2952814110081443D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk( 36) =  DEXP(-0.2778184400566313D+02
     &     - ( -0.2600000000000000D+03 )/temp)
      rk( 37) =  DEXP(-0.2616084527082796D+02
     &     - ( -0.4550000000000000D+03 )/temp)
      rk( 38) =  DEXP(-0.2470785953520939D+02
     &     - ( -0.1750000000000000D+03 )/temp)
      rk( 39) =  0.1400000000000000D-10
      rk( 40) =  0.4000000000000000D-11
      rk( 41) =  DEXP(-0.2894035443591231D+02
     &     - ( -0.1000000000000000D+04 )/temp)
      rk( 42) =  0.1640000000000000D-10
      rk( 43) =  DEXP(-0.2556415835645557D+02
     &     - ( -0.1400000000000000D+03 )/temp)
      rk( 44) =  DEXP(-0.2590825451818744D+02
     &     - ( -0.5300000000000000D+03 )/temp)
      Effko =  0.2700000000000000D-27* (temp / 3.d2)
     &     **(- ( 0.7100000000000000D+01))
      Rapk =  0.1200000000000000D-10* (temp / 3.d2)
     &     **(- ( 0.9000000000000000D+00))
      rk( 45) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.3000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      Effko =  0.4900000000000000D-02* (temp / 3.d2)
     &     **(- ( 0.0000000000000000D+00))*
     &     dexp(- 0.1210000000000000D+05/temp)
      Rapk =  0.5400000000000000D+17* (temp / 3.d2)
     &     **(- ( 0.0000000000000000D+00))*
     &     dexp(- 0.1383000000000000D+05/temp)
      rk( 46) = (Effko*SumM / ( 1.0d0 + Effko * SumM / 
     &     Rapk)) * 0.3000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk( 47) =  DEXP(-0.2875495121258095D+02
     &     - ( -0.5000000000000000D+03 )/temp)
      rk( 48) =  0.2000000000000000D-15
      rk( 49) =  0.9450000000000000D-14
      rk( 50) =  DEXP(-0.2745706780880511D+02
     &     - (  0.4900000000000000D+03 )/temp)
      rk( 51) =  0.3400000000000000D-10
      rk( 52) =  0.7800000000000000D-12
      rk( 53) =  0.4000000000000000D-10
      rk( 54) =  0.1200000000000000D-11
      rk( 55) =  DEXP(-0.2894035443591231D+02
     &     - ( -0.1000000000000000D+04 )/temp)
      rk( 56) =  DEXP(-0.2679811199299344D+02
     &     - (  0.1765000000000000D+04 )/temp)
      rk( 57) =  DEXP(-0.2556415835645557D+02
     &     - (  0.1030000000000000D+04 )/temp)
      rk( 58) =  DEXP(-0.3873183693007194D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     +  0.1900000000000000D+03/temp)
      Effko =  0.6999999999999999D-28* (temp / 3.d2)
     &     **(- ( 0.3100000000000000D+01))
      Rapk =  0.9000000000000000D-11* (temp / 3.d2)
     &     **(- ( 0.0000000000000000D+00))
      rk( 59) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.7000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      Effko =  0.8000000000000000D-26* (temp / 3.d2)
     &     **(- ( 0.3500000000000000D+01))
      Rapk =  0.3000000000000000D-10* (temp / 3.d2)
     &     **(- ( 0.0000000000000000D+00))
      rk( 60) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.5000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk( 61) =  0.1370000000000000D-10
      rk( 62) =  DEXP(-0.2439234266376417D+02
     &     - ( -0.4100000000000000D+03 )/temp)
      rk( 63) =  DEXP(-0.2513781566332585D+02
     &     - ( -0.4440000000000000D+03 )/temp)
      rk( 64) =  DEXP(-0.2547925891266908D+02
     &     - ( -0.2000000000000000D+02 )/temp)
      rk( 65) =  DEXP(-0.2590825451818744D+02
     &     - ( -0.3100000000000000D+03 )/temp)
      rk( 66) =  0.5600000000000000D-10
      rk( 67) =  DEXP(-0.4027095834408858D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     +  0.4140000000000000D+03/temp)
      rk( 68) =  0.1100000000000000D-10
      rk( 69) =  0.1500000000000000D-10
      rk( 70) =  DEXP(-0.2622003414221829D+02
     &     - ( -0.4530000000000000D+03 )/temp)
      rk( 71) =  DEXP(-0.2698916722975615D+02
     &     - ( -0.1900000000000000D+03 )/temp)
      rk( 72) =  DEXP(-0.2698916722975615D+02
     &     - ( -0.1900000000000000D+03 )/temp)
      rk( 73) =  DEXP(-0.2763102111592855D+02
     &     - ( -0.1900000000000000D+03 )/temp)
      rk( 74) =  0.5800000000000000D-15
      rk( 75) =  0.2800000000000000D-14
      rk( 76) =  0.1200000000000000D-11
      rk( 77) =  0.4000000000000000D-11
      rk( 78) =  DEXP(-0.3233050198138788D+02
     &     - (  0.2580000000000000D+04 )/temp)
      rk( 79) =  DEXP(-0.3283402830267226D+02
     &     - (  0.1880000000000000D+04 )/temp)
      rk( 80) =  DEXP(-0.3205386974512268D+02
     &     - (  0.2013000000000000D+04 )/temp)
      rk( 81) =  DEXP(-0.3287106957435261D+02
     &     - (  0.2520000000000000D+04 )/temp)
      rk( 82) =  DEXP(-0.3308016137221117D+02
     &     - (  0.2016000000000000D+04 )/temp)
      rk( 83) =  DEXP(-0.3453877639491068D+02
     &     - (  0.7360000000000000D+03 )/temp)
      rk( 84) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 85) =  0.2000000000000000D-10
      rk( 86) =  DEXP(-0.2852261923521233D+02
     &     - ( -0.7900000000000000D+03 )/temp)
      rk( 87) =  DEXP(-0.2847499118622308D+02
     &     - ( -0.1040000000000000D+04 )/temp)
      rk( 88) =  DEXP(-0.2981138857619834D+02
     &     - ( -0.3560000000000000D+03 )/temp)
      rk( 89) =  DEXP(-0.2642505030893994D+02
     &     - ( -0.4000000000000000D+03 )/temp)
      rk( 90) =  DEXP(-0.2660140169874739D+02
     &     - ( -0.5300000000000000D+03 )/temp)
      Effko =  0.2700000000000000D-27* (temp / 3.d2)
     &     **(- ( 0.7100000000000000D+01))
      Rapk =  0.1200000000000000D-10* (temp / 3.d2)
     &     **(- ( 0.9000000000000000D+00))
      rk( 91) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.3000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      Effko =  0.4900000000000000D-02* (temp / 3.d2)
     &     **(- ( 0.0000000000000000D+00))*
     &     dexp(- 0.1210000000000000D+05/temp)
      Rapk =  0.5400000000000000D+17* (temp / 3.d2)
     &     **(- ( 0.0000000000000000D+00))*
     &     dexp(- 0.1383000000000000D+05/temp)
      rk( 92) = (Effko*SumM / ( 1.0d0 + Effko * SumM / 
     &     Rapk)) * 0.3000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk( 93) =  DEXP(-0.2768231441031610D+02
     &     - (  0.6500000000000000D+03 )/temp)
      rk( 94) =  DEXP(-0.2590825451818744D+02
     &     - ( -0.3100000000000000D+03 )/temp)
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk( 95)= 0.1259338576303841D-10
         rk( 95)=-0.1796667856422333D-07+(azi- 0.00D+00) * rk( 95)
         rk( 95)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 95)
         rk( 95)= 0.5620000000000000D-04+(azi- 0.00D+00) * rk( 95)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk( 95)= 0.1696272501182871D-09
         rk( 95)=-0.1739997620488661D-07+(azi- 0.15D+02) * rk( 95)
         rk( 95)=-0.5304998215366491D-06+(azi- 0.15D+02) * rk( 95)
         rk( 95)= 0.5220000000000000D-04+(azi- 0.15D+02) * rk( 95)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk( 95)= 0.2274161322823413D-09
         rk( 95)=-0.9766749949563713D-08+(azi- 0.30D+02) * rk( 95)
         rk( 95)=-0.9380007138534039D-06+(azi- 0.30D+02) * rk( 95)
         rk( 95)= 0.4090000000000000D-04+(azi- 0.30D+02) * rk( 95)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk( 95)= 0.3133008133449188D-09
         rk( 95)= 0.4669760031417275D-09+(azi- 0.45D+02) * rk( 95)
         rk( 95)=-0.1077497323049733D-05+(azi- 0.45D+02) * rk( 95)
         rk( 95)= 0.2540000000000000D-04+(azi- 0.45D+02) * rk( 95)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 95)= 0.2035486791104444D-09
         rk( 95)= 0.1456551260366256D-07+(azi- 0.60D+02) * rk( 95)
         rk( 95)=-0.8520099939476659D-06+(azi- 0.60D+02) * rk( 95)
         rk( 95)= 0.1040000000000000D-04+(azi- 0.60D+02) * rk( 95)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk( 95)= 0.9101093025693211D-10
         rk( 95)= 0.2067197297697420D-07+(azi- 0.70D+02) * rk( 95)
         rk( 95)=-0.4996351381412993D-06+(azi- 0.70D+02) * rk( 95)
         rk( 95)= 0.3540000000000000D-05+(azi- 0.70D+02) * rk( 95)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk( 95)=-0.8438438420767014D-09
         rk( 95)= 0.2203713693083132D-07+(azi- 0.75D+02) * rk( 95)
         rk( 95)=-0.2860895886022540D-06+(azi- 0.75D+02) * rk( 95)
         rk( 95)= 0.1570000000000000D-05+(azi- 0.75D+02) * rk( 95)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk( 95)=-0.1257700499173490D-09
         rk( 95)= 0.9379479299677700D-08+(azi- 0.80D+02) * rk( 95)
         rk( 95)=-0.1290065074497942D-06+(azi- 0.80D+02) * rk( 95)
         rk( 95)= 0.5850000000000000D-06+(azi- 0.80D+02) * rk( 95)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk( 95)=-0.1796915058390066D-09
         rk( 95)= 0.8247548850589781D-08+(azi- 0.83D+02) * rk( 95)
         rk( 95)=-0.7612542299940390D-07+(azi- 0.83D+02) * rk( 95)
         rk( 95)= 0.2790000000000000D-06+(azi- 0.83D+02) * rk( 95)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk( 95)=-0.2679712511033065D-08
         rk( 95)= 0.6630325298104208D-08+(azi- 0.86D+02) * rk( 95)
         rk( 95)=-0.3149180055280244D-07+(azi- 0.86D+02) * rk( 95)
         rk( 95)= 0.1200000000000000D-06+(azi- 0.86D+02) * rk( 95)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk( 95)= 0.6243237380156087D-08
         rk( 95)=-0.9447949766793139D-08+(azi- 0.88D+02) * rk( 95)
         rk( 95)=-0.3712704948913549D-07+(azi- 0.88D+02) * rk( 95)
         rk( 95)= 0.6209999999999999D-07+(azi- 0.88D+02) * rk( 95)
      elseif(azi.ge.90.D0)then
         rk( 95)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk( 95) = rk( 95) * att
C     
      VO2  = 3.2D-11 * exp(70.D0 /temp) * (0.21D0*SumM)
      VN2  = 1.8D-11 * exp(110.D0/temp) * (0.79D0*SumM)
      VH2O = 2.2D-10 * YlH2O
      rk( 95) = rk( 95) * VH2O / (VH2O + VN2 + VO2) 
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk( 96)=-0.5566360522462900D-08
         rk( 96)=-0.7609490366074974D-06+(azi- 0.00D+00) * rk( 96)
         rk( 96)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 96)
         rk( 96)= 0.9710000000000000D-02+(azi- 0.00D+00) * rk( 96)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk( 96)=-0.1078696210389878D-08
         rk( 96)=-0.1011435260118328D-05+(azi- 0.15D+02) * rk( 96)
         rk( 96)=-0.2658576445088738D-04+(azi- 0.15D+02) * rk( 96)
         rk( 96)= 0.9520000000000001D-02+(azi- 0.15D+02) * rk( 96)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk( 96)=-0.1085959537671774D-07
         rk( 96)=-0.1059976589585874D-05+(azi- 0.30D+02) * rk( 96)
         rk( 96)=-0.5765694219645041D-04+(azi- 0.30D+02) * rk( 96)
         rk( 96)= 0.8890000000000000D-02+(azi- 0.30D+02) * rk( 96)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk( 96)=-0.1770514450496197D-07
         rk( 96)=-0.1548658381538167D-05+(azi- 0.45D+02) * rk( 96)
         rk( 96)=-0.9678646676331106D-04+(azi- 0.45D+02) * rk( 96)
         rk( 96)= 0.7750000000000000D-02+(azi- 0.45D+02) * rk( 96)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 96)=-0.5348910407079377D-07
         rk( 96)=-0.2345389884261477D-05+(azi- 0.60D+02) * rk( 96)
         rk( 96)=-0.1551971907503058D-03+(azi- 0.60D+02) * rk( 96)
         rk( 96)= 0.5890000000000000D-02+(azi- 0.60D+02) * rk( 96)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk( 96)= 0.3160813875479851D-06
         rk( 96)=-0.3950063006385304D-05+(azi- 0.70D+02) * rk( 96)
         rk( 96)=-0.2181517196567737D-03+(azi- 0.70D+02) * rk( 96)
         rk( 96)= 0.4050000000000000D-02+(azi- 0.70D+02) * rk( 96)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk( 96)=-0.8038173518597511D-07
         rk( 96)= 0.7911578068346250D-06+(azi- 0.75D+02) * rk( 96)
         rk( 96)=-0.2339462456545262D-03+(azi- 0.75D+02) * rk( 96)
         rk( 96)= 0.2900000000000000D-02+(azi- 0.75D+02) * rk( 96)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk( 96)= 0.7378150801469573D-06
         rk( 96)=-0.4145682209543721D-06+(azi- 0.80D+02) * rk( 96)
         rk( 96)=-0.2320632977251264D-03+(azi- 0.80D+02) * rk( 96)
         rk( 96)= 0.1740000000000000D-02+(azi- 0.80D+02) * rk( 96)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk( 96)= 0.2328044153972501D-05
         rk( 96)= 0.6225767500363555D-05+(azi- 0.83D+02) * rk( 96)
         rk( 96)=-0.2146296998868898D-03+(azi- 0.83D+02) * rk( 96)
         rk( 96)= 0.1060000000000000D-02+(azi- 0.83D+02) * rk( 96)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk( 96)=-0.1385960676123993D-04
         rk( 96)= 0.2717816488612925D-04+(azi- 0.86D+02) * rk( 96)
         rk( 96)=-0.1144179027273892D-03+(azi- 0.86D+02) * rk( 96)
         rk( 96)= 0.5350000000000000D-03+(azi- 0.86D+02) * rk( 96)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk( 96)= 0.3299486892021050D-04
         rk( 96)=-0.5597947568133812D-04+(azi- 0.88D+02) * rk( 96)
         rk( 96)=-0.1720205243176516D-03+(azi- 0.88D+02) * rk( 96)
         rk( 96)= 0.3040000000000000D-03+(azi- 0.88D+02) * rk( 96)
      elseif(azi.ge.90.D0)then
         rk( 96)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk( 96) = rk( 96) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk( 97)= 0.3837733876083853D-07
         rk( 97)=-0.2353437859190360D-05+(azi- 0.00D+00) * rk( 97)
         rk( 97)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 97)
         rk( 97)= 0.2360000000000000D-01+(azi- 0.00D+00) * rk( 97)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk( 97)=-0.2624312739362525D-07
         rk( 97)=-0.6264576149526262D-06+(azi- 0.15D+02) * rk( 97)
         rk( 97)=-0.4469843211214480D-04+(azi- 0.15D+02) * rk( 97)
         rk( 97)= 0.2320000000000000D-01+(azi- 0.15D+02) * rk( 97)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk( 97)= 0.7335911554402063D-08
         rk( 97)=-0.1807398347665767D-05+(azi- 0.30D+02) * rk( 97)
         rk( 97)=-0.8120627155142067D-04+(azi- 0.30D+02) * rk( 97)
         rk( 97)= 0.2230000000000000D-01+(azi- 0.30D+02) * rk( 97)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk( 97)=-0.9198940771287255D-07
         rk( 97)=-0.1477282327717654D-05+(azi- 0.45D+02) * rk( 97)
         rk( 97)=-0.1304764816821721D-03+(azi- 0.45D+02) * rk( 97)
         rk( 97)= 0.2070000000000000D-01+(azi- 0.45D+02) * rk( 97)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 97)=-0.1694414153213863D-06
         rk( 97)=-0.5616805674796956D-05+(azi- 0.60D+02) * rk( 97)
         rk( 97)=-0.2368878017198911D-03+(azi- 0.60D+02) * rk( 97)
         rk( 97)= 0.1810000000000000D-01+(azi- 0.60D+02) * rk( 97)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk( 97)=-0.2577367806224415D-06
         rk( 97)=-0.1070004813443857D-04+(azi- 0.70D+02) * rk( 97)
         rk( 97)=-0.4000563398122474D-03+(azi- 0.70D+02) * rk( 97)
         rk( 97)= 0.1500000000000000D-01+(azi- 0.70D+02) * rk( 97)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk( 97)=-0.1711296843112510D-05
         rk( 97)=-0.1456609984377550D-04+(azi- 0.75D+02) * rk( 97)
         rk( 97)=-0.5263870797033117D-03+(azi- 0.75D+02) * rk( 97)
         rk( 97)= 0.1270000000000000D-01+(azi- 0.75D+02) * rk( 97)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk( 97)=-0.6182964245272622D-06
         rk( 97)=-0.4023555249046313D-04+(azi- 0.80D+02) * rk( 97)
         rk( 97)=-0.8003953413744993D-03+(azi- 0.80D+02) * rk( 97)
         rk( 97)= 0.9490000000000000D-02+(azi- 0.80D+02) * rk( 97)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk( 97)= 0.9174443042196927D-05
         rk( 97)=-0.4580022031120248D-04+(azi- 0.83D+02) * rk( 97)
         rk( 97)=-0.1058502659779514D-02+(azi- 0.83D+02) * rk( 97)
         rk( 97)= 0.6710000000000000D-02+(azi- 0.83D+02) * rk( 97)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk( 97)=-0.4486378657475137D-05
         rk( 97)= 0.3676976706858538D-04+(azi- 0.86D+02) * rk( 97)
         rk( 97)=-0.1085594019507494D-02+(azi- 0.86D+02) * rk( 97)
         rk( 97)= 0.3370000000000000D-02+(azi- 0.86D+02) * rk( 97)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk( 97)= 0.7941212621879383D-04
         rk( 97)= 0.9851495123734612D-05+(azi- 0.88D+02) * rk( 97)
         rk( 97)=-0.9923514951227167D-03+(azi- 0.88D+02) * rk( 97)
         rk( 97)= 0.1310000000000000D-02+(azi- 0.88D+02) * rk( 97)
      elseif(azi.ge.90.D0)then
         rk( 97)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk( 97) = rk( 97) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk( 98)= 0.1444776912984250D-06
         rk( 98)=-0.1550049870280972D-04+(azi- 0.00D+00) * rk( 98)
         rk( 98)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 98)
         rk( 98)= 0.2030000000000000D+00+(azi- 0.00D+00) * rk( 98)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk( 98)=-0.1371367775989781D-06
         rk( 98)=-0.8999002594380595D-05+(azi- 0.15D+02) * rk( 98)
         rk( 98)=-0.3674925194578547D-03+(azi- 0.15D+02) * rk( 98)
         rk( 98)= 0.2000000000000000D+00+(azi- 0.15D+02) * rk( 98)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk( 98)=-0.1885231734951014D-06
         rk( 98)=-0.1517015758633464D-04+(azi- 0.30D+02) * rk( 98)
         rk( 98)=-0.7300299221685831D-03+(azi- 0.30D+02) * rk( 98)
         rk( 98)= 0.1920000000000000D+00+(azi- 0.30D+02) * rk( 98)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk( 98)= 0.2340582690490313D-08
         rk( 98)=-0.2365370039361419D-04+(azi- 0.45D+02) * rk( 98)
         rk( 98)=-0.1312387791867815D-02+(azi- 0.45D+02) * rk( 98)
         rk( 98)= 0.1770000000000000D+00+(azi- 0.45D+02) * rk( 98)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 98)=-0.4440973479144067D-05
         rk( 98)=-0.2354837417254254D-04+(azi- 0.60D+02) * rk( 98)
         rk( 98)=-0.2020418910360165D-02+(azi- 0.60D+02) * rk( 98)
         rk( 98)= 0.1520000000000000D+00+(azi- 0.60D+02) * rk( 98)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk( 98)= 0.8302653211542395D-05
         rk( 98)=-0.1567775785468651D-03+(azi- 0.70D+02) * rk( 98)
         rk( 98)=-0.3823678437554241D-02+(azi- 0.70D+02) * rk( 98)
         rk( 98)= 0.1250000000000000D+00+(azi- 0.70D+02) * rk( 98)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk( 98)=-0.2280223463896546D-04
         rk( 98)=-0.3223778037373308D-04+(azi- 0.75D+02) * rk( 98)
         rk( 98)=-0.4768755232157193D-02+(azi- 0.75D+02) * rk( 98)
         rk( 98)= 0.1030000000000000D+00+(azi- 0.75D+02) * rk( 98)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk( 98)= 0.1008680003982621D-04
         rk( 98)=-0.3742712999582324D-03+(azi- 0.80D+02) * rk( 98)
         rk( 98)=-0.6801300633816999D-02+(azi- 0.80D+02) * rk( 98)
         rk( 98)= 0.7550000000000000D-01+(azi- 0.80D+02) * rk( 98)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk( 98)= 0.8056168125448204D-04
         rk( 98)=-0.2834900995997822D-03+(azi- 0.83D+02) * rk( 98)
         rk( 98)=-0.8774584832491016D-02+(azi- 0.83D+02) * rk( 98)
         rk( 98)= 0.5200000000000000D-01+(azi- 0.83D+02) * rk( 98)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk( 98)=-0.7319250679102400D-04
         rk( 98)= 0.4415650316906682D-03+(azi- 0.86D+02) * rk( 98)
         rk( 98)=-0.8300360036219359D-02+(azi- 0.86D+02) * rk( 98)
         rk( 98)= 0.2530000000000000D-01+(azi- 0.86D+02) * rk( 98)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk( 98)= 0.6168975022639925D-03
         rk( 98)= 0.2409990945411757D-05+(azi- 0.88D+02) * rk( 98)
         rk( 98)=-0.7412409990948072D-02+(azi- 0.88D+02) * rk( 98)
         rk( 98)= 0.9880000000000000D-02+(azi- 0.88D+02) * rk( 98)
      elseif(azi.ge.90.D0)then
         rk( 98)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk( 98) = rk( 98) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk( 99)= 0.2633657096569521D-11
         rk( 99)=-0.1595060412004099D-08+(azi- 0.00D+00) * rk( 99)
         rk( 99)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 99)
         rk( 99)= 0.9580000000000000D-05+(azi- 0.00D+00) * rk( 99)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk( 99)=-0.1975045363782739D-11
         rk( 99)=-0.1476545842658470D-08+(azi- 0.15D+02) * rk( 99)
         rk( 99)=-0.4607409381993852D-07+(azi- 0.15D+02) * rk( 99)
         rk( 99)= 0.9230000000000000D-05+(azi- 0.15D+02) * rk( 99)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk( 99)= 0.2303561395599154D-11
         rk( 99)=-0.1565422884028695D-08+(azi- 0.30D+02) * rk( 99)
         rk( 99)=-0.9170362472024601D-07+(azi- 0.30D+02) * rk( 99)
         rk( 99)= 0.8199999999999999D-05+(azi- 0.30D+02) * rk( 99)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk( 99)= 0.1053857755916173D-10
         rk( 99)=-0.1461762621226721D-08+(azi- 0.45D+02) * rk( 99)
         rk( 99)=-0.1371114072990772D-06+(azi- 0.45D+02) * rk( 99)
         rk( 99)= 0.6480000000000000D-05+(azi- 0.45D+02) * rk( 99)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 99)= 0.3726012394090174D-10
         rk( 99)=-0.9875266310644730D-09+(azi- 0.60D+02) * rk( 99)
         rk( 99)=-0.1738507460834454D-06+(azi- 0.60D+02) * rk( 99)
         rk( 99)= 0.4130000000000000D-05+(azi- 0.60D+02) * rk( 99)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk( 99)= 0.3108742434660083D-09
         rk( 99)= 0.1302770871625621D-09+(azi- 0.70D+02) * rk( 99)
         rk( 99)=-0.1824232415224647D-06+(azi- 0.70D+02) * rk( 99)
         rk( 99)= 0.2330000000000000D-05+(azi- 0.70D+02) * rk( 99)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk( 99)=-0.1104820521951275D-09
         rk( 99)= 0.4793390739152777D-08+(azi- 0.75D+02) * rk( 99)
         rk( 99)=-0.1578049023908861D-06+(azi- 0.75D+02) * rk( 99)
         rk( 99)= 0.1460000000000000D-05+(azi- 0.75D+02) * rk( 99)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk( 99)= 0.1942965605926046D-09
         rk( 99)= 0.3136159956225139D-08+(azi- 0.80D+02) * rk( 99)
         rk( 99)=-0.1181571489139942D-06+(azi- 0.80D+02) * rk( 99)
         rk( 99)= 0.7770000000000000D-06+(azi- 0.80D+02) * rk( 99)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk( 99)= 0.5303364854700681D-09
         rk( 99)= 0.4884829001568257D-08+(azi- 0.83D+02) * rk( 99)
         rk( 99)=-0.9409418204063895D-07+(azi- 0.83D+02) * rk( 99)
         rk( 99)= 0.4560000000000000D-06+(azi- 0.83D+02) * rk( 99)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk( 99)=-0.5212397954505061D-08
         rk( 99)= 0.9657857370811467D-08+(azi- 0.86D+02) * rk( 99)
         rk( 99)=-0.5046612292364693D-07+(azi- 0.86D+02) * rk( 99)
         rk( 99)= 0.2320000000000000D-06+(azi- 0.86D+02) * rk( 99)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk( 99)= 0.1340413252651251D-07
         rk( 99)=-0.2161653035611051D-07+(azi- 0.88D+02) * rk( 99)
         rk( 99)=-0.7438346889415206D-07+(azi- 0.88D+02) * rk( 99)
         rk( 99)= 0.1280000000000000D-06+(azi- 0.88D+02) * rk( 99)
      elseif(azi.ge.90.D0)then
         rk( 99)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk( 99) = rk( 99) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(100)=-0.1022935012534146D-12
         rk(100)=-0.2117989308145321D-09+(azi- 0.00D+00) * rk(100)
         rk(100)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(100)
         rk(100)= 0.9390000000000000D-06+(azi- 0.00D+00) * rk(100)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(100)= 0.1195769392649132D-11
         rk(100)=-0.2164021383709358D-09+(azi- 0.15D+02) * rk(100)
         rk(100)=-0.6423016037782019D-08+(azi- 0.15D+02) * rk(100)
         rk(100)= 0.8910000000000000D-06+(azi- 0.15D+02) * rk(100)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(100)= 0.1541438152879181D-11
         rk(100)=-0.1625925157017252D-09+(azi- 0.30D+02) * rk(100)
         rk(100)=-0.1210793584887193D-07+(azi- 0.30D+02) * rk(100)
         rk(100)= 0.7500000000000000D-06+(azi- 0.30D+02) * rk(100)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(100)= 0.3305144662500640D-11
         rk(100)=-0.9322779882216104D-10+(azi- 0.45D+02) * rk(100)
         rk(100)=-0.1594524056673023D-07+(azi- 0.45D+02) * rk(100)
         rk(100)= 0.5370000000000000D-06+(azi- 0.45D+02) * rk(100)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(100)= 0.6560647743035671D-11
         rk(100)= 0.5550371099036356D-10+(azi- 0.60D+02) * rk(100)
         rk(100)=-0.1651110188420719D-07+(azi- 0.60D+02) * rk(100)
         rk(100)= 0.2880000000000000D-06+(azi- 0.60D+02) * rk(100)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(100)= 0.1244870500328859D-10
         rk(100)= 0.2523231432814228D-09+(azi- 0.70D+02) * rk(100)
         rk(100)=-0.1343283334148933D-07+(azi- 0.70D+02) * rk(100)
         rk(100)= 0.1350000000000000D-06+(azi- 0.70D+02) * rk(100)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(100)=-0.9572782329016235D-11
         rk(100)= 0.4390537183307108D-09+(azi- 0.75D+02) * rk(100)
         rk(100)=-0.9975949033428471D-08+(azi- 0.75D+02) * rk(100)
         rk(100)= 0.7570000000000000D-07+(azi- 0.75D+02) * rk(100)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(100)= 0.1887174956956943D-11
         rk(100)= 0.2954619833952386D-09+(azi- 0.80D+02) * rk(100)
         rk(100)=-0.6303370524797790D-08+(azi- 0.80D+02) * rk(100)
         rk(100)= 0.3560000000000000D-07+(azi- 0.80D+02) * rk(100)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(100)= 0.1321909924759383D-10
         rk(100)= 0.3124465580080247D-09+(azi- 0.83D+02) * rk(100)
         rk(100)=-0.4479644900591350D-08+(azi- 0.83D+02) * rk(100)
         rk(100)= 0.1940000000000000D-07+(azi- 0.83D+02) * rk(100)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(100)=-0.1949467574011173D-09
         rk(100)= 0.4314184512354448D-09+(azi- 0.86D+02) * rk(100)
         rk(100)=-0.2248049872860789D-08+(azi- 0.86D+02) * rk(100)
         rk(100)= 0.9130000000000000D-08+(azi- 0.86D+02) * rk(100)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk(100)= 0.4845654607626872D-09
         rk(100)=-0.7382620931644927D-09+(azi- 0.88D+02) * rk(100)
         rk(100)=-0.2861737156720102D-08+(azi- 0.88D+02) * rk(100)
         rk(100)= 0.4800000000000000D-08+(azi- 0.88D+02) * rk(100)
      elseif(azi.ge.90.D0)then
         rk(100)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk(100) = rk(100) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(101)=-0.9135326372239089D-10
         rk(101)=-0.2208519232663869D-06+(azi- 0.00D+00) * rk(101)
         rk(101)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(101)
         rk(101)= 0.2150000000000000D-02+(azi- 0.00D+00) * rk(101)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(101)= 0.2740597911673003D-09
         rk(101)=-0.2249628201338945D-06+(azi- 0.15D+02) * rk(101)
         rk(101)=-0.6687221151004222D-05+(azi- 0.15D+02) * rk(101)
         rk(101)= 0.2100000000000000D-02+(azi- 0.15D+02) * rk(101)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(101)=-0.3967848863909754D-08
         rk(101)=-0.2126301295313663D-06+(azi- 0.30D+02) * rk(101)
         rk(101)=-0.1325111539598313D-04+(azi- 0.30D+02) * rk(101)
         rk(101)= 0.1950000000000000D-02+(azi- 0.30D+02) * rk(101)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(101)=-0.2180442113306389D-08
         rk(101)=-0.3911833284073037D-06+(azi- 0.45D+02) * rk(101)
         rk(101)=-0.2230831726506319D-04+(azi- 0.45D+02) * rk(101)
         rk(101)= 0.1690000000000000D-02+(azi- 0.45D+02) * rk(101)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(101)=-0.9913522211748853D-08
         rk(101)=-0.4893032235060958D-06+(azi- 0.60D+02) * rk(101)
         rk(101)=-0.3551561554376414D-04+(azi- 0.60D+02) * rk(101)
         rk(101)= 0.1260000000000000D-02+(azi- 0.60D+02) * rk(101)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(101)= 0.7237124506814654D-07
         rk(101)=-0.7867088898585692D-06+(azi- 0.70D+02) * rk(101)
         rk(101)=-0.4827573667741086D-04+(azi- 0.70D+02) * rk(101)
         rk(101)= 0.8460000000000000D-03+(azi- 0.70D+02) * rk(101)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(101)= 0.8827330602649790D-08
         rk(101)= 0.2988597861636888D-06+(azi- 0.75D+02) * rk(101)
         rk(101)=-0.5071498219588503D-04+(azi- 0.75D+02) * rk(101)
         rk(101)= 0.5940000000000000D-03+(azi- 0.75D+02) * rk(101)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(101)= 0.8561392260454443D-07
         rk(101)= 0.4312697452033083D-06+(azi- 0.80D+02) * rk(101)
         rk(101)=-0.4706433453905104D-04+(azi- 0.80D+02) * rk(101)
         rk(101)= 0.3490000000000000D-03+(azi- 0.80D+02) * rk(101)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(101)= 0.4696024086921817D-06
         rk(101)= 0.1201795048644393D-05+(azi- 0.83D+02) * rk(101)
         rk(101)=-0.4216514015750790D-04+(azi- 0.83D+02) * rk(101)
         rk(101)= 0.2140000000000000D-03+(azi- 0.83D+02) * rk(101)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(101)=-0.2957832155707182D-05
         rk(101)= 0.5428216726878302D-05+(azi- 0.86D+02) * rk(101)
         rk(101)=-0.2227510483094316D-04+(azi- 0.86D+02) * rk(101)
         rk(101)= 0.1110000000000000D-03+(azi- 0.86D+02) * rk(101)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk(101)= 0.7110944051780263D-05
         rk(101)=-0.1231877620737867D-04+(azi- 0.88D+02) * rk(101)
         rk(101)=-0.3605622379193105D-04+(azi- 0.88D+02) * rk(101)
         rk(101)= 0.6450000000000000D-04+(azi- 0.88D+02) * rk(101)
      elseif(azi.ge.90.D0)then
         rk(101)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk(101) = rk(101) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(102)=-0.4532207173071221D-11
         rk(102)=-0.6154239114626155D-08+(azi- 0.00D+00) * rk(102)
         rk(102)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(102)
         rk(102)= 0.3670000000000000D-04+(azi- 0.00D+00) * rk(102)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(102)= 0.1359662151921353D-10
         rk(102)=-0.6358188437414359D-08+(azi- 0.15D+02) * rk(102)
         rk(102)=-0.1876864132806077D-06+(azi- 0.15D+02) * rk(102)
         rk(102)= 0.3530000000000000D-04+(azi- 0.15D+02) * rk(102)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(102)=-0.2022464927415146D-10
         rk(102)=-0.5746340469049758D-08+(azi- 0.30D+02) * rk(102)
         rk(102)=-0.3692543468775694D-06+(azi- 0.30D+02) * rk(102)
         rk(102)= 0.3110000000000000D-04+(azi- 0.30D+02) * rk(102)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(102)= 0.9693160520701594D-10
         rk(102)=-0.6656449686386537D-08+(azi- 0.45D+02) * rk(102)
         rk(102)=-0.5552961992091138D-06+(azi- 0.45D+02) * rk(102)
         rk(102)= 0.2420000000000000D-04+(azi- 0.45D+02) * rk(102)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(102)= 0.2050613080668612D-09
         rk(102)=-0.2294527452070950D-08+(azi- 0.60D+02) * rk(102)
         rk(102)=-0.6895608562859753D-06+(azi- 0.60D+02) * rk(102)
         rk(102)= 0.1470000000000000D-04+(azi- 0.60D+02) * rk(102)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(102)= 0.1065858158306397D-08
         rk(102)= 0.3857311789934561D-08+(azi- 0.70D+02) * rk(102)
         rk(102)=-0.6739330129073387D-06+(azi- 0.70D+02) * rk(102)
         rk(102)= 0.7780000000000000D-05+(azi- 0.70D+02) * rk(102)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(102)=-0.3922155075066590D-09
         rk(102)= 0.1984518416453129D-07+(azi- 0.75D+02) * rk(102)
         rk(102)=-0.5554205331350058D-06+(azi- 0.75D+02) * rk(102)
         rk(102)= 0.4640000000000000D-05+(azi- 0.75D+02) * rk(102)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(102)= 0.4998888774405849D-09
         rk(102)= 0.1396195155192098D-07+(azi- 0.80D+02) * rk(102)
         rk(102)=-0.3863848545527151D-06+(azi- 0.80D+02) * rk(102)
         rk(102)= 0.2310000000000000D-05+(azi- 0.80D+02) * rk(102)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(102)= 0.9703656892749818D-09
         rk(102)= 0.1846095144890422D-07+(azi- 0.83D+02) * rk(102)
         rk(102)=-0.2891161455502100D-06+(azi- 0.83D+02) * rk(102)
         rk(102)= 0.1290000000000000D-05+(azi- 0.83D+02) * rk(102)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(102)=-0.1243448051474426D-07
         rk(102)= 0.2719424265245561D-07+(azi- 0.86D+02) * rk(102)
         rk(102)=-0.1521505632465005D-06+(azi- 0.86D+02) * rk(102)
         rk(102)= 0.6150000000000000D-06+(azi- 0.86D+02) * rk(102)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk(102)= 0.3185316004650972D-07
         rk(102)=-0.4741264043644375D-07+(azi- 0.88D+02) * rk(102)
         rk(102)=-0.1925873588134682D-06+(azi- 0.88D+02) * rk(102)
         rk(102)= 0.3200000000000000D-06+(azi- 0.88D+02) * rk(102)
      elseif(azi.ge.90.D0)then
         rk(102)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk(102) = rk(102) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(103)= 0.4569304782112756D-10
         rk(103)=-0.7796506828428047D-08+(azi- 0.00D+00) * rk(103)
         rk(103)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(103)
         rk(103)= 0.5220000000000000D-04+(azi- 0.00D+00) * rk(103)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(103)=-0.4819025457448743D-10
         rk(103)=-0.5740319676477308D-08+(azi- 0.15D+02) * rk(103)
         rk(103)=-0.2030523975735803D-06+(azi- 0.15D+02) * rk(103)
         rk(103)= 0.5060000000000000D-04+(azi- 0.15D+02) * rk(103)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(103)=-0.3070980730096107D-10
         rk(103)=-0.7908881132329246D-08+(azi- 0.30D+02) * rk(103)
         rk(103)=-0.4077904097056786D-06+(azi- 0.30D+02) * rk(103)
         rk(103)= 0.4610000000000000D-04+(azi- 0.30D+02) * rk(103)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(103)=-0.6748293999447015D-11
         rk(103)=-0.9290822460872481D-08+(azi- 0.45D+02) * rk(103)
         rk(103)=-0.6657859636037043D-06+(azi- 0.45D+02) * rk(103)
         rk(103)= 0.3810000000000000D-04+(azi- 0.45D+02) * rk(103)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(103)= 0.1501069278798551D-09
         rk(103)=-0.9594495690847679D-08+(azi- 0.60D+02) * rk(103)
         rk(103)=-0.9490657358795060D-06+(azi- 0.60D+02) * rk(103)
         rk(103)= 0.2600000000000000D-04+(azi- 0.60D+02) * rk(103)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(103)= 0.1655200424190359D-08
         rk(103)=-0.5091287854451827D-08+(azi- 0.70D+02) * rk(103)
         rk(103)=-0.1095923571332504D-05+(azi- 0.70D+02) * rk(103)
         rk(103)= 0.1570000000000000D-04+(azi- 0.70D+02) * rk(103)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(103)= 0.5130208287822848D-12
         rk(103)= 0.1973671850840231D-07+(azi- 0.75D+02) * rk(103)
         rk(103)=-0.1022696418062729D-05+(azi- 0.75D+02) * rk(103)
         rk(103)= 0.1030000000000000D-04+(azi- 0.75D+02) * rk(103)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(103)= 0.1043427587508059D-08
         rk(103)= 0.1974441382082203D-07+(azi- 0.80D+02) * rk(103)
         rk(103)=-0.8252907564166143D-06+(azi- 0.80D+02) * rk(103)
         rk(103)= 0.5680000000000000D-05+(azi- 0.80D+02) * rk(103)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(103)= 0.4953252848519840D-08
         rk(103)= 0.2913526210840876D-07+(azi- 0.83D+02) * rk(103)
         rk(103)=-0.6786517286288819D-06+(azi- 0.83D+02) * rk(103)
         rk(103)= 0.3410000000000000D-05+(azi- 0.83D+02) * rk(103)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(103)=-0.4133168660579255D-07
         rk(103)= 0.7371453774527828D-07+(azi- 0.86D+02) * rk(103)
         rk(103)=-0.3701023290678778D-06+(azi- 0.86D+02) * rk(103)
         rk(103)= 0.1770000000000000D-05+(azi- 0.86D+02) * rk(103)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk(103)= 0.1056938954088332D-06
         rk(103)=-0.1742755818892601D-06+(azi- 0.88D+02) * rk(103)
         rk(103)=-0.5712244173558217D-06+(azi- 0.88D+02) * rk(103)
         rk(103)= 0.9939999999999999D-06+(azi- 0.88D+02) * rk(103)
      elseif(azi.ge.90.D0)then
         rk(103)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk(103) = rk(103) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(104)= 0.3724328950955041D-11
         rk(104)=-0.1833642712042105D-08+(azi- 0.00D+00) * rk(104)
         rk(104)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(104)
         rk(104)= 0.7340000000000000D-05+(azi- 0.00D+00) * rk(104)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(104)= 0.6604790924913207D-11
         rk(104)=-0.1666047909249129D-08+(azi- 0.15D+02) * rk(104)
         rk(104)=-0.5249535931936850D-07+(azi- 0.15D+02) * rk(104)
         rk(104)= 0.6940000000000000D-05+(azi- 0.15D+02) * rk(104)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(104)= 0.1430095179383651D-10
         rk(104)=-0.1368832317628037D-08+(azi- 0.30D+02) * rk(104)
         rk(104)=-0.9801856272252597D-07+(azi- 0.30D+02) * rk(104)
         rk(104)= 0.5800000000000000D-05+(azi- 0.30D+02) * rk(104)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(104)= 0.3100621671455374D-10
         rk(104)=-0.7252894869053809D-09+(azi- 0.45D+02) * rk(104)
         rk(104)=-0.1294303897905272D-06+(azi- 0.45D+02) * rk(104)
         rk(104)= 0.4070000000000000D-05+(azi- 0.45D+02) * rk(104)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(104)= 0.5559975462870120D-10
         rk(104)= 0.6699902652495123D-09+(azi- 0.60D+02) * rk(104)
         rk(104)=-0.1302598781153651D-06+(azi- 0.60D+02) * rk(104)
         rk(104)= 0.2070000000000000D-05+(azi- 0.60D+02) * rk(104)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(104)= 0.9960927604849773D-10
         rk(104)= 0.2337982904110444D-08+(azi- 0.70D+02) * rk(104)
         rk(104)=-0.1001801464217658D-06+(azi- 0.70D+02) * rk(104)
         rk(104)= 0.8899999999999999D-06+(azi- 0.70D+02) * rk(104)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(104)=-0.1052395418867885D-09
         rk(104)= 0.3832122044837907D-08+(azi- 0.75D+02) * rk(104)
         rk(104)=-0.6932962167702017D-07+(azi- 0.75D+02) * rk(104)
         rk(104)= 0.4600000000000000D-06+(azi- 0.75D+02) * rk(104)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(104)=-0.6579986605469089D-11
         rk(104)= 0.2253528916536305D-08+(azi- 0.80D+02) * rk(104)
         rk(104)=-0.3890136687014406D-07+(azi- 0.80D+02) * rk(104)
         rk(104)= 0.1960000000000000D-06+(azi- 0.80D+02) * rk(104)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(104)= 0.2313991458876232D-10
         rk(104)= 0.2194309037088723D-08+(azi- 0.83D+02) * rk(104)
         rk(104)=-0.2555785300926553D-07+(azi- 0.83D+02) * rk(104)
         rk(104)= 0.9940000000000000D-07+(azi- 0.83D+02) * rk(104)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(104)=-0.9219788610179240D-09
         rk(104)= 0.2402568268373912D-08+(azi- 0.86D+02) * rk(104)
         rk(104)=-0.1176722109283675D-07+(azi- 0.86D+02) * rk(104)
         rk(104)= 0.4310000000000000D-07+(azi- 0.86D+02) * rk(104)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk(104)= 0.2144826161811273D-08
         rk(104)=-0.3129304897679395D-08+(azi- 0.88D+02) * rk(104)
         rk(104)=-0.1322069435144936D-07+(azi- 0.88D+02) * rk(104)
         rk(104)= 0.2180000000000000D-07+(azi- 0.88D+02) * rk(104)
      elseif(azi.ge.90.D0)then
         rk(104)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk(104) = rk(104) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(105)=-0.1500152264127710D-09
         rk(105)=-0.1997199382603072D-07+(azi- 0.00D+00) * rk(105)
         rk(105)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(105)
         rk(105)= 0.2920000000000000D-03+(azi- 0.00D+00) * rk(105)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(105)= 0.1537493829420246D-09
         rk(105)=-0.2672267901460541D-07+(azi- 0.15D+02) * rk(105)
         rk(105)=-0.7004200926095418D-06+(azi- 0.15D+02) * rk(105)
         rk(105)= 0.2870000000000000D-03+(azi- 0.15D+02) * rk(105)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(105)=-0.4649823053553124D-09
         rk(105)=-0.1980395678221434D-07+(azi- 0.30D+02) * rk(105)
         rk(105)=-0.1398319629561838D-05+(azi- 0.30D+02) * rk(105)
         rk(105)= 0.2710000000000000D-03+(azi- 0.30D+02) * rk(105)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(105)=-0.6641905318911713D-09
         rk(105)=-0.4072816052320338D-07+(azi- 0.45D+02) * rk(105)
         rk(105)=-0.2306301389143103D-05+(azi- 0.45D+02) * rk(105)
         rk(105)= 0.2440000000000000D-03+(azi- 0.45D+02) * rk(105)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(105)=-0.3173578415511830D-08
         rk(105)=-0.7061673445830638D-07+(azi- 0.60D+02) * rk(105)
         rk(105)=-0.3976474813865750D-05+(azi- 0.60D+02) * rk(105)
         rk(105)= 0.1980000000000000D-03+(azi- 0.60D+02) * rk(105)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(105)= 0.6800138492150115D-08
         rk(105)=-0.1658240869236626D-06+(azi- 0.70D+02) * rk(105)
         rk(105)=-0.6340883027685440D-05+(azi- 0.70D+02) * rk(105)
         rk(105)= 0.1480000000000000D-03+(azi- 0.70D+02) * rk(105)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(105)=-0.8471057691288821D-08
         rk(105)=-0.6382200954140809D-07+(azi- 0.75D+02) * rk(105)
         rk(105)=-0.7489113510010776D-05+(azi- 0.75D+02) * rk(105)
         rk(105)= 0.1130000000000000D-03+(azi- 0.75D+02) * rk(105)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(105)= 0.2614739522264341D-07
         rk(105)=-0.1908878749107562D-06+(azi- 0.80D+02) * rk(105)
         rk(105)=-0.8762662932271498D-05+(azi- 0.80D+02) * rk(105)
         rk(105)= 0.7290000000000000D-04+(azi- 0.80D+02) * rk(105)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(105)= 0.1187438293827760D-06
         rk(105)= 0.4443868209298948D-07+(azi- 0.83D+02) * rk(105)
         rk(105)=-0.9202010510724728D-05+(azi- 0.83D+02) * rk(105)
         rk(105)= 0.4560000000000000D-04+(azi- 0.83D+02) * rk(105)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(105)=-0.4492428170615806D-06
         rk(105)= 0.1113133146537829D-05+(azi- 0.86D+02) * rk(105)
         rk(105)=-0.5729295024831116D-05+(azi- 0.86D+02) * rk(105)
         rk(105)= 0.2160000000000000D-04+(azi- 0.86D+02) * rk(105)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk(105)= 0.1083080938896138D-05
         rk(105)=-0.1582323755832522D-05+(azi- 0.88D+02) * rk(105)
         rk(105)=-0.6667676243418470D-05+(azi- 0.88D+02) * rk(105)
         rk(105)= 0.1100000000000000D-04+(azi- 0.88D+02) * rk(105)
      elseif(azi.ge.90.D0)then
         rk(105)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk(105) = rk(105) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(106)=-0.6613427913285321D-10
         rk(106)=-0.8341319146340581D-08+(azi- 0.00D+00) * rk(106)
         rk(106)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(106)
         rk(106)= 0.1000000000000000D-03+(azi- 0.00D+00) * rk(106)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(106)= 0.2062505962079355D-10
         rk(106)=-0.1131736170731898D-07+(azi- 0.15D+02) * rk(106)
         rk(106)=-0.2948802128048934D-06+(azi- 0.15D+02) * rk(106)
         rk(106)= 0.9789999999999999D-04+(azi- 0.15D+02) * rk(106)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(106)=-0.7562521860958807D-10
         rk(106)=-0.1038923402438328D-07+(azi- 0.30D+02) * rk(106)
         rk(106)=-0.6204791487804270D-06+(azi- 0.30D+02) * rk(106)
         rk(106)= 0.9100000000000000D-04+(azi- 0.30D+02) * rk(106)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(106)=-0.1921982592565179D-09
         rk(106)=-0.1379236886181469D-07+(azi- 0.45D+02) * rk(106)
         rk(106)=-0.9832031920733968D-06+(azi- 0.45D+02) * rk(106)
         rk(106)= 0.7910000000000000D-04+(azi- 0.45D+02) * rk(106)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(106)=-0.5887901179042785D-09
         rk(106)=-0.2244129052835818D-07+(azi- 0.60D+02) * rk(106)
         rk(106)=-0.1526708082925990D-05+(azi- 0.60D+02) * rk(106)
         rk(106)= 0.6060000000000000D-04+(azi- 0.60D+02) * rk(106)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(106)= 0.2907835967674455D-08
         rk(106)=-0.4010499406548656D-07+(azi- 0.70D+02) * rk(106)
         rk(106)=-0.2152170928864437D-05+(azi- 0.70D+02) * rk(106)
         rk(106)= 0.4250000000000000D-04+(azi- 0.70D+02) * rk(106)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(106)=-0.2497182212178230D-08
         rk(106)= 0.3512545449632635D-08+(azi- 0.75D+02) * rk(106)
         rk(106)=-0.2335133171943709D-05+(azi- 0.75D+02) * rk(106)
         rk(106)= 0.3110000000000000D-04+(azi- 0.75D+02) * rk(106)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(106)= 0.9903549617767796D-08
         rk(106)=-0.3394518773304800D-07+(azi- 0.80D+02) * rk(106)
         rk(106)=-0.2487296383360761D-05+(azi- 0.80D+02) * rk(106)
         rk(106)= 0.1920000000000000D-04+(azi- 0.80D+02) * rk(106)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(106)= 0.2718645114062165D-07
         rk(106)= 0.5518675882682989D-07+(azi- 0.83D+02) * rk(106)
         rk(106)=-0.2423571670079403D-05+(azi- 0.83D+02) * rk(106)
         rk(106)= 0.1170000000000000D-04+(azi- 0.83D+02) * rk(106)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(106)=-0.1353281754659612D-06
         rk(106)= 0.2998648190924280D-06+(azi- 0.86D+02) * rk(106)
         rk(106)=-0.1358416936321149D-05+(azi- 0.86D+02) * rk(106)
         rk(106)= 0.5660000000000000D-05+(azi- 0.86D+02) * rk(106)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk(106)= 0.3192760583621864D-06
         rk(106)=-0.5121042337029058D-06+(azi- 0.88D+02) * rk(106)
         rk(106)=-0.1782895765541186D-05+(azi- 0.88D+02) * rk(106)
         rk(106)= 0.3060000000000000D-05+(azi- 0.88D+02) * rk(106)
      elseif(azi.ge.90.D0)then
         rk(106)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk(106) = rk(106) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(107)= 0.5693759881396559D-10
         rk(107)=-0.8854063982209438D-08+(azi- 0.00D+00) * rk(107)
         rk(107)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(107)
         rk(107)= 0.7949999999999999D-04+(azi- 0.00D+00) * rk(107)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(107)=-0.5229427792338756D-10
         rk(107)=-0.6291872035580985D-08+(azi- 0.15D+02) * rk(107)
         rk(107)=-0.2271890402668564D-06+(azi- 0.15D+02) * rk(107)
         rk(107)= 0.7770000000000000D-04+(azi- 0.15D+02) * rk(107)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(107)=-0.2553826489819193D-10
         rk(107)=-0.8645114542133435D-08+(azi- 0.30D+02) * rk(107)
         rk(107)=-0.4512438389325726D-06+(azi- 0.30D+02) * rk(107)
         rk(107)= 0.7270000000000001D-04+(azi- 0.30D+02) * rk(107)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(107)=-0.1122193291505136D-09
         rk(107)=-0.9794336462552036D-08+(azi- 0.45D+02) * rk(107)
         rk(107)=-0.7278356040028540D-06+(azi- 0.45D+02) * rk(107)
         rk(107)= 0.6389999999999999D-04+(azi- 0.45D+02) * rk(107)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(107)=-0.7414419220073119D-09
         rk(107)=-0.1484420627432533D-07+(azi- 0.60D+02) * rk(107)
         rk(107)=-0.1097413745056014D-05+(azi- 0.60D+02) * rk(107)
         rk(107)= 0.5040000000000000D-04+(azi- 0.60D+02) * rk(107)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(107)= 0.1686710672697369D-08
         rk(107)=-0.3708746393454485D-07+(azi- 0.70D+02) * rk(107)
         rk(107)=-0.1616730447144716D-05+(azi- 0.70D+02) * rk(107)
         rk(107)= 0.3720000000000000D-04+(azi- 0.70D+02) * rk(107)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(107)=-0.2398567789669468D-08
         rk(107)=-0.1178680384408402D-07+(azi- 0.75D+02) * rk(107)
         rk(107)=-0.1861101786037851D-05+(azi- 0.75D+02) * rk(107)
         rk(107)= 0.2840000000000000D-04+(azi- 0.75D+02) * rk(107)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(107)= 0.3943522678299529D-08
         rk(107)=-0.4776532068912244D-07+(azi- 0.80D+02) * rk(107)
         rk(107)=-0.2158862408703929D-05+(azi- 0.80D+02) * rk(107)
         rk(107)= 0.1850000000000000D-04+(azi- 0.80D+02) * rk(107)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(107)= 0.3249630410491862D-07
         rk(107)=-0.1227361658441057D-07+(azi- 0.83D+02) * rk(107)
         rk(107)=-0.2338979220524490D-05+(azi- 0.83D+02) * rk(107)
         rk(107)= 0.1170000000000000D-04+(azi- 0.83D+02) * rk(107)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(107)=-0.1037913828806145D-06
         rk(107)= 0.2801931203598621D-06+(azi- 0.86D+02) * rk(107)
         rk(107)=-0.1535220709198200D-05+(azi- 0.86D+02) * rk(107)
         rk(107)= 0.5450000000000000D-05+(azi- 0.86D+02) * rk(107)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk(107)= 0.2525137941686794D-06
         rk(107)=-0.3425551769242586D-06+(azi- 0.88D+02) * rk(107)
         rk(107)=-0.1659944822328213D-05+(azi- 0.88D+02) * rk(107)
         rk(107)= 0.2670000000000000D-05+(azi- 0.88D+02) * rk(107)
      elseif(azi.ge.90.D0)then
         rk(107)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk(107) = rk(107) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(108)= 0.6230854519209925D-09
         rk(108)=-0.1426796151121476D-06+(azi- 0.00D+00) * rk(108)
         rk(108)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(108)
         rk(108)= 0.1300000000000000D-02+(azi- 0.00D+00) * rk(108)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(108)=-0.1869256355763108D-08
         rk(108)=-0.1146407697757029D-06+(azi- 0.15D+02) * rk(108)
         rk(108)=-0.3859805773317758D-05+(azi- 0.15D+02) * rk(108)
         rk(108)= 0.1270000000000000D-02+(azi- 0.15D+02) * rk(108)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(108)= 0.9280140452056055D-09
         rk(108)=-0.1987573057850430D-06+(azi- 0.30D+02) * rk(108)
         rk(108)=-0.8560776906728947D-05+(azi- 0.30D+02) * rk(108)
         rk(108)= 0.1180000000000000D-02+(azi- 0.30D+02) * rk(108)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(108)=-0.3916873899133496D-08
         rk(108)=-0.1569966737507904D-06+(azi- 0.45D+02) * rk(108)
         rk(108)=-0.1389708659976644D-04+(azi- 0.45D+02) * rk(108)
         rk(108)= 0.1010000000000000D-02+(azi- 0.45D+02) * rk(108)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(108)=-0.3165633136767028D-08
         rk(108)=-0.3332559992118007D-06+(azi- 0.60D+02) * rk(108)
         rk(108)=-0.2125087669420530D-04+(azi- 0.60D+02) * rk(108)
         rk(108)= 0.7530000000000000D-03+(azi- 0.60D+02) * rk(108)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(108)= 0.4027246344182249D-07
         rk(108)=-0.4282249933148174D-06+(azi- 0.70D+02) * rk(108)
         rk(108)=-0.2886568661947152D-04+(azi- 0.70D+02) * rk(108)
         rk(108)= 0.5040000000000000D-03+(azi- 0.70D+02) * rk(108)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(108)= 0.1927680116817761D-08
         rk(108)= 0.1758619583124806D-06+(azi- 0.75D+02) * rk(108)
         rk(108)=-0.3012750179448281D-04+(azi- 0.75D+02) * rk(108)
         rk(108)= 0.3540000000000000D-03+(azi- 0.75D+02) * rk(108)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(108)= 0.6777496915603290D-07
         rk(108)= 0.2047771600647364D-06+(azi- 0.80D+02) * rk(108)
         rk(108)=-0.2822430620259762D-04+(azi- 0.80D+02) * rk(108)
         rk(108)= 0.2080000000000000D-03+(azi- 0.80D+02) * rk(108)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(108)= 0.2579403808431686D-06
         rk(108)= 0.8147518824690754D-06+(azi- 0.83D+02) * rk(108)
         rk(108)=-0.2516571907499688D-04+(azi- 0.83D+02) * rk(108)
         rk(108)= 0.1270000000000000D-03+(azi- 0.83D+02) * rk(108)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(108)=-0.1714903280678956D-05
         rk(108)= 0.3136215310058111D-05+(azi- 0.86D+02) * rk(108)
         rk(108)=-0.1331281749741289D-04+(azi- 0.86D+02) * rk(108)
         rk(108)= 0.6580000000000000D-04+(azi- 0.86D+02) * rk(108)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk(108)= 0.4163301093452661D-05
         rk(108)=-0.7153204374008688D-05+(azi- 0.88D+02) * rk(108)
         rk(108)=-0.2134679562528492D-04+(azi- 0.88D+02) * rk(108)
         rk(108)= 0.3800000000000000D-04+(azi- 0.88D+02) * rk(108)
      elseif(azi.ge.90.D0)then
         rk(108)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk(108) = rk(108) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(109)= 0.1538703706281671D-11
         rk(109)=-0.1311969444483113D-08+(azi- 0.00D+00) * rk(109)
         rk(109)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(109)
         rk(109)= 0.5860000000000000D-05+(azi- 0.00D+00) * rk(109)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(109)= 0.4272777770043511D-11
         rk(109)=-0.1242727777700437D-08+(azi- 0.15D+02) * rk(109)
         rk(109)=-0.3832045833275326D-07+(azi- 0.15D+02) * rk(109)
         rk(109)= 0.5570000000000000D-05+(azi- 0.15D+02) * rk(109)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(109)= 0.8036851880211929D-11
         rk(109)=-0.1050452778048482D-08+(azi- 0.30D+02) * rk(109)
         rk(109)=-0.7271816666898705D-07+(azi- 0.30D+02) * rk(109)
         rk(109)= 0.4730000000000000D-05+(azi- 0.30D+02) * rk(109)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(109)= 0.1987611100540365D-10
         rk(109)=-0.6887944434389405D-09+(azi- 0.45D+02) * rk(109)
         rk(109)=-0.9880687499129843D-07+(azi- 0.45D+02) * rk(109)
         rk(109)= 0.3430000000000000D-05+(azi- 0.45D+02) * rk(109)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(109)= 0.4598027847777921D-10
         rk(109)= 0.2056305518041825D-09+(azi- 0.60D+02) * rk(109)
         rk(109)=-0.1060543333658196D-06+(azi- 0.60D+02) * rk(109)
         rk(109)= 0.1860000000000000D-05+(azi- 0.60D+02) * rk(109)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(109)= 0.9689777022856917D-10
         rk(109)= 0.1585038906137532D-08+(azi- 0.70D+02) * rk(109)
         rk(109)=-0.8814763878640318D-07+(azi- 0.70D+02) * rk(109)
         rk(109)= 0.8660000000000001D-06+(azi- 0.70D+02) * rk(109)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(109)=-0.7050441359800293D-10
         rk(109)= 0.3038505459566144D-08+(azi- 0.75D+02) * rk(109)
         rk(109)=-0.6502991695788216D-07+(azi- 0.75D+02) * rk(109)
         rk(109)= 0.4770000000000000D-06+(azi- 0.75D+02) * rk(109)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(109)=-0.1124931633177059D-11
         rk(109)= 0.1980939255595080D-08+(azi- 0.80D+02) * rk(109)
         rk(109)=-0.3993269338207273D-07+(azi- 0.80D+02) * rk(109)
         rk(109)= 0.2190000000000000D-06+(azi- 0.80D+02) * rk(109)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(109)= 0.8870219146703247D-10
         rk(109)= 0.1970814870898873D-08+(azi- 0.83D+02) * rk(109)
         rk(109)=-0.2807743100258308D-07+(azi- 0.83D+02) * rk(109)
         rk(109)= 0.1170000000000000D-06+(azi- 0.83D+02) * rk(109)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(109)=-0.1132671645186649D-08
         rk(109)= 0.2769134594113713D-08+(azi- 0.86D+02) * rk(109)
         rk(109)=-0.1385758260754810D-07+(azi- 0.86D+02) * rk(109)
         rk(109)= 0.5290000000000000D-07+(azi- 0.86D+02) * rk(109)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk(109)= 0.2706723756737038D-08
         rk(109)=-0.4026895276951957D-08+(azi- 0.88D+02) * rk(109)
         rk(109)=-0.1637310397309412D-07+(azi- 0.88D+02) * rk(109)
         rk(109)= 0.2720000000000000D-07+(azi- 0.88D+02) * rk(109)
      elseif(azi.ge.90.D0)then
         rk(109)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk(109) = rk(109) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(110)= 0.4330678693496827D-10
         rk(110)=-0.1042737958180230D-07+(azi- 0.00D+00) * rk(110)
         rk(110)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(110)
         rk(110)= 0.6060000000000000D-04+(azi- 0.00D+00) * rk(110)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(110)=-0.1140184228638725D-10
         rk(110)=-0.8478574169728729D-08+(azi- 0.15D+02) * rk(110)
         rk(110)=-0.2835893062729654D-06+(azi- 0.15D+02) * rk(110)
         rk(110)= 0.5840000000000000D-04+(azi- 0.15D+02) * rk(110)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(110)=-0.2732904741904292D-10
         rk(110)=-0.8991657072616176D-08+(azi- 0.30D+02) * rk(110)
         rk(110)=-0.5456427749081390D-06+(azi- 0.30D+02) * rk(110)
         rk(110)= 0.5220000000000000D-04+(azi- 0.30D+02) * rk(110)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(110)= 0.9108840233291629D-10
         rk(110)=-0.1022146420647306D-07+(azi- 0.45D+02) * rk(110)
         rk(110)=-0.8338395940944771D-06+(azi- 0.45D+02) * rk(110)
         rk(110)= 0.4190000000000000D-04+(azi- 0.45D+02) * rk(110)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(110)= 0.1022370972887488D-09
         rk(110)=-0.6122486101492077D-08+(azi- 0.60D+02) * rk(110)
         rk(110)=-0.1078998848713954D-05+(azi- 0.60D+02) * rk(110)
         rk(110)= 0.2740000000000000D-04+(azi- 0.60D+02) * rk(110)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(110)= 0.1842172298852917D-08
         rk(110)=-0.3055373182830407D-08+(azi- 0.70D+02) * rk(110)
         rk(110)=-0.1170777441557173D-05+(azi- 0.70D+02) * rk(110)
         rk(110)= 0.1610000000000000D-04+(azi- 0.70D+02) * rk(110)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(110)=-0.3087122211341997D-09
         rk(110)= 0.2457721129996479D-07+(azi- 0.75D+02) * rk(110)
         rk(110)=-0.1063168250971489D-05+(azi- 0.75D+02) * rk(110)
         rk(110)= 0.1040000000000000D-04+(azi- 0.75D+02) * rk(110)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(110)= 0.1189996734244374D-08
         rk(110)= 0.1994652798294366D-07+(azi- 0.80D+02) * rk(110)
         rk(110)=-0.8405495545569407D-06+(azi- 0.80D+02) * rk(110)
         rk(110)= 0.5660000000000000D-05+(azi- 0.80D+02) * rk(110)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(110)= 0.5196775451230619D-08
         rk(110)= 0.3065649859117554D-07+(azi- 0.83D+02) * rk(110)
         rk(110)=-0.6887404748346156D-06+(azi- 0.83D+02) * rk(110)
         rk(110)= 0.3350000000000000D-05+(azi- 0.83D+02) * rk(110)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(110)=-0.4096660230022848D-07
         rk(110)= 0.7742747765223488D-07+(azi- 0.86D+02) * rk(110)
         rk(110)=-0.3644885461044601D-06+(azi- 0.86D+02) * rk(110)
         rk(110)= 0.1700000000000000D-05+(azi- 0.86D+02) * rk(110)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk(110)= 0.1016555339752180D-06
         rk(110)=-0.1683721361504370D-06+(azi- 0.88D+02) * rk(110)
         rk(110)=-0.5463778630993894D-06+(azi- 0.88D+02) * rk(110)
         rk(110)= 0.9530000000000000D-06+(azi- 0.88D+02) * rk(110)
      elseif(azi.ge.90.D0)then
         rk(110)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk(110) = rk(110) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(111)=-0.8681317595742691D-13
         rk(111)=-0.1020920024582862D-08+(azi- 0.00D+00) * rk(111)
         rk(111)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(111)
         rk(111)= 0.6640000000000000D-05+(azi- 0.00D+00) * rk(111)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(111)= 0.2604395278727706D-12
         rk(111)=-0.1024826617500946D-08+(azi- 0.15D+02) * rk(111)
         rk(111)=-0.3068619963125713D-07+(azi- 0.15D+02) * rk(111)
         rk(111)= 0.6410000000000000D-05+(azi- 0.15D+02) * rk(111)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(111)=-0.9549449355338672D-12
         rk(111)=-0.1013106838746673D-08+(azi- 0.30D+02) * rk(111)
         rk(111)=-0.6125520147497143D-07+(azi- 0.30D+02) * rk(111)
         rk(111)= 0.5720000000000000D-05+(azi- 0.30D+02) * rk(111)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(111)= 0.6522303177225098D-11
         rk(111)=-0.1056079360845699D-08+(azi- 0.45D+02) * rk(111)
         rk(111)=-0.9229299446885695D-07+(azi- 0.45D+02) * rk(111)
         rk(111)= 0.4570000000000000D-05+(azi- 0.45D+02) * rk(111)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(111)= 0.2198577828307057D-10
         rk(111)=-0.7625757178705869D-09+(azi- 0.60D+02) * rk(111)
         rk(111)=-0.1195728206496012D-06+(azi- 0.60D+02) * rk(111)
         rk(111)= 0.2970000000000000D-05+(azi- 0.60D+02) * rk(111)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(111)= 0.1897445347593964D-09
         rk(111)=-0.1030023693785656D-09+(azi- 0.70D+02) * rk(111)
         rk(111)=-0.1282286015220926D-06+(azi- 0.70D+02) * rk(111)
         rk(111)= 0.1720000000000000D-05+(azi- 0.70D+02) * rk(111)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(111)=-0.1952172604562540D-10
         rk(111)= 0.2743165652012333D-08+(azi- 0.75D+02) * rk(111)
         rk(111)=-0.1150277851089213D-06+(azi- 0.75D+02) * rk(111)
         rk(111)= 0.1100000000000000D-05+(azi- 0.75D+02) * rk(111)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(111)= 0.1158413435082285D-09
         rk(111)= 0.2450339761328123D-08+(azi- 0.80D+02) * rk(111)
         rk(111)=-0.8906025804221852D-07+(azi- 0.80D+02) * rk(111)
         rk(111)= 0.5910000000000000D-06+(azi- 0.80D+02) * rk(111)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(111)= 0.4539001082388528D-09
         rk(111)= 0.3492911852905733D-08+(azi- 0.83D+02) * rk(111)
         rk(111)=-0.7123050319952390D-07+(azi- 0.83D+02) * rk(111)
         rk(111)= 0.3490000000000000D-06+(azi- 0.83D+02) * rk(111)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(111)=-0.4159574123628927D-08
         rk(111)= 0.7578012827042183D-08+(azi- 0.86D+02) * rk(111)
         rk(111)=-0.3801772915965371D-07+(azi- 0.86D+02) * rk(111)
         rk(111)= 0.1790000000000000D-06+(azi- 0.86D+02) * rk(111)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk(111)= 0.1059485791616453D-07
         rk(111)=-0.1737943191478559D-07+(azi- 0.88D+02) * rk(111)
         rk(111)=-0.5762056733497268D-07+(azi- 0.88D+02) * rk(111)
         rk(111)= 0.1000000000000000D-06+(azi- 0.88D+02) * rk(111)
      elseif(azi.ge.90.D0)then
         rk(111)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk(111) = rk(111) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(112)=-0.8681317595742691D-13
         rk(112)=-0.1020920024582862D-08+(azi- 0.00D+00) * rk(112)
         rk(112)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(112)
         rk(112)= 0.6640000000000000D-05+(azi- 0.00D+00) * rk(112)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(112)= 0.2604395278727706D-12
         rk(112)=-0.1024826617500946D-08+(azi- 0.15D+02) * rk(112)
         rk(112)=-0.3068619963125713D-07+(azi- 0.15D+02) * rk(112)
         rk(112)= 0.6410000000000000D-05+(azi- 0.15D+02) * rk(112)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(112)=-0.9549449355338672D-12
         rk(112)=-0.1013106838746673D-08+(azi- 0.30D+02) * rk(112)
         rk(112)=-0.6125520147497143D-07+(azi- 0.30D+02) * rk(112)
         rk(112)= 0.5720000000000000D-05+(azi- 0.30D+02) * rk(112)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(112)= 0.6522303177225098D-11
         rk(112)=-0.1056079360845699D-08+(azi- 0.45D+02) * rk(112)
         rk(112)=-0.9229299446885695D-07+(azi- 0.45D+02) * rk(112)
         rk(112)= 0.4570000000000000D-05+(azi- 0.45D+02) * rk(112)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(112)= 0.2198577828307057D-10
         rk(112)=-0.7625757178705869D-09+(azi- 0.60D+02) * rk(112)
         rk(112)=-0.1195728206496012D-06+(azi- 0.60D+02) * rk(112)
         rk(112)= 0.2970000000000000D-05+(azi- 0.60D+02) * rk(112)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(112)= 0.1897445347593964D-09
         rk(112)=-0.1030023693785656D-09+(azi- 0.70D+02) * rk(112)
         rk(112)=-0.1282286015220926D-06+(azi- 0.70D+02) * rk(112)
         rk(112)= 0.1720000000000000D-05+(azi- 0.70D+02) * rk(112)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(112)=-0.1952172604562540D-10
         rk(112)= 0.2743165652012333D-08+(azi- 0.75D+02) * rk(112)
         rk(112)=-0.1150277851089213D-06+(azi- 0.75D+02) * rk(112)
         rk(112)= 0.1100000000000000D-05+(azi- 0.75D+02) * rk(112)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(112)= 0.1158413435082285D-09
         rk(112)= 0.2450339761328123D-08+(azi- 0.80D+02) * rk(112)
         rk(112)=-0.8906025804221852D-07+(azi- 0.80D+02) * rk(112)
         rk(112)= 0.5910000000000000D-06+(azi- 0.80D+02) * rk(112)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(112)= 0.4539001082388528D-09
         rk(112)= 0.3492911852905733D-08+(azi- 0.83D+02) * rk(112)
         rk(112)=-0.7123050319952390D-07+(azi- 0.83D+02) * rk(112)
         rk(112)= 0.3490000000000000D-06+(azi- 0.83D+02) * rk(112)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(112)=-0.4159574123628927D-08
         rk(112)= 0.7578012827042183D-08+(azi- 0.86D+02) * rk(112)
         rk(112)=-0.3801772915965371D-07+(azi- 0.86D+02) * rk(112)
         rk(112)= 0.1790000000000000D-06+(azi- 0.86D+02) * rk(112)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk(112)= 0.1059485791616453D-07
         rk(112)=-0.1737943191478559D-07+(azi- 0.88D+02) * rk(112)
         rk(112)=-0.5762056733497268D-07+(azi- 0.88D+02) * rk(112)
         rk(112)= 0.1000000000000000D-06+(azi- 0.88D+02) * rk(112)
      elseif(azi.ge.90.D0)then
         rk(112)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk(112) = rk(112) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(113)= 0.6754926481843469D-12
         rk(113)=-0.2323546119449872D-09+(azi- 0.00D+00) * rk(113)
         rk(113)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(113)
         rk(113)= 0.1090000000000000D-05+(azi- 0.00D+00) * rk(113)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(113)= 0.6401887221135747D-12
         rk(113)=-0.2019574427766916D-09+(azi- 0.15D+02) * rk(113)
         rk(113)=-0.6514680820825181D-08+(azi- 0.15D+02) * rk(113)
         rk(113)= 0.1040000000000000D-05+(azi- 0.15D+02) * rk(113)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(113)= 0.6156043152132658D-12
         rk(113)=-0.1731489502815810D-09+(azi- 0.30D+02) * rk(113)
         rk(113)=-0.1214127671669927D-07+(azi- 0.30D+02) * rk(113)
         rk(113)= 0.8990000000000000D-06+(azi- 0.30D+02) * rk(113)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(113)= 0.2823319942959151D-11
         rk(113)=-0.1454467560969839D-09+(azi- 0.45D+02) * rk(113)
         rk(113)=-0.1692021231237774D-07+(azi- 0.45D+02) * rk(113)
         rk(113)= 0.6799999999999999D-06+(azi- 0.45D+02) * rk(113)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(113)= 0.4618476204281437D-11
         rk(113)=-0.1839735866382561D-10+(azi- 0.60D+02) * rk(113)
         rk(113)=-0.1937787403378988D-07+(azi- 0.60D+02) * rk(113)
         rk(113)= 0.4030000000000000D-06+(azi- 0.60D+02) * rk(113)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(113)= 0.3037974833835553D-10
         rk(113)= 0.1201569274646159D-09+(azi- 0.70D+02) * rk(113)
         rk(113)=-0.1836027834578209D-07+(azi- 0.70D+02) * rk(113)
         rk(113)= 0.2120000000000000D-06+(azi- 0.70D+02) * rk(113)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(113)=-0.1676151267765709D-10
         rk(113)= 0.5758531525399885D-09+(azi- 0.75D+02) * rk(113)
         rk(113)=-0.1488022794575889D-07+(azi- 0.75D+02) * rk(113)
         rk(113)= 0.1270000000000000D-06+(azi- 0.75D+02) * rk(113)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(113)= 0.1542797971055980D-10
         rk(113)= 0.3244304623747618D-09+(azi- 0.80D+02) * rk(113)
         rk(113)=-0.1037880987118535D-07+(azi- 0.80D+02) * rk(113)
         rk(113)= 0.6490000000000001D-07+(azi- 0.80D+02) * rk(113)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(113)= 0.3990645986355911D-10
         rk(113)= 0.4632822797708576D-09+(azi- 0.83D+02) * rk(113)
         rk(113)=-0.8015671644751452D-08+(azi- 0.83D+02) * rk(113)
         rk(113)= 0.3710000000000000D-07+(azi- 0.83D+02) * rk(113)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(113)=-0.4128443218222688D-09
         rk(113)= 0.8224404185428884D-09+(azi- 0.86D+02) * rk(113)
         rk(113)=-0.4158503549810212D-08+(azi- 0.86D+02) * rk(113)
         rk(113)= 0.1830000000000000D-07+(azi- 0.86D+02) * rk(113)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk(113)= 0.1036781315582954D-08
         rk(113)=-0.1654625512390731D-08+(azi- 0.88D+02) * rk(113)
         rk(113)=-0.5822873737492358D-08+(azi- 0.88D+02) * rk(113)
         rk(113)= 0.9969999999999999D-08+(azi- 0.88D+02) * rk(113)
      elseif(azi.ge.90.D0)then
         rk(113)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk(113) = rk(113) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(114)=-0.8681317595742691D-13
         rk(114)=-0.1020920024582862D-08+(azi- 0.00D+00) * rk(114)
         rk(114)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(114)
         rk(114)= 0.6640000000000000D-05+(azi- 0.00D+00) * rk(114)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(114)= 0.2604395278727706D-12
         rk(114)=-0.1024826617500946D-08+(azi- 0.15D+02) * rk(114)
         rk(114)=-0.3068619963125713D-07+(azi- 0.15D+02) * rk(114)
         rk(114)= 0.6410000000000000D-05+(azi- 0.15D+02) * rk(114)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(114)=-0.9549449355338672D-12
         rk(114)=-0.1013106838746673D-08+(azi- 0.30D+02) * rk(114)
         rk(114)=-0.6125520147497143D-07+(azi- 0.30D+02) * rk(114)
         rk(114)= 0.5720000000000000D-05+(azi- 0.30D+02) * rk(114)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(114)= 0.6522303177225098D-11
         rk(114)=-0.1056079360845699D-08+(azi- 0.45D+02) * rk(114)
         rk(114)=-0.9229299446885695D-07+(azi- 0.45D+02) * rk(114)
         rk(114)= 0.4570000000000000D-05+(azi- 0.45D+02) * rk(114)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(114)= 0.2198577828307057D-10
         rk(114)=-0.7625757178705869D-09+(azi- 0.60D+02) * rk(114)
         rk(114)=-0.1195728206496012D-06+(azi- 0.60D+02) * rk(114)
         rk(114)= 0.2970000000000000D-05+(azi- 0.60D+02) * rk(114)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(114)= 0.1897445347593964D-09
         rk(114)=-0.1030023693785656D-09+(azi- 0.70D+02) * rk(114)
         rk(114)=-0.1282286015220926D-06+(azi- 0.70D+02) * rk(114)
         rk(114)= 0.1720000000000000D-05+(azi- 0.70D+02) * rk(114)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(114)=-0.1952172604562540D-10
         rk(114)= 0.2743165652012333D-08+(azi- 0.75D+02) * rk(114)
         rk(114)=-0.1150277851089213D-06+(azi- 0.75D+02) * rk(114)
         rk(114)= 0.1100000000000000D-05+(azi- 0.75D+02) * rk(114)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(114)= 0.1158413435082285D-09
         rk(114)= 0.2450339761328123D-08+(azi- 0.80D+02) * rk(114)
         rk(114)=-0.8906025804221852D-07+(azi- 0.80D+02) * rk(114)
         rk(114)= 0.5910000000000000D-06+(azi- 0.80D+02) * rk(114)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(114)= 0.4539001082388528D-09
         rk(114)= 0.3492911852905733D-08+(azi- 0.83D+02) * rk(114)
         rk(114)=-0.7123050319952390D-07+(azi- 0.83D+02) * rk(114)
         rk(114)= 0.3490000000000000D-06+(azi- 0.83D+02) * rk(114)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(114)=-0.4159574123628927D-08
         rk(114)= 0.7578012827042183D-08+(azi- 0.86D+02) * rk(114)
         rk(114)=-0.3801772915965371D-07+(azi- 0.86D+02) * rk(114)
         rk(114)= 0.1790000000000000D-06+(azi- 0.86D+02) * rk(114)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk(114)= 0.1059485791616453D-07
         rk(114)=-0.1737943191478559D-07+(azi- 0.88D+02) * rk(114)
         rk(114)=-0.5762056733497268D-07+(azi- 0.88D+02) * rk(114)
         rk(114)= 0.1000000000000000D-06+(azi- 0.88D+02) * rk(114)
      elseif(azi.ge.90.D0)then
         rk(114)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk(114) = rk(114) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(115)=-0.8681317595742691D-13
         rk(115)=-0.1020920024582862D-08+(azi- 0.00D+00) * rk(115)
         rk(115)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(115)
         rk(115)= 0.6640000000000000D-05+(azi- 0.00D+00) * rk(115)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(115)= 0.2604395278727706D-12
         rk(115)=-0.1024826617500946D-08+(azi- 0.15D+02) * rk(115)
         rk(115)=-0.3068619963125713D-07+(azi- 0.15D+02) * rk(115)
         rk(115)= 0.6410000000000000D-05+(azi- 0.15D+02) * rk(115)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(115)=-0.9549449355338672D-12
         rk(115)=-0.1013106838746673D-08+(azi- 0.30D+02) * rk(115)
         rk(115)=-0.6125520147497143D-07+(azi- 0.30D+02) * rk(115)
         rk(115)= 0.5720000000000000D-05+(azi- 0.30D+02) * rk(115)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(115)= 0.6522303177225098D-11
         rk(115)=-0.1056079360845699D-08+(azi- 0.45D+02) * rk(115)
         rk(115)=-0.9229299446885695D-07+(azi- 0.45D+02) * rk(115)
         rk(115)= 0.4570000000000000D-05+(azi- 0.45D+02) * rk(115)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(115)= 0.2198577828307057D-10
         rk(115)=-0.7625757178705869D-09+(azi- 0.60D+02) * rk(115)
         rk(115)=-0.1195728206496012D-06+(azi- 0.60D+02) * rk(115)
         rk(115)= 0.2970000000000000D-05+(azi- 0.60D+02) * rk(115)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(115)= 0.1897445347593964D-09
         rk(115)=-0.1030023693785656D-09+(azi- 0.70D+02) * rk(115)
         rk(115)=-0.1282286015220926D-06+(azi- 0.70D+02) * rk(115)
         rk(115)= 0.1720000000000000D-05+(azi- 0.70D+02) * rk(115)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(115)=-0.1952172604562540D-10
         rk(115)= 0.2743165652012333D-08+(azi- 0.75D+02) * rk(115)
         rk(115)=-0.1150277851089213D-06+(azi- 0.75D+02) * rk(115)
         rk(115)= 0.1100000000000000D-05+(azi- 0.75D+02) * rk(115)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(115)= 0.1158413435082285D-09
         rk(115)= 0.2450339761328123D-08+(azi- 0.80D+02) * rk(115)
         rk(115)=-0.8906025804221852D-07+(azi- 0.80D+02) * rk(115)
         rk(115)= 0.5910000000000000D-06+(azi- 0.80D+02) * rk(115)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(115)= 0.4539001082388528D-09
         rk(115)= 0.3492911852905733D-08+(azi- 0.83D+02) * rk(115)
         rk(115)=-0.7123050319952390D-07+(azi- 0.83D+02) * rk(115)
         rk(115)= 0.3490000000000000D-06+(azi- 0.83D+02) * rk(115)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(115)=-0.4159574123628927D-08
         rk(115)= 0.7578012827042183D-08+(azi- 0.86D+02) * rk(115)
         rk(115)=-0.3801772915965371D-07+(azi- 0.86D+02) * rk(115)
         rk(115)= 0.1790000000000000D-06+(azi- 0.86D+02) * rk(115)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk(115)= 0.1059485791616453D-07
         rk(115)=-0.1737943191478559D-07+(azi- 0.88D+02) * rk(115)
         rk(115)=-0.5762056733497268D-07+(azi- 0.88D+02) * rk(115)
         rk(115)= 0.1000000000000000D-06+(azi- 0.88D+02) * rk(115)
      elseif(azi.ge.90.D0)then
         rk(115)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk(115) = rk(115) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.15D+02) then
         rk(116)=-0.8681317595742691D-13
         rk(116)=-0.1020920024582862D-08+(azi- 0.00D+00) * rk(116)
         rk(116)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(116)
         rk(116)= 0.6640000000000000D-05+(azi- 0.00D+00) * rk(116)
      elseif(azi.ge. 0.15D+02 .and. azi.lt. 0.30D+02) then
         rk(116)= 0.2604395278727706D-12
         rk(116)=-0.1024826617500946D-08+(azi- 0.15D+02) * rk(116)
         rk(116)=-0.3068619963125713D-07+(azi- 0.15D+02) * rk(116)
         rk(116)= 0.6410000000000000D-05+(azi- 0.15D+02) * rk(116)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.45D+02) then
         rk(116)=-0.9549449355338672D-12
         rk(116)=-0.1013106838746673D-08+(azi- 0.30D+02) * rk(116)
         rk(116)=-0.6125520147497143D-07+(azi- 0.30D+02) * rk(116)
         rk(116)= 0.5720000000000000D-05+(azi- 0.30D+02) * rk(116)
      elseif(azi.ge. 0.45D+02 .and. azi.lt. 0.60D+02) then
         rk(116)= 0.6522303177225098D-11
         rk(116)=-0.1056079360845699D-08+(azi- 0.45D+02) * rk(116)
         rk(116)=-0.9229299446885695D-07+(azi- 0.45D+02) * rk(116)
         rk(116)= 0.4570000000000000D-05+(azi- 0.45D+02) * rk(116)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk(116)= 0.2198577828307057D-10
         rk(116)=-0.7625757178705869D-09+(azi- 0.60D+02) * rk(116)
         rk(116)=-0.1195728206496012D-06+(azi- 0.60D+02) * rk(116)
         rk(116)= 0.2970000000000000D-05+(azi- 0.60D+02) * rk(116)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.75D+02) then
         rk(116)= 0.1897445347593964D-09
         rk(116)=-0.1030023693785656D-09+(azi- 0.70D+02) * rk(116)
         rk(116)=-0.1282286015220926D-06+(azi- 0.70D+02) * rk(116)
         rk(116)= 0.1720000000000000D-05+(azi- 0.70D+02) * rk(116)
      elseif(azi.ge. 0.75D+02 .and. azi.lt. 0.80D+02) then
         rk(116)=-0.1952172604562540D-10
         rk(116)= 0.2743165652012333D-08+(azi- 0.75D+02) * rk(116)
         rk(116)=-0.1150277851089213D-06+(azi- 0.75D+02) * rk(116)
         rk(116)= 0.1100000000000000D-05+(azi- 0.75D+02) * rk(116)
      elseif(azi.ge. 0.80D+02 .and. azi.lt. 0.83D+02) then
         rk(116)= 0.1158413435082285D-09
         rk(116)= 0.2450339761328123D-08+(azi- 0.80D+02) * rk(116)
         rk(116)=-0.8906025804221852D-07+(azi- 0.80D+02) * rk(116)
         rk(116)= 0.5910000000000000D-06+(azi- 0.80D+02) * rk(116)
      elseif(azi.ge. 0.83D+02 .and. azi.lt. 0.86D+02) then
         rk(116)= 0.4539001082388528D-09
         rk(116)= 0.3492911852905733D-08+(azi- 0.83D+02) * rk(116)
         rk(116)=-0.7123050319952390D-07+(azi- 0.83D+02) * rk(116)
         rk(116)= 0.3490000000000000D-06+(azi- 0.83D+02) * rk(116)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.88D+02) then
         rk(116)=-0.4159574123628927D-08
         rk(116)= 0.7578012827042183D-08+(azi- 0.86D+02) * rk(116)
         rk(116)=-0.3801772915965371D-07+(azi- 0.86D+02) * rk(116)
         rk(116)= 0.1790000000000000D-06+(azi- 0.86D+02) * rk(116)
      elseif(azi.ge. 0.88D+02 .and. azi.lt. 0.90D+02) then
         rk(116)= 0.1059485791616453D-07
         rk(116)=-0.1737943191478559D-07+(azi- 0.88D+02) * rk(116)
         rk(116)=-0.5762056733497268D-07+(azi- 0.88D+02) * rk(116)
         rk(116)= 0.1000000000000000D-06+(azi- 0.88D+02) * rk(116)
      elseif(azi.ge.90.D0)then
         rk(116)= 0.1000000000000000D-14
      endif
      if(att.lt.0.99999) rk(116) = rk(116) * att
C     
      
      RETURN
      END
      
