C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      subroutine fexchem(y,rk,ZCsourc,chem)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes the chemical production term for the
C     gas-phase mechanism MOCA.
C     This routine is automatically generated by SPACK.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     ZCSOURC: volumic emissions.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     CHEM: array of chemical production terms.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Karine Sartelet and Bruno Sportisse, CEREA, February 2002.
C     
C------------------------------------------------------------------------

      implicit none

C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMUSE: flags and parameters for numerics. 
C     PARADOM: parameters for all forced fields.

      include 'PARACHEM.INC' 
      INCLUDE 'PARADOM.INC' 
      INCLUDE 'COMUSE.INC' 

      integer                                             i
      double precision               w(nr),rk(nr),y(nesp),chem(nesp)
      double precision                                 ZCsourc(nesp)

      do i = 1,nesp
         chem(i) = 0.d0
      enddo

C     Chemical production terms.

      w(  1) =  rk(  1) * Y(  1) * Y(  3)
      chem(  1) = chem(  1) - w(  1)
      chem(  2) = chem(  2) + w(  1)
      chem(  3) = chem(  3) - w(  1)
      w(  2) =  rk(  2) * Y(  1) * Y(  2)
      chem(  1) = chem(  1) - w(  2)
      chem(  2) = chem(  2) - w(  2)
      chem( 14) = chem( 14) + w(  2)
      w(  3) =  rk(  3) * Y(  1) * Y( 12)
      chem(  1) = chem(  1) - w(  3)
      chem( 12) = chem( 12) - w(  3)
      chem( 13) = chem( 13) + w(  3)
      w(  4) =  rk(  4) * Y(  1) * Y( 13)
      chem(  1) = chem(  1) - w(  4)
      chem( 12) = chem( 12) + w(  4)
      chem( 13) = chem( 13) - w(  4)
      w(  5) =  rk(  5) * Y(  3) * Y( 14)
      chem(  2) = chem(  2) +  0.2000000000000000D+01 * w(  5)
      chem(  3) = chem(  3) - w(  5)
      chem( 14) = chem( 14) - w(  5)
      w(  6) =  rk(  6) * Y(  3) * Y( 13)
      chem(  2) = chem(  2) + w(  6)
      chem(  3) = chem(  3) - w(  6)
      chem( 12) = chem( 12) + w(  6)
      chem( 13) = chem( 13) - w(  6)
      w(  7) =  rk(  7) * Y(  2) * Y( 14)
      chem(  3) = chem(  3) + w(  7)
      chem( 14) = chem( 14) - w(  7)
      w(  8) =  rk(  8) * Y( 12) * Y( 13)
      chem( 12) = chem( 12) - w(  8)
      chem( 13) = chem( 13) - w(  8)
      w(  9) =  rk(  9) * Y( 12) * Y( 10)
      chem( 10) = chem( 10) - w(  9)
      chem( 12) = chem( 12) - w(  9)
      chem( 13) = chem( 13) + w(  9)
      w( 10) =  rk( 10) * Y( 13) * Y( 13)
      chem( 10) = chem( 10) + w( 10)
      chem( 13) = chem( 13) -  0.2000000000000000D+01 * w( 10)
      w( 11) =  rk( 11) * Y( 13) * Y( 13)
      chem( 10) = chem( 10) + w( 11)
      chem( 13) = chem( 13) -  0.2000000000000000D+01 * w( 11)
      w( 12) =  rk( 12) * Y( 14) * Y( 13)
      chem(  4) = chem(  4) + w( 12)
      chem( 13) = chem( 13) - w( 12)
      chem( 14) = chem( 14) - w( 12)
      w( 13) =  rk( 13) * Y( 14) * Y( 13)
      chem(  2) = chem(  2) + w( 13)
      chem( 12) = chem( 12) + w( 13)
      chem( 13) = chem( 13) - w( 13)
      chem( 14) = chem( 14) - w( 13)
      w( 14) =  rk( 14) * Y(  3) * Y(  3)
      chem(  2) = chem(  2) +  0.2000000000000000D+01 * w( 14)
      chem(  3) = chem(  3) -  0.2000000000000000D+01 * w( 14)
      w( 15) =  rk( 15) * Y( 12) * Y(  5)
      chem(  2) = chem(  2) + w( 15)
      chem(  5) = chem(  5) - w( 15)
      chem( 12) = chem( 12) - w( 15)
      w( 16) =  rk( 16) * Y( 12) * Y( 11)
      chem( 11) = chem( 11) - w( 16)
      chem( 12) = chem( 12) - w( 16)
      chem( 13) = chem( 13) + w( 16)
      w( 17) =  rk( 17) * Y( 12) * Y( 11)
      chem( 11) = chem( 11) - w( 17)
      chem( 12) = chem( 12) - w( 17)
      chem( 13) = chem( 13) + w( 17)
      w( 18) =  rk( 18) * Y(  3) * Y( 12)
      chem(  3) = chem(  3) - w( 18)
      chem(  6) = chem(  6) + w( 18)
      chem( 12) = chem( 12) - w( 18)
      w( 19) =  rk( 19) * Y(  2) * Y( 12)
      chem(  2) = chem(  2) - w( 19)
      chem(  4) = chem(  4) + w( 19)
      chem( 12) = chem( 12) - w( 19)
      w( 20) =  rk( 20) * Y(  2) * Y( 13)
      chem(  2) = chem(  2) - w( 20)
      chem(  5) = chem(  5) + w( 20)
      chem( 13) = chem( 13) - w( 20)
      w( 21) =  rk( 21) * Y(  5)
      chem(  2) = chem(  2) + w( 21)
      chem(  5) = chem(  5) - w( 21)
      chem( 13) = chem( 13) + w( 21)
      w( 22) =  rk( 22) * Y(  2) * Y( 14)
      chem(  2) = chem(  2) - w( 22)
      chem(  7) = chem(  7) + w( 22)
      chem( 14) = chem( 14) - w( 22)
      w( 23) =  rk( 23) * Y(  7)
      chem(  2) = chem(  2) + w( 23)
      chem(  7) = chem(  7) - w( 23)
      chem( 14) = chem( 14) + w( 23)
      w( 24) =  rk( 24) * Y( 12) * Y(  8)
      chem(  8) = chem(  8) - w( 24)
      chem(  9) = chem(  9) + w( 24)
      chem( 12) = chem( 12) - w( 24)
      chem( 13) = chem( 13) + w( 24)
      w( 25) =  rk( 25) * Y( 13) * Y( 13)
      chem( 10) = chem( 10) + w( 25)
      chem( 13) = chem( 13) -  0.2000000000000000D+01 * w( 25)
      w( 26) =  rk( 26) * Y(  7)
      chem(  4) = chem(  4) +  0.2000000000000000D+01 * w( 26)
      chem(  7) = chem(  7) - w( 26)
      w( 27) =  rk( 27) * Y(  1)
      chem(  1) = chem(  1) - w( 27)
      chem( 12) = chem( 12) +  0.2000000000000000D+01 * w( 27)
      w( 28) =  rk( 28) * Y(  2)
      chem(  1) = chem(  1) + w( 28)
      chem(  2) = chem(  2) - w( 28)
      chem(  3) = chem(  3) + w( 28)
      w( 29) =  rk( 29) * Y( 10)
      chem( 10) = chem( 10) - w( 29)
      chem( 12) = chem( 12) +  0.2000000000000000D+01 * w( 29)
      w( 30) =  rk( 30) * Y( 14)
      chem(  3) = chem(  3) + w( 30)
      chem( 14) = chem( 14) - w( 30)
      w( 31) =  rk( 31) * Y( 14)
      chem(  1) = chem(  1) + w( 31)
      chem(  2) = chem(  2) + w( 31)
      chem( 14) = chem( 14) - w( 31)
      w( 32) =  rk( 32) * Y(  6)
      chem(  3) = chem(  3) + w( 32)
      chem(  6) = chem(  6) - w( 32)
      chem( 12) = chem( 12) + w( 32)
      w( 33) =  rk( 33) * Y( 34) * Y(  3)
      chem(  2) = chem(  2) + w( 33)
      chem(  3) = chem(  3) - w( 33)
      chem( 13) = chem( 13) + w( 33)
      chem( 34) = chem( 34) - w( 33)
      w( 34) =  rk( 34) * Y( 34) * Y( 13)
      chem( 13) = chem( 13) - w( 34)
      chem( 33) = chem( 33) + w( 34)
      chem( 34) = chem( 34) - w( 34)
      w( 35) =  rk( 35) * Y( 37) * Y(  3)
      chem(  3) = chem(  3) - w( 35)
      chem( 31) = chem( 31) + w( 35)
      chem( 37) = chem( 37) - w( 35)
      w( 36) =  rk( 36) * Y( 37) * Y( 13)
      chem( 13) = chem( 13) - w( 36)
      chem( 33) = chem( 33) + w( 36)
      chem( 37) = chem( 37) - w( 36)
      w( 37) =  rk( 37) * Y( 35) * Y(  3)
      chem(  2) = chem(  2) + w( 37)
      chem(  3) = chem(  3) - w( 37)
      chem( 34) = chem( 34) + w( 37)
      chem( 35) = chem( 35) - w( 37)
      w( 38) =  rk( 38) * Y( 35) * Y( 13)
      chem( 13) = chem( 13) - w( 38)
      chem( 33) = chem( 33) + w( 38)
      chem( 35) = chem( 35) - w( 38)
      w( 39) =  rk( 39) * Y( 38) * Y(  3)
      chem(  3) = chem(  3) - w( 39)
      chem( 32) = chem( 32) + w( 39)
      chem( 38) = chem( 38) - w( 39)
      w( 40) =  rk( 40) * Y( 38) * Y( 13)
      chem( 13) = chem( 13) - w( 40)
      chem( 33) = chem( 33) + w( 40)
      chem( 38) = chem( 38) - w( 40)
      w( 41) =  rk( 41) * Y( 36) * Y(  3)
      chem(  2) = chem(  2) + w( 41)
      chem(  3) = chem(  3) - w( 41)
      chem( 36) = chem( 36) - w( 41)
      w( 42) =  rk( 42) * Y( 36) * Y( 13)
      chem( 13) = chem( 13) - w( 42)
      chem( 33) = chem( 33) + w( 42)
      chem( 36) = chem( 36) - w( 42)
      w( 43) =  rk( 43) * Y( 12) * Y( 15)
      chem( 11) = chem( 11) + w( 43)
      chem( 12) = chem( 12) - w( 43)
      chem( 13) = chem( 13) + w( 43)
      chem( 15) = chem( 15) - w( 43)
      w( 44) =  rk( 44) * Y( 12) * Y( 16)
      chem( 12) = chem( 12) - w( 44)
      chem( 16) = chem( 16) - w( 44)
      chem( 39) = chem( 39) + w( 44)
      w( 45) =  rk( 45) * Y( 39) * Y(  3)
      chem(  2) = chem(  2) + w( 45)
      chem(  3) = chem(  3) - w( 45)
      chem( 15) = chem( 15) + w( 45)
      chem( 34) = chem( 34) + w( 45)
      chem( 39) = chem( 39) - w( 45)
      w( 46) =  rk( 46) * Y( 13) * Y( 39)
      chem(  1) = chem(  1) +  0.3000000000000000D+00 * w( 46)
      chem( 13) = chem( 13) - w( 46)
      chem( 33) = chem( 33) +  0.7000000000000000D+00 * w( 46)
      chem( 39) = chem( 39) - w( 46)
      w( 47) =  rk( 47) * Y( 17) * Y( 12)
      chem( 12) = chem( 12) - w( 47)
      chem( 17) = chem( 17) - w( 47)
      chem( 40) = chem( 40) + w( 47)
      w( 48) =  rk( 48) * Y( 40) * Y(  3)
      chem(  2) = chem(  2) + w( 48)
      chem(  3) = chem(  3) - w( 48)
      chem( 16) = chem( 16) + w( 48)
      chem( 34) = chem( 34) + w( 48)
      chem( 40) = chem( 40) - w( 48)
      w( 49) =  rk( 49) * Y( 40) * Y( 13)
      chem(  1) = chem(  1) +  0.3000000000000000D+00 * w( 49)
      chem( 13) = chem( 13) - w( 49)
      chem( 33) = chem( 33) +  0.7000000000000000D+00 * w( 49)
      chem( 40) = chem( 40) - w( 49)
      w( 50) =  rk( 50) * Y( 40) * Y(  2)
      chem(  2) = chem(  2) - w( 50)
      chem( 28) = chem( 28) + w( 50)
      chem( 40) = chem( 40) - w( 50)
      w( 51) =  rk( 51) * Y( 28)
      chem(  2) = chem(  2) + w( 51)
      chem( 28) = chem( 28) - w( 51)
      chem( 40) = chem( 40) + w( 51)
      w( 52) =  rk( 52) * Y( 12) * Y( 18)
      chem( 12) = chem( 12) - w( 52)
      chem( 15) = chem( 15) +  0.2000000000000000D+00 * w( 52)
      chem( 18) = chem( 18) - w( 52)
      chem( 22) = chem( 22) +  0.8000000000000000D+00 * w( 52)
      chem( 34) = chem( 34) +  0.8000000000000000D+00 * w( 52)
      chem( 36) = chem( 36) +  0.2000000000000000D+00 * w( 52)
      chem( 39) = chem( 39) +  0.2000000000000000D+00 * w( 52)
      w( 53) =  rk( 53) * Y( 12) * Y( 19)
      chem( 12) = chem( 12) - w( 53)
      chem( 15) = chem( 15) +  0.5000000000000000D+00 * w( 53)
      chem( 16) = chem( 16) +  0.5000000000000000D+00 * w( 53)
      chem( 19) = chem( 19) - w( 53)
      chem( 36) = chem( 36) +  0.1500000000000000D+01 * w( 53)
      chem( 39) = chem( 39) +  0.5000000000000000D+00 * w( 53)
      chem( 40) = chem( 40) +  0.5000000000000000D+00 * w( 53)
      w( 54) =  rk( 54) * Y( 12) * Y( 26)
      chem( 12) = chem( 12) - w( 54)
      chem( 22) = chem( 22) +  0.2000000000000000D+00 * w( 54)
      chem( 26) = chem( 26) - w( 54)
      chem( 34) = chem( 34) +  0.8500000000000000D+00 * w( 54)
      chem( 38) = chem( 38) +  0.1500000000000000D+00 * w( 54)
      w( 55) =  rk( 55) * Y( 14) * Y( 26)
      chem(  4) = chem(  4) + w( 55)
      chem( 14) = chem( 14) - w( 55)
      chem( 26) = chem( 26) - w( 55)
      chem( 45) = chem( 45) + w( 55)
      w( 56) =  rk( 56) * Y( 12) * Y( 25)
      chem( 12) = chem( 12) - w( 56)
      chem( 21) = chem( 21) +  0.2000000000000000D+00 * w( 56)
      chem( 25) = chem( 25) - w( 56)
      chem( 34) = chem( 34) +  0.8500000000000000D+00 * w( 56)
      chem( 38) = chem( 38) +  0.1500000000000000D+00 * w( 56)
      w( 57) =  rk( 57) * Y( 14) * Y( 25)
      chem(  4) = chem(  4) + w( 57)
      chem( 14) = chem( 14) - w( 57)
      chem( 25) = chem( 25) - w( 57)
      chem( 45) = chem( 45) + w( 57)
      w( 58) =  rk( 58) * Y( 20) * Y( 12)
      chem( 12) = chem( 12) - w( 58)
      chem( 20) = chem( 20) - w( 58)
      chem( 42) = chem( 42) + w( 58)
      w( 59) =  rk( 59) * Y( 42) * Y(  3)
      chem(  2) = chem(  2) + w( 59)
      chem(  3) = chem(  3) - w( 59)
      chem( 42) = chem( 42) - w( 59)
      chem( 44) = chem( 44) + w( 59)
      w( 60) =  rk( 60) * Y( 42) * Y( 13)
      chem(  1) = chem(  1) +  0.3000000000000000D+00 * w( 60)
      chem( 13) = chem( 13) - w( 60)
      chem( 33) = chem( 33) +  0.7000000000000000D+00 * w( 60)
      chem( 42) = chem( 42) - w( 60)
      w( 61) =  rk( 61) * Y( 42) * Y(  2)
      chem(  2) = chem(  2) - w( 61)
      chem( 29) = chem( 29) + w( 61)
      chem( 42) = chem( 42) - w( 61)
      w( 62) =  rk( 62) * Y( 29)
      chem(  2) = chem(  2) + w( 62)
      chem( 29) = chem( 29) - w( 62)
      chem( 42) = chem( 42) + w( 62)
      w( 63) =  rk( 63) * Y( 44) * Y(  3)
      chem(  2) = chem(  2) + w( 63)
      chem(  3) = chem(  3) - w( 63)
      chem( 44) = chem( 44) - w( 63)
      chem( 45) = chem( 45) + w( 63)
      w( 64) =  rk( 64) * Y( 44) * Y( 13)
      chem( 13) = chem( 13) - w( 64)
      chem( 33) = chem( 33) + w( 64)
      chem( 44) = chem( 44) - w( 64)
      w( 65) =  rk( 65) * Y( 45) * Y(  2)
      chem(  2) = chem(  2) - w( 65)
      chem( 32) = chem( 32) + w( 65)
      chem( 45) = chem( 45) - w( 65)
      w( 66) =  rk( 66) * Y( 45) * Y( 13)
      chem( 13) = chem( 13) - w( 66)
      chem( 25) = chem( 25) + w( 66)
      chem( 45) = chem( 45) - w( 66)
      w( 67) =  rk( 67) * Y( 45)
      chem( 25) = chem( 25) + w( 67)
      chem( 45) = chem( 45) - w( 67)
      w( 68) =  rk( 68) * Y( 32) * Y( 14)
      chem(  4) = chem(  4) + w( 68)
      chem( 14) = chem( 14) - w( 68)
      chem( 32) = chem( 32) - w( 68)
      chem( 46) = chem( 46) + w( 68)
      w( 69) =  rk( 69) * Y( 46) * Y(  2)
      chem(  2) = chem(  2) - w( 69)
      chem( 46) = chem( 46) - w( 69)
      w( 70) =  rk( 70) * Y( 46) * Y( 13)
      chem( 13) = chem( 13) - w( 70)
      chem( 32) = chem( 32) + w( 70)
      chem( 46) = chem( 46) - w( 70)
      w( 71) =  rk( 71) * Y( 46)
      chem( 32) = chem( 32) + w( 71)
      chem( 46) = chem( 46) - w( 71)
      w( 72) =  rk( 72) * Y( 24) * Y( 12)
      chem( 12) = chem( 12) - w( 72)
      chem( 24) = chem( 24) - w( 72)
      chem( 41) = chem( 41) + w( 72)
      w( 73) =  rk( 73) * Y( 23) * Y( 12)
      chem( 12) = chem( 12) - w( 73)
      chem( 23) = chem( 23) - w( 73)
      chem( 40) = chem( 40) + w( 73)
      w( 74) =  rk( 74) * Y( 21) * Y( 12)
      chem( 11) = chem( 11) +  0.1200000000000000D+01 * w( 74)
      chem( 12) = chem( 12) - w( 74)
      chem( 13) = chem( 13) +  0.6000000000000000D+00 * w( 74)
      chem( 21) = chem( 21) - w( 74)
      chem( 41) = chem( 41) +  0.4000000000000000D+00 * w( 74)
      w( 75) =  rk( 75) * Y( 41) * Y(  3)
      chem(  2) = chem(  2) + w( 75)
      chem(  3) = chem(  3) - w( 75)
      chem( 11) = chem( 11) + w( 75)
      chem( 13) = chem( 13) + w( 75)
      chem( 41) = chem( 41) - w( 75)
      w( 76) =  rk( 76) * Y( 41) * Y( 13)
      chem(  1) = chem(  1) +  0.3000000000000000D+00 * w( 76)
      chem( 13) = chem( 13) - w( 76)
      chem( 33) = chem( 33) +  0.7000000000000000D+00 * w( 76)
      chem( 41) = chem( 41) - w( 76)
      w( 77) =  rk( 77) * Y( 22) * Y( 12)
      chem( 11) = chem( 11) + w( 77)
      chem( 12) = chem( 12) - w( 77)
      chem( 22) = chem( 22) - w( 77)
      chem( 39) = chem( 39) + w( 77)
      w( 78) =  rk( 78) * Y( 47) * Y(  8)
      chem(  8) = chem(  8) - w( 78)
      chem(  9) = chem(  9) + w( 78)
      chem( 47) = chem( 47) - w( 78)
      w( 79) =  rk( 79) * Y( 33) * Y( 12)
      chem( 33) = chem( 33) - w( 79)
      w( 80) =  rk( 80) * Y( 33) * Y( 12)
      chem( 12) = chem( 12) - w( 80)
      chem( 33) = chem( 33) - w( 80)
      chem( 34) = chem( 34) + w( 80)
      w( 81) =  rk( 81) * Y( 31) * Y( 12)
      chem(  2) = chem(  2) + w( 81)
      chem( 12) = chem( 12) - w( 81)
      chem( 15) = chem( 15) +  0.1600000000000000D+00 * w( 81)
      chem( 16) = chem( 16) +  0.4800000000000000D+00 * w( 81)
      chem( 17) = chem( 17) +  0.1050000000000000D+01 * w( 81)
      chem( 19) = chem( 19) +  0.1550000000000000D+00 * w( 81)
      chem( 31) = chem( 31) - w( 81)
      chem( 36) = chem( 36) +  0.1390000000000000D+01 * w( 81)
      w( 82) =  rk( 82) * Y( 39) * Y(  2)
      chem(  2) = chem(  2) - w( 82)
      chem( 27) = chem( 27) + w( 82)
      chem( 39) = chem( 39) - w( 82)
      w( 83) =  rk( 83) * Y( 27)
      chem(  2) = chem(  2) + w( 83)
      chem( 27) = chem( 27) - w( 83)
      chem( 39) = chem( 39) + w( 83)
      w( 84) =  rk( 84) * Y( 41) * Y(  2)
      chem(  2) = chem(  2) - w( 84)
      chem( 30) = chem( 30) + w( 84)
      chem( 41) = chem( 41) - w( 84)
      w( 85) =  rk( 85) * Y( 30)
      chem(  2) = chem(  2) + w( 85)
      chem( 30) = chem( 30) - w( 85)
      chem( 41) = chem( 41) + w( 85)
      w( 86) =  rk( 86) * Y( 15)
      chem( 11) = chem( 11) + w( 86)
      chem( 13) = chem( 13) +  0.2000000000000000D+01 * w( 86)
      chem( 15) = chem( 15) - w( 86)
      w( 87) =  rk( 87) * Y( 15)
      chem( 11) = chem( 11) + w( 87)
      chem( 15) = chem( 15) - w( 87)
      w( 88) =  rk( 88) * Y( 16)
      chem( 11) = chem( 11) + w( 88)
      chem( 13) = chem( 13) + w( 88)
      chem( 15) = chem( 15) + w( 88)
      chem( 16) = chem( 16) - w( 88)
      chem( 34) = chem( 34) + w( 88)
      w( 89) =  rk( 89) * Y( 17)
      chem( 11) = chem( 11) + w( 89)
      chem( 13) = chem( 13) + w( 89)
      chem( 16) = chem( 16) + w( 89)
      chem( 17) = chem( 17) - w( 89)
      chem( 34) = chem( 34) + w( 89)
      w( 90) =  rk( 90) * Y( 18)
      chem( 15) = chem( 15) + w( 90)
      chem( 18) = chem( 18) - w( 90)
      chem( 34) = chem( 34) + w( 90)
      chem( 39) = chem( 39) + w( 90)
      w( 91) =  rk( 91) * Y( 19)
      chem( 16) = chem( 16) + w( 91)
      chem( 19) = chem( 19) - w( 91)
      chem( 34) = chem( 34) + w( 91)
      chem( 39) = chem( 39) + w( 91)
      w( 92) =  rk( 92) * Y( 21)
      chem( 11) = chem( 11) +  0.1550000000000000D+01 * w( 92)
      chem( 13) = chem( 13) +  0.8000000000000000D+00 * w( 92)
      chem( 15) = chem( 15) +  0.4500000000000000D+00 * w( 92)
      chem( 21) = chem( 21) - w( 92)
      w( 93) =  rk( 93) * Y( 21)
      chem( 11) = chem( 11) +  0.1870000000000000D+01 * w( 93)
      chem( 15) = chem( 15) +  0.1300000000000000D+00 * w( 93)
      chem( 21) = chem( 21) - w( 93)
      w( 94) =  rk( 94) * Y( 22)
      chem( 11) = chem( 11) + w( 94)
      chem( 13) = chem( 13) + w( 94)
      chem( 22) = chem( 22) - w( 94)
      chem( 39) = chem( 39) + w( 94)
      w( 95) =  rk( 95) * Y( 24)
      chem( 13) = chem( 13) + w( 95)
      chem( 24) = chem( 24) - w( 95)
      chem( 41) = chem( 41) + w( 95)
      w( 96) =  rk( 96) * Y( 23)
      chem( 11) = chem( 11) + w( 96)
      chem( 13) = chem( 13) + w( 96)
      chem( 23) = chem( 23) - w( 96)
      chem( 39) = chem( 39) + w( 96)
      w( 97) =  rk( 97) * Y( 20)
      chem( 20) = chem( 20) - w( 97)
      w( 98) =  rk( 98) * Y( 33)
      chem( 12) = chem( 12) + w( 98)
      chem( 13) = chem( 13) + w( 98)
      chem( 33) = chem( 33) - w( 98)
      w( 99) =  rk( 99) * Y( 31)
      chem(  2) = chem(  2) + w( 99)
      chem( 13) = chem( 13) +  0.5030000000000000D+00 * w( 99)
      chem( 16) = chem( 16) +  0.1190000000000000D+00 * w( 99)
      chem( 19) = chem( 19) +  0.1315000000000000D+01 * w( 99)
      chem( 31) = chem( 31) - w( 99)
      chem( 34) = chem( 34) +  0.4970000000000000D+00 * w( 99)
      w(100) =  rk(100) * Y( 48) * Y( 12)
      chem( 12) = chem( 12) - w(100)
      chem( 15) = chem( 15) + w(100)
      chem( 34) = chem( 34) + w(100)
      chem( 48) = chem( 48) - w(100)
      w(101) =  rk(101) * Y( 49) * Y( 12)
      chem( 12) = chem( 12) - w(101)
      chem( 16) = chem( 16) + w(101)
      chem( 34) = chem( 34) + w(101)
      chem( 49) = chem( 49) - w(101)
      w(102) =  rk(102) * Y( 50) * Y( 12)
      chem( 12) = chem( 12) - w(102)
      chem( 50) = chem( 50) - w(102)
      w(103) =  rk(103) * Y( 50) * Y( 12)
      chem( 15) = chem( 15) + w(103)
      chem( 16) = chem( 16) + w(103)
      chem( 35) = chem( 35) + w(103)
      w(104) =  rk(104) * Y( 50) * Y( 12)
      chem( 17) = chem( 17) + w(104)
      w(105) =  rk(105) * Y( 50) * Y( 12)
      chem( 18) = chem( 18) + w(105)
      w(106) =  rk(106) * Y( 50) * Y( 12)
      chem( 34) = chem( 34) + w(106)
      w(107) =  rk(107) * Y( 50) * Y( 12)
      chem( 37) = chem( 37) + w(107)
      w(108) =  rk(108) * Y( 51) * Y( 12)
      chem( 12) = chem( 12) - w(108)
      chem( 34) = chem( 34) + w(108)
      chem( 51) = chem( 51) - w(108)
      w(109) =  rk(109) * Y( 51) * Y( 12)
      chem( 15) = chem( 15) + w(109)
      w(110) =  rk(110) * Y( 51) * Y( 12)
      chem( 16) = chem( 16) + w(110)
      w(111) =  rk(111) * Y( 51) * Y(  1)
      chem(  1) = chem(  1) - w(111)
      chem( 11) = chem( 11) +  0.4400000000000000D+00 * w(111)
      chem( 13) = chem( 13) +  0.1200000000000000D+00 * w(111)
      chem( 15) = chem( 15) + w(111)
      chem( 47) = chem( 47) +  0.3700000000000000D+00 * w(111)
      chem( 51) = chem( 51) - w(111)
      w(112) =  rk(112) * Y( 52) * Y( 12)
      chem( 12) = chem( 12) - w(112)
      chem( 15) = chem( 15) + w(112)
      chem( 16) = chem( 16) + w(112)
      chem( 34) = chem( 34) + w(112)
      chem( 52) = chem( 52) - w(112)
      w(113) =  rk(113) * Y( 52) * Y(  1)
      chem(  1) = chem(  1) - w(113)
      chem( 11) = chem( 11) +  0.4000000000000000D+00 * w(113)
      chem( 12) = chem( 12) +  0.1500000000000000D+00 * w(113)
      chem( 13) = chem( 13) +  0.2800000000000000D+00 * w(113)
      chem( 15) = chem( 15) +  0.8400000000000001D+00 * w(113)
      chem( 16) = chem( 16) +  0.5000000000000000D+00 * w(113)
      chem( 34) = chem( 34) +  0.3100000000000000D+00 * w(113)
      chem( 47) = chem( 47) +  0.2250000000000000D+00 * w(113)
      chem( 48) = chem( 48) +  0.7000000000000001D-01 * w(113)
      chem( 52) = chem( 52) - w(113)
      w(114) =  rk(114) * Y( 53) * Y( 12)
      chem( 12) = chem( 12) - w(114)
      chem( 15) = chem( 15) + w(114)
      chem( 17) = chem( 17) + w(114)
      chem( 34) = chem( 34) + w(114)
      chem( 53) = chem( 53) - w(114)
      w(115) =  rk(115) * Y( 53) * Y(  1)
      chem(  1) = chem(  1) - w(115)
      chem( 11) = chem( 11) +  0.4000000000000000D+00 * w(115)
      chem( 12) = chem( 12) +  0.1500000000000000D+00 * w(115)
      chem( 13) = chem( 13) +  0.2800000000000000D+00 * w(115)
      chem( 15) = chem( 15) +  0.5000000000000000D+00 * w(115)
      chem( 16) = chem( 16) +  0.3400000000000000D+00 * w(115)
      chem( 17) = chem( 17) +  0.5000000000000000D+00 * w(115)
      chem( 34) = chem( 34) +  0.3100000000000000D+00 * w(115)
      chem( 47) = chem( 47) +  0.2750000000000000D+00 * w(115)
      chem( 49) = chem( 49) +  0.7000000000000001D-01 * w(115)
      chem( 53) = chem( 53) - w(115)
      w(116) =  rk(116) * Y( 53) * Y( 14)
      chem(  2) = chem(  2) + w(116)
      chem( 14) = chem( 14) - w(116)
      chem( 15) = chem( 15) + w(116)
      chem( 17) = chem( 17) + w(116)
      chem( 36) = chem( 36) + w(116)
      chem( 53) = chem( 53) - w(116)
      w(117) =  rk(117) * Y( 54) * Y( 12)
      chem( 11) = chem( 11) +  0.3600000000000000D+00 * w(117)
      chem( 12) = chem( 12) -  0.3600000000000000D+00 * w(117)
      chem( 13) = chem( 13) +  0.3600000000000000D+00 * w(117)
      chem( 21) = chem( 21) +  0.6400000000000000D+00 * w(117)
      chem( 54) = chem( 54) - w(117)
      w(118) =  rk(118) * Y( 55) * Y( 12)
      chem( 12) = chem( 12) - w(118)
      chem( 13) = chem( 13) +  0.2360000000000000D+00 * w(118)
      chem( 21) = chem( 21) +  0.2070000000000000D+00 * w(118)
      chem( 24) = chem( 24) +  0.4900000000000000D+00 * w(118)
      chem( 25) = chem( 25) +  0.2360000000000000D+00 * w(118)
      chem( 34) = chem( 34) +  0.7640000000000000D+00 * w(118)
      chem( 55) = chem( 55) - w(118)
      w(119) =  rk(119) * Y( 56) * Y( 12)
      chem( 12) = chem( 12) - w(119)
      chem( 15) = chem( 15) + w(119)
      chem( 20) = chem( 20) + w(119)
      chem( 34) = chem( 34) + w(119)
      chem( 56) = chem( 56) - w(119)
      w(120) =  rk(120) * Y( 57) * Y( 12)
      chem( 12) = chem( 12) - w(120)
      chem( 13) = chem( 13) + w(120)
      chem( 15) = chem( 15) + w(120)
      chem( 57) = chem( 57) - w(120)
      w(121) =  rk(121) * Y( 58) * Y( 12)
      chem( 12) = chem( 12) - w(121)
      chem( 13) = chem( 13) + w(121)
      chem( 16) = chem( 16) + w(121)
      chem( 58) = chem( 58) - w(121)
      w(122) =  rk(122) * Y( 59) * Y( 12)
      chem( 12) = chem( 12) - w(122)
      chem( 59) = chem( 59) - w(122)
      w(123) =  rk(123) * Y( 59) * Y( 12)
      chem( 15) = chem( 15) + w(123)
      w(124) =  rk(124) * Y( 59) * Y( 12)
      chem( 16) = chem( 16) + w(124)
      w(125) =  rk(125) * Y( 59) * Y( 12)
      chem( 17) = chem( 17) + w(125)
      w(126) =  rk(126) * Y( 59) * Y( 12)
      chem( 18) = chem( 18) + w(126)
      w(127) =  rk(127) * Y( 59) * Y( 12)
      chem( 19) = chem( 19) + w(127)
      w(128) =  rk(128) * Y( 59) * Y( 12)
      chem( 34) = chem( 34) + w(128)
      w(129) =  rk(129) * Y( 59) * Y( 12)
      chem( 35) = chem( 35) + w(129)
      w(130) =  rk(130) * Y( 59) * Y( 12)
      chem( 36) = chem( 36) + w(130)
      w(131) =  rk(131) * Y( 59) * Y( 12)
      chem( 37) = chem( 37) + w(131)
      w(132) =  rk(132) * Y( 60) * Y( 12)
      chem( 12) = chem( 12) - w(132)
      chem( 60) = chem( 60) - w(132)
      w(133) =  rk(133) * Y( 60) * Y( 12)
      chem( 15) = chem( 15) + w(133)
      w(134) =  rk(134) * Y( 60) * Y( 12)
      chem( 16) = chem( 16) + w(134)
      w(135) =  rk(135) * Y( 60) * Y( 12)
      chem( 17) = chem( 17) + w(135)
      w(136) =  rk(136) * Y( 60) * Y( 12)
      chem( 18) = chem( 18) + w(136)
      w(137) =  rk(137) * Y( 60) * Y( 12)
      chem( 19) = chem( 19) + w(137)
      w(138) =  rk(138) * Y( 60) * Y( 12)
      chem( 34) = chem( 34) + w(138)
      w(139) =  rk(139) * Y( 60) * Y( 12)
      chem( 35) = chem( 35) + w(139)
      w(140) =  rk(140) * Y( 60) * Y( 12)
      chem( 36) = chem( 36) + w(140)
      w(141) =  rk(141) * Y( 60) * Y( 12)
      chem( 37) = chem( 37) + w(141)
      w(142) =  rk(142) * Y( 61) * Y( 12)
      chem( 12) = chem( 12) - w(142)
      chem( 61) = chem( 61) - w(142)
      w(143) =  rk(143) * Y( 61) * Y( 12)
      chem( 15) = chem( 15) + w(143)
      w(144) =  rk(144) * Y( 61) * Y( 12)
      chem( 16) = chem( 16) + w(144)
      w(145) =  rk(145) * Y( 61) * Y( 12)
      chem( 17) = chem( 17) + w(145)
      w(146) =  rk(146) * Y( 61) * Y( 12)
      chem( 18) = chem( 18) + w(146)
      w(147) =  rk(147) * Y( 61) * Y( 12)
      chem( 19) = chem( 19) + w(147)
      w(148) =  rk(148) * Y( 61) * Y( 12)
      chem( 34) = chem( 34) + w(148)
      w(149) =  rk(149) * Y( 61) * Y( 12)
      chem( 35) = chem( 35) + w(149)
      w(150) =  rk(150) * Y( 61) * Y( 12)
      chem( 36) = chem( 36) + w(150)
      w(151) =  rk(151) * Y( 61) * Y( 12)
      chem( 37) = chem( 37) + w(151)
      w(152) =  rk(152) * Y( 62) * Y( 12)
      chem( 12) = chem( 12) - w(152)
      chem( 15) = chem( 15) +  0.9270000000000000D+00 * w(152)
      chem( 17) = chem( 17) +  0.9270000000000000D+00 * w(152)
      chem( 34) = chem( 34) +  0.9270000000000000D+00 * w(152)
      chem( 37) = chem( 37) +  0.7300000000000000D-01 * w(152)
      chem( 62) = chem( 62) - w(152)
      w(153) =  rk(153) * Y( 62) * Y(  1)
      chem(  1) = chem(  1) - w(153)
      chem( 11) = chem( 11) +  0.4000000000000000D+00 * w(153)
      chem( 12) = chem( 12) +  0.1500000000000000D+00 * w(153)
      chem( 13) = chem( 13) +  0.2800000000000000D+00 * w(153)
      chem( 15) = chem( 15) +  0.5000000000000000D+00 * w(153)
      chem( 16) = chem( 16) +  0.3400000000000000D+00 * w(153)
      chem( 17) = chem( 17) +  0.5000000000000000D+00 * w(153)
      chem( 34) = chem( 34) +  0.3100000000000000D+00 * w(153)
      chem( 47) = chem( 47) +  0.2750000000000000D+00 * w(153)
      chem( 49) = chem( 49) +  0.7000000000000001D-01 * w(153)
      chem( 62) = chem( 62) - w(153)
      w(154) =  rk(154) * Y( 62) * Y( 14)
      chem(  2) = chem(  2) + w(154)
      chem( 14) = chem( 14) - w(154)
      chem( 15) = chem( 15) + w(154)
      chem( 17) = chem( 17) + w(154)
      chem( 36) = chem( 36) + w(154)
      chem( 62) = chem( 62) - w(154)
      w(155) =  rk(155) * Y( 63) * Y( 12)
      chem( 12) = chem( 12) - w(155)
      chem( 15) = chem( 15) +  0.2500000000000000D+00 * w(155)
      chem( 16) = chem( 16) +  0.1178000000000000D+01 * w(155)
      chem( 17) = chem( 17) +  0.2010000000000000D+00 * w(155)
      chem( 18) = chem( 18) +  0.2500000000000000D+00 * w(155)
      chem( 19) = chem( 19) +  0.7600000000000000D-01 * w(155)
      chem( 34) = chem( 34) +  0.9780000000000000D+00 * w(155)
      chem( 37) = chem( 37) +  0.2200000000000000D-01 * w(155)
      chem( 63) = chem( 63) - w(155)
      w(156) =  rk(156) * Y( 63) * Y(  1)
      chem(  1) = chem(  1) - w(156)
      chem( 15) = chem( 15) +  0.5090000000000000D+00 * w(156)
      chem( 16) = chem( 16) +  0.8280000000000000D+00 * w(156)
      chem( 17) = chem( 17) +  0.1420000000000000D+00 * w(156)
      chem( 18) = chem( 18) +  0.1180000000000000D+00 * w(156)
      chem( 19) = chem( 19) +  0.9800000000000000D-01 * w(156)
      chem( 22) = chem( 22) +  0.1900000000000000D-01 * w(156)
      chem( 39) = chem( 39) +  0.5000000000000000D-02 * w(156)
      chem( 47) = chem( 47) +  0.1600000000000000D+00 * w(156)
      chem( 63) = chem( 63) - w(156)
      w(157) =  rk(157) * Y( 63) * Y(  1)
      chem( 11) = chem( 11) +  0.3170000000000000D+00 * w(157)
      chem( 12) = chem( 12) +  0.2860000000000000D+00 * w(157)
      chem( 13) = chem( 13) +  0.3850000000000000D+00 * w(157)
      chem( 34) = chem( 34) +  0.5600000000000001D+00 * w(157)
      chem( 36) = chem( 36) +  0.5000000000000000D-02 * w(157)
      chem( 48) = chem( 48) +  0.1020000000000000D+00 * w(157)
      chem( 49) = chem( 49) +  0.2000000000000000D-01 * w(157)
      w(158) =  rk(158) * Y( 63) * Y( 14)
      chem(  2) = chem(  2) + w(158)
      chem( 14) = chem( 14) - w(158)
      chem( 15) = chem( 15) +  0.5600000000000000D-01 * w(158)
      chem( 16) = chem( 16) +  0.1122000000000000D+01 * w(158)
      chem( 17) = chem( 17) +  0.6000000000000000D-01 * w(158)
      chem( 18) = chem( 18) +  0.7460000000000000D+00 * w(158)
      chem( 19) = chem( 19) +  0.1700000000000000D-01 * w(158)
      chem( 36) = chem( 36) + w(158)
      chem( 63) = chem( 63) - w(158)
      w(159) =  rk(159) * Y( 64) * Y( 12)
      chem( 12) = chem( 12) - w(159)
      chem( 13) = chem( 13) +  0.2600000000000000D+00 * w(159)
      chem( 20) = chem( 20) +  0.7700000000000000D-01 * w(159)
      chem( 21) = chem( 21) +  0.1180000000000000D+00 * w(159)
      chem( 22) = chem( 22) +  0.1310000000000000D+00 * w(159)
      chem( 23) = chem( 23) +  0.4100000000000000D+00 * w(159)
      chem( 26) = chem( 26) +  0.2600000000000000D+00 * w(159)
      chem( 34) = chem( 34) +  0.7320000000000000D+00 * w(159)
      chem( 64) = chem( 64) - w(159)
      w(160) =  rk(160) * Y( 65) * Y( 12)
      chem( 12) = chem( 12) - w(160)
      chem( 13) = chem( 13) +  0.1800000000000000D+00 * w(160)
      chem( 20) = chem( 20) +  0.3400000000000000D-01 * w(160)
      chem( 21) = chem( 21) +  0.8000000000000000D-01 * w(160)
      chem( 22) = chem( 22) +  0.4340000000000000D+00 * w(160)
      chem( 23) = chem( 23) +  0.6490000000000000D+00 * w(160)
      chem( 26) = chem( 26) +  0.1800000000000000D+00 * w(160)
      chem( 34) = chem( 34) +  0.8169999999999999D+00 * w(160)
      chem( 65) = chem( 65) - w(160)
      w(161) =  rk(161) * Y( 66) * Y( 12)
      chem( 12) = chem( 12) - w(161)
      chem( 13) = chem( 13) +  0.7960000000000000D+00 * w(161)
      chem( 16) = chem( 16) +  0.6200000000000000D-01 * w(161)
      chem( 17) = chem( 17) +  0.3950000000000000D+00 * w(161)
      chem( 18) = chem( 18) +  0.1780000000000000D+00 * w(161)
      chem( 19) = chem( 19) +  0.2710000000000000D+00 * w(161)
      chem( 34) = chem( 34) +  0.2040000000000000D+00 * w(161)
      chem( 66) = chem( 66) - w(161)

C     Volumic source terms.

      IF(LSOURC) then
         do i=1,nesp
            chem(i)=chem(i)+ZCsourc(i)
         enddo
      endif

      END

