C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      subroutine jacdchemdc(y,rk,JacC)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes the Jacobian Matrix for the
C     gas-phase mechanism MOCA.
C     This routine is automatically generated by SPACK.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     JACC: Jacobian matrix.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C     The matrix JACC could be stored in a low-dimensional vector.
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Karine Sartelet and Bruno Sportisse, CEREA, February 2002.
C     
C------------------------------------------------------------------------

      implicit none

C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     PARADOM: parameters for all forced fields.

      include 'PARACHEM.INC' 
      INCLUDE 'PARADOM.INC' 

      integer                                           i,j
      double precision                    dw(nr,nesp),rk(nr),y(nesp)
      double precision                               JacC(nesp,nesp)

      do i = 1,nesp
         do j = 1,nesp
            JacC(i,j) = 0.d0
         enddo
      enddo

      dw(  1,  1) =  rk(  1) * Y(  3)
      dw(  1,  3) =  rk(  1) * Y(  1)
      JacC(  1,  1) = JacC(  1,  1) - dw(  1,  1)
      JacC(  1,  3) = JacC(  1,  3) - dw(  1,  3)
      JacC(  2,  1) = JacC(  2,  1) + dw(  1,  1)
      JacC(  2,  3) = JacC(  2,  3) + dw(  1,  3)
      JacC(  3,  1) = JacC(  3,  1) - dw(  1,  1)
      JacC(  3,  3) = JacC(  3,  3) - dw(  1,  3)
      dw(  2,  1) =  rk(  2) * Y(  2)
      dw(  2,  2) =  rk(  2) * Y(  1)
      JacC(  1,  1) = JacC(  1,  1) - dw(  2,  1)
      JacC(  1,  2) = JacC(  1,  2) - dw(  2,  2)
      JacC(  2,  1) = JacC(  2,  1) - dw(  2,  1)
      JacC(  2,  2) = JacC(  2,  2) - dw(  2,  2)
      JacC( 14,  1) = JacC( 14,  1) + dw(  2,  1)
      JacC( 14,  2) = JacC( 14,  2) + dw(  2,  2)
      dw(  3,  1) =  rk(  3) * Y( 12)
      dw(  3, 12) =  rk(  3) * Y(  1)
      JacC(  1,  1) = JacC(  1,  1) - dw(  3,  1)
      JacC(  1, 12) = JacC(  1, 12) - dw(  3, 12)
      JacC( 12,  1) = JacC( 12,  1) - dw(  3,  1)
      JacC( 12, 12) = JacC( 12, 12) - dw(  3, 12)
      JacC( 13,  1) = JacC( 13,  1) + dw(  3,  1)
      JacC( 13, 12) = JacC( 13, 12) + dw(  3, 12)
      dw(  4,  1) =  rk(  4) * Y( 13)
      dw(  4, 13) =  rk(  4) * Y(  1)
      JacC(  1,  1) = JacC(  1,  1) - dw(  4,  1)
      JacC(  1, 13) = JacC(  1, 13) - dw(  4, 13)
      JacC( 12,  1) = JacC( 12,  1) + dw(  4,  1)
      JacC( 12, 13) = JacC( 12, 13) + dw(  4, 13)
      JacC( 13,  1) = JacC( 13,  1) - dw(  4,  1)
      JacC( 13, 13) = JacC( 13, 13) - dw(  4, 13)
      dw(  5,  3) =  rk(  5) * Y( 14)
      dw(  5, 14) =  rk(  5) * Y(  3)
      JacC(  2,  3) = JacC(  2,  3)+ 0.2000000000000000D+01*dw(  5,  3)
      JacC(  2, 14) = JacC(  2, 14)+ 0.2000000000000000D+01*dw(  5, 14)
      JacC(  3,  3) = JacC(  3,  3) - dw(  5,  3)
      JacC(  3, 14) = JacC(  3, 14) - dw(  5, 14)
      JacC( 14,  3) = JacC( 14,  3) - dw(  5,  3)
      JacC( 14, 14) = JacC( 14, 14) - dw(  5, 14)
      dw(  6,  3) =  rk(  6) * Y( 13)
      dw(  6, 13) =  rk(  6) * Y(  3)
      JacC(  2,  3) = JacC(  2,  3) + dw(  6,  3)
      JacC(  2, 13) = JacC(  2, 13) + dw(  6, 13)
      JacC(  3,  3) = JacC(  3,  3) - dw(  6,  3)
      JacC(  3, 13) = JacC(  3, 13) - dw(  6, 13)
      JacC( 12,  3) = JacC( 12,  3) + dw(  6,  3)
      JacC( 12, 13) = JacC( 12, 13) + dw(  6, 13)
      JacC( 13,  3) = JacC( 13,  3) - dw(  6,  3)
      JacC( 13, 13) = JacC( 13, 13) - dw(  6, 13)
      dw(  7,  2) =  rk(  7) * Y( 14)
      dw(  7, 14) =  rk(  7) * Y(  2)
      JacC(  3,  2) = JacC(  3,  2) + dw(  7,  2)
      JacC(  3, 14) = JacC(  3, 14) + dw(  7, 14)
      JacC( 14,  2) = JacC( 14,  2) - dw(  7,  2)
      JacC( 14, 14) = JacC( 14, 14) - dw(  7, 14)
      dw(  8, 12) =  rk(  8) * Y( 13)
      dw(  8, 13) =  rk(  8) * Y( 12)
      JacC( 12, 12) = JacC( 12, 12) - dw(  8, 12)
      JacC( 12, 13) = JacC( 12, 13) - dw(  8, 13)
      JacC( 13, 12) = JacC( 13, 12) - dw(  8, 12)
      JacC( 13, 13) = JacC( 13, 13) - dw(  8, 13)
      dw(  9, 12) =  rk(  9) * Y( 10)
      dw(  9, 10) =  rk(  9) * Y( 12)
      JacC( 10, 12) = JacC( 10, 12) - dw(  9, 12)
      JacC( 10, 10) = JacC( 10, 10) - dw(  9, 10)
      JacC( 12, 12) = JacC( 12, 12) - dw(  9, 12)
      JacC( 12, 10) = JacC( 12, 10) - dw(  9, 10)
      JacC( 13, 12) = JacC( 13, 12) + dw(  9, 12)
      JacC( 13, 10) = JacC( 13, 10) + dw(  9, 10)
      dw( 10, 13) =  rk( 10) * Y( 13)
      dw( 10, 13) =  rk( 10) * Y( 13)
      JacC( 10, 13) = JacC( 10, 13) + dw( 10, 13)
      JacC( 10, 13) = JacC( 10, 13) + dw( 10, 13)
      JacC( 13, 13) = JacC( 13, 13)- 0.2000000000000000D+01*dw( 10, 13)
      JacC( 13, 13) = JacC( 13, 13)- 0.2000000000000000D+01*dw( 10, 13)
      dw( 11, 13) =  rk( 11) * Y( 13)
      dw( 11, 13) =  rk( 11) * Y( 13)
      JacC( 10, 13) = JacC( 10, 13) + dw( 11, 13)
      JacC( 10, 13) = JacC( 10, 13) + dw( 11, 13)
      JacC( 13, 13) = JacC( 13, 13)- 0.2000000000000000D+01*dw( 11, 13)
      JacC( 13, 13) = JacC( 13, 13)- 0.2000000000000000D+01*dw( 11, 13)
      dw( 12, 14) =  rk( 12) * Y( 13)
      dw( 12, 13) =  rk( 12) * Y( 14)
      JacC(  4, 14) = JacC(  4, 14) + dw( 12, 14)
      JacC(  4, 13) = JacC(  4, 13) + dw( 12, 13)
      JacC( 13, 14) = JacC( 13, 14) - dw( 12, 14)
      JacC( 13, 13) = JacC( 13, 13) - dw( 12, 13)
      JacC( 14, 14) = JacC( 14, 14) - dw( 12, 14)
      JacC( 14, 13) = JacC( 14, 13) - dw( 12, 13)
      dw( 13, 14) =  rk( 13) * Y( 13)
      dw( 13, 13) =  rk( 13) * Y( 14)
      JacC(  2, 14) = JacC(  2, 14) + dw( 13, 14)
      JacC(  2, 13) = JacC(  2, 13) + dw( 13, 13)
      JacC( 12, 14) = JacC( 12, 14) + dw( 13, 14)
      JacC( 12, 13) = JacC( 12, 13) + dw( 13, 13)
      JacC( 13, 14) = JacC( 13, 14) - dw( 13, 14)
      JacC( 13, 13) = JacC( 13, 13) - dw( 13, 13)
      JacC( 14, 14) = JacC( 14, 14) - dw( 13, 14)
      JacC( 14, 13) = JacC( 14, 13) - dw( 13, 13)
      dw( 14,  3) =  rk( 14) * Y(  3)
      dw( 14,  3) =  rk( 14) * Y(  3)
      JacC(  2,  3) = JacC(  2,  3)+ 0.2000000000000000D+01*dw( 14,  3)
      JacC(  2,  3) = JacC(  2,  3)+ 0.2000000000000000D+01*dw( 14,  3)
      JacC(  3,  3) = JacC(  3,  3)- 0.2000000000000000D+01*dw( 14,  3)
      JacC(  3,  3) = JacC(  3,  3)- 0.2000000000000000D+01*dw( 14,  3)
      dw( 15, 12) =  rk( 15) * Y(  5)
      dw( 15,  5) =  rk( 15) * Y( 12)
      JacC(  2, 12) = JacC(  2, 12) + dw( 15, 12)
      JacC(  2,  5) = JacC(  2,  5) + dw( 15,  5)
      JacC(  5, 12) = JacC(  5, 12) - dw( 15, 12)
      JacC(  5,  5) = JacC(  5,  5) - dw( 15,  5)
      JacC( 12, 12) = JacC( 12, 12) - dw( 15, 12)
      JacC( 12,  5) = JacC( 12,  5) - dw( 15,  5)
      dw( 16, 12) =  rk( 16) * Y( 11)
      dw( 16, 11) =  rk( 16) * Y( 12)
      JacC( 11, 12) = JacC( 11, 12) - dw( 16, 12)
      JacC( 11, 11) = JacC( 11, 11) - dw( 16, 11)
      JacC( 12, 12) = JacC( 12, 12) - dw( 16, 12)
      JacC( 12, 11) = JacC( 12, 11) - dw( 16, 11)
      JacC( 13, 12) = JacC( 13, 12) + dw( 16, 12)
      JacC( 13, 11) = JacC( 13, 11) + dw( 16, 11)
      dw( 17, 12) =  rk( 17) * Y( 11)
      dw( 17, 11) =  rk( 17) * Y( 12)
      JacC( 11, 12) = JacC( 11, 12) - dw( 17, 12)
      JacC( 11, 11) = JacC( 11, 11) - dw( 17, 11)
      JacC( 12, 12) = JacC( 12, 12) - dw( 17, 12)
      JacC( 12, 11) = JacC( 12, 11) - dw( 17, 11)
      JacC( 13, 12) = JacC( 13, 12) + dw( 17, 12)
      JacC( 13, 11) = JacC( 13, 11) + dw( 17, 11)
      dw( 18,  3) =  rk( 18) * Y( 12)
      dw( 18, 12) =  rk( 18) * Y(  3)
      JacC(  3,  3) = JacC(  3,  3) - dw( 18,  3)
      JacC(  3, 12) = JacC(  3, 12) - dw( 18, 12)
      JacC(  6,  3) = JacC(  6,  3) + dw( 18,  3)
      JacC(  6, 12) = JacC(  6, 12) + dw( 18, 12)
      JacC( 12,  3) = JacC( 12,  3) - dw( 18,  3)
      JacC( 12, 12) = JacC( 12, 12) - dw( 18, 12)
      dw( 19,  2) =  rk( 19) * Y( 12)
      dw( 19, 12) =  rk( 19) * Y(  2)
      JacC(  2,  2) = JacC(  2,  2) - dw( 19,  2)
      JacC(  2, 12) = JacC(  2, 12) - dw( 19, 12)
      JacC(  4,  2) = JacC(  4,  2) + dw( 19,  2)
      JacC(  4, 12) = JacC(  4, 12) + dw( 19, 12)
      JacC( 12,  2) = JacC( 12,  2) - dw( 19,  2)
      JacC( 12, 12) = JacC( 12, 12) - dw( 19, 12)
      dw( 20,  2) =  rk( 20) * Y( 13)
      dw( 20, 13) =  rk( 20) * Y(  2)
      JacC(  2,  2) = JacC(  2,  2) - dw( 20,  2)
      JacC(  2, 13) = JacC(  2, 13) - dw( 20, 13)
      JacC(  5,  2) = JacC(  5,  2) + dw( 20,  2)
      JacC(  5, 13) = JacC(  5, 13) + dw( 20, 13)
      JacC( 13,  2) = JacC( 13,  2) - dw( 20,  2)
      JacC( 13, 13) = JacC( 13, 13) - dw( 20, 13)
      dw( 21,  5) =  rk( 21)
      JacC(  2,  5) = JacC(  2,  5) + dw( 21,  5)
      JacC(  5,  5) = JacC(  5,  5) - dw( 21,  5)
      JacC( 13,  5) = JacC( 13,  5) + dw( 21,  5)
      dw( 22,  2) =  rk( 22) * Y( 14)
      dw( 22, 14) =  rk( 22) * Y(  2)
      JacC(  2,  2) = JacC(  2,  2) - dw( 22,  2)
      JacC(  2, 14) = JacC(  2, 14) - dw( 22, 14)
      JacC(  7,  2) = JacC(  7,  2) + dw( 22,  2)
      JacC(  7, 14) = JacC(  7, 14) + dw( 22, 14)
      JacC( 14,  2) = JacC( 14,  2) - dw( 22,  2)
      JacC( 14, 14) = JacC( 14, 14) - dw( 22, 14)
      dw( 23,  7) =  rk( 23)
      JacC(  2,  7) = JacC(  2,  7) + dw( 23,  7)
      JacC(  7,  7) = JacC(  7,  7) - dw( 23,  7)
      JacC( 14,  7) = JacC( 14,  7) + dw( 23,  7)
      dw( 24, 12) =  rk( 24) * Y(  8)
      dw( 24,  8) =  rk( 24) * Y( 12)
      JacC(  8, 12) = JacC(  8, 12) - dw( 24, 12)
      JacC(  8,  8) = JacC(  8,  8) - dw( 24,  8)
      JacC(  9, 12) = JacC(  9, 12) + dw( 24, 12)
      JacC(  9,  8) = JacC(  9,  8) + dw( 24,  8)
      JacC( 12, 12) = JacC( 12, 12) - dw( 24, 12)
      JacC( 12,  8) = JacC( 12,  8) - dw( 24,  8)
      JacC( 13, 12) = JacC( 13, 12) + dw( 24, 12)
      JacC( 13,  8) = JacC( 13,  8) + dw( 24,  8)
      dw( 25, 13) =  rk( 25) * Y( 13)
      dw( 25, 13) =  rk( 25) * Y( 13)
      JacC( 10, 13) = JacC( 10, 13) + dw( 25, 13)
      JacC( 10, 13) = JacC( 10, 13) + dw( 25, 13)
      JacC( 13, 13) = JacC( 13, 13)- 0.2000000000000000D+01*dw( 25, 13)
      JacC( 13, 13) = JacC( 13, 13)- 0.2000000000000000D+01*dw( 25, 13)
      dw( 26,  7) =  rk( 26)
      JacC(  4,  7) = JacC(  4,  7)+ 0.2000000000000000D+01*dw( 26,  7)
      JacC(  7,  7) = JacC(  7,  7) - dw( 26,  7)
      dw( 27,  1) =  rk( 27)
      JacC(  1,  1) = JacC(  1,  1) - dw( 27,  1)
      JacC( 12,  1) = JacC( 12,  1)+ 0.2000000000000000D+01*dw( 27,  1)
      dw( 28,  2) =  rk( 28)
      JacC(  1,  2) = JacC(  1,  2) + dw( 28,  2)
      JacC(  2,  2) = JacC(  2,  2) - dw( 28,  2)
      JacC(  3,  2) = JacC(  3,  2) + dw( 28,  2)
      dw( 29, 10) =  rk( 29)
      JacC( 10, 10) = JacC( 10, 10) - dw( 29, 10)
      JacC( 12, 10) = JacC( 12, 10)+ 0.2000000000000000D+01*dw( 29, 10)
      dw( 30, 14) =  rk( 30)
      JacC(  3, 14) = JacC(  3, 14) + dw( 30, 14)
      JacC( 14, 14) = JacC( 14, 14) - dw( 30, 14)
      dw( 31, 14) =  rk( 31)
      JacC(  1, 14) = JacC(  1, 14) + dw( 31, 14)
      JacC(  2, 14) = JacC(  2, 14) + dw( 31, 14)
      JacC( 14, 14) = JacC( 14, 14) - dw( 31, 14)
      dw( 32,  6) =  rk( 32)
      JacC(  3,  6) = JacC(  3,  6) + dw( 32,  6)
      JacC(  6,  6) = JacC(  6,  6) - dw( 32,  6)
      JacC( 12,  6) = JacC( 12,  6) + dw( 32,  6)
      dw( 33, 34) =  rk( 33) * Y(  3)
      dw( 33,  3) =  rk( 33) * Y( 34)
      JacC(  2, 34) = JacC(  2, 34) + dw( 33, 34)
      JacC(  2,  3) = JacC(  2,  3) + dw( 33,  3)
      JacC(  3, 34) = JacC(  3, 34) - dw( 33, 34)
      JacC(  3,  3) = JacC(  3,  3) - dw( 33,  3)
      JacC( 13, 34) = JacC( 13, 34) + dw( 33, 34)
      JacC( 13,  3) = JacC( 13,  3) + dw( 33,  3)
      JacC( 34, 34) = JacC( 34, 34) - dw( 33, 34)
      JacC( 34,  3) = JacC( 34,  3) - dw( 33,  3)
      dw( 34, 34) =  rk( 34) * Y( 13)
      dw( 34, 13) =  rk( 34) * Y( 34)
      JacC( 13, 34) = JacC( 13, 34) - dw( 34, 34)
      JacC( 13, 13) = JacC( 13, 13) - dw( 34, 13)
      JacC( 33, 34) = JacC( 33, 34) + dw( 34, 34)
      JacC( 33, 13) = JacC( 33, 13) + dw( 34, 13)
      JacC( 34, 34) = JacC( 34, 34) - dw( 34, 34)
      JacC( 34, 13) = JacC( 34, 13) - dw( 34, 13)
      dw( 35, 37) =  rk( 35) * Y(  3)
      dw( 35,  3) =  rk( 35) * Y( 37)
      JacC(  3, 37) = JacC(  3, 37) - dw( 35, 37)
      JacC(  3,  3) = JacC(  3,  3) - dw( 35,  3)
      JacC( 31, 37) = JacC( 31, 37) + dw( 35, 37)
      JacC( 31,  3) = JacC( 31,  3) + dw( 35,  3)
      JacC( 37, 37) = JacC( 37, 37) - dw( 35, 37)
      JacC( 37,  3) = JacC( 37,  3) - dw( 35,  3)
      dw( 36, 37) =  rk( 36) * Y( 13)
      dw( 36, 13) =  rk( 36) * Y( 37)
      JacC( 13, 37) = JacC( 13, 37) - dw( 36, 37)
      JacC( 13, 13) = JacC( 13, 13) - dw( 36, 13)
      JacC( 33, 37) = JacC( 33, 37) + dw( 36, 37)
      JacC( 33, 13) = JacC( 33, 13) + dw( 36, 13)
      JacC( 37, 37) = JacC( 37, 37) - dw( 36, 37)
      JacC( 37, 13) = JacC( 37, 13) - dw( 36, 13)
      dw( 37, 35) =  rk( 37) * Y(  3)
      dw( 37,  3) =  rk( 37) * Y( 35)
      JacC(  2, 35) = JacC(  2, 35) + dw( 37, 35)
      JacC(  2,  3) = JacC(  2,  3) + dw( 37,  3)
      JacC(  3, 35) = JacC(  3, 35) - dw( 37, 35)
      JacC(  3,  3) = JacC(  3,  3) - dw( 37,  3)
      JacC( 34, 35) = JacC( 34, 35) + dw( 37, 35)
      JacC( 34,  3) = JacC( 34,  3) + dw( 37,  3)
      JacC( 35, 35) = JacC( 35, 35) - dw( 37, 35)
      JacC( 35,  3) = JacC( 35,  3) - dw( 37,  3)
      dw( 38, 35) =  rk( 38) * Y( 13)
      dw( 38, 13) =  rk( 38) * Y( 35)
      JacC( 13, 35) = JacC( 13, 35) - dw( 38, 35)
      JacC( 13, 13) = JacC( 13, 13) - dw( 38, 13)
      JacC( 33, 35) = JacC( 33, 35) + dw( 38, 35)
      JacC( 33, 13) = JacC( 33, 13) + dw( 38, 13)
      JacC( 35, 35) = JacC( 35, 35) - dw( 38, 35)
      JacC( 35, 13) = JacC( 35, 13) - dw( 38, 13)
      dw( 39, 38) =  rk( 39) * Y(  3)
      dw( 39,  3) =  rk( 39) * Y( 38)
      JacC(  3, 38) = JacC(  3, 38) - dw( 39, 38)
      JacC(  3,  3) = JacC(  3,  3) - dw( 39,  3)
      JacC( 32, 38) = JacC( 32, 38) + dw( 39, 38)
      JacC( 32,  3) = JacC( 32,  3) + dw( 39,  3)
      JacC( 38, 38) = JacC( 38, 38) - dw( 39, 38)
      JacC( 38,  3) = JacC( 38,  3) - dw( 39,  3)
      dw( 40, 38) =  rk( 40) * Y( 13)
      dw( 40, 13) =  rk( 40) * Y( 38)
      JacC( 13, 38) = JacC( 13, 38) - dw( 40, 38)
      JacC( 13, 13) = JacC( 13, 13) - dw( 40, 13)
      JacC( 33, 38) = JacC( 33, 38) + dw( 40, 38)
      JacC( 33, 13) = JacC( 33, 13) + dw( 40, 13)
      JacC( 38, 38) = JacC( 38, 38) - dw( 40, 38)
      JacC( 38, 13) = JacC( 38, 13) - dw( 40, 13)
      dw( 41, 36) =  rk( 41) * Y(  3)
      dw( 41,  3) =  rk( 41) * Y( 36)
      JacC(  2, 36) = JacC(  2, 36) + dw( 41, 36)
      JacC(  2,  3) = JacC(  2,  3) + dw( 41,  3)
      JacC(  3, 36) = JacC(  3, 36) - dw( 41, 36)
      JacC(  3,  3) = JacC(  3,  3) - dw( 41,  3)
      JacC( 36, 36) = JacC( 36, 36) - dw( 41, 36)
      JacC( 36,  3) = JacC( 36,  3) - dw( 41,  3)
      dw( 42, 36) =  rk( 42) * Y( 13)
      dw( 42, 13) =  rk( 42) * Y( 36)
      JacC( 13, 36) = JacC( 13, 36) - dw( 42, 36)
      JacC( 13, 13) = JacC( 13, 13) - dw( 42, 13)
      JacC( 33, 36) = JacC( 33, 36) + dw( 42, 36)
      JacC( 33, 13) = JacC( 33, 13) + dw( 42, 13)
      JacC( 36, 36) = JacC( 36, 36) - dw( 42, 36)
      JacC( 36, 13) = JacC( 36, 13) - dw( 42, 13)
      dw( 43, 12) =  rk( 43) * Y( 15)
      dw( 43, 15) =  rk( 43) * Y( 12)
      JacC( 11, 12) = JacC( 11, 12) + dw( 43, 12)
      JacC( 11, 15) = JacC( 11, 15) + dw( 43, 15)
      JacC( 12, 12) = JacC( 12, 12) - dw( 43, 12)
      JacC( 12, 15) = JacC( 12, 15) - dw( 43, 15)
      JacC( 13, 12) = JacC( 13, 12) + dw( 43, 12)
      JacC( 13, 15) = JacC( 13, 15) + dw( 43, 15)
      JacC( 15, 12) = JacC( 15, 12) - dw( 43, 12)
      JacC( 15, 15) = JacC( 15, 15) - dw( 43, 15)
      dw( 44, 12) =  rk( 44) * Y( 16)
      dw( 44, 16) =  rk( 44) * Y( 12)
      JacC( 12, 12) = JacC( 12, 12) - dw( 44, 12)
      JacC( 12, 16) = JacC( 12, 16) - dw( 44, 16)
      JacC( 16, 12) = JacC( 16, 12) - dw( 44, 12)
      JacC( 16, 16) = JacC( 16, 16) - dw( 44, 16)
      JacC( 39, 12) = JacC( 39, 12) + dw( 44, 12)
      JacC( 39, 16) = JacC( 39, 16) + dw( 44, 16)
      dw( 45, 39) =  rk( 45) * Y(  3)
      dw( 45,  3) =  rk( 45) * Y( 39)
      JacC(  2, 39) = JacC(  2, 39) + dw( 45, 39)
      JacC(  2,  3) = JacC(  2,  3) + dw( 45,  3)
      JacC(  3, 39) = JacC(  3, 39) - dw( 45, 39)
      JacC(  3,  3) = JacC(  3,  3) - dw( 45,  3)
      JacC( 15, 39) = JacC( 15, 39) + dw( 45, 39)
      JacC( 15,  3) = JacC( 15,  3) + dw( 45,  3)
      JacC( 34, 39) = JacC( 34, 39) + dw( 45, 39)
      JacC( 34,  3) = JacC( 34,  3) + dw( 45,  3)
      JacC( 39, 39) = JacC( 39, 39) - dw( 45, 39)
      JacC( 39,  3) = JacC( 39,  3) - dw( 45,  3)
      dw( 46, 13) =  rk( 46) * Y( 39)
      dw( 46, 39) =  rk( 46) * Y( 13)
      JacC(  1, 13) = JacC(  1, 13)+ 0.3000000000000000D+00*dw( 46, 13)
      JacC(  1, 39) = JacC(  1, 39)+ 0.3000000000000000D+00*dw( 46, 39)
      JacC( 13, 13) = JacC( 13, 13) - dw( 46, 13)
      JacC( 13, 39) = JacC( 13, 39) - dw( 46, 39)
      JacC( 33, 13) = JacC( 33, 13)+ 0.7000000000000000D+00*dw( 46, 13)
      JacC( 33, 39) = JacC( 33, 39)+ 0.7000000000000000D+00*dw( 46, 39)
      JacC( 39, 13) = JacC( 39, 13) - dw( 46, 13)
      JacC( 39, 39) = JacC( 39, 39) - dw( 46, 39)
      dw( 47, 17) =  rk( 47) * Y( 12)
      dw( 47, 12) =  rk( 47) * Y( 17)
      JacC( 12, 17) = JacC( 12, 17) - dw( 47, 17)
      JacC( 12, 12) = JacC( 12, 12) - dw( 47, 12)
      JacC( 17, 17) = JacC( 17, 17) - dw( 47, 17)
      JacC( 17, 12) = JacC( 17, 12) - dw( 47, 12)
      JacC( 40, 17) = JacC( 40, 17) + dw( 47, 17)
      JacC( 40, 12) = JacC( 40, 12) + dw( 47, 12)
      dw( 48, 40) =  rk( 48) * Y(  3)
      dw( 48,  3) =  rk( 48) * Y( 40)
      JacC(  2, 40) = JacC(  2, 40) + dw( 48, 40)
      JacC(  2,  3) = JacC(  2,  3) + dw( 48,  3)
      JacC(  3, 40) = JacC(  3, 40) - dw( 48, 40)
      JacC(  3,  3) = JacC(  3,  3) - dw( 48,  3)
      JacC( 16, 40) = JacC( 16, 40) + dw( 48, 40)
      JacC( 16,  3) = JacC( 16,  3) + dw( 48,  3)
      JacC( 34, 40) = JacC( 34, 40) + dw( 48, 40)
      JacC( 34,  3) = JacC( 34,  3) + dw( 48,  3)
      JacC( 40, 40) = JacC( 40, 40) - dw( 48, 40)
      JacC( 40,  3) = JacC( 40,  3) - dw( 48,  3)
      dw( 49, 40) =  rk( 49) * Y( 13)
      dw( 49, 13) =  rk( 49) * Y( 40)
      JacC(  1, 40) = JacC(  1, 40)+ 0.3000000000000000D+00*dw( 49, 40)
      JacC(  1, 13) = JacC(  1, 13)+ 0.3000000000000000D+00*dw( 49, 13)
      JacC( 13, 40) = JacC( 13, 40) - dw( 49, 40)
      JacC( 13, 13) = JacC( 13, 13) - dw( 49, 13)
      JacC( 33, 40) = JacC( 33, 40)+ 0.7000000000000000D+00*dw( 49, 40)
      JacC( 33, 13) = JacC( 33, 13)+ 0.7000000000000000D+00*dw( 49, 13)
      JacC( 40, 40) = JacC( 40, 40) - dw( 49, 40)
      JacC( 40, 13) = JacC( 40, 13) - dw( 49, 13)
      dw( 50, 40) =  rk( 50) * Y(  2)
      dw( 50,  2) =  rk( 50) * Y( 40)
      JacC(  2, 40) = JacC(  2, 40) - dw( 50, 40)
      JacC(  2,  2) = JacC(  2,  2) - dw( 50,  2)
      JacC( 28, 40) = JacC( 28, 40) + dw( 50, 40)
      JacC( 28,  2) = JacC( 28,  2) + dw( 50,  2)
      JacC( 40, 40) = JacC( 40, 40) - dw( 50, 40)
      JacC( 40,  2) = JacC( 40,  2) - dw( 50,  2)
      dw( 51, 28) =  rk( 51)
      JacC(  2, 28) = JacC(  2, 28) + dw( 51, 28)
      JacC( 28, 28) = JacC( 28, 28) - dw( 51, 28)
      JacC( 40, 28) = JacC( 40, 28) + dw( 51, 28)
      dw( 52, 12) =  rk( 52) * Y( 18)
      dw( 52, 18) =  rk( 52) * Y( 12)
      JacC( 12, 12) = JacC( 12, 12) - dw( 52, 12)
      JacC( 12, 18) = JacC( 12, 18) - dw( 52, 18)
      JacC( 15, 12) = JacC( 15, 12)+ 0.2000000000000000D+00*dw( 52, 12)
      JacC( 15, 18) = JacC( 15, 18)+ 0.2000000000000000D+00*dw( 52, 18)
      JacC( 18, 12) = JacC( 18, 12) - dw( 52, 12)
      JacC( 18, 18) = JacC( 18, 18) - dw( 52, 18)
      JacC( 22, 12) = JacC( 22, 12)+ 0.8000000000000000D+00*dw( 52, 12)
      JacC( 22, 18) = JacC( 22, 18)+ 0.8000000000000000D+00*dw( 52, 18)
      JacC( 34, 12) = JacC( 34, 12)+ 0.8000000000000000D+00*dw( 52, 12)
      JacC( 34, 18) = JacC( 34, 18)+ 0.8000000000000000D+00*dw( 52, 18)
      JacC( 36, 12) = JacC( 36, 12)+ 0.2000000000000000D+00*dw( 52, 12)
      JacC( 36, 18) = JacC( 36, 18)+ 0.2000000000000000D+00*dw( 52, 18)
      JacC( 39, 12) = JacC( 39, 12)+ 0.2000000000000000D+00*dw( 52, 12)
      JacC( 39, 18) = JacC( 39, 18)+ 0.2000000000000000D+00*dw( 52, 18)
      dw( 53, 12) =  rk( 53) * Y( 19)
      dw( 53, 19) =  rk( 53) * Y( 12)
      JacC( 12, 12) = JacC( 12, 12) - dw( 53, 12)
      JacC( 12, 19) = JacC( 12, 19) - dw( 53, 19)
      JacC( 15, 12) = JacC( 15, 12)+ 0.5000000000000000D+00*dw( 53, 12)
      JacC( 15, 19) = JacC( 15, 19)+ 0.5000000000000000D+00*dw( 53, 19)
      JacC( 16, 12) = JacC( 16, 12)+ 0.5000000000000000D+00*dw( 53, 12)
      JacC( 16, 19) = JacC( 16, 19)+ 0.5000000000000000D+00*dw( 53, 19)
      JacC( 19, 12) = JacC( 19, 12) - dw( 53, 12)
      JacC( 19, 19) = JacC( 19, 19) - dw( 53, 19)
      JacC( 36, 12) = JacC( 36, 12)+ 0.1500000000000000D+01*dw( 53, 12)
      JacC( 36, 19) = JacC( 36, 19)+ 0.1500000000000000D+01*dw( 53, 19)
      JacC( 39, 12) = JacC( 39, 12)+ 0.5000000000000000D+00*dw( 53, 12)
      JacC( 39, 19) = JacC( 39, 19)+ 0.5000000000000000D+00*dw( 53, 19)
      JacC( 40, 12) = JacC( 40, 12)+ 0.5000000000000000D+00*dw( 53, 12)
      JacC( 40, 19) = JacC( 40, 19)+ 0.5000000000000000D+00*dw( 53, 19)
      dw( 54, 12) =  rk( 54) * Y( 26)
      dw( 54, 26) =  rk( 54) * Y( 12)
      JacC( 12, 12) = JacC( 12, 12) - dw( 54, 12)
      JacC( 12, 26) = JacC( 12, 26) - dw( 54, 26)
      JacC( 22, 12) = JacC( 22, 12)+ 0.2000000000000000D+00*dw( 54, 12)
      JacC( 22, 26) = JacC( 22, 26)+ 0.2000000000000000D+00*dw( 54, 26)
      JacC( 26, 12) = JacC( 26, 12) - dw( 54, 12)
      JacC( 26, 26) = JacC( 26, 26) - dw( 54, 26)
      JacC( 34, 12) = JacC( 34, 12)+ 0.8500000000000000D+00*dw( 54, 12)
      JacC( 34, 26) = JacC( 34, 26)+ 0.8500000000000000D+00*dw( 54, 26)
      JacC( 38, 12) = JacC( 38, 12)+ 0.1500000000000000D+00*dw( 54, 12)
      JacC( 38, 26) = JacC( 38, 26)+ 0.1500000000000000D+00*dw( 54, 26)
      dw( 55, 14) =  rk( 55) * Y( 26)
      dw( 55, 26) =  rk( 55) * Y( 14)
      JacC(  4, 14) = JacC(  4, 14) + dw( 55, 14)
      JacC(  4, 26) = JacC(  4, 26) + dw( 55, 26)
      JacC( 14, 14) = JacC( 14, 14) - dw( 55, 14)
      JacC( 14, 26) = JacC( 14, 26) - dw( 55, 26)
      JacC( 26, 14) = JacC( 26, 14) - dw( 55, 14)
      JacC( 26, 26) = JacC( 26, 26) - dw( 55, 26)
      JacC( 45, 14) = JacC( 45, 14) + dw( 55, 14)
      JacC( 45, 26) = JacC( 45, 26) + dw( 55, 26)
      dw( 56, 12) =  rk( 56) * Y( 25)
      dw( 56, 25) =  rk( 56) * Y( 12)
      JacC( 12, 12) = JacC( 12, 12) - dw( 56, 12)
      JacC( 12, 25) = JacC( 12, 25) - dw( 56, 25)
      JacC( 21, 12) = JacC( 21, 12)+ 0.2000000000000000D+00*dw( 56, 12)
      JacC( 21, 25) = JacC( 21, 25)+ 0.2000000000000000D+00*dw( 56, 25)
      JacC( 25, 12) = JacC( 25, 12) - dw( 56, 12)
      JacC( 25, 25) = JacC( 25, 25) - dw( 56, 25)
      JacC( 34, 12) = JacC( 34, 12)+ 0.8500000000000000D+00*dw( 56, 12)
      JacC( 34, 25) = JacC( 34, 25)+ 0.8500000000000000D+00*dw( 56, 25)
      JacC( 38, 12) = JacC( 38, 12)+ 0.1500000000000000D+00*dw( 56, 12)
      JacC( 38, 25) = JacC( 38, 25)+ 0.1500000000000000D+00*dw( 56, 25)
      dw( 57, 14) =  rk( 57) * Y( 25)
      dw( 57, 25) =  rk( 57) * Y( 14)
      JacC(  4, 14) = JacC(  4, 14) + dw( 57, 14)
      JacC(  4, 25) = JacC(  4, 25) + dw( 57, 25)
      JacC( 14, 14) = JacC( 14, 14) - dw( 57, 14)
      JacC( 14, 25) = JacC( 14, 25) - dw( 57, 25)
      JacC( 25, 14) = JacC( 25, 14) - dw( 57, 14)
      JacC( 25, 25) = JacC( 25, 25) - dw( 57, 25)
      JacC( 45, 14) = JacC( 45, 14) + dw( 57, 14)
      JacC( 45, 25) = JacC( 45, 25) + dw( 57, 25)
      dw( 58, 20) =  rk( 58) * Y( 12)
      dw( 58, 12) =  rk( 58) * Y( 20)
      JacC( 12, 20) = JacC( 12, 20) - dw( 58, 20)
      JacC( 12, 12) = JacC( 12, 12) - dw( 58, 12)
      JacC( 20, 20) = JacC( 20, 20) - dw( 58, 20)
      JacC( 20, 12) = JacC( 20, 12) - dw( 58, 12)
      JacC( 42, 20) = JacC( 42, 20) + dw( 58, 20)
      JacC( 42, 12) = JacC( 42, 12) + dw( 58, 12)
      dw( 59, 42) =  rk( 59) * Y(  3)
      dw( 59,  3) =  rk( 59) * Y( 42)
      JacC(  2, 42) = JacC(  2, 42) + dw( 59, 42)
      JacC(  2,  3) = JacC(  2,  3) + dw( 59,  3)
      JacC(  3, 42) = JacC(  3, 42) - dw( 59, 42)
      JacC(  3,  3) = JacC(  3,  3) - dw( 59,  3)
      JacC( 42, 42) = JacC( 42, 42) - dw( 59, 42)
      JacC( 42,  3) = JacC( 42,  3) - dw( 59,  3)
      JacC( 44, 42) = JacC( 44, 42) + dw( 59, 42)
      JacC( 44,  3) = JacC( 44,  3) + dw( 59,  3)
      dw( 60, 42) =  rk( 60) * Y( 13)
      dw( 60, 13) =  rk( 60) * Y( 42)
      JacC(  1, 42) = JacC(  1, 42)+ 0.3000000000000000D+00*dw( 60, 42)
      JacC(  1, 13) = JacC(  1, 13)+ 0.3000000000000000D+00*dw( 60, 13)
      JacC( 13, 42) = JacC( 13, 42) - dw( 60, 42)
      JacC( 13, 13) = JacC( 13, 13) - dw( 60, 13)
      JacC( 33, 42) = JacC( 33, 42)+ 0.7000000000000000D+00*dw( 60, 42)
      JacC( 33, 13) = JacC( 33, 13)+ 0.7000000000000000D+00*dw( 60, 13)
      JacC( 42, 42) = JacC( 42, 42) - dw( 60, 42)
      JacC( 42, 13) = JacC( 42, 13) - dw( 60, 13)
      dw( 61, 42) =  rk( 61) * Y(  2)
      dw( 61,  2) =  rk( 61) * Y( 42)
      JacC(  2, 42) = JacC(  2, 42) - dw( 61, 42)
      JacC(  2,  2) = JacC(  2,  2) - dw( 61,  2)
      JacC( 29, 42) = JacC( 29, 42) + dw( 61, 42)
      JacC( 29,  2) = JacC( 29,  2) + dw( 61,  2)
      JacC( 42, 42) = JacC( 42, 42) - dw( 61, 42)
      JacC( 42,  2) = JacC( 42,  2) - dw( 61,  2)
      dw( 62, 29) =  rk( 62)
      JacC(  2, 29) = JacC(  2, 29) + dw( 62, 29)
      JacC( 29, 29) = JacC( 29, 29) - dw( 62, 29)
      JacC( 42, 29) = JacC( 42, 29) + dw( 62, 29)
      dw( 63, 44) =  rk( 63) * Y(  3)
      dw( 63,  3) =  rk( 63) * Y( 44)
      JacC(  2, 44) = JacC(  2, 44) + dw( 63, 44)
      JacC(  2,  3) = JacC(  2,  3) + dw( 63,  3)
      JacC(  3, 44) = JacC(  3, 44) - dw( 63, 44)
      JacC(  3,  3) = JacC(  3,  3) - dw( 63,  3)
      JacC( 44, 44) = JacC( 44, 44) - dw( 63, 44)
      JacC( 44,  3) = JacC( 44,  3) - dw( 63,  3)
      JacC( 45, 44) = JacC( 45, 44) + dw( 63, 44)
      JacC( 45,  3) = JacC( 45,  3) + dw( 63,  3)
      dw( 64, 44) =  rk( 64) * Y( 13)
      dw( 64, 13) =  rk( 64) * Y( 44)
      JacC( 13, 44) = JacC( 13, 44) - dw( 64, 44)
      JacC( 13, 13) = JacC( 13, 13) - dw( 64, 13)
      JacC( 33, 44) = JacC( 33, 44) + dw( 64, 44)
      JacC( 33, 13) = JacC( 33, 13) + dw( 64, 13)
      JacC( 44, 44) = JacC( 44, 44) - dw( 64, 44)
      JacC( 44, 13) = JacC( 44, 13) - dw( 64, 13)
      dw( 65, 45) =  rk( 65) * Y(  2)
      dw( 65,  2) =  rk( 65) * Y( 45)
      JacC(  2, 45) = JacC(  2, 45) - dw( 65, 45)
      JacC(  2,  2) = JacC(  2,  2) - dw( 65,  2)
      JacC( 32, 45) = JacC( 32, 45) + dw( 65, 45)
      JacC( 32,  2) = JacC( 32,  2) + dw( 65,  2)
      JacC( 45, 45) = JacC( 45, 45) - dw( 65, 45)
      JacC( 45,  2) = JacC( 45,  2) - dw( 65,  2)
      dw( 66, 45) =  rk( 66) * Y( 13)
      dw( 66, 13) =  rk( 66) * Y( 45)
      JacC( 13, 45) = JacC( 13, 45) - dw( 66, 45)
      JacC( 13, 13) = JacC( 13, 13) - dw( 66, 13)
      JacC( 25, 45) = JacC( 25, 45) + dw( 66, 45)
      JacC( 25, 13) = JacC( 25, 13) + dw( 66, 13)
      JacC( 45, 45) = JacC( 45, 45) - dw( 66, 45)
      JacC( 45, 13) = JacC( 45, 13) - dw( 66, 13)
      dw( 67, 45) =  rk( 67)
      JacC( 25, 45) = JacC( 25, 45) + dw( 67, 45)
      JacC( 45, 45) = JacC( 45, 45) - dw( 67, 45)
      dw( 68, 32) =  rk( 68) * Y( 14)
      dw( 68, 14) =  rk( 68) * Y( 32)
      JacC(  4, 32) = JacC(  4, 32) + dw( 68, 32)
      JacC(  4, 14) = JacC(  4, 14) + dw( 68, 14)
      JacC( 14, 32) = JacC( 14, 32) - dw( 68, 32)
      JacC( 14, 14) = JacC( 14, 14) - dw( 68, 14)
      JacC( 32, 32) = JacC( 32, 32) - dw( 68, 32)
      JacC( 32, 14) = JacC( 32, 14) - dw( 68, 14)
      JacC( 46, 32) = JacC( 46, 32) + dw( 68, 32)
      JacC( 46, 14) = JacC( 46, 14) + dw( 68, 14)
      dw( 69, 46) =  rk( 69) * Y(  2)
      dw( 69,  2) =  rk( 69) * Y( 46)
      JacC(  2, 46) = JacC(  2, 46) - dw( 69, 46)
      JacC(  2,  2) = JacC(  2,  2) - dw( 69,  2)
      JacC( 46, 46) = JacC( 46, 46) - dw( 69, 46)
      JacC( 46,  2) = JacC( 46,  2) - dw( 69,  2)
      dw( 70, 46) =  rk( 70) * Y( 13)
      dw( 70, 13) =  rk( 70) * Y( 46)
      JacC( 13, 46) = JacC( 13, 46) - dw( 70, 46)
      JacC( 13, 13) = JacC( 13, 13) - dw( 70, 13)
      JacC( 32, 46) = JacC( 32, 46) + dw( 70, 46)
      JacC( 32, 13) = JacC( 32, 13) + dw( 70, 13)
      JacC( 46, 46) = JacC( 46, 46) - dw( 70, 46)
      JacC( 46, 13) = JacC( 46, 13) - dw( 70, 13)
      dw( 71, 46) =  rk( 71)
      JacC( 32, 46) = JacC( 32, 46) + dw( 71, 46)
      JacC( 46, 46) = JacC( 46, 46) - dw( 71, 46)
      dw( 72, 24) =  rk( 72) * Y( 12)
      dw( 72, 12) =  rk( 72) * Y( 24)
      JacC( 12, 24) = JacC( 12, 24) - dw( 72, 24)
      JacC( 12, 12) = JacC( 12, 12) - dw( 72, 12)
      JacC( 24, 24) = JacC( 24, 24) - dw( 72, 24)
      JacC( 24, 12) = JacC( 24, 12) - dw( 72, 12)
      JacC( 41, 24) = JacC( 41, 24) + dw( 72, 24)
      JacC( 41, 12) = JacC( 41, 12) + dw( 72, 12)
      dw( 73, 23) =  rk( 73) * Y( 12)
      dw( 73, 12) =  rk( 73) * Y( 23)
      JacC( 12, 23) = JacC( 12, 23) - dw( 73, 23)
      JacC( 12, 12) = JacC( 12, 12) - dw( 73, 12)
      JacC( 23, 23) = JacC( 23, 23) - dw( 73, 23)
      JacC( 23, 12) = JacC( 23, 12) - dw( 73, 12)
      JacC( 40, 23) = JacC( 40, 23) + dw( 73, 23)
      JacC( 40, 12) = JacC( 40, 12) + dw( 73, 12)
      dw( 74, 21) =  rk( 74) * Y( 12)
      dw( 74, 12) =  rk( 74) * Y( 21)
      JacC( 11, 21) = JacC( 11, 21)+ 0.1200000000000000D+01*dw( 74, 21)
      JacC( 11, 12) = JacC( 11, 12)+ 0.1200000000000000D+01*dw( 74, 12)
      JacC( 12, 21) = JacC( 12, 21) - dw( 74, 21)
      JacC( 12, 12) = JacC( 12, 12) - dw( 74, 12)
      JacC( 13, 21) = JacC( 13, 21)+ 0.6000000000000000D+00*dw( 74, 21)
      JacC( 13, 12) = JacC( 13, 12)+ 0.6000000000000000D+00*dw( 74, 12)
      JacC( 21, 21) = JacC( 21, 21) - dw( 74, 21)
      JacC( 21, 12) = JacC( 21, 12) - dw( 74, 12)
      JacC( 41, 21) = JacC( 41, 21)+ 0.4000000000000000D+00*dw( 74, 21)
      JacC( 41, 12) = JacC( 41, 12)+ 0.4000000000000000D+00*dw( 74, 12)
      dw( 75, 41) =  rk( 75) * Y(  3)
      dw( 75,  3) =  rk( 75) * Y( 41)
      JacC(  2, 41) = JacC(  2, 41) + dw( 75, 41)
      JacC(  2,  3) = JacC(  2,  3) + dw( 75,  3)
      JacC(  3, 41) = JacC(  3, 41) - dw( 75, 41)
      JacC(  3,  3) = JacC(  3,  3) - dw( 75,  3)
      JacC( 11, 41) = JacC( 11, 41) + dw( 75, 41)
      JacC( 11,  3) = JacC( 11,  3) + dw( 75,  3)
      JacC( 13, 41) = JacC( 13, 41) + dw( 75, 41)
      JacC( 13,  3) = JacC( 13,  3) + dw( 75,  3)
      JacC( 41, 41) = JacC( 41, 41) - dw( 75, 41)
      JacC( 41,  3) = JacC( 41,  3) - dw( 75,  3)
      dw( 76, 41) =  rk( 76) * Y( 13)
      dw( 76, 13) =  rk( 76) * Y( 41)
      JacC(  1, 41) = JacC(  1, 41)+ 0.3000000000000000D+00*dw( 76, 41)
      JacC(  1, 13) = JacC(  1, 13)+ 0.3000000000000000D+00*dw( 76, 13)
      JacC( 13, 41) = JacC( 13, 41) - dw( 76, 41)
      JacC( 13, 13) = JacC( 13, 13) - dw( 76, 13)
      JacC( 33, 41) = JacC( 33, 41)+ 0.7000000000000000D+00*dw( 76, 41)
      JacC( 33, 13) = JacC( 33, 13)+ 0.7000000000000000D+00*dw( 76, 13)
      JacC( 41, 41) = JacC( 41, 41) - dw( 76, 41)
      JacC( 41, 13) = JacC( 41, 13) - dw( 76, 13)
      dw( 77, 22) =  rk( 77) * Y( 12)
      dw( 77, 12) =  rk( 77) * Y( 22)
      JacC( 11, 22) = JacC( 11, 22) + dw( 77, 22)
      JacC( 11, 12) = JacC( 11, 12) + dw( 77, 12)
      JacC( 12, 22) = JacC( 12, 22) - dw( 77, 22)
      JacC( 12, 12) = JacC( 12, 12) - dw( 77, 12)
      JacC( 22, 22) = JacC( 22, 22) - dw( 77, 22)
      JacC( 22, 12) = JacC( 22, 12) - dw( 77, 12)
      JacC( 39, 22) = JacC( 39, 22) + dw( 77, 22)
      JacC( 39, 12) = JacC( 39, 12) + dw( 77, 12)
      dw( 78, 47) =  rk( 78) * Y(  8)
      dw( 78,  8) =  rk( 78) * Y( 47)
      JacC(  8, 47) = JacC(  8, 47) - dw( 78, 47)
      JacC(  8,  8) = JacC(  8,  8) - dw( 78,  8)
      JacC(  9, 47) = JacC(  9, 47) + dw( 78, 47)
      JacC(  9,  8) = JacC(  9,  8) + dw( 78,  8)
      JacC( 47, 47) = JacC( 47, 47) - dw( 78, 47)
      JacC( 47,  8) = JacC( 47,  8) - dw( 78,  8)
      dw( 79, 33) =  rk( 79) * Y( 12)
      dw( 79, 12) =  rk( 79) * Y( 33)
      JacC( 33, 33) = JacC( 33, 33) - dw( 79, 33)
      JacC( 33, 12) = JacC( 33, 12) - dw( 79, 12)
      dw( 80, 33) =  rk( 80) * Y( 12)
      dw( 80, 12) =  rk( 80) * Y( 33)
      JacC( 12, 33) = JacC( 12, 33) - dw( 80, 33)
      JacC( 12, 12) = JacC( 12, 12) - dw( 80, 12)
      JacC( 33, 33) = JacC( 33, 33) - dw( 80, 33)
      JacC( 33, 12) = JacC( 33, 12) - dw( 80, 12)
      JacC( 34, 33) = JacC( 34, 33) + dw( 80, 33)
      JacC( 34, 12) = JacC( 34, 12) + dw( 80, 12)
      dw( 81, 31) =  rk( 81) * Y( 12)
      dw( 81, 12) =  rk( 81) * Y( 31)
      JacC(  2, 31) = JacC(  2, 31) + dw( 81, 31)
      JacC(  2, 12) = JacC(  2, 12) + dw( 81, 12)
      JacC( 12, 31) = JacC( 12, 31) - dw( 81, 31)
      JacC( 12, 12) = JacC( 12, 12) - dw( 81, 12)
      JacC( 15, 31) = JacC( 15, 31)+ 0.1600000000000000D+00*dw( 81, 31)
      JacC( 15, 12) = JacC( 15, 12)+ 0.1600000000000000D+00*dw( 81, 12)
      JacC( 16, 31) = JacC( 16, 31)+ 0.4800000000000000D+00*dw( 81, 31)
      JacC( 16, 12) = JacC( 16, 12)+ 0.4800000000000000D+00*dw( 81, 12)
      JacC( 17, 31) = JacC( 17, 31)+ 0.1050000000000000D+01*dw( 81, 31)
      JacC( 17, 12) = JacC( 17, 12)+ 0.1050000000000000D+01*dw( 81, 12)
      JacC( 19, 31) = JacC( 19, 31)+ 0.1550000000000000D+00*dw( 81, 31)
      JacC( 19, 12) = JacC( 19, 12)+ 0.1550000000000000D+00*dw( 81, 12)
      JacC( 31, 31) = JacC( 31, 31) - dw( 81, 31)
      JacC( 31, 12) = JacC( 31, 12) - dw( 81, 12)
      JacC( 36, 31) = JacC( 36, 31)+ 0.1390000000000000D+01*dw( 81, 31)
      JacC( 36, 12) = JacC( 36, 12)+ 0.1390000000000000D+01*dw( 81, 12)
      dw( 82, 39) =  rk( 82) * Y(  2)
      dw( 82,  2) =  rk( 82) * Y( 39)
      JacC(  2, 39) = JacC(  2, 39) - dw( 82, 39)
      JacC(  2,  2) = JacC(  2,  2) - dw( 82,  2)
      JacC( 27, 39) = JacC( 27, 39) + dw( 82, 39)
      JacC( 27,  2) = JacC( 27,  2) + dw( 82,  2)
      JacC( 39, 39) = JacC( 39, 39) - dw( 82, 39)
      JacC( 39,  2) = JacC( 39,  2) - dw( 82,  2)
      dw( 83, 27) =  rk( 83)
      JacC(  2, 27) = JacC(  2, 27) + dw( 83, 27)
      JacC( 27, 27) = JacC( 27, 27) - dw( 83, 27)
      JacC( 39, 27) = JacC( 39, 27) + dw( 83, 27)
      dw( 84, 41) =  rk( 84) * Y(  2)
      dw( 84,  2) =  rk( 84) * Y( 41)
      JacC(  2, 41) = JacC(  2, 41) - dw( 84, 41)
      JacC(  2,  2) = JacC(  2,  2) - dw( 84,  2)
      JacC( 30, 41) = JacC( 30, 41) + dw( 84, 41)
      JacC( 30,  2) = JacC( 30,  2) + dw( 84,  2)
      JacC( 41, 41) = JacC( 41, 41) - dw( 84, 41)
      JacC( 41,  2) = JacC( 41,  2) - dw( 84,  2)
      dw( 85, 30) =  rk( 85)
      JacC(  2, 30) = JacC(  2, 30) + dw( 85, 30)
      JacC( 30, 30) = JacC( 30, 30) - dw( 85, 30)
      JacC( 41, 30) = JacC( 41, 30) + dw( 85, 30)
      dw( 86, 15) =  rk( 86)
      JacC( 11, 15) = JacC( 11, 15) + dw( 86, 15)
      JacC( 13, 15) = JacC( 13, 15)+ 0.2000000000000000D+01*dw( 86, 15)
      JacC( 15, 15) = JacC( 15, 15) - dw( 86, 15)
      dw( 87, 15) =  rk( 87)
      JacC( 11, 15) = JacC( 11, 15) + dw( 87, 15)
      JacC( 15, 15) = JacC( 15, 15) - dw( 87, 15)
      dw( 88, 16) =  rk( 88)
      JacC( 11, 16) = JacC( 11, 16) + dw( 88, 16)
      JacC( 13, 16) = JacC( 13, 16) + dw( 88, 16)
      JacC( 15, 16) = JacC( 15, 16) + dw( 88, 16)
      JacC( 16, 16) = JacC( 16, 16) - dw( 88, 16)
      JacC( 34, 16) = JacC( 34, 16) + dw( 88, 16)
      dw( 89, 17) =  rk( 89)
      JacC( 11, 17) = JacC( 11, 17) + dw( 89, 17)
      JacC( 13, 17) = JacC( 13, 17) + dw( 89, 17)
      JacC( 16, 17) = JacC( 16, 17) + dw( 89, 17)
      JacC( 17, 17) = JacC( 17, 17) - dw( 89, 17)
      JacC( 34, 17) = JacC( 34, 17) + dw( 89, 17)
      dw( 90, 18) =  rk( 90)
      JacC( 15, 18) = JacC( 15, 18) + dw( 90, 18)
      JacC( 18, 18) = JacC( 18, 18) - dw( 90, 18)
      JacC( 34, 18) = JacC( 34, 18) + dw( 90, 18)
      JacC( 39, 18) = JacC( 39, 18) + dw( 90, 18)
      dw( 91, 19) =  rk( 91)
      JacC( 16, 19) = JacC( 16, 19) + dw( 91, 19)
      JacC( 19, 19) = JacC( 19, 19) - dw( 91, 19)
      JacC( 34, 19) = JacC( 34, 19) + dw( 91, 19)
      JacC( 39, 19) = JacC( 39, 19) + dw( 91, 19)
      dw( 92, 21) =  rk( 92)
      JacC( 11, 21) = JacC( 11, 21)+ 0.1550000000000000D+01*dw( 92, 21)
      JacC( 13, 21) = JacC( 13, 21)+ 0.8000000000000000D+00*dw( 92, 21)
      JacC( 15, 21) = JacC( 15, 21)+ 0.4500000000000000D+00*dw( 92, 21)
      JacC( 21, 21) = JacC( 21, 21) - dw( 92, 21)
      dw( 93, 21) =  rk( 93)
      JacC( 11, 21) = JacC( 11, 21)+ 0.1870000000000000D+01*dw( 93, 21)
      JacC( 15, 21) = JacC( 15, 21)+ 0.1300000000000000D+00*dw( 93, 21)
      JacC( 21, 21) = JacC( 21, 21) - dw( 93, 21)
      dw( 94, 22) =  rk( 94)
      JacC( 11, 22) = JacC( 11, 22) + dw( 94, 22)
      JacC( 13, 22) = JacC( 13, 22) + dw( 94, 22)
      JacC( 22, 22) = JacC( 22, 22) - dw( 94, 22)
      JacC( 39, 22) = JacC( 39, 22) + dw( 94, 22)
      dw( 95, 24) =  rk( 95)
      JacC( 13, 24) = JacC( 13, 24) + dw( 95, 24)
      JacC( 24, 24) = JacC( 24, 24) - dw( 95, 24)
      JacC( 41, 24) = JacC( 41, 24) + dw( 95, 24)
      dw( 96, 23) =  rk( 96)
      JacC( 11, 23) = JacC( 11, 23) + dw( 96, 23)
      JacC( 13, 23) = JacC( 13, 23) + dw( 96, 23)
      JacC( 23, 23) = JacC( 23, 23) - dw( 96, 23)
      JacC( 39, 23) = JacC( 39, 23) + dw( 96, 23)
      dw( 97, 20) =  rk( 97)
      JacC( 20, 20) = JacC( 20, 20) - dw( 97, 20)
      dw( 98, 33) =  rk( 98)
      JacC( 12, 33) = JacC( 12, 33) + dw( 98, 33)
      JacC( 13, 33) = JacC( 13, 33) + dw( 98, 33)
      JacC( 33, 33) = JacC( 33, 33) - dw( 98, 33)
      dw( 99, 31) =  rk( 99)
      JacC(  2, 31) = JacC(  2, 31) + dw( 99, 31)
      JacC( 13, 31) = JacC( 13, 31)+ 0.5030000000000000D+00*dw( 99, 31)
      JacC( 16, 31) = JacC( 16, 31)+ 0.1190000000000000D+00*dw( 99, 31)
      JacC( 19, 31) = JacC( 19, 31)+ 0.1315000000000000D+01*dw( 99, 31)
      JacC( 31, 31) = JacC( 31, 31) - dw( 99, 31)
      JacC( 34, 31) = JacC( 34, 31)+ 0.4970000000000000D+00*dw( 99, 31)
      dw(100, 48) =  rk(100) * Y( 12)
      dw(100, 12) =  rk(100) * Y( 48)
      JacC( 12, 48) = JacC( 12, 48) - dw(100, 48)
      JacC( 12, 12) = JacC( 12, 12) - dw(100, 12)
      JacC( 15, 48) = JacC( 15, 48) + dw(100, 48)
      JacC( 15, 12) = JacC( 15, 12) + dw(100, 12)
      JacC( 34, 48) = JacC( 34, 48) + dw(100, 48)
      JacC( 34, 12) = JacC( 34, 12) + dw(100, 12)
      JacC( 48, 48) = JacC( 48, 48) - dw(100, 48)
      JacC( 48, 12) = JacC( 48, 12) - dw(100, 12)
      dw(101, 49) =  rk(101) * Y( 12)
      dw(101, 12) =  rk(101) * Y( 49)
      JacC( 12, 49) = JacC( 12, 49) - dw(101, 49)
      JacC( 12, 12) = JacC( 12, 12) - dw(101, 12)
      JacC( 16, 49) = JacC( 16, 49) + dw(101, 49)
      JacC( 16, 12) = JacC( 16, 12) + dw(101, 12)
      JacC( 34, 49) = JacC( 34, 49) + dw(101, 49)
      JacC( 34, 12) = JacC( 34, 12) + dw(101, 12)
      JacC( 49, 49) = JacC( 49, 49) - dw(101, 49)
      JacC( 49, 12) = JacC( 49, 12) - dw(101, 12)
      dw(102, 50) =  rk(102) * Y( 12)
      dw(102, 12) =  rk(102) * Y( 50)
      JacC( 12, 50) = JacC( 12, 50) - dw(102, 50)
      JacC( 12, 12) = JacC( 12, 12) - dw(102, 12)
      JacC( 50, 50) = JacC( 50, 50) - dw(102, 50)
      JacC( 50, 12) = JacC( 50, 12) - dw(102, 12)
      dw(103, 50) =  rk(103) * Y( 12)
      dw(103, 12) =  rk(103) * Y( 50)
      JacC( 15, 50) = JacC( 15, 50) + dw(103, 50)
      JacC( 15, 12) = JacC( 15, 12) + dw(103, 12)
      JacC( 16, 50) = JacC( 16, 50) + dw(103, 50)
      JacC( 16, 12) = JacC( 16, 12) + dw(103, 12)
      JacC( 35, 50) = JacC( 35, 50) + dw(103, 50)
      JacC( 35, 12) = JacC( 35, 12) + dw(103, 12)
      dw(104, 50) =  rk(104) * Y( 12)
      dw(104, 12) =  rk(104) * Y( 50)
      JacC( 17, 50) = JacC( 17, 50) + dw(104, 50)
      JacC( 17, 12) = JacC( 17, 12) + dw(104, 12)
      dw(105, 50) =  rk(105) * Y( 12)
      dw(105, 12) =  rk(105) * Y( 50)
      JacC( 18, 50) = JacC( 18, 50) + dw(105, 50)
      JacC( 18, 12) = JacC( 18, 12) + dw(105, 12)
      dw(106, 50) =  rk(106) * Y( 12)
      dw(106, 12) =  rk(106) * Y( 50)
      JacC( 34, 50) = JacC( 34, 50) + dw(106, 50)
      JacC( 34, 12) = JacC( 34, 12) + dw(106, 12)
      dw(107, 50) =  rk(107) * Y( 12)
      dw(107, 12) =  rk(107) * Y( 50)
      JacC( 37, 50) = JacC( 37, 50) + dw(107, 50)
      JacC( 37, 12) = JacC( 37, 12) + dw(107, 12)
      dw(108, 51) =  rk(108) * Y( 12)
      dw(108, 12) =  rk(108) * Y( 51)
      JacC( 12, 51) = JacC( 12, 51) - dw(108, 51)
      JacC( 12, 12) = JacC( 12, 12) - dw(108, 12)
      JacC( 34, 51) = JacC( 34, 51) + dw(108, 51)
      JacC( 34, 12) = JacC( 34, 12) + dw(108, 12)
      JacC( 51, 51) = JacC( 51, 51) - dw(108, 51)
      JacC( 51, 12) = JacC( 51, 12) - dw(108, 12)
      dw(109, 51) =  rk(109) * Y( 12)
      dw(109, 12) =  rk(109) * Y( 51)
      JacC( 15, 51) = JacC( 15, 51) + dw(109, 51)
      JacC( 15, 12) = JacC( 15, 12) + dw(109, 12)
      dw(110, 51) =  rk(110) * Y( 12)
      dw(110, 12) =  rk(110) * Y( 51)
      JacC( 16, 51) = JacC( 16, 51) + dw(110, 51)
      JacC( 16, 12) = JacC( 16, 12) + dw(110, 12)
      dw(111, 51) =  rk(111) * Y(  1)
      dw(111,  1) =  rk(111) * Y( 51)
      JacC(  1, 51) = JacC(  1, 51) - dw(111, 51)
      JacC(  1,  1) = JacC(  1,  1) - dw(111,  1)
      JacC( 11, 51) = JacC( 11, 51)+ 0.4400000000000000D+00*dw(111, 51)
      JacC( 11,  1) = JacC( 11,  1)+ 0.4400000000000000D+00*dw(111,  1)
      JacC( 13, 51) = JacC( 13, 51)+ 0.1200000000000000D+00*dw(111, 51)
      JacC( 13,  1) = JacC( 13,  1)+ 0.1200000000000000D+00*dw(111,  1)
      JacC( 15, 51) = JacC( 15, 51) + dw(111, 51)
      JacC( 15,  1) = JacC( 15,  1) + dw(111,  1)
      JacC( 47, 51) = JacC( 47, 51)+ 0.3700000000000000D+00*dw(111, 51)
      JacC( 47,  1) = JacC( 47,  1)+ 0.3700000000000000D+00*dw(111,  1)
      JacC( 51, 51) = JacC( 51, 51) - dw(111, 51)
      JacC( 51,  1) = JacC( 51,  1) - dw(111,  1)
      dw(112, 52) =  rk(112) * Y( 12)
      dw(112, 12) =  rk(112) * Y( 52)
      JacC( 12, 52) = JacC( 12, 52) - dw(112, 52)
      JacC( 12, 12) = JacC( 12, 12) - dw(112, 12)
      JacC( 15, 52) = JacC( 15, 52) + dw(112, 52)
      JacC( 15, 12) = JacC( 15, 12) + dw(112, 12)
      JacC( 16, 52) = JacC( 16, 52) + dw(112, 52)
      JacC( 16, 12) = JacC( 16, 12) + dw(112, 12)
      JacC( 34, 52) = JacC( 34, 52) + dw(112, 52)
      JacC( 34, 12) = JacC( 34, 12) + dw(112, 12)
      JacC( 52, 52) = JacC( 52, 52) - dw(112, 52)
      JacC( 52, 12) = JacC( 52, 12) - dw(112, 12)
      dw(113, 52) =  rk(113) * Y(  1)
      dw(113,  1) =  rk(113) * Y( 52)
      JacC(  1, 52) = JacC(  1, 52) - dw(113, 52)
      JacC(  1,  1) = JacC(  1,  1) - dw(113,  1)
      JacC( 11, 52) = JacC( 11, 52)+ 0.4000000000000000D+00*dw(113, 52)
      JacC( 11,  1) = JacC( 11,  1)+ 0.4000000000000000D+00*dw(113,  1)
      JacC( 12, 52) = JacC( 12, 52)+ 0.1500000000000000D+00*dw(113, 52)
      JacC( 12,  1) = JacC( 12,  1)+ 0.1500000000000000D+00*dw(113,  1)
      JacC( 13, 52) = JacC( 13, 52)+ 0.2800000000000000D+00*dw(113, 52)
      JacC( 13,  1) = JacC( 13,  1)+ 0.2800000000000000D+00*dw(113,  1)
      JacC( 15, 52) = JacC( 15, 52)+ 0.8400000000000001D+00*dw(113, 52)
      JacC( 15,  1) = JacC( 15,  1)+ 0.8400000000000001D+00*dw(113,  1)
      JacC( 16, 52) = JacC( 16, 52)+ 0.5000000000000000D+00*dw(113, 52)
      JacC( 16,  1) = JacC( 16,  1)+ 0.5000000000000000D+00*dw(113,  1)
      JacC( 34, 52) = JacC( 34, 52)+ 0.3100000000000000D+00*dw(113, 52)
      JacC( 34,  1) = JacC( 34,  1)+ 0.3100000000000000D+00*dw(113,  1)
      JacC( 47, 52) = JacC( 47, 52)+ 0.2250000000000000D+00*dw(113, 52)
      JacC( 47,  1) = JacC( 47,  1)+ 0.2250000000000000D+00*dw(113,  1)
      JacC( 48, 52) = JacC( 48, 52)+ 0.7000000000000001D-01*dw(113, 52)
      JacC( 48,  1) = JacC( 48,  1)+ 0.7000000000000001D-01*dw(113,  1)
      JacC( 52, 52) = JacC( 52, 52) - dw(113, 52)
      JacC( 52,  1) = JacC( 52,  1) - dw(113,  1)
      dw(114, 53) =  rk(114) * Y( 12)
      dw(114, 12) =  rk(114) * Y( 53)
      JacC( 12, 53) = JacC( 12, 53) - dw(114, 53)
      JacC( 12, 12) = JacC( 12, 12) - dw(114, 12)
      JacC( 15, 53) = JacC( 15, 53) + dw(114, 53)
      JacC( 15, 12) = JacC( 15, 12) + dw(114, 12)
      JacC( 17, 53) = JacC( 17, 53) + dw(114, 53)
      JacC( 17, 12) = JacC( 17, 12) + dw(114, 12)
      JacC( 34, 53) = JacC( 34, 53) + dw(114, 53)
      JacC( 34, 12) = JacC( 34, 12) + dw(114, 12)
      JacC( 53, 53) = JacC( 53, 53) - dw(114, 53)
      JacC( 53, 12) = JacC( 53, 12) - dw(114, 12)
      dw(115, 53) =  rk(115) * Y(  1)
      dw(115,  1) =  rk(115) * Y( 53)
      JacC(  1, 53) = JacC(  1, 53) - dw(115, 53)
      JacC(  1,  1) = JacC(  1,  1) - dw(115,  1)
      JacC( 11, 53) = JacC( 11, 53)+ 0.4000000000000000D+00*dw(115, 53)
      JacC( 11,  1) = JacC( 11,  1)+ 0.4000000000000000D+00*dw(115,  1)
      JacC( 12, 53) = JacC( 12, 53)+ 0.1500000000000000D+00*dw(115, 53)
      JacC( 12,  1) = JacC( 12,  1)+ 0.1500000000000000D+00*dw(115,  1)
      JacC( 13, 53) = JacC( 13, 53)+ 0.2800000000000000D+00*dw(115, 53)
      JacC( 13,  1) = JacC( 13,  1)+ 0.2800000000000000D+00*dw(115,  1)
      JacC( 15, 53) = JacC( 15, 53)+ 0.5000000000000000D+00*dw(115, 53)
      JacC( 15,  1) = JacC( 15,  1)+ 0.5000000000000000D+00*dw(115,  1)
      JacC( 16, 53) = JacC( 16, 53)+ 0.3400000000000000D+00*dw(115, 53)
      JacC( 16,  1) = JacC( 16,  1)+ 0.3400000000000000D+00*dw(115,  1)
      JacC( 17, 53) = JacC( 17, 53)+ 0.5000000000000000D+00*dw(115, 53)
      JacC( 17,  1) = JacC( 17,  1)+ 0.5000000000000000D+00*dw(115,  1)
      JacC( 34, 53) = JacC( 34, 53)+ 0.3100000000000000D+00*dw(115, 53)
      JacC( 34,  1) = JacC( 34,  1)+ 0.3100000000000000D+00*dw(115,  1)
      JacC( 47, 53) = JacC( 47, 53)+ 0.2750000000000000D+00*dw(115, 53)
      JacC( 47,  1) = JacC( 47,  1)+ 0.2750000000000000D+00*dw(115,  1)
      JacC( 49, 53) = JacC( 49, 53)+ 0.7000000000000001D-01*dw(115, 53)
      JacC( 49,  1) = JacC( 49,  1)+ 0.7000000000000001D-01*dw(115,  1)
      JacC( 53, 53) = JacC( 53, 53) - dw(115, 53)
      JacC( 53,  1) = JacC( 53,  1) - dw(115,  1)
      dw(116, 53) =  rk(116) * Y( 14)
      dw(116, 14) =  rk(116) * Y( 53)
      JacC(  2, 53) = JacC(  2, 53) + dw(116, 53)
      JacC(  2, 14) = JacC(  2, 14) + dw(116, 14)
      JacC( 14, 53) = JacC( 14, 53) - dw(116, 53)
      JacC( 14, 14) = JacC( 14, 14) - dw(116, 14)
      JacC( 15, 53) = JacC( 15, 53) + dw(116, 53)
      JacC( 15, 14) = JacC( 15, 14) + dw(116, 14)
      JacC( 17, 53) = JacC( 17, 53) + dw(116, 53)
      JacC( 17, 14) = JacC( 17, 14) + dw(116, 14)
      JacC( 36, 53) = JacC( 36, 53) + dw(116, 53)
      JacC( 36, 14) = JacC( 36, 14) + dw(116, 14)
      JacC( 53, 53) = JacC( 53, 53) - dw(116, 53)
      JacC( 53, 14) = JacC( 53, 14) - dw(116, 14)
      dw(117, 54) =  rk(117) * Y( 12)
      dw(117, 12) =  rk(117) * Y( 54)
      JacC( 11, 54) = JacC( 11, 54)+ 0.3600000000000000D+00*dw(117, 54)
      JacC( 11, 12) = JacC( 11, 12)+ 0.3600000000000000D+00*dw(117, 12)
      JacC( 12, 54) = JacC( 12, 54)- 0.3600000000000000D+00*dw(117, 54)
      JacC( 12, 12) = JacC( 12, 12)- 0.3600000000000000D+00*dw(117, 12)
      JacC( 13, 54) = JacC( 13, 54)+ 0.3600000000000000D+00*dw(117, 54)
      JacC( 13, 12) = JacC( 13, 12)+ 0.3600000000000000D+00*dw(117, 12)
      JacC( 21, 54) = JacC( 21, 54)+ 0.6400000000000000D+00*dw(117, 54)
      JacC( 21, 12) = JacC( 21, 12)+ 0.6400000000000000D+00*dw(117, 12)
      JacC( 54, 54) = JacC( 54, 54) - dw(117, 54)
      JacC( 54, 12) = JacC( 54, 12) - dw(117, 12)
      dw(118, 55) =  rk(118) * Y( 12)
      dw(118, 12) =  rk(118) * Y( 55)
      JacC( 12, 55) = JacC( 12, 55) - dw(118, 55)
      JacC( 12, 12) = JacC( 12, 12) - dw(118, 12)
      JacC( 13, 55) = JacC( 13, 55)+ 0.2360000000000000D+00*dw(118, 55)
      JacC( 13, 12) = JacC( 13, 12)+ 0.2360000000000000D+00*dw(118, 12)
      JacC( 21, 55) = JacC( 21, 55)+ 0.2070000000000000D+00*dw(118, 55)
      JacC( 21, 12) = JacC( 21, 12)+ 0.2070000000000000D+00*dw(118, 12)
      JacC( 24, 55) = JacC( 24, 55)+ 0.4900000000000000D+00*dw(118, 55)
      JacC( 24, 12) = JacC( 24, 12)+ 0.4900000000000000D+00*dw(118, 12)
      JacC( 25, 55) = JacC( 25, 55)+ 0.2360000000000000D+00*dw(118, 55)
      JacC( 25, 12) = JacC( 25, 12)+ 0.2360000000000000D+00*dw(118, 12)
      JacC( 34, 55) = JacC( 34, 55)+ 0.7640000000000000D+00*dw(118, 55)
      JacC( 34, 12) = JacC( 34, 12)+ 0.7640000000000000D+00*dw(118, 12)
      JacC( 55, 55) = JacC( 55, 55) - dw(118, 55)
      JacC( 55, 12) = JacC( 55, 12) - dw(118, 12)
      dw(119, 56) =  rk(119) * Y( 12)
      dw(119, 12) =  rk(119) * Y( 56)
      JacC( 12, 56) = JacC( 12, 56) - dw(119, 56)
      JacC( 12, 12) = JacC( 12, 12) - dw(119, 12)
      JacC( 15, 56) = JacC( 15, 56) + dw(119, 56)
      JacC( 15, 12) = JacC( 15, 12) + dw(119, 12)
      JacC( 20, 56) = JacC( 20, 56) + dw(119, 56)
      JacC( 20, 12) = JacC( 20, 12) + dw(119, 12)
      JacC( 34, 56) = JacC( 34, 56) + dw(119, 56)
      JacC( 34, 12) = JacC( 34, 12) + dw(119, 12)
      JacC( 56, 56) = JacC( 56, 56) - dw(119, 56)
      JacC( 56, 12) = JacC( 56, 12) - dw(119, 12)
      dw(120, 57) =  rk(120) * Y( 12)
      dw(120, 12) =  rk(120) * Y( 57)
      JacC( 12, 57) = JacC( 12, 57) - dw(120, 57)
      JacC( 12, 12) = JacC( 12, 12) - dw(120, 12)
      JacC( 13, 57) = JacC( 13, 57) + dw(120, 57)
      JacC( 13, 12) = JacC( 13, 12) + dw(120, 12)
      JacC( 15, 57) = JacC( 15, 57) + dw(120, 57)
      JacC( 15, 12) = JacC( 15, 12) + dw(120, 12)
      JacC( 57, 57) = JacC( 57, 57) - dw(120, 57)
      JacC( 57, 12) = JacC( 57, 12) - dw(120, 12)
      dw(121, 58) =  rk(121) * Y( 12)
      dw(121, 12) =  rk(121) * Y( 58)
      JacC( 12, 58) = JacC( 12, 58) - dw(121, 58)
      JacC( 12, 12) = JacC( 12, 12) - dw(121, 12)
      JacC( 13, 58) = JacC( 13, 58) + dw(121, 58)
      JacC( 13, 12) = JacC( 13, 12) + dw(121, 12)
      JacC( 16, 58) = JacC( 16, 58) + dw(121, 58)
      JacC( 16, 12) = JacC( 16, 12) + dw(121, 12)
      JacC( 58, 58) = JacC( 58, 58) - dw(121, 58)
      JacC( 58, 12) = JacC( 58, 12) - dw(121, 12)
      dw(122, 59) =  rk(122) * Y( 12)
      dw(122, 12) =  rk(122) * Y( 59)
      JacC( 12, 59) = JacC( 12, 59) - dw(122, 59)
      JacC( 12, 12) = JacC( 12, 12) - dw(122, 12)
      JacC( 59, 59) = JacC( 59, 59) - dw(122, 59)
      JacC( 59, 12) = JacC( 59, 12) - dw(122, 12)
      dw(123, 59) =  rk(123) * Y( 12)
      dw(123, 12) =  rk(123) * Y( 59)
      JacC( 15, 59) = JacC( 15, 59) + dw(123, 59)
      JacC( 15, 12) = JacC( 15, 12) + dw(123, 12)
      dw(124, 59) =  rk(124) * Y( 12)
      dw(124, 12) =  rk(124) * Y( 59)
      JacC( 16, 59) = JacC( 16, 59) + dw(124, 59)
      JacC( 16, 12) = JacC( 16, 12) + dw(124, 12)
      dw(125, 59) =  rk(125) * Y( 12)
      dw(125, 12) =  rk(125) * Y( 59)
      JacC( 17, 59) = JacC( 17, 59) + dw(125, 59)
      JacC( 17, 12) = JacC( 17, 12) + dw(125, 12)
      dw(126, 59) =  rk(126) * Y( 12)
      dw(126, 12) =  rk(126) * Y( 59)
      JacC( 18, 59) = JacC( 18, 59) + dw(126, 59)
      JacC( 18, 12) = JacC( 18, 12) + dw(126, 12)
      dw(127, 59) =  rk(127) * Y( 12)
      dw(127, 12) =  rk(127) * Y( 59)
      JacC( 19, 59) = JacC( 19, 59) + dw(127, 59)
      JacC( 19, 12) = JacC( 19, 12) + dw(127, 12)
      dw(128, 59) =  rk(128) * Y( 12)
      dw(128, 12) =  rk(128) * Y( 59)
      JacC( 34, 59) = JacC( 34, 59) + dw(128, 59)
      JacC( 34, 12) = JacC( 34, 12) + dw(128, 12)
      dw(129, 59) =  rk(129) * Y( 12)
      dw(129, 12) =  rk(129) * Y( 59)
      JacC( 35, 59) = JacC( 35, 59) + dw(129, 59)
      JacC( 35, 12) = JacC( 35, 12) + dw(129, 12)
      dw(130, 59) =  rk(130) * Y( 12)
      dw(130, 12) =  rk(130) * Y( 59)
      JacC( 36, 59) = JacC( 36, 59) + dw(130, 59)
      JacC( 36, 12) = JacC( 36, 12) + dw(130, 12)
      dw(131, 59) =  rk(131) * Y( 12)
      dw(131, 12) =  rk(131) * Y( 59)
      JacC( 37, 59) = JacC( 37, 59) + dw(131, 59)
      JacC( 37, 12) = JacC( 37, 12) + dw(131, 12)
      dw(132, 60) =  rk(132) * Y( 12)
      dw(132, 12) =  rk(132) * Y( 60)
      JacC( 12, 60) = JacC( 12, 60) - dw(132, 60)
      JacC( 12, 12) = JacC( 12, 12) - dw(132, 12)
      JacC( 60, 60) = JacC( 60, 60) - dw(132, 60)
      JacC( 60, 12) = JacC( 60, 12) - dw(132, 12)
      dw(133, 60) =  rk(133) * Y( 12)
      dw(133, 12) =  rk(133) * Y( 60)
      JacC( 15, 60) = JacC( 15, 60) + dw(133, 60)
      JacC( 15, 12) = JacC( 15, 12) + dw(133, 12)
      dw(134, 60) =  rk(134) * Y( 12)
      dw(134, 12) =  rk(134) * Y( 60)
      JacC( 16, 60) = JacC( 16, 60) + dw(134, 60)
      JacC( 16, 12) = JacC( 16, 12) + dw(134, 12)
      dw(135, 60) =  rk(135) * Y( 12)
      dw(135, 12) =  rk(135) * Y( 60)
      JacC( 17, 60) = JacC( 17, 60) + dw(135, 60)
      JacC( 17, 12) = JacC( 17, 12) + dw(135, 12)
      dw(136, 60) =  rk(136) * Y( 12)
      dw(136, 12) =  rk(136) * Y( 60)
      JacC( 18, 60) = JacC( 18, 60) + dw(136, 60)
      JacC( 18, 12) = JacC( 18, 12) + dw(136, 12)
      dw(137, 60) =  rk(137) * Y( 12)
      dw(137, 12) =  rk(137) * Y( 60)
      JacC( 19, 60) = JacC( 19, 60) + dw(137, 60)
      JacC( 19, 12) = JacC( 19, 12) + dw(137, 12)
      dw(138, 60) =  rk(138) * Y( 12)
      dw(138, 12) =  rk(138) * Y( 60)
      JacC( 34, 60) = JacC( 34, 60) + dw(138, 60)
      JacC( 34, 12) = JacC( 34, 12) + dw(138, 12)
      dw(139, 60) =  rk(139) * Y( 12)
      dw(139, 12) =  rk(139) * Y( 60)
      JacC( 35, 60) = JacC( 35, 60) + dw(139, 60)
      JacC( 35, 12) = JacC( 35, 12) + dw(139, 12)
      dw(140, 60) =  rk(140) * Y( 12)
      dw(140, 12) =  rk(140) * Y( 60)
      JacC( 36, 60) = JacC( 36, 60) + dw(140, 60)
      JacC( 36, 12) = JacC( 36, 12) + dw(140, 12)
      dw(141, 60) =  rk(141) * Y( 12)
      dw(141, 12) =  rk(141) * Y( 60)
      JacC( 37, 60) = JacC( 37, 60) + dw(141, 60)
      JacC( 37, 12) = JacC( 37, 12) + dw(141, 12)
      dw(142, 61) =  rk(142) * Y( 12)
      dw(142, 12) =  rk(142) * Y( 61)
      JacC( 12, 61) = JacC( 12, 61) - dw(142, 61)
      JacC( 12, 12) = JacC( 12, 12) - dw(142, 12)
      JacC( 61, 61) = JacC( 61, 61) - dw(142, 61)
      JacC( 61, 12) = JacC( 61, 12) - dw(142, 12)
      dw(143, 61) =  rk(143) * Y( 12)
      dw(143, 12) =  rk(143) * Y( 61)
      JacC( 15, 61) = JacC( 15, 61) + dw(143, 61)
      JacC( 15, 12) = JacC( 15, 12) + dw(143, 12)
      dw(144, 61) =  rk(144) * Y( 12)
      dw(144, 12) =  rk(144) * Y( 61)
      JacC( 16, 61) = JacC( 16, 61) + dw(144, 61)
      JacC( 16, 12) = JacC( 16, 12) + dw(144, 12)
      dw(145, 61) =  rk(145) * Y( 12)
      dw(145, 12) =  rk(145) * Y( 61)
      JacC( 17, 61) = JacC( 17, 61) + dw(145, 61)
      JacC( 17, 12) = JacC( 17, 12) + dw(145, 12)
      dw(146, 61) =  rk(146) * Y( 12)
      dw(146, 12) =  rk(146) * Y( 61)
      JacC( 18, 61) = JacC( 18, 61) + dw(146, 61)
      JacC( 18, 12) = JacC( 18, 12) + dw(146, 12)
      dw(147, 61) =  rk(147) * Y( 12)
      dw(147, 12) =  rk(147) * Y( 61)
      JacC( 19, 61) = JacC( 19, 61) + dw(147, 61)
      JacC( 19, 12) = JacC( 19, 12) + dw(147, 12)
      dw(148, 61) =  rk(148) * Y( 12)
      dw(148, 12) =  rk(148) * Y( 61)
      JacC( 34, 61) = JacC( 34, 61) + dw(148, 61)
      JacC( 34, 12) = JacC( 34, 12) + dw(148, 12)
      dw(149, 61) =  rk(149) * Y( 12)
      dw(149, 12) =  rk(149) * Y( 61)
      JacC( 35, 61) = JacC( 35, 61) + dw(149, 61)
      JacC( 35, 12) = JacC( 35, 12) + dw(149, 12)
      dw(150, 61) =  rk(150) * Y( 12)
      dw(150, 12) =  rk(150) * Y( 61)
      JacC( 36, 61) = JacC( 36, 61) + dw(150, 61)
      JacC( 36, 12) = JacC( 36, 12) + dw(150, 12)
      dw(151, 61) =  rk(151) * Y( 12)
      dw(151, 12) =  rk(151) * Y( 61)
      JacC( 37, 61) = JacC( 37, 61) + dw(151, 61)
      JacC( 37, 12) = JacC( 37, 12) + dw(151, 12)
      dw(152, 62) =  rk(152) * Y( 12)
      dw(152, 12) =  rk(152) * Y( 62)
      JacC( 12, 62) = JacC( 12, 62) - dw(152, 62)
      JacC( 12, 12) = JacC( 12, 12) - dw(152, 12)
      JacC( 15, 62) = JacC( 15, 62)+ 0.9270000000000000D+00*dw(152, 62)
      JacC( 15, 12) = JacC( 15, 12)+ 0.9270000000000000D+00*dw(152, 12)
      JacC( 17, 62) = JacC( 17, 62)+ 0.9270000000000000D+00*dw(152, 62)
      JacC( 17, 12) = JacC( 17, 12)+ 0.9270000000000000D+00*dw(152, 12)
      JacC( 34, 62) = JacC( 34, 62)+ 0.9270000000000000D+00*dw(152, 62)
      JacC( 34, 12) = JacC( 34, 12)+ 0.9270000000000000D+00*dw(152, 12)
      JacC( 37, 62) = JacC( 37, 62)+ 0.7300000000000000D-01*dw(152, 62)
      JacC( 37, 12) = JacC( 37, 12)+ 0.7300000000000000D-01*dw(152, 12)
      JacC( 62, 62) = JacC( 62, 62) - dw(152, 62)
      JacC( 62, 12) = JacC( 62, 12) - dw(152, 12)
      dw(153, 62) =  rk(153) * Y(  1)
      dw(153,  1) =  rk(153) * Y( 62)
      JacC(  1, 62) = JacC(  1, 62) - dw(153, 62)
      JacC(  1,  1) = JacC(  1,  1) - dw(153,  1)
      JacC( 11, 62) = JacC( 11, 62)+ 0.4000000000000000D+00*dw(153, 62)
      JacC( 11,  1) = JacC( 11,  1)+ 0.4000000000000000D+00*dw(153,  1)
      JacC( 12, 62) = JacC( 12, 62)+ 0.1500000000000000D+00*dw(153, 62)
      JacC( 12,  1) = JacC( 12,  1)+ 0.1500000000000000D+00*dw(153,  1)
      JacC( 13, 62) = JacC( 13, 62)+ 0.2800000000000000D+00*dw(153, 62)
      JacC( 13,  1) = JacC( 13,  1)+ 0.2800000000000000D+00*dw(153,  1)
      JacC( 15, 62) = JacC( 15, 62)+ 0.5000000000000000D+00*dw(153, 62)
      JacC( 15,  1) = JacC( 15,  1)+ 0.5000000000000000D+00*dw(153,  1)
      JacC( 16, 62) = JacC( 16, 62)+ 0.3400000000000000D+00*dw(153, 62)
      JacC( 16,  1) = JacC( 16,  1)+ 0.3400000000000000D+00*dw(153,  1)
      JacC( 17, 62) = JacC( 17, 62)+ 0.5000000000000000D+00*dw(153, 62)
      JacC( 17,  1) = JacC( 17,  1)+ 0.5000000000000000D+00*dw(153,  1)
      JacC( 34, 62) = JacC( 34, 62)+ 0.3100000000000000D+00*dw(153, 62)
      JacC( 34,  1) = JacC( 34,  1)+ 0.3100000000000000D+00*dw(153,  1)
      JacC( 47, 62) = JacC( 47, 62)+ 0.2750000000000000D+00*dw(153, 62)
      JacC( 47,  1) = JacC( 47,  1)+ 0.2750000000000000D+00*dw(153,  1)
      JacC( 49, 62) = JacC( 49, 62)+ 0.7000000000000001D-01*dw(153, 62)
      JacC( 49,  1) = JacC( 49,  1)+ 0.7000000000000001D-01*dw(153,  1)
      JacC( 62, 62) = JacC( 62, 62) - dw(153, 62)
      JacC( 62,  1) = JacC( 62,  1) - dw(153,  1)
      dw(154, 62) =  rk(154) * Y( 14)
      dw(154, 14) =  rk(154) * Y( 62)
      JacC(  2, 62) = JacC(  2, 62) + dw(154, 62)
      JacC(  2, 14) = JacC(  2, 14) + dw(154, 14)
      JacC( 14, 62) = JacC( 14, 62) - dw(154, 62)
      JacC( 14, 14) = JacC( 14, 14) - dw(154, 14)
      JacC( 15, 62) = JacC( 15, 62) + dw(154, 62)
      JacC( 15, 14) = JacC( 15, 14) + dw(154, 14)
      JacC( 17, 62) = JacC( 17, 62) + dw(154, 62)
      JacC( 17, 14) = JacC( 17, 14) + dw(154, 14)
      JacC( 36, 62) = JacC( 36, 62) + dw(154, 62)
      JacC( 36, 14) = JacC( 36, 14) + dw(154, 14)
      JacC( 62, 62) = JacC( 62, 62) - dw(154, 62)
      JacC( 62, 14) = JacC( 62, 14) - dw(154, 14)
      dw(155, 63) =  rk(155) * Y( 12)
      dw(155, 12) =  rk(155) * Y( 63)
      JacC( 12, 63) = JacC( 12, 63) - dw(155, 63)
      JacC( 12, 12) = JacC( 12, 12) - dw(155, 12)
      JacC( 15, 63) = JacC( 15, 63)+ 0.2500000000000000D+00*dw(155, 63)
      JacC( 15, 12) = JacC( 15, 12)+ 0.2500000000000000D+00*dw(155, 12)
      JacC( 16, 63) = JacC( 16, 63)+ 0.1178000000000000D+01*dw(155, 63)
      JacC( 16, 12) = JacC( 16, 12)+ 0.1178000000000000D+01*dw(155, 12)
      JacC( 17, 63) = JacC( 17, 63)+ 0.2010000000000000D+00*dw(155, 63)
      JacC( 17, 12) = JacC( 17, 12)+ 0.2010000000000000D+00*dw(155, 12)
      JacC( 18, 63) = JacC( 18, 63)+ 0.2500000000000000D+00*dw(155, 63)
      JacC( 18, 12) = JacC( 18, 12)+ 0.2500000000000000D+00*dw(155, 12)
      JacC( 19, 63) = JacC( 19, 63)+ 0.7600000000000000D-01*dw(155, 63)
      JacC( 19, 12) = JacC( 19, 12)+ 0.7600000000000000D-01*dw(155, 12)
      JacC( 34, 63) = JacC( 34, 63)+ 0.9780000000000000D+00*dw(155, 63)
      JacC( 34, 12) = JacC( 34, 12)+ 0.9780000000000000D+00*dw(155, 12)
      JacC( 37, 63) = JacC( 37, 63)+ 0.2200000000000000D-01*dw(155, 63)
      JacC( 37, 12) = JacC( 37, 12)+ 0.2200000000000000D-01*dw(155, 12)
      JacC( 63, 63) = JacC( 63, 63) - dw(155, 63)
      JacC( 63, 12) = JacC( 63, 12) - dw(155, 12)
      dw(156, 63) =  rk(156) * Y(  1)
      dw(156,  1) =  rk(156) * Y( 63)
      JacC(  1, 63) = JacC(  1, 63) - dw(156, 63)
      JacC(  1,  1) = JacC(  1,  1) - dw(156,  1)
      JacC( 15, 63) = JacC( 15, 63)+ 0.5090000000000000D+00*dw(156, 63)
      JacC( 15,  1) = JacC( 15,  1)+ 0.5090000000000000D+00*dw(156,  1)
      JacC( 16, 63) = JacC( 16, 63)+ 0.8280000000000000D+00*dw(156, 63)
      JacC( 16,  1) = JacC( 16,  1)+ 0.8280000000000000D+00*dw(156,  1)
      JacC( 17, 63) = JacC( 17, 63)+ 0.1420000000000000D+00*dw(156, 63)
      JacC( 17,  1) = JacC( 17,  1)+ 0.1420000000000000D+00*dw(156,  1)
      JacC( 18, 63) = JacC( 18, 63)+ 0.1180000000000000D+00*dw(156, 63)
      JacC( 18,  1) = JacC( 18,  1)+ 0.1180000000000000D+00*dw(156,  1)
      JacC( 19, 63) = JacC( 19, 63)+ 0.9800000000000000D-01*dw(156, 63)
      JacC( 19,  1) = JacC( 19,  1)+ 0.9800000000000000D-01*dw(156,  1)
      JacC( 22, 63) = JacC( 22, 63)+ 0.1900000000000000D-01*dw(156, 63)
      JacC( 22,  1) = JacC( 22,  1)+ 0.1900000000000000D-01*dw(156,  1)
      JacC( 39, 63) = JacC( 39, 63)+ 0.5000000000000000D-02*dw(156, 63)
      JacC( 39,  1) = JacC( 39,  1)+ 0.5000000000000000D-02*dw(156,  1)
      JacC( 47, 63) = JacC( 47, 63)+ 0.1600000000000000D+00*dw(156, 63)
      JacC( 47,  1) = JacC( 47,  1)+ 0.1600000000000000D+00*dw(156,  1)
      JacC( 63, 63) = JacC( 63, 63) - dw(156, 63)
      JacC( 63,  1) = JacC( 63,  1) - dw(156,  1)
      dw(157, 63) =  rk(157) * Y(  1)
      dw(157,  1) =  rk(157) * Y( 63)
      JacC( 11, 63) = JacC( 11, 63)+ 0.3170000000000000D+00*dw(157, 63)
      JacC( 11,  1) = JacC( 11,  1)+ 0.3170000000000000D+00*dw(157,  1)
      JacC( 12, 63) = JacC( 12, 63)+ 0.2860000000000000D+00*dw(157, 63)
      JacC( 12,  1) = JacC( 12,  1)+ 0.2860000000000000D+00*dw(157,  1)
      JacC( 13, 63) = JacC( 13, 63)+ 0.3850000000000000D+00*dw(157, 63)
      JacC( 13,  1) = JacC( 13,  1)+ 0.3850000000000000D+00*dw(157,  1)
      JacC( 34, 63) = JacC( 34, 63)+ 0.5600000000000001D+00*dw(157, 63)
      JacC( 34,  1) = JacC( 34,  1)+ 0.5600000000000001D+00*dw(157,  1)
      JacC( 36, 63) = JacC( 36, 63)+ 0.5000000000000000D-02*dw(157, 63)
      JacC( 36,  1) = JacC( 36,  1)+ 0.5000000000000000D-02*dw(157,  1)
      JacC( 48, 63) = JacC( 48, 63)+ 0.1020000000000000D+00*dw(157, 63)
      JacC( 48,  1) = JacC( 48,  1)+ 0.1020000000000000D+00*dw(157,  1)
      JacC( 49, 63) = JacC( 49, 63)+ 0.2000000000000000D-01*dw(157, 63)
      JacC( 49,  1) = JacC( 49,  1)+ 0.2000000000000000D-01*dw(157,  1)
      dw(158, 63) =  rk(158) * Y( 14)
      dw(158, 14) =  rk(158) * Y( 63)
      JacC(  2, 63) = JacC(  2, 63) + dw(158, 63)
      JacC(  2, 14) = JacC(  2, 14) + dw(158, 14)
      JacC( 14, 63) = JacC( 14, 63) - dw(158, 63)
      JacC( 14, 14) = JacC( 14, 14) - dw(158, 14)
      JacC( 15, 63) = JacC( 15, 63)+ 0.5600000000000000D-01*dw(158, 63)
      JacC( 15, 14) = JacC( 15, 14)+ 0.5600000000000000D-01*dw(158, 14)
      JacC( 16, 63) = JacC( 16, 63)+ 0.1122000000000000D+01*dw(158, 63)
      JacC( 16, 14) = JacC( 16, 14)+ 0.1122000000000000D+01*dw(158, 14)
      JacC( 17, 63) = JacC( 17, 63)+ 0.6000000000000000D-01*dw(158, 63)
      JacC( 17, 14) = JacC( 17, 14)+ 0.6000000000000000D-01*dw(158, 14)
      JacC( 18, 63) = JacC( 18, 63)+ 0.7460000000000000D+00*dw(158, 63)
      JacC( 18, 14) = JacC( 18, 14)+ 0.7460000000000000D+00*dw(158, 14)
      JacC( 19, 63) = JacC( 19, 63)+ 0.1700000000000000D-01*dw(158, 63)
      JacC( 19, 14) = JacC( 19, 14)+ 0.1700000000000000D-01*dw(158, 14)
      JacC( 36, 63) = JacC( 36, 63) + dw(158, 63)
      JacC( 36, 14) = JacC( 36, 14) + dw(158, 14)
      JacC( 63, 63) = JacC( 63, 63) - dw(158, 63)
      JacC( 63, 14) = JacC( 63, 14) - dw(158, 14)
      dw(159, 64) =  rk(159) * Y( 12)
      dw(159, 12) =  rk(159) * Y( 64)
      JacC( 12, 64) = JacC( 12, 64) - dw(159, 64)
      JacC( 12, 12) = JacC( 12, 12) - dw(159, 12)
      JacC( 13, 64) = JacC( 13, 64)+ 0.2600000000000000D+00*dw(159, 64)
      JacC( 13, 12) = JacC( 13, 12)+ 0.2600000000000000D+00*dw(159, 12)
      JacC( 20, 64) = JacC( 20, 64)+ 0.7700000000000000D-01*dw(159, 64)
      JacC( 20, 12) = JacC( 20, 12)+ 0.7700000000000000D-01*dw(159, 12)
      JacC( 21, 64) = JacC( 21, 64)+ 0.1180000000000000D+00*dw(159, 64)
      JacC( 21, 12) = JacC( 21, 12)+ 0.1180000000000000D+00*dw(159, 12)
      JacC( 22, 64) = JacC( 22, 64)+ 0.1310000000000000D+00*dw(159, 64)
      JacC( 22, 12) = JacC( 22, 12)+ 0.1310000000000000D+00*dw(159, 12)
      JacC( 23, 64) = JacC( 23, 64)+ 0.4100000000000000D+00*dw(159, 64)
      JacC( 23, 12) = JacC( 23, 12)+ 0.4100000000000000D+00*dw(159, 12)
      JacC( 26, 64) = JacC( 26, 64)+ 0.2600000000000000D+00*dw(159, 64)
      JacC( 26, 12) = JacC( 26, 12)+ 0.2600000000000000D+00*dw(159, 12)
      JacC( 34, 64) = JacC( 34, 64)+ 0.7320000000000000D+00*dw(159, 64)
      JacC( 34, 12) = JacC( 34, 12)+ 0.7320000000000000D+00*dw(159, 12)
      JacC( 64, 64) = JacC( 64, 64) - dw(159, 64)
      JacC( 64, 12) = JacC( 64, 12) - dw(159, 12)
      dw(160, 65) =  rk(160) * Y( 12)
      dw(160, 12) =  rk(160) * Y( 65)
      JacC( 12, 65) = JacC( 12, 65) - dw(160, 65)
      JacC( 12, 12) = JacC( 12, 12) - dw(160, 12)
      JacC( 13, 65) = JacC( 13, 65)+ 0.1800000000000000D+00*dw(160, 65)
      JacC( 13, 12) = JacC( 13, 12)+ 0.1800000000000000D+00*dw(160, 12)
      JacC( 20, 65) = JacC( 20, 65)+ 0.3400000000000000D-01*dw(160, 65)
      JacC( 20, 12) = JacC( 20, 12)+ 0.3400000000000000D-01*dw(160, 12)
      JacC( 21, 65) = JacC( 21, 65)+ 0.8000000000000000D-01*dw(160, 65)
      JacC( 21, 12) = JacC( 21, 12)+ 0.8000000000000000D-01*dw(160, 12)
      JacC( 22, 65) = JacC( 22, 65)+ 0.4340000000000000D+00*dw(160, 65)
      JacC( 22, 12) = JacC( 22, 12)+ 0.4340000000000000D+00*dw(160, 12)
      JacC( 23, 65) = JacC( 23, 65)+ 0.6490000000000000D+00*dw(160, 65)
      JacC( 23, 12) = JacC( 23, 12)+ 0.6490000000000000D+00*dw(160, 12)
      JacC( 26, 65) = JacC( 26, 65)+ 0.1800000000000000D+00*dw(160, 65)
      JacC( 26, 12) = JacC( 26, 12)+ 0.1800000000000000D+00*dw(160, 12)
      JacC( 34, 65) = JacC( 34, 65)+ 0.8169999999999999D+00*dw(160, 65)
      JacC( 34, 12) = JacC( 34, 12)+ 0.8169999999999999D+00*dw(160, 12)
      JacC( 65, 65) = JacC( 65, 65) - dw(160, 65)
      JacC( 65, 12) = JacC( 65, 12) - dw(160, 12)
      dw(161, 66) =  rk(161) * Y( 12)
      dw(161, 12) =  rk(161) * Y( 66)
      JacC( 12, 66) = JacC( 12, 66) - dw(161, 66)
      JacC( 12, 12) = JacC( 12, 12) - dw(161, 12)
      JacC( 13, 66) = JacC( 13, 66)+ 0.7960000000000000D+00*dw(161, 66)
      JacC( 13, 12) = JacC( 13, 12)+ 0.7960000000000000D+00*dw(161, 12)
      JacC( 16, 66) = JacC( 16, 66)+ 0.6200000000000000D-01*dw(161, 66)
      JacC( 16, 12) = JacC( 16, 12)+ 0.6200000000000000D-01*dw(161, 12)
      JacC( 17, 66) = JacC( 17, 66)+ 0.3950000000000000D+00*dw(161, 66)
      JacC( 17, 12) = JacC( 17, 12)+ 0.3950000000000000D+00*dw(161, 12)
      JacC( 18, 66) = JacC( 18, 66)+ 0.1780000000000000D+00*dw(161, 66)
      JacC( 18, 12) = JacC( 18, 12)+ 0.1780000000000000D+00*dw(161, 12)
      JacC( 19, 66) = JacC( 19, 66)+ 0.2710000000000000D+00*dw(161, 66)
      JacC( 19, 12) = JacC( 19, 12)+ 0.2710000000000000D+00*dw(161, 12)
      JacC( 34, 66) = JacC( 34, 66)+ 0.2040000000000000D+00*dw(161, 66)
      JacC( 34, 12) = JacC( 34, 12)+ 0.2040000000000000D+00*dw(161, 12)
      JacC( 66, 66) = JacC( 66, 66) - dw(161, 66)
      JacC( 66, 12) = JacC( 66, 12) - dw(161, 12)

      RETURN
      END

