C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      subroutine kinetic(rk,temp,xlw,Press,azi,att)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes the kinetic rates for the gas-phase 
C     mechanism RADM.
C     This routine is automatically generated by SPACK.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     TEMP: temperature ([K]).
C     XLW: water massic fraction.
C     PRESS: pressure ([Pa]).
C     AZI: zenithal angle ([degree]).
C     ATT: ???
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     RK: kinetic rates.
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Karine Sartelet and Bruno Sportisse, CEREA, February 2002.
C     
C------------------------------------------------------------------------

      implicit none

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMUSE: flags and parameters for numerics. 
C     COMDATA: global variables for chemical data (e.g. molar mass). 
C     COMCHEM: global variables for chemical species. 

      include 'PARACHEM.INC'
      include 'COMUSE.INC'
      INCLUDE 'PARADOM.INC'
      include 'COMDATA.INC'
      include 'COMCHEM.INC'

      double precision                         rk(nr),temp,xlw,Press
      double precision         Effko,Rapk,facteur,SumM,Fcent,azi,att
      double precision                            YlH2O,VO2,VN2,VH2O
      INTEGER j,k

C     Compute third body.
C     Conversion = Avogadro*1d-6/Perfect gas constant
C     PRESS in Pascal, SUMM in molecules/cm3, TEMP in Kelvin

      SumM = Press * 7.243D16 / temp

C     Number of water molecules computed from the massic fraction
C     (absolute humidity)

      YlH2O = 29.d0*SumM*xlw/(18.d0+11.d0*xlw)

C------------------------------------------------------------------------
C     1 - Photolytic reactions.

C     For the zenithal angle at tropics.

      azi = abs(azi)

C------------------------------------------------------------------------
C     2 - Thermal reactions.

      rk(  1) =  DEXP(-0.2704323445102643D+02
     &     - (  0.1370000000000000D+04 )/temp)
      rk(  2) =  DEXP(-0.2975128465212864D+02
     &     - (  0.2450000000000000D+04 )/temp)
      rk(  3) =  DEXP(-0.2698916722975615D+02
     &     - (  0.1000000000000000D+04 )/temp)
      rk(  4) =  DEXP(-0.3189971906529543D+02
     &     - (  0.6000000000000000D+03 )/temp)
      rk(  5) =  DEXP(-0.2474064935803238D+02
     &     - ( -0.1100000000000000D+03 )/temp)
      rk(  6) =  DEXP(-0.2632268829627837D+02
     &     - ( -0.2400000000000000D+03 )/temp)
      rk(  7) =  DEXP(-0.3026211027589463D+02
     &     - (  0.1414000000000000D+04 )/temp)
      rk(  8) =  DEXP(-0.2375982010502066D+02
     &     - ( -0.2500000000000000D+03 )/temp)
      rk(  9) =  DEXP(-0.2656631037893612D+02
     &     - (  0.1600000000000000D+03 )/temp)
      rk( 10) =  DEXP(-0.2914514884855832D+02
     &     - ( -0.6200000000000000D+03 )/temp)
      rk( 11) =  DEXP(-0.7534345418263111D+02
     &     - ( -0.9800000000000000D+03 )/temp)
      rk( 11) = rk( 11) * SumM
      rk( 12) =  0.9199999999999999D-12
      rk( 13) =  0.3600000000000000D-11
      rk( 14) =  DEXP(-0.9016754390656001D+02
     &     - ( -0.5300000000000000D+03 )/temp)
      rk( 14) = rk( 14) * SumM
      rk( 15) =  DEXP(-0.2722555600782038D+02
     &     - ( -0.3600000000000000D+03 )/temp)
      rk( 16) =  0.1500000000000000D-12
      rk( 17) =  0.3660000000000000D-32
      rk( 17) = rk( 17) * SumM

C------------------------------------------------------------------------
C     3 - TROE/Fall-off reactions.

      Effko =  0.7400000000000000D-30*DEXP(
     s     -0.2400000000000000D+01 * DLOG(temp/3.d2)) * SumM
      Rapk = Effko / DEXP(-0.2416528521312882D+02 + 
     &     ( 0.0000000000000000D+00)* DLOG(temp/3.d2) ) 
      facteur = 1.d0/(1.d0+DLOG10(Rapk)**2)
      Fcent =  0.1000000000000000D+01 * DEXP(-temp/
     &     ( 0.1300000000000000D+04))
     &     + ( 0.0000000000000000D+00) * DEXP(-temp/
     &     ( 0.1000000000000000D+01))
     &     +  DEXP (-( 0.0000000000000000D+00)/temp)
      Fcent = Fcent -1.d0
      rk( 18) = DEXP ( DLOG(Effko/(1.d0+Rapk)) 
     &     + facteur*DLOG(Fcent))
      Effko =  0.2600000000000000D-29*DEXP(
     s     -0.2900000000000000D+01 * DLOG(temp/3.d2)) * SumM
      Rapk = Effko / DEXP(-0.2353667655370645D+02 + 
     &     ( 0.0000000000000000D+00)* DLOG(temp/3.d2) ) 
      facteur = 1.d0/(1.d0+DLOG10(Rapk)**2)
      rk( 19) = DEXP( DLOG(Effko/(1.d0+Rapk)) + 
     &     DLOG( 0.4300000000000000D+00) * facteur)
      Effko =  0.1800000000000000D-30*DEXP(
     s     -0.3200000000000000D+01 * DLOG(temp/3.d2)) * SumM
      Rapk = Effko / DEXP(-0.2608345860721253D+02 + 
     &     ( 0.0000000000000000D+00)* DLOG(temp/3.d2) ) 
      facteur = 1.d0/(1.d0+DLOG10(Rapk)**2)
      rk( 20) = DEXP( DLOG(Effko/(1.d0+Rapk)) + 
     &     DLOG( 0.6000000000000000D+00) * facteur)
      Effko =  0.5000000000000000D-05* SumM * 
     &     DEXP(-( 0.1000000000000000D+05)/temp + 
     &     ( 0.0000000000000000D+00) * DLOG(temp/3.d2))
      Rapk = Effko / DEXP( 0.3549428783993812D+02 + 
     &     ( 0.0000000000000000D+00)* DLOG(temp/3.d2) - 
     &     ( 0.1090000000000000D+05)/temp)
      facteur = 1.d0/(1.d0+DLOG10(Rapk)**2)
      rk( 21) = DEXP( DLOG(Effko/(1.d0+Rapk)) + 
     &     DLOG( 0.6000000000000000D+00) * facteur)
      Effko =  0.2700000000000000D-29*DEXP(
     s     -0.3400000000000000D+01 * DLOG(temp/3.d2)) * SumM
      Rapk = Effko / DEXP(-0.2693787393536860D+02 + 
     &     ( 0.2000000000000000D+00)* DLOG(temp/3.d2) ) 
      facteur = 1.d0/(1.d0+DLOG10(Rapk)**2)
      Fcent =  0.1000000000000000D+01 * DEXP(-temp/
     &     ( 0.2500000000000000D+03))
     &     + ( 0.0000000000000000D+00) * DEXP(-temp/
     &     ( 0.1000000000000000D+01))
     &     +  DEXP (-( 0.1050000000000000D+04)/temp)
      rk( 22) = DEXP ( DLOG(Effko/(1.d0+Rapk)) 
     &     + facteur*DLOG(Fcent))
      Effko =  0.2200000000000000D-02* SumM * 
     &     DEXP(-( 0.1108000000000000D+05)/temp + 
     &     (-0.4400000000000000D+01) * DLOG(temp/3.d2))
      Rapk = Effko / DEXP( 0.3450831718742597D+02 + 
     &     ( 0.1000000000000000D+00)* DLOG(temp/3.d2) - 
     &     ( 0.1108000000000000D+05)/temp)
      facteur = 1.d0/(1.d0+DLOG10(Rapk)**2)
      Fcent =  0.1000000000000000D+01 * DEXP(-temp/
     &     ( 0.2500000000000000D+03))
     &     + ( 0.0000000000000000D+00) * DEXP(-temp/
     &     ( 0.1000000000000000D+01))
     &     +  DEXP (-( 0.1050000000000000D+04)/temp)
      rk( 23) = DEXP ( DLOG(Effko/(1.d0+Rapk)) 
     &     + facteur*DLOG(Fcent))
      Effko =  0.4000000000000000D-30*DEXP(
     s     -0.3300000000000000D+01 * DLOG(temp/3.d2)) * SumM
      Rapk = Effko / DEXP(-0.2693787393536860D+02 + 
     &     ( 0.0000000000000000D+00)* DLOG(temp/3.d2) ) 
      facteur = 1.d0/(1.d0+DLOG10(Rapk)**2)
      rk( 24) = DEXP( DLOG(Effko/(1.d0+Rapk)) + 
     &     DLOG( 0.4500000000000000D+00) * facteur)
      rk( 25) =  DEXP(-0.7715649105030646D+02
     &     - ( -0.2820000000000000D+04 )/temp)
      rk( 25) = rk( 25) +  0.2700000000000000D-53
     &     * exp(-(-0.3180000000000000D+04)/temp) * SumM
      rk( 25) = rk( 25) * YlH2O
      rk( 26) =  0.2000000000000000D-20 * YlH2O
C------------------------------------------------------------------------
C     1 - Photolytic reactions if not read.

      If(.NOT.LREAD_PHOTOLYSIS) THEN
         if(azi.lt.0.D0)then
            STOP
         elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
            rk( 27)= 0.4184013519966214D-10
            rk( 27)=-0.1571840135199663D-07+(azi- 0.00D+00) * rk( 27)
            rk( 27)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 27)
            rk( 27)= 0.3912000000000000D-04+(azi- 0.00D+00) * rk( 27)
         elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
            rk( 27)= 0.9447959440101465D-10
            rk( 27)=-0.1446319729600676D-07+(azi- 0.10D+02) * rk( 27)
            rk( 27)=-0.3018159864800339D-06+(azi- 0.10D+02) * rk( 27)
            rk( 27)= 0.3759000000000000D-04+(azi- 0.10D+02) * rk( 27)
         elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
            rk( 27)= 0.1802414871962840D-09
            rk( 27)=-0.1162880946397632D-07+(azi- 0.20D+02) * rk( 27)
            rk( 27)=-0.5627360540798647D-06+(azi- 0.20D+02) * rk( 27)
            rk( 27)= 0.3322000000000000D-04+(azi- 0.20D+02) * rk( 27)
         elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
            rk( 27)= 0.2145544568138516D-09
            rk( 27)=-0.6221564848087829D-08+(azi- 0.30D+02) * rk( 27)
            rk( 27)=-0.7412397972005057D-06+(azi- 0.30D+02) * rk( 27)
            rk( 27)= 0.2661000000000000D-04+(azi- 0.30D+02) * rk( 27)
         elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
            rk( 27)= 0.2715406855482865D-09
            rk( 27)= 0.2150688563279617D-09+(azi- 0.40D+02) * rk( 27)
            rk( 27)=-0.8013047571181050D-06+(azi- 0.40D+02) * rk( 27)
            rk( 27)= 0.1879000000000000D-04+(azi- 0.40D+02) * rk( 27)
         elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
            rk( 27)= 0.1892828009929273D-09
            rk( 27)= 0.8361289422776624D-08+(azi- 0.50D+02) * rk( 27)
            rk( 27)=-0.7155411743270510D-06+(azi- 0.50D+02) * rk( 27)
            rk( 27)= 0.1107000000000000D-04+(azi- 0.50D+02) * rk( 27)
         elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
            rk( 27)=-0.2167188952024055D-10
            rk( 27)= 0.1403977345256617D-07+(azi- 0.60D+02) * rk( 27)
            rk( 27)=-0.4915305455736546D-06+(azi- 0.60D+02) * rk( 27)
            rk( 27)= 0.4940000000000000D-05+(azi- 0.60D+02) * rk( 27)
         elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
            rk( 27)=-0.3303561055862432D-09
            rk( 27)= 0.1338961676696926D-07+(azi- 0.70D+02) * rk( 27)
            rk( 27)=-0.2172366433783838D-06+(azi- 0.70D+02) * rk( 27)
            rk( 27)= 0.1407000000000000D-05+(azi- 0.70D+02) * rk( 27)
         elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
            rk( 27)=-0.2256431950615235D-09
            rk( 27)= 0.5461070232899399D-08+(azi- 0.78D+02) * rk( 27)
            rk( 27)=-0.6643114737932308D-07+(azi- 0.78D+02) * rk( 27)
            rk( 27)= 0.3569000000000000D-06+(azi- 0.78D+02) * rk( 27)
         elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
            rk( 27)= 0.4585926811607814D-09
            rk( 27)= 0.4563355136862396D-10+(azi- 0.86D+02) * rk( 27)
            rk( 27)=-0.2237751710431090D-07+(azi- 0.86D+02) * rk( 27)
            rk( 27)= 0.5943000000000000D-07+(azi- 0.86D+02) * rk( 27)
         elseif(azi.ge.90.D0)then
            rk( 27)= 0.0000000000000000D+00
         endif
         if(att.lt.0.99999) rk( 27) = rk( 27) * att
      ENDIF
C     
      VO2  = 3.2D-11 * exp(70.D0 /temp) * (0.21D0*SumM)
      VN2  = 1.8D-11 * exp(110.D0/temp) * (0.79D0*SumM)
      VH2O = 2.2D-10 * YlH2O
      rk( 27) = rk( 27) * VH2O / (VH2O + VN2 + VO2) 
C     
      If(.NOT.LREAD_PHOTOLYSIS) THEN
         if(azi.lt.0.D0)then
            STOP
         elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
            rk( 28)= 0.1560577364291253D-07
            rk( 28)=-0.1556057736429120D-05+(azi- 0.00D+00) * rk( 28)
            rk( 28)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 28)
            rk( 28)= 0.1070000000000000D-01+(azi- 0.00D+00) * rk( 28)
         elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
            rk( 28)=-0.1681732092873881D-07
            rk( 28)=-0.1087884527141744D-05+(azi- 0.10D+02) * rk( 28)
            rk( 28)=-0.2643942263570865D-04+(azi- 0.10D+02) * rk( 28)
            rk( 28)= 0.1056000000000000D-01+(azi- 0.10D+02) * rk( 28)
         elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
            rk( 28)= 0.4663510072042447D-08
            rk( 28)=-0.1592404155003909D-05+(azi- 0.20D+02) * rk( 28)
            rk( 28)=-0.5324230945716518D-04+(azi- 0.20D+02) * rk( 28)
            rk( 28)= 0.1017000000000000D-01+(azi- 0.20D+02) * rk( 28)
         elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
            rk( 28)=-0.1083671935942940D-07
            rk( 28)=-0.1452498852842640D-05+(azi- 0.30D+02) * rk( 28)
            rk( 28)=-0.8369133953563067D-04+(azi- 0.30D+02) * rk( 28)
            rk( 28)= 0.9483000000000000D-02+(azi- 0.30D+02) * rk( 28)
         elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
            rk( 28)=-0.6316632634325648D-08
            rk( 28)=-0.1777600433625494D-05+(azi- 0.40D+02) * rk( 28)
            rk( 28)=-0.1159923324003122D-03+(azi- 0.40D+02) * rk( 28)
            rk( 28)= 0.8489999999999999D-02+(azi- 0.40D+02) * rk( 28)
         elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
            rk( 28)= 0.1032498967235339D-09
            rk( 28)=-0.1967099412655263D-05+(azi- 0.50D+02) * rk( 28)
            rk( 28)=-0.1534393308631193D-03+(azi- 0.50D+02) * rk( 28)
            rk( 28)= 0.7146000000000000D-02+(azi- 0.50D+02) * rk( 28)
         elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
            rk( 28)= 0.4390363304737353D-07
            rk( 28)=-0.1964001915753599D-05+(azi- 0.60D+02) * rk( 28)
            rk( 28)=-0.1927503441472085D-03+(azi- 0.60D+02) * rk( 28)
            rk( 28)= 0.5415000000000000D-02+(azi- 0.60D+02) * rk( 28)
         elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
            rk( 28)= 0.3481943116049149D-06
            rk( 28)=-0.6468929243311525D-06+(azi- 0.70D+02) * rk( 28)
            rk( 28)=-0.2188592925480646D-03+(azi- 0.70D+02) * rk( 28)
            rk( 28)= 0.3335000000000000D-02+(azi- 0.70D+02) * rk( 28)
         elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
            rk( 28)=-0.7401858269410775D-06
            rk( 28)= 0.7709770554181602D-05+(azi- 0.78D+02) * rk( 28)
            rk( 28)=-0.1623562715092345D-03+(azi- 0.78D+02) * rk( 28)
            rk( 28)= 0.1721000000000000D-02+(azi- 0.78D+02) * rk( 28)
         elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
            rk( 28)= 0.5449023661551723D-05
            rk( 28)=-0.1005468929241120D-04+(azi- 0.86D+02) * rk( 28)
            rk( 28)=-0.1811156214151268D-03+(azi- 0.86D+02) * rk( 28)
            rk( 28)= 0.5366000000000000D-03+(azi- 0.86D+02) * rk( 28)
         elseif(azi.ge.90.D0)then
            rk( 28)= 0.0000000000000000D+00
         endif
         if(att.lt.0.99999) rk( 28) = rk( 28) * att
      ENDIF
C     
C     
      If(.NOT.LREAD_PHOTOLYSIS) THEN
         if(azi.lt.0.D0)then
            STOP
         elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
            rk( 29)= 0.1141646687009563D-11
            rk( 29)=-0.1871416466870091D-08+(azi- 0.00D+00) * rk( 29)
            rk( 29)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 29)
            rk( 29)= 0.9660999999999999D-05+(azi- 0.00D+00) * rk( 29)
         elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
            rk( 29)= 0.1575059938970413D-11
            rk( 29)=-0.1837167066259804D-08+(azi- 0.10D+02) * rk( 29)
            rk( 29)=-0.3708583533129895D-07+(azi- 0.10D+02) * rk( 29)
            rk( 29)= 0.9475000000000000D-05+(azi- 0.10D+02) * rk( 29)
         elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
            rk( 29)= 0.3558113557107039D-11
            rk( 29)=-0.1789915268090689D-08+(azi- 0.20D+02) * rk( 29)
            rk( 29)=-0.7335665867480389D-07+(azi- 0.20D+02) * rk( 29)
            rk( 29)= 0.8922000000000000D-05+(azi- 0.20D+02) * rk( 29)
         elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
            rk( 29)= 0.7192485832605286D-11
            rk( 29)=-0.1683171861377483D-08+(azi- 0.30D+02) * rk( 29)
            rk( 29)=-0.1080875299694856D-06+(azi- 0.30D+02) * rk( 29)
            rk( 29)= 0.8012999999999999D-05+(azi- 0.30D+02) * rk( 29)
         elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
            rk( 29)= 0.1767194311247392D-10
            rk( 29)=-0.1467397286399335D-08+(azi- 0.40D+02) * rk( 29)
            rk( 29)=-0.1395932214472540D-06+(azi- 0.40D+02) * rk( 29)
            rk( 29)= 0.6771000000000000D-05+(azi- 0.40D+02) * rk( 29)
         elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
            rk( 29)= 0.3211974171751287D-10
            rk( 29)=-0.9372389930251697D-09+(azi- 0.50D+02) * rk( 29)
            rk( 29)=-0.1636395842414981D-06+(azi- 0.50D+02) * rk( 29)
            rk( 29)= 0.5246000000000000D-05+(azi- 0.50D+02) * rk( 29)
         elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
            rk( 29)= 0.7484909001740748D-10
            rk( 29)= 0.2635325850032244D-10+(azi- 0.60D+02) * rk( 29)
            rk( 29)=-0.1727484415867466D-06+(azi- 0.60D+02) * rk( 29)
            rk( 29)= 0.3548000000000000D-05+(azi- 0.60D+02) * rk( 29)
         elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
            rk( 29)= 0.9089127717682368D-10
            rk( 29)= 0.2271825959022548D-08+(azi- 0.70D+02) * rk( 29)
            rk( 29)=-0.1497666494115205D-06+(azi- 0.70D+02) * rk( 29)
            rk( 29)= 0.1898000000000000D-05+(azi- 0.70D+02) * rk( 29)
         elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
            rk( 29)=-0.3185066256402764D-09
            rk( 29)= 0.4453216611266316D-08+(azi- 0.78D+02) * rk( 29)
            rk( 29)=-0.9596630884919601D-07+(azi- 0.78D+02) * rk( 29)
            rk( 29)= 0.8918000000000000D-06+(azi- 0.78D+02) * rk( 29)
         elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
            rk( 29)= 0.2320742800510518D-08
            rk( 29)=-0.3190942404100315D-08+(azi- 0.86D+02) * rk( 29)
            rk( 29)=-0.8586811519192221D-07+(azi- 0.86D+02) * rk( 29)
            rk( 29)= 0.2460000000000000D-06+(azi- 0.86D+02) * rk( 29)
         elseif(azi.ge.90.D0)then
            rk( 29)= 0.0000000000000000D+00
         endif
         if(att.lt.0.99999) rk( 29) = rk( 29) * att
      ENDIF
C     
C     
      If(.NOT.LREAD_PHOTOLYSIS) THEN
         if(azi.lt.0.D0)then
            STOP
         elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
            rk( 30)= 0.6536853146652567D-07
            rk( 30)=-0.3353685314665251D-05+(azi- 0.00D+00) * rk( 30)
            rk( 30)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 30)
            rk( 30)= 0.3089000000000000D-01+(azi- 0.00D+00) * rk( 30)
         elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
            rk( 30)=-0.5610559439957920D-07
            rk( 30)=-0.1392629370669480D-05+(azi- 0.10D+02) * rk( 30)
            rk( 30)=-0.4746314685334731D-04+(azi- 0.10D+02) * rk( 30)
            rk( 30)= 0.3062000000000000D-01+(azi- 0.10D+02) * rk( 30)
         elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
            rk( 30)= 0.9053846131789433D-08
            rk( 30)=-0.3075797202656853D-05+(azi- 0.20D+02) * rk( 30)
            rk( 30)=-0.9214741258661067D-04+(azi- 0.20D+02) * rk( 30)
            rk( 30)= 0.2995000000000000D-01+(azi- 0.20D+02) * rk( 30)
         elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
            rk( 30)=-0.3010979012757052D-07
            rk( 30)=-0.2804181818703172D-05+(azi- 0.30D+02) * rk( 30)
            rk( 30)=-0.1509472028002109D-03+(azi- 0.30D+02) * rk( 30)
            rk( 30)= 0.2873000000000000D-01+(azi- 0.30D+02) * rk( 30)
         elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
            rk( 30)=-0.3861468562151119D-07
            rk( 30)=-0.3707475522530249D-05+(azi- 0.40D+02) * rk( 30)
            rk( 30)=-0.2160637762125457D-03+(azi- 0.40D+02) * rk( 30)
            rk( 30)= 0.2691000000000000D-01+(azi- 0.40D+02) * rk( 30)
         elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
            rk( 30)=-0.1454314673863808D-06
            rk( 30)=-0.4865916091175484D-05+(azi- 0.50D+02) * rk( 30)
            rk( 30)=-0.3017976923496041D-03+(azi- 0.50D+02) * rk( 30)
            rk( 30)= 0.2434000000000000D-01+(azi- 0.50D+02) * rk( 30)
         elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
            rk( 30)=-0.1096594448331512D-06
            rk( 30)=-0.9228860112766277D-05+(azi- 0.60D+02) * rk( 30)
            rk( 30)=-0.4427454543890262D-03+(azi- 0.60D+02) * rk( 30)
            rk( 30)= 0.2069000000000000D-01+(azi- 0.60D+02) * rk( 30)
         elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
            rk( 30)=-0.3028181600570878D-06
            rk( 30)=-0.1251864345775742D-04+(azi- 0.70D+02) * rk( 30)
            rk( 30)=-0.6602204900942949D-03+(azi- 0.70D+02) * rk( 30)
            rk( 30)= 0.1523000000000000D-01+(azi- 0.70D+02) * rk( 30)
         elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
            rk( 30)= 0.2624220414725269D-05
            rk( 30)=-0.1978627929913447D-04+(azi- 0.78D+02) * rk( 30)
            rk( 30)=-0.9186598721493901D-03+(azi- 0.78D+02) * rk( 30)
            rk( 30)= 0.8992000000000000D-02+(azi- 0.78D+02) * rk( 30)
         elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
            rk( 30)= 0.8038123668211420D-05
            rk( 30)= 0.4319501065424422D-04+(azi- 0.86D+02) * rk( 30)
            rk( 30)=-0.7313900213082900D-03+(azi- 0.86D+02) * rk( 30)
            rk( 30)= 0.1720000000000000D-02+(azi- 0.86D+02) * rk( 30)
         elseif(azi.ge.90.D0)then
            rk( 30)= 0.0000000000000000D+00
         endif
         if(att.lt.0.99999) rk( 30) = rk( 30) * att
      ENDIF
C     
C     
      If(.NOT.LREAD_PHOTOLYSIS) THEN
         if(azi.lt.0.D0)then
            STOP
         elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
            rk( 31)= 0.1200328983217089D-05
            rk( 31)=-0.3700328983217092D-04+(azi- 0.00D+00) * rk( 31)
            rk( 31)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 31)
            rk( 31)= 0.2485000000000000D+00+(azi- 0.00D+00) * rk( 31)
         elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
            rk( 31)=-0.1100986949651267D-05
            rk( 31)=-0.9934203356582266D-06+(azi- 0.10D+02) * rk( 31)
            rk( 31)=-0.3799671016782914D-03+(azi- 0.10D+02) * rk( 31)
            rk( 31)= 0.2460000000000000D+00+(azi- 0.10D+02) * rk( 31)
         elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
            rk( 31)= 0.4036188153879798D-06
            rk( 31)=-0.3402302882519623D-04+(azi- 0.20D+02) * rk( 31)
            rk( 31)=-0.7301315932868359D-03+(azi- 0.20D+02) * rk( 31)
            rk( 31)= 0.2410000000000000D+00+(azi- 0.20D+02) * rk( 31)
         elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
            rk( 31)=-0.3134883119006123D-06
            rk( 31)=-0.2191446436355691D-04+(azi- 0.30D+02) * rk( 31)
            rk( 31)=-0.1289506525174367D-02+(azi- 0.30D+02) * rk( 31)
            rk( 31)= 0.2307000000000000D+00+(azi- 0.30D+02) * rk( 31)
         elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
            rk( 31)=-0.3496655677856244D-06
            rk( 31)=-0.3131911372057487D-04+(azi- 0.40D+02) * rk( 31)
            rk( 31)=-0.1821842306015688D-02+(azi- 0.40D+02) * rk( 31)
            rk( 31)= 0.2153000000000000D+00+(azi- 0.40D+02) * rk( 31)
         elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
            rk( 31)=-0.9878494169568548D-06
            rk( 31)=-0.4180908075414338D-04+(azi- 0.50D+02) * rk( 31)
            rk( 31)=-0.2553124250762869D-02+(azi- 0.50D+02) * rk( 31)
            rk( 31)= 0.1936000000000000D+00+(azi- 0.50D+02) * rk( 31)
         elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
            rk( 31)=-0.1098936764387874D-05
            rk( 31)=-0.7144456326284571D-04+(azi- 0.60D+02) * rk( 31)
            rk( 31)=-0.3685660690932817D-02+(azi- 0.60D+02) * rk( 31)
            rk( 31)= 0.1629000000000000D+00+(azi- 0.60D+02) * rk( 31)
         elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
            rk( 31)= 0.7739736728346950D-06
            rk( 31)=-0.1044126661944444D-03+(azi- 0.70D+02) * rk( 31)
            rk( 31)=-0.5444232985505958D-02+(azi- 0.70D+02) * rk( 31)
            rk( 31)= 0.1178000000000000D+00+(azi- 0.70D+02) * rk( 31)
         elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
            rk( 31)= 0.1385439193444951D-04
            rk( 31)=-0.8583729804641167D-04+(azi- 0.78D+02) * rk( 31)
            rk( 31)=-0.6966232699433560D-02+(azi- 0.78D+02) * rk( 31)
            rk( 31)= 0.6796000000000001D-01+(azi- 0.78D+02) * rk( 31)
         elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
            rk( 31)= 0.7721336145259715D-04
            rk( 31)= 0.2466681083801545D-03+(azi- 0.86D+02) * rk( 31)
            rk( 31)=-0.5679586216763617D-02+(azi- 0.86D+02) * rk( 31)
            rk( 31)= 0.1383000000000000D-01+(azi- 0.86D+02) * rk( 31)
         elseif(azi.ge.90.D0)then
            rk( 31)= 0.0000000000000000D+00
         endif
         if(att.lt.0.99999) rk( 31) = rk( 31) * att
      ENDIF
C     
C     
      If(.NOT.LREAD_PHOTOLYSIS) THEN
         if(azi.lt.0.D0)then
            STOP
         elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
            rk( 32)=-0.6765697414312527D-09
            rk( 32)=-0.2932343025856839D-06+(azi- 0.00D+00) * rk( 32)
            rk( 32)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 32)
            rk( 32)= 0.2374000000000000D-02+(azi- 0.00D+00) * rk( 32)
         elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
            rk( 32)= 0.2970922429260691D-10
            rk( 32)=-0.3135313948286214D-06+(azi- 0.10D+02) * rk( 32)
            rk( 32)=-0.6067656974143053D-05+(azi- 0.10D+02) * rk( 32)
            rk( 32)= 0.2344000000000000D-02+(azi- 0.10D+02) * rk( 32)
         elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
            rk( 32)=-0.1442267155738489D-08
            rk( 32)=-0.3126401180998434D-06+(azi- 0.20D+02) * rk( 32)
            rk( 32)=-0.1232937210342770D-04+(azi- 0.20D+02) * rk( 32)
            rk( 32)= 0.2252000000000000D-02+(azi- 0.20D+02) * rk( 32)
         elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
            rk( 32)=-0.1260640601339324D-08
            rk( 32)=-0.3559081327719976D-06+(azi- 0.30D+02) * rk( 32)
            rk( 32)=-0.1901485461214611D-04+(azi- 0.30D+02) * rk( 32)
            rk( 32)= 0.2096000000000000D-02+(azi- 0.30D+02) * rk( 32)
         elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
            rk( 32)=-0.1515170438903362D-08
            rk( 32)=-0.3937273508121724D-06+(azi- 0.40D+02) * rk( 32)
            rk( 32)=-0.2651120944798786D-04+(azi- 0.40D+02) * rk( 32)
            rk( 32)= 0.1869000000000000D-02+(azi- 0.40D+02) * rk( 32)
         elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
            rk( 32)= 0.1321322356949277D-08
            rk( 32)=-0.4391824639792698D-06+(azi- 0.50D+02) * rk( 32)
            rk( 32)=-0.3484030759590233D-04+(azi- 0.50D+02) * rk( 32)
            rk( 32)= 0.1563000000000000D-02+(azi- 0.50D+02) * rk( 32)
         elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
            rk( 32)= 0.1272988101110407D-07
            rk( 32)=-0.3995427932708061D-06+(azi- 0.60D+02) * rk( 32)
            rk( 32)=-0.4322756016840306D-04+(azi- 0.60D+02) * rk( 32)
            rk( 32)= 0.1172000000000000D-02+(azi- 0.60D+02) * rk( 32)
         elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
            rk( 32)= 0.7016597865607275D-07
            rk( 32)=-0.1764636293760712D-07+(azi- 0.70D+02) * rk( 32)
            rk( 32)=-0.4739945173048821D-04+(azi- 0.70D+02) * rk( 32)
            rk( 32)= 0.7125000000000000D-03+(azi- 0.70D+02) * rk( 32)
         elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
            rk( 32)=-0.1647776775459971D-06
            rk( 32)= 0.1666337124808139D-05+(azi- 0.78D+02) * rk( 32)
            rk( 32)=-0.3420992563552289D-04+(azi- 0.78D+02) * rk( 32)
            rk( 32)= 0.3681000000000000D-03+(azi- 0.78D+02) * rk( 32)
         elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
            rk( 32)= 0.1197759642038430D-05
            rk( 32)=-0.2288327136295792D-05+(azi- 0.86D+02) * rk( 32)
            rk( 32)=-0.3918584572742411D-04+(azi- 0.86D+02) * rk( 32)
            rk( 32)= 0.1167000000000000D-03+(azi- 0.86D+02) * rk( 32)
         elseif(azi.ge.90.D0)then
            rk( 32)= 0.0000000000000000D+00
         endif
         if(att.lt.0.99999) rk( 32) = rk( 32) * att
      ENDIF
C     
      rk( 33) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 34) =  DEXP(-0.2852261923521233D+02
     &     - ( -0.7900000000000000D+03 )/temp)
      rk( 35) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 36) =  DEXP(-0.2852261923521233D+02
     &     - ( -0.7900000000000000D+03 )/temp)
      rk( 37) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 38) =  DEXP(-0.2852261923521233D+02
     &     - ( -0.7900000000000000D+03 )/temp)
      rk( 39) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 40) =  DEXP(-0.2852261923521233D+02
     &     - ( -0.7900000000000000D+03 )/temp)
      rk( 41) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 42) =  DEXP(-0.2852261923521233D+02
     &     - ( -0.7900000000000000D+03 )/temp)
      rk( 43) =  DEXP(-0.3892080302958457D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     +  0.6480000000000000D+03/temp)
      rk( 44) =  DEXP(-0.2591722318817020D+02
     &     - ( -0.3110000000000000D+03 )/temp)
      rk( 45) =  0.2000000000000000D-10
      rk( 46) =  DEXP(-0.2847499118622308D+02
     &     - ( -0.1040000000000000D+04 )/temp)
      rk( 47) =  DEXP(-0.2549095495243228D+02
     &     - ( -0.2520000000000000D+03 )/temp)
      rk( 48) =  0.2000000000000000D-10
      rk( 49) =  DEXP(-0.2847499118622308D+02
     &     - ( -0.1040000000000000D+04 )/temp)
      rk( 50) =  0.8400000000000000D-11
      rk( 51) =  DEXP( 0.3961395021014451D+02
     &     - (  0.1407300000000000D+05 )/temp)
      rk( 52) =  DEXP(-0.4069040969417149D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     +  0.5300000000000000D+02/temp)
      rk( 53) =  DEXP(-0.4027095834408858D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     +  0.4140000000000000D+03/temp)
      rk( 54) =  0.4200000000000000D-10
      rk( 55) =  0.2100000000000000D-10
      rk( 56) =  0.2630000000000000D-10
      rk( 57) =  0.3600000000000000D-11
      rk( 58) =  0.1290000000000000D-10
      rk( 59) =  0.2000000000000000D-10
      rk( 60) =  DEXP(-0.2847499118622308D+02
     &     - ( -0.1040000000000000D+04 )/temp)
      rk( 61) =  0.8400000000000000D-11
      rk( 62) =  DEXP( 0.3961395021014451D+02
     &     - (  0.1407300000000000D+05 )/temp)
      rk( 63) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 64) =  DEXP(-0.2852261923521233D+02
     &     - ( -0.7900000000000000D+03 )/temp)
      rk( 65) =  DEXP(-0.2506607175846701D+02
     &     - ( -0.3000000000000000D+03 )/temp)
      rk( 66) =  DEXP(-0.2852261923521233D+02
     &     - ( -0.7900000000000000D+03 )/temp)
      rk( 67) =  0.1000000000000000D-02
      rk( 68) =  0.3600000000000000D-11
      rk( 69) =  DEXP(-0.2506607175846701D+02
     &     - ( -0.3000000000000000D+03 )/temp)
      rk( 70) =  DEXP(-0.2852261923521233D+02
     &     - ( -0.7900000000000000D+03 )/temp)
      rk( 71) =  0.1000000000000000D-02
      rk( 72) =  0.1140000000000000D-10
      rk( 73) =  0.1720000000000000D-10
      rk( 74) =  0.1140000000000000D-10
      rk( 75) =  0.2000000000000000D-10
      rk( 76) =  DEXP(-0.2847499118622308D+02
     &     - ( -0.1040000000000000D+04 )/temp)
      rk( 77) =  0.1720000000000000D-10
      rk( 78) =  0.1000000000000000D-12
      rk( 79) =  DEXP(-0.2763102111592855D+02
     &     - ( -0.1900000000000000D+03 )/temp)
      rk( 80) =  DEXP(-0.2698916722975615D+02
     &     - ( -0.1900000000000000D+03 )/temp)
      rk( 81) =  DEXP(-0.2454453447910609D+02
     &     - (  0.7080000000000000D+03 )/temp)
      Effko =  0.2700000000000000D-27*DEXP(
     s     -0.7100000000000000D+01 * DLOG(temp/3.d2)) * SumM
      Rapk = Effko / DEXP(-0.2514611446614055D+02 + 
     &     (-0.9000000000000000D+00)* DLOG(temp/3.d2) ) 
      facteur = 1.d0/(1.d0+DLOG10(Rapk)**2)
      rk( 82) = DEXP( DLOG(Effko/(1.d0+Rapk)) + 
     &     DLOG( 0.3000000000000000D+00) * facteur)
      Effko =  0.4900000000000000D-02* SumM * 
     &     DEXP(-( 0.1210000000000000D+05)/temp + 
     &     ( 0.0000000000000000D+00) * DLOG(temp/3.d2))
      Rapk = Effko / DEXP( 0.3822765584902462D+02 + 
     &     ( 0.0000000000000000D+00)* DLOG(temp/3.d2) - 
     &     ( 0.1360000000000000D+05)/temp)
      facteur = 1.d0/(1.d0+DLOG10(Rapk)**2)
      rk( 83) = DEXP( DLOG(Effko/(1.d0+Rapk)) + 
     &     DLOG( 0.3000000000000000D+00) * facteur)
      Effko =  0.2700000000000000D-27*DEXP(
     s     -0.7100000000000000D+01 * DLOG(temp/3.d2)) * SumM
      Rapk = Effko / DEXP(-0.2514611446614055D+02 + 
     &     (-0.9000000000000000D+00)* DLOG(temp/3.d2) ) 
      facteur = 1.d0/(1.d0+DLOG10(Rapk)**2)
      rk( 84) = DEXP( DLOG(Effko/(1.d0+Rapk)) + 
     &     DLOG( 0.3000000000000000D+00) * facteur)
      Effko =  0.4900000000000000D-02* SumM * 
     &     DEXP(-( 0.1210000000000000D+05)/temp + 
     &     ( 0.0000000000000000D+00) * DLOG(temp/3.d2))
      Rapk = Effko / DEXP( 0.3822765584902462D+02 + 
     &     ( 0.0000000000000000D+00)* DLOG(temp/3.d2) - 
     &     ( 0.1360000000000000D+05)/temp)
      facteur = 1.d0/(1.d0+DLOG10(Rapk)**2)
      rk( 85) = DEXP( DLOG(Effko/(1.d0+Rapk)) + 
     &     DLOG( 0.3000000000000000D+00) * facteur)
C     
      If(.NOT.LREAD_PHOTOLYSIS) THEN
         if(azi.lt.0.D0)then
            STOP
         elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
            rk( 86)= 0.2716026935249886D-11
            rk( 86)=-0.7827160269352458D-08+(azi- 0.00D+00) * rk( 86)
            rk( 86)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 86)
            rk( 86)= 0.3839000000000000D-04+(azi- 0.00D+00) * rk( 86)
         elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
            rk( 86)= 0.1851919194238200D-11
            rk( 86)=-0.7745679461294959D-08+(azi- 0.10D+02) * rk( 86)
            rk( 86)=-0.1557283973064742D-06+(azi- 0.10D+02) * rk( 86)
            rk( 86)= 0.3761000000000000D-04+(azi- 0.10D+02) * rk( 86)
         elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
            rk( 86)= 0.2987629628779911D-10
            rk( 86)=-0.7690121885467817D-08+(azi- 0.20D+02) * rk( 86)
            rk( 86)=-0.3100864107741020D-06+(azi- 0.20D+02) * rk( 86)
            rk( 86)= 0.3528000000000000D-04+(azi- 0.20D+02) * rk( 86)
         elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
            rk( 86)= 0.2864289565457978D-10
            rk( 86)=-0.6793832996833864D-08+(azi- 0.30D+02) * rk( 86)
            rk( 86)=-0.4549259595971186D-06+(azi- 0.30D+02) * rk( 86)
            rk( 86)= 0.3144000000000000D-04+(azi- 0.30D+02) * rk( 86)
         elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
            rk( 86)= 0.9555212109386953D-10
            rk( 86)=-0.5934546127196417D-08+(azi- 0.40D+02) * rk( 86)
            rk( 86)=-0.5822097508374217D-06+(azi- 0.40D+02) * rk( 86)
            rk( 86)= 0.2624000000000000D-04+(azi- 0.40D+02) * rk( 86)
         elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
            rk( 86)= 0.1491486199698736D-09
            rk( 86)=-0.3067982494380404D-08+(azi- 0.50D+02) * rk( 86)
            rk( 86)=-0.6722350370531864D-06+(azi- 0.50D+02) * rk( 86)
            rk( 86)= 0.1992000000000000D-04+(azi- 0.50D+02) * rk( 86)
         elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
            rk( 86)= 0.3248533990265006D-09
            rk( 86)= 0.1406476104717198D-08+(azi- 0.60D+02) * rk( 86)
            rk( 86)=-0.6888501009498257D-06+(azi- 0.60D+02) * rk( 86)
            rk( 86)= 0.1304000000000000D-04+(azi- 0.60D+02) * rk( 86)
         elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
            rk( 86)= 0.1980146022410333D-09
            rk( 86)= 0.1115207807551016D-07+(azi- 0.70D+02) * rk( 86)
            rk( 86)=-0.5632645591475498D-06+(azi- 0.70D+02) * rk( 86)
            rk( 86)= 0.6617000000000000D-05+(azi- 0.70D+02) * rk( 86)
         elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
            rk( 86)=-0.8749675300769761D-09
            rk( 86)= 0.1590442852928141D-07+(azi- 0.78D+02) * rk( 86)
            rk( 86)=-0.3468125063091887D-06+(azi- 0.78D+02) * rk( 86)
            rk( 86)= 0.2926000000000000D-05+(azi- 0.78D+02) * rk( 86)
         elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
            rk( 86)= 0.6272786524092938D-08
            rk( 86)=-0.5094792192620236D-08+(azi- 0.86D+02) * rk( 86)
            rk( 86)=-0.2603354156155741D-06+(azi- 0.86D+02) * rk( 86)
            rk( 86)= 0.7214000000000000D-06+(azi- 0.86D+02) * rk( 86)
         elseif(azi.ge.90.D0)then
            rk( 86)= 0.0000000000000000D+00
         endif
         if(att.lt.0.99999) rk( 86) = rk( 86) * att
      ENDIF
C     
C     
      If(.NOT.LREAD_PHOTOLYSIS) THEN
         if(azi.lt.0.D0)then
            STOP
         elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
            rk( 87)= 0.3109205077314861D-11
            rk( 87)=-0.8831092050773131D-08+(azi- 0.00D+00) * rk( 87)
            rk( 87)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 87)
            rk( 87)= 0.5529000000000000D-04+(azi- 0.00D+00) * rk( 87)
         elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
            rk( 87)=-0.9327615231951341D-11
            rk( 87)=-0.8737815898453686D-08+(azi- 0.10D+02) * rk( 87)
            rk( 87)=-0.1756890794922682D-06+(azi- 0.10D+02) * rk( 87)
            rk( 87)= 0.5441000000000000D-04+(azi- 0.10D+02) * rk( 87)
         elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
            rk( 87)=-0.5798744149500685D-11
            rk( 87)=-0.9017644355412235D-08+(azi- 0.20D+02) * rk( 87)
            rk( 87)=-0.3532436820309273D-06+(azi- 0.20D+02) * rk( 87)
            rk( 87)= 0.5177000000000000D-04+(azi- 0.20D+02) * rk( 87)
         elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
            rk( 87)= 0.2522591829958209D-11
            rk( 87)=-0.9191606679897260D-08+(azi- 0.30D+02) * rk( 87)
            rk( 87)=-0.5353361923840225D-06+(azi- 0.30D+02) * rk( 87)
            rk( 87)= 0.4733000000000000D-04+(azi- 0.30D+02) * rk( 87)
         elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
            rk( 87)= 0.3570837682967578D-10
            rk( 87)=-0.9115928924998536D-08+(azi- 0.40D+02) * rk( 87)
            rk( 87)=-0.7184115484329801D-06+(azi- 0.40D+02) * rk( 87)
            rk( 87)= 0.4106000000000000D-04+(azi- 0.40D+02) * rk( 87)
         elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
            rk( 87)= 0.1246439008513066D-09
            rk( 87)=-0.8044677620108317D-08+(azi- 0.50D+02) * rk( 87)
            rk( 87)=-0.8900176138840430D-06+(azi- 0.50D+02) * rk( 87)
            rk( 87)= 0.3300000000000000D-04+(azi- 0.50D+02) * rk( 87)
         elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
            rk( 87)= 0.4457160197651463D-09
            rk( 87)=-0.4305360594569589D-08+(azi- 0.60D+02) * rk( 87)
            rk( 87)=-0.1013517996030827D-05+(azi- 0.60D+02) * rk( 87)
            rk( 87)= 0.2342000000000000D-04+(azi- 0.60D+02) * rk( 87)
         elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
            rk( 87)= 0.8438506563361095D-09
            rk( 87)= 0.9066119998390116D-08+(azi- 0.70D+02) * rk( 87)
            rk( 87)=-0.9659104019926666D-06+(azi- 0.70D+02) * rk( 87)
            rk( 87)= 0.1330000000000000D-04+(azi- 0.70D+02) * rk( 87)
         elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
            rk( 87)=-0.2466252031274503D-08
            rk( 87)= 0.2931853575044997D-07+(azi- 0.78D+02) * rk( 87)
            rk( 87)=-0.6588331560018053D-06+(azi- 0.78D+02) * rk( 87)
            rk( 87)= 0.6585000000000000D-05+(azi- 0.78D+02) * rk( 87)
         elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
            rk( 87)= 0.1879643912497789D-07
            rk( 87)=-0.2987151300008388D-07+(azi- 0.86D+02) * rk( 87)
            rk( 87)=-0.6632569739993106D-06+(azi- 0.86D+02) * rk( 87)
            rk( 87)= 0.1928000000000000D-05+(azi- 0.86D+02) * rk( 87)
         elseif(azi.ge.90.D0)then
            rk( 87)= 0.0000000000000000D+00
         endif
         if(att.lt.0.99999) rk( 87) = rk( 87) * att
      ENDIF
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 88)= 0.2766803417379858D-11
         rk( 88)=-0.2177668034173786D-08+(azi- 0.00D+00) * rk( 88)
         rk( 88)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 88)
         rk( 88)= 0.7976000000000000D-05+(azi- 0.00D+00) * rk( 88)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 88)= 0.6699589747856126D-11
         rk( 88)=-0.2094663931652391D-08+(azi- 0.10D+02) * rk( 88)
         rk( 88)=-0.4272331965826177D-07+(azi- 0.10D+02) * rk( 88)
         rk( 88)= 0.7761000000000001D-05+(azi- 0.10D+02) * rk( 88)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 88)= 0.1343483759119846D-10
         rk( 88)=-0.1893676239216708D-08+(azi- 0.20D+02) * rk( 88)
         rk( 88)=-0.8260672136695275D-07+(azi- 0.20D+02) * rk( 88)
         rk( 88)= 0.7131000000000000D-05+(azi- 0.20D+02) * rk( 88)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 88)= 0.2056105988735212D-10
         rk( 88)=-0.1490631111480762D-08+(azi- 0.30D+02) * rk( 88)
         rk( 88)=-0.1164497948739274D-06+(azi- 0.30D+02) * rk( 88)
         rk( 88)= 0.6129000000000000D-05+(azi- 0.30D+02) * rk( 88)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 88)= 0.3332092285940258D-10
         rk( 88)=-0.8737993148602008D-09+(azi- 0.40D+02) * rk( 88)
         rk( 88)=-0.1400940991373373D-06+(azi- 0.40D+02) * rk( 88)
         rk( 88)= 0.4836000000000000D-05+(azi- 0.40D+02) * rk( 88)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 88)= 0.4415524867503707D-10
         rk( 88)= 0.1258283709218226D-09+(azi- 0.50D+02) * rk( 88)
         rk( 88)=-0.1475738085767203D-06+(azi- 0.50D+02) * rk( 88)
         rk( 88)= 0.3381000000000000D-05+(azi- 0.50D+02) * rk( 88)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 88)= 0.4885808244040716D-10
         rk( 88)= 0.1450485831173239D-08+(azi- 0.60D+02) * rk( 88)
         rk( 88)=-0.1318106665557747D-06+(azi- 0.60D+02) * rk( 88)
         rk( 88)= 0.1962000000000000D-05+(azi- 0.60D+02) * rk( 88)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 88)=-0.1736408179566271D-10
         rk( 88)= 0.2916228304386884D-08+(azi- 0.70D+02) * rk( 88)
         rk( 88)=-0.8814352520017776D-07+(azi- 0.70D+02) * rk( 88)
         rk( 88)= 0.8378000000000001D-06+(azi- 0.70D+02) * rk( 88)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 88)=-0.9747104211915541D-10
         rk( 88)= 0.2499490341292671D-08+(azi- 0.78D+02) * rk( 88)
         rk( 88)=-0.4481777603471982D-07+(azi- 0.78D+02) * rk( 88)
         rk( 88)= 0.3104000000000000D-06+(azi- 0.78D+02) * rk( 88)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 88)= 0.4637268336973354D-09
         rk( 88)= 0.1601853304329316D-09+(azi- 0.86D+02) * rk( 88)
         rk( 88)=-0.2354037066094206D-07+(azi- 0.86D+02) * rk( 88)
         rk( 88)= 0.6192000000000000D-07+(azi- 0.86D+02) * rk( 88)
      elseif(azi.ge.90.D0)then
         rk( 88)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 88) = rk( 88) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 89)= 0.3132467277332680D-11
         rk( 89)=-0.6031324672773303D-08+(azi- 0.00D+00) * rk( 89)
         rk( 89)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 89)
         rk( 89)= 0.2435000000000000D-04+(azi- 0.00D+00) * rk( 89)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 89)= 0.2060259816799311D-10
         rk( 89)=-0.5937350654453322D-08+(azi- 0.10D+02) * rk( 89)
         rk( 89)=-0.1196867532722662D-06+(azi- 0.10D+02) * rk( 89)
         rk( 89)= 0.2375000000000000D-04+(azi- 0.10D+02) * rk( 89)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 89)= 0.2445714005070197D-10
         rk( 89)=-0.5319272709413528D-08+(azi- 0.20D+02) * rk( 89)
         rk( 89)=-0.2322529869109347D-06+(azi- 0.20D+02) * rk( 89)
         rk( 89)= 0.2198000000000000D-04+(azi- 0.20D+02) * rk( 89)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 89)= 0.5156884162919750D-10
         rk( 89)=-0.4585558507892493D-08+(azi- 0.30D+02) * rk( 89)
         rk( 89)=-0.3313012990839948D-06+(azi- 0.30D+02) * rk( 89)
         rk( 89)= 0.1915000000000000D-04+(azi- 0.30D+02) * rk( 89)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 89)= 0.8926749343252285D-10
         rk( 89)=-0.3038493259016520D-08+(azi- 0.40D+02) * rk( 89)
         rk( 89)=-0.4075418167530857D-06+(azi- 0.40D+02) * rk( 89)
         rk( 89)= 0.1543000000000000D-04+(azi- 0.40D+02) * rk( 89)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 89)= 0.1163611846406257D-09
         rk( 89)=-0.3604684560406742D-09+(azi- 0.50D+02) * rk( 89)
         rk( 89)=-0.4415314339036547D-06+(azi- 0.50D+02) * rk( 89)
         rk( 89)= 0.1114000000000000D-04+(azi- 0.50D+02) * rk( 89)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 89)= 0.1702877680048214D-09
         rk( 89)= 0.3130367083178037D-08+(azi- 0.60D+02) * rk( 89)
         rk( 89)=-0.4138324476322809D-06+(azi- 0.60D+02) * rk( 89)
         rk( 89)= 0.6805000000000000D-05+(azi- 0.60D+02) * rk( 89)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 89)= 0.1135585282427272D-10
         rk( 89)= 0.8239000123319896D-08+(azi- 0.70D+02) * rk( 89)
         rk( 89)=-0.3001387755672977D-06+(azi- 0.70D+02) * rk( 89)
         rk( 89)= 0.3150000000000000D-05+(azi- 0.70D+02) * rk( 89)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 89)=-0.4020761699477644D-09
         rk( 89)= 0.8511540591095658D-08+(azi- 0.78D+02) * rk( 89)
         rk( 89)=-0.1661344498520326D-06+(azi- 0.78D+02) * rk( 89)
         rk( 89)= 0.1282000000000000D-05+(azi- 0.78D+02) * rk( 89)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 89)= 0.2421973435959521D-08
         rk( 89)=-0.1138287487677766D-08+(azi- 0.86D+02) * rk( 89)
         rk( 89)=-0.1071484250245809D-06+(azi- 0.86D+02) * rk( 89)
         rk( 89)= 0.2918000000000000D-06+(azi- 0.86D+02) * rk( 89)
      elseif(azi.ge.90.D0)then
         rk( 89)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 89) = rk( 89) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 90)= 0.2811543199078747D-12
         rk( 90)=-0.3428115431990788D-09+(azi- 0.00D+00) * rk( 90)
         rk( 90)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 90)
         rk( 90)= 0.1403000000000000D-05+(azi- 0.00D+00) * rk( 90)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 90)= 0.1156537040276515D-11
         rk( 90)=-0.3343769136018426D-09+(azi- 0.10D+02) * rk( 90)
         rk( 90)=-0.6771884568009214D-08+(azi- 0.10D+02) * rk( 90)
         rk( 90)= 0.1369000000000000D-05+(azi- 0.10D+02) * rk( 90)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 90)= 0.1092697518985785D-11
         rk( 90)=-0.2996808023935467D-09+(azi- 0.20D+02) * rk( 90)
         rk( 90)=-0.1311246172796311D-07+(azi- 0.20D+02) * rk( 90)
         rk( 90)= 0.1269000000000000D-05+(azi- 0.20D+02) * rk( 90)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 90)= 0.3072672883780446D-11
         rk( 90)=-0.2668998768239733D-09+(azi- 0.30D+02) * rk( 90)
         rk( 90)=-0.1877826852013831D-07+(azi- 0.30D+02) * rk( 90)
         rk( 90)= 0.1109000000000000D-05+(azi- 0.30D+02) * rk( 90)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 90)= 0.4516610945892076D-11
         rk( 90)=-0.1747196903105571D-09+(azi- 0.40D+02) * rk( 90)
         rk( 90)=-0.2319446419148363D-07+(azi- 0.40D+02) * rk( 90)
         rk( 90)= 0.8976000000000000D-06+(azi- 0.40D+02) * rk( 90)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 90)= 0.6860883332653876D-11
         rk( 90)=-0.3922136193379695D-10+(azi- 0.50D+02) * rk( 90)
         rk( 90)=-0.2533387471392717D-07+(azi- 0.50D+02) * rk( 90)
         rk( 90)= 0.6527000000000000D-06+(azi- 0.50D+02) * rk( 90)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 90)= 0.1003985572348201D-10
         rk( 90)= 0.1666051380458604D-09+(azi- 0.60D+02) * rk( 90)
         rk( 90)=-0.2406003695280700D-07+(azi- 0.60D+02) * rk( 90)
         rk( 90)= 0.4023000000000000D-06+(azi- 0.60D+02) * rk( 90)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 90)= 0.1422984325654930D-11
         rk( 90)= 0.4678008097501411D-09+(azi- 0.70D+02) * rk( 90)
         rk( 90)=-0.1771597747484644D-07+(azi- 0.70D+02) * rk( 90)
         rk( 90)= 0.1884000000000000D-06+(azi- 0.70D+02) * rk( 90)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 90)=-0.2373309281596454D-10
         rk( 90)= 0.5019524335662831D-09+(azi- 0.78D+02) * rk( 90)
         rk( 90)=-0.9957951528317190D-08+(azi- 0.78D+02) * rk( 90)
         rk( 90)= 0.7734000000000000D-07+(azi- 0.78D+02) * rk( 90)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 90)= 0.1463458492510032D-09
         rk( 90)=-0.6764179401855870D-10+(azi- 0.86D+02) * rk( 90)
         rk( 90)=-0.6483466411928615D-08+(azi- 0.86D+02) * rk( 90)
         rk( 90)= 0.1765000000000000D-07+(azi- 0.86D+02) * rk( 90)
      elseif(azi.ge.90.D0)then
         rk( 90)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 90) = rk( 90) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 91)= 0.1027967516805940D-11
         rk( 91)=-0.4802796751680608D-09+(azi- 0.00D+00) * rk( 91)
         rk( 91)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 91)
         rk( 91)= 0.1908000000000000D-05+(azi- 0.00D+00) * rk( 91)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 91)= 0.9160974495824568D-12
         rk( 91)=-0.4494406496638824D-09+(azi- 0.10D+02) * rk( 91)
         rk( 91)=-0.9297203248319432D-08+(azi- 0.10D+02) * rk( 91)
         rk( 91)= 0.1861000000000000D-05+(azi- 0.10D+02) * rk( 91)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 91)= 0.2307642684864382D-11
         rk( 91)=-0.4219577261764092D-09+(azi- 0.20D+02) * rk( 91)
         rk( 91)=-0.1801118700672235D-07+(azi- 0.20D+02) * rk( 91)
         rk( 91)= 0.1724000000000000D-05+(azi- 0.20D+02) * rk( 91)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 91)= 0.3853331810960157D-11
         rk( 91)=-0.3527284456304786D-09+(azi- 0.30D+02) * rk( 91)
         rk( 91)=-0.2575804872479121D-07+(azi- 0.30D+02) * rk( 91)
         rk( 91)= 0.1504000000000000D-05+(azi- 0.30D+02) * rk( 91)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 91)= 0.6579030071294798D-11
         rk( 91)=-0.2371284913016697D-09+(azi- 0.40D+02) * rk( 91)
         rk( 91)=-0.3165661809411267D-07+(azi- 0.40D+02) * rk( 91)
         rk( 91)= 0.1215000000000000D-05+(azi- 0.40D+02) * rk( 91)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 91)= 0.9130547903861046D-11
         rk( 91)=-0.3975758916283210D-10+(azi- 0.50D+02) * rk( 91)
         rk( 91)=-0.3442547889875753D-07+(azi- 0.50D+02) * rk( 91)
         rk( 91)= 0.8813000000000000D-06+(azi- 0.50D+02) * rk( 91)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 91)= 0.1319877831324460D-10
         rk( 91)= 0.2341588479531058D-09+(azi- 0.60D+02) * rk( 91)
         rk( 91)=-0.3248146631085624D-07+(azi- 0.60D+02) * rk( 91)
         rk( 91)= 0.5422000000000000D-06+(azi- 0.60D+02) * rk( 91)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 91)= 0.1916848109586924D-11
         rk( 91)= 0.6301221973503934D-09+(azi- 0.70D+02) * rk( 91)
         rk( 91)=-0.2383865585782214D-07+(azi- 0.70D+02) * rk( 91)
         rk( 91)= 0.2540000000000000D-06+(azi- 0.70D+02) * rk( 91)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 91)=-0.3256400863551721D-10
         rk( 91)= 0.6761265519804800D-09+(azi- 0.78D+02) * rk( 91)
         rk( 91)=-0.1338866586317510D-07+(azi- 0.78D+02) * rk( 91)
         rk( 91)= 0.1046000000000000D-06+(azi- 0.78D+02) * rk( 91)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 91)= 0.2013793319101760D-09
         rk( 91)=-0.1054096552736294D-09+(azi- 0.86D+02) * rk( 91)
         rk( 91)=-0.8822930689499956D-08+(azi- 0.86D+02) * rk( 91)
         rk( 91)= 0.2409000000000000D-07+(azi- 0.86D+02) * rk( 91)
      elseif(azi.ge.90.D0)then
         rk( 91)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 91) = rk( 91) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 92)=-0.1135094267648454D-11
         rk( 92)=-0.1128864905732356D-07+(azi- 0.00D+00) * rk( 92)
         rk( 92)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 92)
         rk( 92)= 0.5653000000000000D-04+(azi- 0.00D+00) * rk( 92)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 92)= 0.1340528280296032D-10
         rk( 92)=-0.1132270188535301D-07+(azi- 0.10D+02) * rk( 92)
         rk( 92)=-0.2261135094267657D-06+(azi- 0.10D+02) * rk( 92)
         rk( 92)= 0.5540000000000000D-04+(azi- 0.10D+02) * rk( 92)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 92)= 0.2751396305579915D-10
         rk( 92)=-0.1092054340126420D-07+(azi- 0.20D+02) * rk( 92)
         rk( 92)=-0.4485459622929379D-06+(azi- 0.20D+02) * rk( 92)
         rk( 92)= 0.5202000000000000D-04+(azi- 0.20D+02) * rk( 92)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 92)= 0.4653886497385603D-10
         rk( 92)=-0.1009512450959028D-07+(azi- 0.30D+02) * rk( 92)
         rk( 92)=-0.6587026414014824D-06+(azi- 0.30D+02) * rk( 92)
         rk( 92)= 0.4647000000000000D-04+(azi- 0.30D+02) * rk( 92)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 92)= 0.1263305770487802D-09
         rk( 92)=-0.8698958560374555D-08+(azi- 0.40D+02) * rk( 92)
         rk( 92)=-0.8466434721011313D-06+(azi- 0.40D+02) * rk( 92)
         rk( 92)= 0.3892000000000000D-04+(azi- 0.40D+02) * rk( 92)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 92)= 0.2181388268307774D-09
         rk( 92)=-0.4909041248910261D-08+(azi- 0.50D+02) * rk( 92)
         rk( 92)=-0.9827234701939811D-06+(azi- 0.50D+02) * rk( 92)
         rk( 92)= 0.2971000000000000D-04+(azi- 0.50D+02) * rk( 92)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 92)= 0.4711141156283397D-09
         rk( 92)= 0.1635123556011636D-08+(azi- 0.60D+02) * rk( 92)
         rk( 92)=-0.1015462647122983D-05+(azi- 0.60D+02) * rk( 92)
         rk( 92)= 0.1961000000000000D-04+(azi- 0.60D+02) * rk( 92)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 92)= 0.3422275799287201D-09
         rk( 92)= 0.1576854702486291D-07+(azi- 0.70D+02) * rk( 92)
         rk( 92)=-0.8414259413143087D-06+(azi- 0.70D+02) * rk( 92)
         rk( 92)= 0.1009000000000000D-04+(azi- 0.70D+02) * rk( 92)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 92)=-0.1428665280860361D-08
         rk( 92)= 0.2398200894315219D-07+(azi- 0.78D+02) * rk( 92)
         rk( 92)=-0.5234214935702011D-06+(azi- 0.78D+02) * rk( 92)
         rk( 92)= 0.4543000000000000D-05+(azi- 0.78D+02) * rk( 92)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 92)= 0.1034293222470193D-07
         rk( 92)=-0.1030595779755070D-07+(azi- 0.86D+02) * rk( 92)
         rk( 92)=-0.4140130844051721D-06+(azi- 0.86D+02) * rk( 92)
         rk( 92)= 0.1159000000000000D-05+(azi- 0.86D+02) * rk( 92)
      elseif(azi.ge.90.D0)then
         rk( 92)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 92) = rk( 92) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 93)=-0.9760839202951312D-10
         rk( 93)=-0.6102391607970529D-07+(azi- 0.00D+00) * rk( 93)
         rk( 93)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 93)
         rk( 93)= 0.6344000000000000D-03+(azi- 0.00D+00) * rk( 93)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 93)=-0.1071748239113633D-09
         rk( 93)=-0.6395216784059067D-07+(azi- 0.10D+02) * rk( 93)
         rk( 93)=-0.1249760839202959D-05+(azi- 0.10D+02) * rk( 93)
         rk( 93)= 0.6282000000000000D-03+(azi- 0.10D+02) * rk( 93)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 93)=-0.3736923123250004D-09
         rk( 93)=-0.6716741255793162D-07+(azi- 0.20D+02) * rk( 93)
         rk( 93)=-0.2560956643188182D-05+(azi- 0.20D+02) * rk( 93)
         rk( 93)= 0.6092000000000000D-03+(azi- 0.20D+02) * rk( 93)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 93)=-0.4980559267885704D-09
         rk( 93)=-0.7837818192768172D-07+(azi- 0.30D+02) * rk( 93)
         rk( 93)=-0.4016412588044315D-05+(azi- 0.30D+02) * rk( 93)
         rk( 93)= 0.5765000000000000D-03+(azi- 0.30D+02) * rk( 93)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 93)=-0.1034083980520827D-08
         rk( 93)=-0.9331985973133861D-07+(azi- 0.40D+02) * rk( 93)
         rk( 93)=-0.5733393004634522D-05+(azi- 0.40D+02) * rk( 93)
         rk( 93)= 0.5280000000000000D-03+(azi- 0.40D+02) * rk( 93)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 93)=-0.1165608151128246D-08
         rk( 93)=-0.1243423791469634D-06+(azi- 0.50D+02) * rk( 93)
         rk( 93)=-0.7910015393417532D-05+(azi- 0.50D+02) * rk( 93)
         rk( 93)= 0.4603000000000000D-03+(azi- 0.50D+02) * rk( 93)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 93)=-0.1403483414969069D-08
         rk( 93)=-0.1593106236808006D-06+(azi- 0.60D+02) * rk( 93)
         rk( 93)=-0.1074654542169522D-04+(azi- 0.60D+02) * rk( 93)
         rk( 93)= 0.3676000000000000D-03+(azi- 0.60D+02) * rk( 93)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 93)= 0.2582224888813576D-07
         rk( 93)=-0.2014151261298622D-06+(azi- 0.70D+02) * rk( 93)
         rk( 93)=-0.1435380291980202D-04+(azi- 0.70D+02) * rk( 93)
         rk( 93)= 0.2428000000000000D-03+(azi- 0.70D+02) * rk( 93)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 93)=-0.3520277540823476D-07
         rk( 93)= 0.4183188471853961D-06+(azi- 0.78D+02) * rk( 93)
         rk( 93)=-0.1261857315135796D-04+(azi- 0.78D+02) * rk( 93)
         rk( 93)= 0.1283000000000000D-03+(azi- 0.78D+02) * rk( 93)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 93)= 0.3353497203262330D-06
         rk( 93)=-0.4265477626120210D-06+(azi- 0.86D+02) * rk( 93)
         rk( 93)=-0.1268440447477443D-04+(azi- 0.86D+02) * rk( 93)
         rk( 93)= 0.3610000000000000D-04+(azi- 0.86D+02) * rk( 93)
      elseif(azi.ge.90.D0)then
         rk( 93)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 93) = rk( 93) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 94)= 0.2077227349381971D-10
         rk( 94)=-0.2020772273493841D-07+(azi- 0.00D+00) * rk( 94)
         rk( 94)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 94)
         rk( 94)= 0.1866000000000000D-03+(azi- 0.00D+00) * rk( 94)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 94)=-0.6231682048137741D-10
         rk( 94)=-0.1958455453012382D-07+(azi- 0.10D+02) * rk( 94)
         rk( 94)=-0.3979227726506224D-06+(azi- 0.10D+02) * rk( 94)
         rk( 94)= 0.1846000000000000D-03+(azi- 0.10D+02) * rk( 94)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 94)=-0.7150499156837445D-10
         rk( 94)=-0.2145405914456513D-07+(azi- 0.20D+02) * rk( 94)
         rk( 94)=-0.8083089093975119D-06+(azi- 0.20D+02) * rk( 94)
         rk( 94)= 0.1786000000000000D-03+(azi- 0.20D+02) * rk( 94)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 94)=-0.1516632132450819D-09
         rk( 94)=-0.2359920889161637D-07+(azi- 0.30D+02) * rk( 94)
         rk( 94)=-0.1258841589759327D-05+(azi- 0.30D+02) * rk( 94)
         rk( 94)= 0.1683000000000000D-03+(azi- 0.30D+02) * rk( 94)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 94)=-0.2218421554513698D-09
         rk( 94)=-0.2814910528896865D-07+(azi- 0.40D+02) * rk( 94)
         rk( 94)=-0.1776324731565180D-05+(azi- 0.40D+02) * rk( 94)
         rk( 94)= 0.1532000000000000D-03+(azi- 0.40D+02) * rk( 94)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 94)=-0.2609681649494325D-09
         rk( 94)=-0.3480436995250896D-07+(azi- 0.50D+02) * rk( 94)
         rk( 94)=-0.2405859483979962D-05+(azi- 0.50D+02) * rk( 94)
         rk( 94)= 0.1324000000000000D-03+(azi- 0.50D+02) * rk( 94)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 94)=-0.2742851847502513D-09
         rk( 94)=-0.4263341490099320D-07+(azi- 0.60D+02) * rk( 94)
         rk( 94)=-0.3180237332515008D-05+(azi- 0.60D+02) * rk( 94)
         rk( 94)= 0.1046000000000000D-03+(azi- 0.60D+02) * rk( 94)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 94)= 0.7298233586061392D-08
         rk( 94)=-0.5086197044350575D-07+(azi- 0.70D+02) * rk( 94)
         rk( 94)=-0.4115191185960052D-05+(azi- 0.70D+02) * rk( 94)
         rk( 94)= 0.6826000000000000D-04+(azi- 0.70D+02) * rk( 94)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 94)=-0.1051395656943136D-07
         rk( 94)= 0.1242956356219677D-06+(azi- 0.78D+02) * rk( 94)
         rk( 94)=-0.3527721864532392D-05+(azi- 0.78D+02) * rk( 94)
         rk( 94)= 0.3582000000000000D-04+(azi- 0.78D+02) * rk( 94)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 94)= 0.9545804025557432D-07
         rk( 94)=-0.1280393220443848D-06+(azi- 0.86D+02) * rk( 94)
         rk( 94)=-0.3557671355911730D-05+(azi- 0.86D+02) * rk( 94)
         rk( 94)= 0.1017000000000000D-04+(azi- 0.86D+02) * rk( 94)
      elseif(azi.ge.90.D0)then
         rk( 94)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 94) = rk( 94) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 95)= 0.1848930849451708D-12
         rk( 95)=-0.1010184893084951D-07+(azi- 0.00D+00) * rk( 95)
         rk( 95)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 95)
         rk( 95)= 0.6579000000000001D-04+(azi- 0.00D+00) * rk( 95)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 95)=-0.1055467925481632D-10
         rk( 95)=-0.1009630213830115D-07+(azi- 0.10D+02) * rk( 95)
         rk( 95)=-0.2019815106915066D-06+(azi- 0.10D+02) * rk( 95)
         rk( 95)= 0.6478000000000000D-04+(azi- 0.10D+02) * rk( 95)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 95)=-0.7966176065696279D-11
         rk( 95)=-0.1041294251594564D-07+(azi- 0.20D+02) * rk( 95)
         rk( 95)=-0.4070739572339746D-06+(azi- 0.20D+02) * rk( 95)
         rk( 95)= 0.6174000000000000D-04+(azi- 0.20D+02) * rk( 95)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 95)=-0.7580616482369125D-11
         rk( 95)=-0.1065192779791656D-07+(azi- 0.30D+02) * rk( 95)
         rk( 95)=-0.6177226603725965D-06+(azi- 0.30D+02) * rk( 95)
         rk( 95)= 0.5662000000000000D-04+(azi- 0.30D+02) * rk( 95)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 95)= 0.2828864199517916D-10
         rk( 95)=-0.1087934629238771D-07+(azi- 0.40D+02) * rk( 95)
         rk( 95)=-0.8330354012756383D-06+(azi- 0.40D+02) * rk( 95)
         rk( 95)= 0.4937000000000000D-04+(azi- 0.40D+02) * rk( 95)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 95)= 0.1344260485016326D-09
         rk( 95)=-0.1003068703253215D-07+(azi- 0.50D+02) * rk( 95)
         rk( 95)=-0.1042135734524834D-05+(azi- 0.50D+02) * rk( 95)
         rk( 95)= 0.3998000000000000D-04+(azi- 0.50D+02) * rk( 95)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 95)= 0.4840071639981380D-09
         rk( 95)=-0.5997905577482744D-08+(azi- 0.60D+02) * rk( 95)
         rk( 95)=-0.1202421660625002D-05+(azi- 0.60D+02) * rk( 95)
         rk( 95)= 0.2869000000000000D-04+(azi- 0.60D+02) * rk( 95)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 95)= 0.1210924191180651D-08
         rk( 95)= 0.8522309342458883D-08+(azi- 0.70D+02) * rk( 95)
         rk( 95)=-0.1177177622975248D-05+(azi- 0.70D+02) * rk( 95)
         rk( 95)= 0.1655000000000000D-04+(azi- 0.70D+02) * rk( 95)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 95)=-0.3372698291525215D-08
         rk( 95)= 0.3758448993081486D-07+(azi- 0.78D+02) * rk( 95)
         rk( 95)=-0.8083232287888584D-06+(azi- 0.78D+02) * rk( 95)
         rk( 95)= 0.8297999999999999D-05+(azi- 0.78D+02) * rk( 95)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 95)= 0.2502940863321436D-07
         rk( 95)=-0.4336026906584454D-07+(azi- 0.86D+02) * rk( 95)
         rk( 95)=-0.8545294618682283D-06+(azi- 0.86D+02) * rk( 95)
         rk( 95)= 0.2510000000000000D-05+(azi- 0.86D+02) * rk( 95)
      elseif(azi.ge.90.D0)then
         rk( 95)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 95) = rk( 95) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 96)= 0.1848930849340286D-11
         rk( 96)=-0.1010184893084931D-06+(azi- 0.00D+00) * rk( 96)
         rk( 96)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 96)
         rk( 96)= 0.6579000000000000D-03+(azi- 0.00D+00) * rk( 96)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 96)=-0.1055467925480874D-09
         rk( 96)=-0.1009630213830129D-06+(azi- 0.10D+02) * rk( 96)
         rk( 96)=-0.2019815106915060D-05+(azi- 0.10D+02) * rk( 96)
         rk( 96)= 0.6478000000000000D-03+(azi- 0.10D+02) * rk( 96)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 96)=-0.7966176065705972D-10
         rk( 96)=-0.1041294251594555D-06+(azi- 0.20D+02) * rk( 96)
         rk( 96)=-0.4070739572339743D-05+(azi- 0.20D+02) * rk( 96)
         rk( 96)= 0.6174000000000000D-03+(azi- 0.20D+02) * rk( 96)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 96)=-0.7580616482345864D-10
         rk( 96)=-0.1065192779791676D-06+(azi- 0.30D+02) * rk( 96)
         rk( 96)=-0.6177226603725975D-05+(azi- 0.30D+02) * rk( 96)
         rk( 96)= 0.5662000000000000D-03+(azi- 0.30D+02) * rk( 96)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 96)= 0.2828864199506537D-09
         rk( 96)=-0.1087934629238704D-06+(azi- 0.40D+02) * rk( 96)
         rk( 96)=-0.8330354012756360D-05+(azi- 0.40D+02) * rk( 96)
         rk( 96)= 0.4937000000000000D-03+(azi- 0.40D+02) * rk( 96)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 96)= 0.1344260485020591D-08
         rk( 96)=-0.1003068703253507D-06+(azi- 0.50D+02) * rk( 96)
         rk( 96)=-0.1042135734524852D-04+(azi- 0.50D+02) * rk( 96)
         rk( 96)= 0.3998000000000000D-03+(azi- 0.50D+02) * rk( 96)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 96)= 0.4840071639967571D-08
         rk( 96)=-0.5997905577473537D-07+(azi- 0.60D+02) * rk( 96)
         rk( 96)=-0.1202421660624950D-04+(azi- 0.60D+02) * rk( 96)
         rk( 96)= 0.2869000000000000D-03+(azi- 0.60D+02) * rk( 96)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 96)= 0.1210924191185999D-07
         rk( 96)= 0.8522309342433610D-07+(azi- 0.70D+02) * rk( 96)
         rk( 96)=-0.1177177622975399D-04+(azi- 0.70D+02) * rk( 96)
         rk( 96)= 0.1655000000000000D-03+(azi- 0.70D+02) * rk( 96)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 96)=-0.3372698291537163D-07
         rk( 96)= 0.3758448993090844D-06+(azi- 0.78D+02) * rk( 96)
         rk( 96)=-0.8083232287886688D-05+(azi- 0.78D+02) * rk( 96)
         rk( 96)= 0.8297999999999999D-04+(azi- 0.78D+02) * rk( 96)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 96)= 0.2502940863329249D-06
         rk( 96)=-0.4336026906602687D-06+(azi- 0.86D+02) * rk( 96)
         rk( 96)=-0.8545294618692693D-05+(azi- 0.86D+02) * rk( 96)
         rk( 96)= 0.2510000000000000D-04+(azi- 0.86D+02) * rk( 96)
      elseif(azi.ge.90.D0)then
         rk( 96)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 96) = rk( 96) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 97)=-0.6415190657548639D-11
         rk( 97)=-0.7335848093424543D-08+(azi- 0.00D+00) * rk( 97)
         rk( 97)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 97)
         rk( 97)= 0.5304000000000000D-04+(azi- 0.00D+00) * rk( 97)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 97)=-0.1075442802734550D-10
         rk( 97)=-0.7528303813151003D-08+(azi- 0.10D+02) * rk( 97)
         rk( 97)=-0.1486415190657555D-06+(azi- 0.10D+02) * rk( 97)
         rk( 97)= 0.5230000000000000D-04+(azi- 0.10D+02) * rk( 97)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 97)=-0.1056709723306461D-10
         rk( 97)=-0.7850936653971374D-08+(azi- 0.20D+02) * rk( 97)
         rk( 97)=-0.3024339237369792D-06+(azi- 0.20D+02) * rk( 97)
         rk( 97)= 0.5005000000000000D-04+(azi- 0.20D+02) * rk( 97)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 97)=-0.1697718304040810D-10
         rk( 97)=-0.8167949570963313D-08+(azi- 0.30D+02) * rk( 97)
         rk( 97)=-0.4626227859863262D-06+(azi- 0.30D+02) * rk( 97)
         rk( 97)= 0.4623000000000000D-04+(azi- 0.30D+02) * rk( 97)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 97)=-0.1152417060528927D-10
         rk( 97)=-0.8677265062175557D-08+(azi- 0.40D+02) * rk( 97)
         rk( 97)=-0.6310749323177147D-06+(azi- 0.40D+02) * rk( 97)
         rk( 97)= 0.4077000000000000D-04+(azi- 0.40D+02) * rk( 97)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 97)= 0.7307386546149775D-10
         rk( 97)=-0.9022990180333760D-08+(azi- 0.50D+02) * rk( 97)
         rk( 97)=-0.8080774847428105D-06+(azi- 0.50D+02) * rk( 97)
         rk( 97)= 0.3358000000000000D-04+(azi- 0.50D+02) * rk( 97)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 97)= 0.3292287087592239D-09
         rk( 97)=-0.6830774216488621D-08+(azi- 0.60D+02) * rk( 97)
         rk( 97)=-0.9666151287110545D-06+(azi- 0.60D+02) * rk( 97)
         rk( 97)= 0.2467000000000000D-04+(azi- 0.60D+02) * rk( 97)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 97)= 0.1288567250666127D-08
         rk( 97)= 0.3046087046293154D-08+(azi- 0.70D+02) * rk( 97)
         rk( 97)=-0.1004462000413029D-05+(azi- 0.70D+02) * rk( 97)
         rk( 97)= 0.1465000000000000D-04+(azi- 0.70D+02) * rk( 97)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 97)=-0.3227795514901450D-08
         rk( 97)= 0.3397170106227342D-07+(azi- 0.78D+02) * rk( 97)
         rk( 97)=-0.7083196955444699D-06+(azi- 0.78D+02) * rk( 97)
         rk( 97)= 0.7469000000000000D-05+(azi- 0.78D+02) * rk( 97)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 97)= 0.2359317391190438D-07
         rk( 97)=-0.4349539129536139D-07+(azi- 0.86D+02) * rk( 97)
         rk( 97)=-0.7845092174085231D-06+(azi- 0.86D+02) * rk( 97)
         rk( 97)= 0.2324000000000000D-05+(azi- 0.86D+02) * rk( 97)
      elseif(azi.ge.90.D0)then
         rk( 97)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 97) = rk( 97) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 98)=-0.6214255294127368D-12
         rk( 98)=-0.1273785744705876D-08+(azi- 0.00D+00) * rk( 98)
         rk( 98)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 98)
         rk( 98)= 0.6980000000000000D-05+(azi- 0.00D+00) * rk( 98)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 98)= 0.1864276588239080D-11
         rk( 98)=-0.1292428510588258D-08+(azi- 0.10D+02) * rk( 98)
         rk( 98)=-0.2566214255294133D-07+(azi- 0.10D+02) * rk( 98)
         rk( 98)= 0.6852000000000000D-05+(azi- 0.10D+02) * rk( 98)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 98)= 0.1164319176455948D-11
         rk( 98)=-0.1236500212941084D-08+(azi- 0.20D+02) * rk( 98)
         rk( 98)=-0.5095142978823476D-07+(azi- 0.20D+02) * rk( 98)
         rk( 98)= 0.6468000000000000D-05+(azi- 0.20D+02) * rk( 98)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 98)= 0.4478446705937887D-11
         rk( 98)=-0.1201570637647404D-08+(azi- 0.30D+02) * rk( 98)
         rk( 98)=-0.7533213829411966D-07+(azi- 0.30D+02) * rk( 98)
         rk( 98)= 0.5836000000000000D-05+(azi- 0.30D+02) * rk( 98)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 98)= 0.9921893999794724D-11
         rk( 98)=-0.1067217236469250D-08+(azi- 0.40D+02) * rk( 98)
         rk( 98)=-0.9802001703528645D-07+(azi- 0.40D+02) * rk( 98)
         rk( 98)= 0.4967000000000000D-05+(azi- 0.40D+02) * rk( 98)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 98)= 0.2183397729487517D-10
         rk( 98)=-0.7695604164753526D-09+(azi- 0.50D+02) * rk( 98)
         rk( 98)=-0.1163877935647324D-06+(azi- 0.50D+02) * rk( 98)
         rk( 98)= 0.3890000000000000D-05+(azi- 0.50D+02) * rk( 98)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 98)= 0.5174219682066253D-10
         rk( 98)=-0.1145410976289639D-09+(azi- 0.60D+02) * rk( 98)
         rk( 98)=-0.1252288087057770D-06+(azi- 0.60D+02) * rk( 98)
         rk( 98)= 0.2671000000000000D-05+(azi- 0.60D+02) * rk( 98)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 98)= 0.8293239306604600D-10
         rk( 98)= 0.1437724806990917D-08+(azi- 0.70D+02) * rk( 98)
         rk( 98)=-0.1119969716121601D-06+(azi- 0.70D+02) * rk( 98)
         rk( 98)= 0.1459000000000000D-05+(azi- 0.70D+02) * rk( 98)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 98)=-0.2621791045785176D-09
         rk( 98)= 0.3428102240575173D-08+(azi- 0.78D+02) * rk( 98)
         rk( 98)=-0.7307035523161320D-07+(azi- 0.78D+02) * rk( 98)
         rk( 98)= 0.6975000000000000D-06+(azi- 0.78D+02) * rk( 98)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 98)= 0.1905680783669210D-08
         rk( 98)=-0.2864196269305862D-08+(azi- 0.86D+02) * rk( 98)
         rk( 98)=-0.6855910746145870D-07+(azi- 0.86D+02) * rk( 98)
         rk( 98)= 0.1981000000000000D-06+(azi- 0.86D+02) * rk( 98)
      elseif(azi.ge.90.D0)then
         rk( 98)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 98) = rk( 98) * att
C     
C     
      if(azi.lt.0.D0)then
         STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
         rk( 99)= 0.1883357184646318D-11
         rk( 99)=-0.1018833571846462D-08+(azi- 0.00D+00) * rk( 99)
         rk( 99)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 99)
         rk( 99)= 0.4056000000000000D-05+(azi- 0.00D+00) * rk( 99)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
         rk( 99)= 0.2349928446060861D-11
         rk( 99)=-0.9623328563070727D-09+(azi- 0.10D+02) * rk( 99)
         rk( 99)=-0.1981166428153535D-07+(azi- 0.10D+02) * rk( 99)
         rk( 99)= 0.3956000000000000D-05+(azi- 0.10D+02) * rk( 99)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
         rk( 99)= 0.4716929031110280D-11
         rk( 99)=-0.8918350029252474D-09+(azi- 0.20D+02) * rk( 99)
         rk( 99)=-0.3835334287385854D-07+(azi- 0.20D+02) * rk( 99)
         rk( 99)= 0.3664000000000000D-05+(azi- 0.20D+02) * rk( 99)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
         rk( 99)= 0.8782355429498127D-11
         rk( 99)=-0.7503271319919395D-09+(azi- 0.30D+02) * rk( 99)
         rk( 99)=-0.5477496422303039D-07+(azi- 0.30D+02) * rk( 99)
         rk( 99)= 0.3196000000000000D-05+(azi- 0.30D+02) * rk( 99)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
         rk( 99)= 0.1315364925089841D-10
         rk( 99)=-0.4868564691069920D-09+(azi- 0.40D+02) * rk( 99)
         rk( 99)=-0.6714680023401975D-07+(azi- 0.40D+02) * rk( 99)
         rk( 99)= 0.2582000000000000D-05+(azi- 0.40D+02) * rk( 99)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
         rk( 99)= 0.1960304756690532D-10
         rk( 99)=-0.9224699158005476D-10+(azi- 0.50D+02) * rk( 99)
         rk( 99)=-0.7293783484088980D-07+(azi- 0.50D+02) * rk( 99)
         rk( 99)= 0.1875000000000000D-05+(azi- 0.50D+02) * rk( 99)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
         rk( 99)= 0.2753416048149880D-10
         rk( 99)= 0.4958444354270291D-09+(azi- 0.60D+02) * rk( 99)
         rk( 99)=-0.6890186040242166D-07+(azi- 0.60D+02) * rk( 99)
         rk( 99)= 0.1156000000000000D-05+(azi- 0.60D+02) * rk( 99)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
         rk( 99)= 0.4488586725700234D-11
         rk( 99)= 0.1321869249872432D-08+(azi- 0.70D+02) * rk( 99)
         rk( 99)=-0.5072472354942813D-07+(azi- 0.70D+02) * rk( 99)
         rk( 99)= 0.5441000000000000D-06+(azi- 0.70D+02) * rk( 99)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
         rk( 99)=-0.6861337109588502D-10
         rk( 99)= 0.1429595331286696D-08+(azi- 0.78D+02) * rk( 99)
         rk( 99)=-0.2871300690015141D-07+(azi- 0.78D+02) * rk( 99)
         rk( 99)= 0.2252000000000000D-06+(azi- 0.78D+02) * rk( 99)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
         rk( 99)= 0.4322969468749726D-09
         rk( 99)=-0.2171255750179361D-09+(azi- 0.86D+02) * rk( 99)
         rk( 99)=-0.1901324884994710D-07+(azi- 0.86D+02) * rk( 99)
         rk( 99)= 0.5186000000000000D-07+(azi- 0.86D+02) * rk( 99)
      elseif(azi.ge.90.D0)then
         rk( 99)= 0.0000000000000000D+00
      endif
      if(att.lt.0.99999) rk( 99) = rk( 99) * att
C     
      rk(100) =  DEXP(-0.3950779001431612D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     -  0.1282000000000000D+04/temp)
      rk(101) =  DEXP(-0.3879328970928561D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     -  0.4620000000000000D+03/temp)
      rk(102) =  DEXP(-0.3873848147279061D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     -  0.4400000000000000D+02/temp)
      rk(103) =  DEXP(-0.3873848147279061D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     -  0.4400000000000000D+02/temp)
      if (temp.le.260.d0) then 
         rk(103) = 0.d0
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(103) = 0.d0
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(103) = 0.d0
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(103) = rk(103) * ( 0.0000000000000000D+00
     &        + (temp- 0.300D+03) * ( 0.4000000000000000D-03))
      else
         rk(103) = rk(103) *   0.8000000000000000D-02
      endif
C     
      rk(104) =  DEXP(-0.3873848147279061D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     -  0.4400000000000000D+02/temp)
      if (temp.le.260.d0) then 
         rk(104) = rk(104) *   0.2120000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(104) = rk(104) * ( 0.2120000000000000D+00
     &        + (temp- 0.260D+03) * ( 0.1300000000000000D-02))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(104) = rk(104) * ( 0.2380000000000000D+00
     &        + (temp- 0.280D+03) * ( 0.1150000000000001D-02))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(104) = rk(104) * ( 0.2610000000000000D+00
     &        + (temp- 0.300D+03) * ( 0.1099999999999998D-02))
      else
         rk(104) = rk(104) *   0.2830000000000000D+00
      endif
C     
      rk(105) =  DEXP(-0.3873848147279061D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     -  0.4400000000000000D+02/temp)
      if (temp.le.260.d0) then 
         rk(105) = rk(105) *   0.7290000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(105) = rk(105) * ( 0.7290000000000000D+00
     &        + (temp- 0.260D+03) * (-0.8000000000000008D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(105) = rk(105) * ( 0.7130000000000000D+00
     &        + (temp- 0.280D+03) * (-0.7000000000000006D-03))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(105) = rk(105) * ( 0.6990000000000000D+00
     &        + (temp- 0.300D+03) * (-0.1099999999999996D-02))
      else
         rk(105) = rk(105) *   0.6770000000000000D+00
      endif
C     
      rk(106) =  DEXP(-0.3873848147279061D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     -  0.4400000000000000D+02/temp)
      if (temp.le.260.d0) then 
         rk(106) = rk(106) *   0.9419999999999999D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(106) = rk(106) * ( 0.9419999999999999D+00
     &        + (temp- 0.260D+03) * ( 0.4500000000000004D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(106) = rk(106) * ( 0.9510000000000000D+00
     &        + (temp- 0.280D+03) * ( 0.4500000000000004D-03))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(106) = rk(106) * ( 0.9600000000000000D+00
     &        + (temp- 0.300D+03) * ( 0.0000000000000000D+00))
      else
         rk(106) = rk(106) *   0.9600000000000000D+00
      endif
C     
      rk(107) =  DEXP(-0.3873848147279061D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     -  0.4400000000000000D+02/temp)
      if (temp.le.260.d0) then 
         rk(107) = rk(107) *   0.5800000000000000D-01
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(107) = rk(107) * ( 0.5800000000000000D-01
     &        + (temp- 0.260D+03) * (-0.4500000000000001D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(107) = rk(107) * ( 0.4900000000000000D-01
     &        + (temp- 0.280D+03) * (-0.4500000000000001D-03))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(107) = rk(107) * ( 0.4000000000000000D-01
     &        + (temp- 0.300D+03) * (-0.4000000000000000D-03))
      else
         rk(107) = rk(107) *   0.3200000000000000D-01
      endif
C     
      rk(108) =  0.1960000000000000D-11
      rk(109) =  DEXP(-0.2695807664268612D+02
     &     - ( -0.4380000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(109) = rk(109) *   0.3380000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(109) = rk(109) * ( 0.3380000000000000D+00
     &        + (temp- 0.260D+03) * ( 0.3380000000000000D-01))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(109) = rk(109) * ( 0.1014000000000000D+01
     &        + (temp- 0.280D+03) * ( 0.3000000000000001D-01))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(109) = rk(109) * ( 0.1614000000000000D+01
     &        + (temp- 0.300D+03) * ( 0.1270000000000000D-01))
      else
         rk(109) = rk(109) *   0.1868000000000000D+01
      endif
C     
      rk(110) =  DEXP(-0.2695807664268612D+02
     &     - ( -0.4380000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(110) = rk(110) *   0.8310000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(110) = rk(110) * ( 0.8310000000000000D+00
     &        + (temp- 0.260D+03) * (-0.1690000000000000D-01))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(110) = rk(110) * ( 0.4930000000000000D+00
     &        + (temp- 0.280D+03) * (-0.1500000000000000D-01))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(110) = rk(110) * ( 0.1930000000000000D+00
     &        + (temp- 0.300D+03) * (-0.6350000000000001D-02))
      else
         rk(110) = rk(110) *   0.6600000000000000D-01
      endif
C     
      rk(111) =  DEXP(-0.3232611600944463D+02
     &     - (  0.2580000000000000D+04 )/temp)
      rk(112) =  DEXP(-0.2605204241097915D+02
     &     - ( -0.5040000000000000D+03 )/temp)
      rk(113) =  DEXP(-0.3283221177174586D+02
     &     - (  0.1878000000000000D+04 )/temp)
      rk(114) =  DEXP(-0.2439627194190406D+02
     &     - ( -0.4100000000000000D+03 )/temp)
      rk(115) =  DEXP(-0.3202917713253231D+02
     &     - (  0.2013000000000000D+04 )/temp)
      rk(116) =  DEXP(-0.2439627194190406D+02
     &     - (  0.1080000000000000D+04 )/temp)
      Effko =  0.5000000000000000D-29*DEXP(
     s     -0.1500000000000000D+01 * DLOG(temp/3.d2)) * SumM
      Rapk = Effko / DEXP(-0.2773638163158638D+02 + 
     &     ( 0.2000000000000000D+01)* DLOG(temp/3.d2) ) 
      facteur = 1.d0/(1.d0+DLOG10(Rapk)**2)
      rk(117) = DEXP( DLOG(Effko/(1.d0+Rapk)) + 
     &     DLOG( 0.6200000000000000D+00) * facteur)
      rk(118) =  DEXP(-0.2672680296528866D+02
     &     - (  0.2070000000000000D+03 )/temp)
      rk(119) =  0.5800000000000000D-10
      rk(120) =  DEXP(-0.3959179740550338D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     +  0.1480000000000000D+03/temp)
      rk(121) =  DEXP(-0.3962521340242322D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     +  0.5320000000000000D+03/temp)
      rk(122) =  DEXP(-0.2573941631173078D+02
     &     - (  0.3030000000000000D+03 )/temp)
      rk(123) =  DEXP(-0.2573941631173078D+02
     &     - (  0.3030000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(123) = rk(123) *   0.3110000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(123) = rk(123) * ( 0.3110000000000000D+00
     &        + (temp- 0.260D+03) * (-0.7000000000000006D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(123) = rk(123) * ( 0.2970000000000000D+00
     &        + (temp- 0.280D+03) * (-0.5000000000000005D-04))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(123) = rk(123) * ( 0.2960000000000000D+00
     &        + (temp- 0.300D+03) * (-0.1000000000000001D-03))
      else
         rk(123) = rk(123) *   0.2940000000000000D+00
      endif
C     
      rk(124) =  DEXP(-0.2573941631173078D+02
     &     - (  0.3030000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(124) = rk(124) *   0.1440000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(124) = rk(124) * ( 0.1440000000000000D+00
     &        + (temp- 0.260D+03) * ( 0.2500000000000002D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(124) = rk(124) * ( 0.1490000000000000D+00
     &        + (temp- 0.280D+03) * ( 0.3750000000000001D-02))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(124) = rk(124) * ( 0.2240000000000000D+00
     &        + (temp- 0.300D+03) * ( 0.1030000000000000D-01))
      else
         rk(124) = rk(124) *   0.4300000000000000D+00
      endif
C     
      rk(125) =  DEXP(-0.2573941631173078D+02
     &     - (  0.3030000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(125) = rk(125) *   0.1000000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(125) = rk(125) * ( 0.1000000000000000D+00
     &        + (temp- 0.260D+03) * ( 0.8999999999999994D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(125) = rk(125) * ( 0.1180000000000000D+00
     &        + (temp- 0.280D+03) * ( 0.9000000000000008D-03))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(125) = rk(125) * ( 0.1360000000000000D+00
     &        + (temp- 0.300D+03) * ( 0.8999999999999994D-03))
      else
         rk(125) = rk(125) *   0.1540000000000000D+00
      endif
C     
      rk(126) =  DEXP(-0.2573941631173078D+02
     &     - (  0.3030000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(126) = rk(126) *   0.1540000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(126) = rk(126) * ( 0.1540000000000000D+00
     &        + (temp- 0.260D+03) * ( 0.2500000000000002D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(126) = rk(126) * ( 0.1590000000000000D+00
     &        + (temp- 0.280D+03) * ( 0.7499999999999994D-03))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(126) = rk(126) * ( 0.1740000000000000D+00
     &        + (temp- 0.300D+03) * ( 0.5000000000000004D-03))
      else
         rk(126) = rk(126) *   0.1840000000000000D+00
      endif
C     
      rk(127) =  DEXP(-0.2573941631173078D+02
     &     - (  0.3030000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(127) = rk(127) *   0.4200000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(127) = rk(127) * ( 0.4200000000000000D+00
     &        + (temp- 0.260D+03) * ( 0.8000000000000008D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(127) = rk(127) * ( 0.4360000000000000D+00
     &        + (temp- 0.280D+03) * (-0.1250000000000001D-02))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(127) = rk(127) * ( 0.4110000000000000D+00
     &        + (temp- 0.300D+03) * (-0.5149999999999999D-02))
      else
         rk(127) = rk(127) *   0.3080000000000000D+00
      endif
C     
      rk(128) =  DEXP(-0.2573941631173078D+02
     &     - (  0.3030000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(128) = rk(128) *   0.5930000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(128) = rk(128) * ( 0.5930000000000000D+00
     &        + (temp- 0.260D+03) * (-0.2000000000000002D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(128) = rk(128) * ( 0.5890000000000000D+00
     &        + (temp- 0.280D+03) * (-0.2299999999999996D-02))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(128) = rk(128) * ( 0.5430000000000000D+00
     &        + (temp- 0.300D+03) * (-0.5450000000000003D-02))
      else
         rk(128) = rk(128) *   0.4340000000000000D+00
      endif
C     
      rk(129) =  DEXP(-0.2573941631173078D+02
     &     - (  0.3030000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(129) = rk(129) *   0.3320000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(129) = rk(129) * ( 0.3320000000000000D+00
     &        + (temp- 0.260D+03) * ( 0.8999999999999980D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(129) = rk(129) * ( 0.3500000000000000D+00
     &        + (temp- 0.280D+03) * ( 0.2950000000000000D-02))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(129) = rk(129) * ( 0.4090000000000000D+00
     &        + (temp- 0.300D+03) * ( 0.6000000000000003D-02))
      else
         rk(129) = rk(129) *   0.5290000000000000D+00
      endif
C     
      rk(130) =  DEXP(-0.2573941631173078D+02
     &     - (  0.3030000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(130) = rk(130) *   0.3000000000000000D-02
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(130) = rk(130) * ( 0.3000000000000000D-02
     &        + (temp- 0.260D+03) * ( 0.5000000000000000D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(130) = rk(130) * ( 0.1300000000000000D-01
     &        + (temp- 0.280D+03) * ( 0.1100000000000000D-02))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(130) = rk(130) * ( 0.3500000000000000D-01
     &        + (temp- 0.300D+03) * ( 0.8499999999999997D-03))
      else
         rk(130) = rk(130) *   0.5200000000000000D-01
      endif
C     
      rk(131) =  DEXP(-0.2573941631173078D+02
     &     - (  0.3030000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(131) = rk(131) *   0.8300000000000000D-01
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(131) = rk(131) * ( 0.8300000000000000D-01
     &        + (temp- 0.260D+03) * (-0.7500000000000000D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(131) = rk(131) * ( 0.6800000000000000D-01
     &        + (temp- 0.280D+03) * (-0.6500000000000003D-03))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(131) = rk(131) * ( 0.5500000000000000D-01
     &        + (temp- 0.300D+03) * (-0.6000000000000003D-03))
      else
         rk(131) = rk(131) *   0.4300000000000000D-01
      endif
C     
      rk(132) =  DEXP(-0.2575155606628139D+02
     &     - (  0.9300000000000000D+02 )/temp)
      rk(133) =  DEXP(-0.2575155606628139D+02
     &     - (  0.9300000000000000D+02 )/temp)
      if (temp.le.260.d0) then 
         rk(133) = rk(133) *   0.4900000000000000D-01
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(133) = rk(133) * ( 0.4900000000000000D-01
     &        + (temp- 0.260D+03) * (-0.5000000000000005D-04))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(133) = rk(133) * ( 0.4800000000000000D-01
     &        + (temp- 0.280D+03) * (-0.1500000000000001D-03))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(133) = rk(133) * ( 0.4500000000000000D-01
     &        + (temp- 0.300D+03) * ( 0.5000000000000005D-04))
      else
         rk(133) = rk(133) *   0.4600000000000000D-01
      endif
C     
      rk(134) =  DEXP(-0.2575155606628139D+02
     &     - (  0.9300000000000000D+02 )/temp)
      if (temp.le.260.d0) then 
         rk(134) = rk(134) *   0.1650000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(134) = rk(134) * ( 0.1650000000000000D+00
     &        + (temp- 0.260D+03) * (-0.1000000000000001D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(134) = rk(134) * ( 0.1630000000000000D+00
     &        + (temp- 0.280D+03) * ( 0.1250000000000000D-02))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(134) = rk(134) * ( 0.1880000000000000D+00
     &        + (temp- 0.300D+03) * ( 0.3100000000000000D-02))
      else
         rk(134) = rk(134) *   0.2500000000000000D+00
      endif
C     
      rk(135) =  DEXP(-0.2575155606628139D+02
     &     - (  0.9300000000000000D+02 )/temp)
      if (temp.le.260.d0) then 
         rk(135) = rk(135) *   0.1220000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(135) = rk(135) * ( 0.1220000000000000D+00
     &        + (temp- 0.260D+03) * ( 0.9499999999999995D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(135) = rk(135) * ( 0.1410000000000000D+00
     &        + (temp- 0.280D+03) * ( 0.2100000000000001D-02))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(135) = rk(135) * ( 0.1830000000000000D+00
     &        + (temp- 0.300D+03) * ( 0.3250000000000000D-02))
      else
         rk(135) = rk(135) *   0.2480000000000000D+00
      endif
C     
      rk(136) =  DEXP(-0.2575155606628139D+02
     &     - (  0.9300000000000000D+02 )/temp)
      if (temp.le.260.d0) then 
         rk(136) = rk(136) *   0.3090000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(136) = rk(136) * ( 0.3090000000000000D+00
     &        + (temp- 0.260D+03) * (-0.1000000000000001D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(136) = rk(136) * ( 0.3070000000000000D+00
     &        + (temp- 0.280D+03) * ( 0.3000000000000003D-03))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(136) = rk(136) * ( 0.3130000000000000D+00
     &        + (temp- 0.300D+03) * ( 0.8000000000000008D-03))
      else
         rk(136) = rk(136) *   0.3290000000000000D+00
      endif
C     
      rk(137) =  DEXP(-0.2575155606628139D+02
     &     - (  0.9300000000000000D+02 )/temp)
      if (temp.le.260.d0) then 
         rk(137) = rk(137) *   0.6600000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(137) = rk(137) * ( 0.6600000000000000D+00
     &        + (temp- 0.260D+03) * ( 0.2549999999999997D-02))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(137) = rk(137) * ( 0.7110000000000000D+00
     &        + (temp- 0.280D+03) * (-0.5000000000000005D-04))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(137) = rk(137) * ( 0.7100000000000000D+00
     &        + (temp- 0.300D+03) * (-0.3049999999999997D-02))
      else
         rk(137) = rk(137) *   0.6490000000000000D+00
      endif
C     
      rk(138) =  DEXP(-0.2575155606628139D+02
     &     - (  0.9300000000000000D+02 )/temp)
      if (temp.le.260.d0) then 
         rk(138) = rk(138) *   0.3380000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(138) = rk(138) * ( 0.3380000000000000D+00
     &        + (temp- 0.260D+03) * (-0.2350000000000002D-02))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(138) = rk(138) * ( 0.2910000000000000D+00
     &        + (temp- 0.280D+03) * (-0.3499999999999999D-02))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(138) = rk(138) * ( 0.2210000000000000D+00
     &        + (temp- 0.300D+03) * (-0.4099999999999999D-02))
      else
         rk(138) = rk(138) *   0.1390000000000000D+00
      endif
C     
      rk(139) =  DEXP(-0.2575155606628139D+02
     &     - (  0.9300000000000000D+02 )/temp)
      if (temp.le.260.d0) then 
         rk(139) = rk(139) *   0.4760000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(139) = rk(139) * ( 0.4760000000000000D+00
     &        + (temp- 0.260D+03) * ( 0.4200000000000004D-02))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(139) = rk(139) * ( 0.5600000000000001D+00
     &        + (temp- 0.280D+03) * ( 0.4849999999999999D-02))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(139) = rk(139) * ( 0.6570000000000000D+00
     &        + (temp- 0.300D+03) * ( 0.5249999999999999D-02))
      else
         rk(139) = rk(139) *   0.7620000000000000D+00
      endif
C     
      rk(140) =  DEXP(-0.2575155606628139D+02
     &     - (  0.9300000000000000D+02 )/temp)
      if (temp.le.260.d0) then 
         rk(140) = rk(140) *   0.3000000000000000D-02
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(140) = rk(140) * ( 0.3000000000000000D-02
     &        + (temp- 0.260D+03) * ( 0.3000000000000000D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(140) = rk(140) * ( 0.8999999999999999D-02
     &        + (temp- 0.280D+03) * ( 0.2500000000000001D-03))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(140) = rk(140) * ( 0.1400000000000000D-01
     &        + (temp- 0.300D+03) * ( 0.5500000000000000D-03))
      else
         rk(140) = rk(140) *   0.2500000000000000D-01
      endif
C     
      rk(141) =  DEXP(-0.2575155606628139D+02
     &     - (  0.9300000000000000D+02 )/temp)
      if (temp.le.260.d0) then 
         rk(141) = rk(141) *   0.1880000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(141) = rk(141) * ( 0.1880000000000000D+00
     &        + (temp- 0.260D+03) * (-0.1800000000000000D-02))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(141) = rk(141) * ( 0.1520000000000000D+00
     &        + (temp- 0.280D+03) * (-0.1450000000000000D-02))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(141) = rk(141) * ( 0.1230000000000000D+00
     &        + (temp- 0.300D+03) * (-0.1100000000000000D-02))
      else
         rk(141) = rk(141) *   0.1010000000000000D+00
      endif
C     
      rk(142) =  DEXP(-0.2518867408055934D+02
     &     - (  0.1050000000000000D+03 )/temp)
      rk(143) =  DEXP(-0.2518867408055934D+02
     &     - (  0.1050000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(143) = rk(143) *   0.4000000000000000D-02
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(143) = rk(143) * ( 0.4000000000000000D-02
     &        + (temp- 0.260D+03) * ( 0.2000000000000000D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(143) = rk(143) * ( 0.8000000000000000D-02
     &        + (temp- 0.280D+03) * ( 0.3000000000000000D-03))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(143) = rk(143) * ( 0.1400000000000000D-01
     &        + (temp- 0.300D+03) * ( 0.5999999999999999D-03))
      else
         rk(143) = rk(143) *   0.2600000000000000D-01
      endif
C     
      rk(144) =  DEXP(-0.2518867408055934D+02
     &     - (  0.1050000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(144) = rk(144) *   0.2200000000000000D-01
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(144) = rk(144) * ( 0.2200000000000000D-01
     &        + (temp- 0.260D+03) * ( 0.4500000000000001D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(144) = rk(144) * ( 0.3100000000000000D-01
     &        + (temp- 0.280D+03) * ( 0.9500000000000002D-03))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(144) = rk(144) * ( 0.5000000000000000D-01
     &        + (temp- 0.300D+03) * ( 0.2150000000000000D-02))
      else
         rk(144) = rk(144) *   0.9300000000000000D-01
      endif
C     
      rk(145) =  DEXP(-0.2518867408055934D+02
     &     - (  0.1050000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(145) = rk(145) *   0.1880000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(145) = rk(145) * ( 0.1880000000000000D+00
     &        + (temp- 0.260D+03) * (-0.5000000000000005D-04))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(145) = rk(145) * ( 0.1870000000000000D+00
     &        + (temp- 0.280D+03) * ( 0.1400000000000000D-02))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(145) = rk(145) * ( 0.2150000000000000D+00
     &        + (temp- 0.300D+03) * ( 0.3150000000000002D-02))
      else
         rk(145) = rk(145) *   0.2780000000000000D+00
      endif
C     
      rk(146) =  DEXP(-0.2518867408055934D+02
     &     - (  0.1050000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(146) = rk(146) *   0.3100000000000000D-01
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(146) = rk(146) * ( 0.3100000000000000D-01
     &        + (temp- 0.260D+03) * ( 0.7000000000000000D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(146) = rk(146) * ( 0.4500000000000000D-01
     &        + (temp- 0.280D+03) * ( 0.1100000000000000D-02))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(146) = rk(146) * ( 0.6700000000000000D-01
     &        + (temp- 0.300D+03) * ( 0.1550000000000000D-02))
      else
         rk(146) = rk(146) *   0.9800000000000000D-01
      endif
C     
      rk(147) =  DEXP(-0.2518867408055934D+02
     &     - (  0.1050000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(147) = rk(147) *   0.1008000000000000D+01
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(147) = rk(147) * ( 0.1008000000000000D+01
     &        + (temp- 0.260D+03) * ( 0.5149999999999999D-02))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(147) = rk(147) * ( 0.1111000000000000D+01
     &        + (temp- 0.280D+03) * ( 0.3749999999999998D-02))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(147) = rk(147) * ( 0.1186000000000000D+01
     &        + (temp- 0.300D+03) * ( 0.9500000000000064D-03))
      else
         rk(147) = rk(147) *   0.1205000000000000D+01
      endif
C     
      rk(148) =  DEXP(-0.2518867408055934D+02
     &     - (  0.1050000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(148) = rk(148) *   0.9600000000000000D-01
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(148) = rk(148) * ( 0.9600000000000000D-01
     &        + (temp- 0.260D+03) * (-0.5000000000000004D-03))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(148) = rk(148) * ( 0.8599999999999999D-01
     &        + (temp- 0.280D+03) * (-0.9499999999999995D-03))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(148) = rk(148) * ( 0.6700000000000000D-01
     &        + (temp- 0.300D+03) * (-0.1450000000000000D-02))
      else
         rk(148) = rk(148) *   0.3800000000000000D-01
      endif
C     
      rk(149) =  DEXP(-0.2518867408055934D+02
     &     - (  0.1050000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(149) = rk(149) *   0.5620000000000001D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(149) = rk(149) * ( 0.5620000000000001D+00
     &        + (temp- 0.260D+03) * ( 0.3499999999999998D-02))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(149) = rk(149) * ( 0.6320000000000000D+00
     &        + (temp- 0.280D+03) * ( 0.3949999999999998D-02))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(149) = rk(149) * ( 0.7110000000000000D+00
     &        + (temp- 0.300D+03) * ( 0.4400000000000004D-02))
      else
         rk(149) = rk(149) *   0.7990000000000000D+00
      endif
C     
      rk(150) =  DEXP(-0.2518867408055934D+02
     &     - (  0.1050000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(150) = rk(150) *   0.5800000000000000D-01
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(150) = rk(150) * ( 0.5800000000000000D-01
     &        + (temp- 0.260D+03) * ( 0.1600000000000000D-02))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(150) = rk(150) * ( 0.9000000000000000D-01
     &        + (temp- 0.280D+03) * ( 0.2450000000000001D-02))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(150) = rk(150) * ( 0.1390000000000000D+00
     &        + (temp- 0.300D+03) * ( 0.4400000000000000D-02))
      else
         rk(150) = rk(150) *   0.2270000000000000D+00
      endif
C     
      rk(151) =  DEXP(-0.2518867408055934D+02
     &     - (  0.1050000000000000D+03 )/temp)
      if (temp.le.260.d0) then 
         rk(151) = rk(151) *   0.3460000000000000D+00
      elseif(temp.gt. 0.260D+03.and.temp.le. 0.280D+03) then
         rk(151) = rk(151) * ( 0.3460000000000000D+00
     &        + (temp- 0.260D+03) * (-0.2950000000000000D-02))
      elseif(temp.gt. 0.280D+03.and.temp.le. 0.300D+03) then
         rk(151) = rk(151) * ( 0.2870000000000000D+00
     &        + (temp- 0.280D+03) * (-0.2949999999999999D-02))
      elseif(temp.gt. 0.300D+03.and.temp.le. 0.320D+03) then
         rk(151) = rk(151) * ( 0.2280000000000000D+00
     &        + (temp- 0.300D+03) * (-0.2700000000000001D-02))
      else
         rk(151) = rk(151) *   0.1740000000000000D+00
      endif
C     
      rk(152) =  DEXP(-0.2548743175442496D+02
     &     - ( -0.3980000000000000D+03 )/temp)
      rk(153) =  DEXP(-0.3330913584383617D+02
     &     - (  0.1721000000000000D+04 )/temp)
      rk(154) =  DEXP(-0.2575155606628139D+02
     &     - (  0.1875000000000000D+04 )/temp)
      rk(155) =  DEXP(-0.2524225832669345D+02
     &     - ( -0.5160000000000000D+03 )/temp)
      rk(156) =  DEXP(-0.3298696759531322D+02
     &     - (  0.1027000000000000D+04 )/temp)
      rk(157) =  DEXP(-0.3298696759531322D+02
     &     - (  0.1027000000000000D+04 )/temp)
      rk(158) =  DEXP(-0.2648044908832973D+02
     &     - (  0.3240000000000000D+03 )/temp)
      rk(159) =  DEXP(-0.2672276255575166D+02
     &     - ( -0.2690000000000000D+03 )/temp)
      rk(160) =  0.2280000000000000D-10
      rk(161) =  DEXP(-0.2573040724178841D+02
     &     - ( -0.1050000000000000D+03 )/temp)

      RETURN
      END





