C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE FEXCHEM (DLconc,RK,ZCsourc,DLchem)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes the chemical production term for the
C     gas-phase mechanism OZONE 16 (12 reactions, 16 species).
C     
C     OD + AIR + O2 --k1--> O3 + AIR + O2
C     O3 + NO       --k2--> NO2
C     NO + HO2      --k3--> NO2 +OH
C     OH + NO2      --k4--> HNO3
C     NO2           --k5--> NO  + OD
C     RH + OH       --k6--> RO2
C     RCHO + OH     --k7--> RCO3
C     RCHO          --k8--> RO2 + CO + HO2
C     NO + RO2      --k9--> RCHO + HO2 + NO2
C     NO + RCO3     --k10-> NO2 + RO2 + CO2
C     NO2 + RCO3    --k11-> PAN
C     PAN           --k12-> RCO3 + NO2
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     DLCONC: chemical concentrations.
C     RK: kinetic rates.
C     ZCSOURC: volumic emissions.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     DLCHEM: array of chemical production terms.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Denis Qulo, CEREA, February 2002.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMUSE: flags and parameters for numerics. 

      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMUSE.INC'

      DOUBLE PRECISION DLconc(NESP),DLchem(NESP)
      DOUBLE PRECISION W(nr),Rk(Nr)
      DOUBLE PRECISION ZCsourc(NESP)
      DOUBLE PRECISION RH,NO,NO2,PAN,RCHO,O3,OH,HO2,RCO3,RO2,OD
      DOUBLE PRECISION O2,AIR,CO,CO2,HNO3
      INTEGER Ji

C     Species.

      RH=DLconc(1)
      NO=DLconc(2)
      NO2=DLconc(3)
      PAN=DLconc(4)
      RCHO=DLconc(5)
      O3=DLconc(6)
      OH=DLconc(7)
      HO2=DLconc(8)
      RCO3=DLconc(9)
      RO2=DLconc(10)
      OD=DLconc(11)
      O2=DLconc(12)
      AIR=DLconc(13)
      CO=DLconc(14)
      CO2=DLconc(15)
      HNO3=DLconc(16)

C     Reaction rates.

      W(1)=RK(1)*OD*AIR*O2
      W(2)=RK(2)*O3*NO
      W(3)=RK(3)*NO*HO2
      W(4)=RK(4)*OH*NO2
      W(5)=RK(5)*NO2
      W(6)=RK(6)*RH*OH
      W(7)=RK(7)*RCHO*OH
      W(8)=RK(8)*RCHO
      W(9)=RK(9)*NO*RO2
      W(10)=RK(10)*NO*RCO3
      W(11)=RK(11)*NO2*RCO3
      W(12)=RK(12)*PAN

C     Chemical production terms.

      DLchem(1)=-W(6)
      DLchem(2)=-W(2)-W(3)+W(5)-W(9)-W(10)
      DLchem(3)=W(2)+W(3)-W(4)-W(5)+W(9)+W(10)-W(11)+W(12)
      DLchem(4)=W(11)-W(12)
      DLchem(5)=-W(7)-W(8)+W(9)
      DLchem(6)=W(1)-W(2)
      DLchem(7)=W(3)-W(4)-W(6)-W(7)
      DLchem(8)=-W(3)+W(8)+W(9)
      DLchem(9)=W(7)-W(10)-W(11)+W(12)
      DLchem(10)=W(6)+W(8)-W(9)+W(10)
      DLchem(11)=-W(1)+W(5)
      DLchem(12)=0.D0
      DLchem(13)=0.D0
      DLchem(14)=W(8)
      DLchem(15)=W(10)
      DLchem(16)=W(4)

C     Volumic emission term.

      IF(LSOURC)THEN
         DO Ji=1,NESP
            DLchem(Ji)=DLchem(Ji)+ZCsourc(Ji)
         ENDDO
      ENDIF

      END
