C------------------------------------------------------------------------
C       
C       Copyright (C) 2001-2003 CEREA (ENPC)
C       
C       This file is part of Polair.
C       Polair is a 3D eulerian chemistry-transport-model.
C       
C       Polair is free software; you can redistribute it and/or modify
C       it under the terms of the GNU General Public License as published by
C       the Free Software Foundation; either version 2 of the License, or
C       (at your option) any later version.
C       
C       Polair is distributed in the hope that it will be useful,
C       but WITHOUT ANY WARRANTY; without even the implied warranty of
C       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C       GNU General Public License (file "LICENSE") for more details.
C       
C------------------------------------------------------------------------

	SUBROUTINE jacdchemdc (DLconc,RK,DLdchemdc)

C------------------------------------------------------------------------
C       
C       -- DESCRIPTION 
C       
C       This routine computes the Jacobian Matrix for the
C       gas-phase mechanism OZONE 16 (12 reactions, 16 species).
C       
C       OD + AIR + O2 --k1--> O3 + AIR + O2
C       O3 + NO       --k2--> NO2
C       NO + HO2      --k3--> NO2 +OH
C       OH + NO2      --k4--> HNO3
C       NO2           --k5--> NO  + OD
C       RH + OH       --k6--> RO2
C       RCHO + OH     --k7--> RCO3
C       RCHO          --k8--> RO2 + CO + HO2
C       NO + RO2      --k9--> RCHO + HO2 + NO2
C       NO + RCO3     --k10-> NO2 + RO2 + CO2
C       NO2 + RCO3    --k11-> PAN
C       PAN           --k12-> RCO3 + NO2
C------------------------------------------------------------------------
C       
C       -- INPUT VARIABLES
C       
C       DLCONC: chemical concentrations.
C       RK: kinetic rates.
C       
C       -- INPUT/OUTPUT VARIABLES
C       
C       -- OUTPUT VARIABLES
C       
C       DLDCHEMDC: Jacobian matrix.
C       
C------------------------------------------------------------------------
C       
C       -- REMARKS
C       
C------------------------------------------------------------------------
C       
C       -- MODIFICATIONS
C       
C------------------------------------------------------------------------
C       
C       -- AUTHOR(S)
C       
C       Denis Qulo, CEREA, February 2002.
C       
C------------------------------------------------------------------------

	IMPLICIT NONE

C       -- INCLUDE FILES
C       PARACHEM: parameters for sizes of 'chemical' arrays.
C       PARADOM: parameters for all forced fields.

	INCLUDE 'PARADOM.INC' 
	INCLUDE 'PARACHEM.INC' 

	DOUBLE PRECISION DLconc(NESP),DLdchemdc(NESP,NESP)
	DOUBLE PRECISION RK(nr)
	DOUBLE PRECISION RH,NO,NO2,RCHO,O3,OD,O2,AIR
	DOUBLE PRECISION OH,HO2,RCO3,RO2

C       Species.

	RH=DLconc(1)
	NO=DLconc(2)
	NO2=DLconc(3)
	RCHO=DLconc(5)
	O3=DLconc(6)
	OH=DLconc(7)
	HO2=DLconc(8)
	RCO3=DLconc(9)
	RO2=DLconc(10)
	OD=DLconc(11)
	O2=DLconc(12)
	AIR=DLconc(13)

C       First row of Jacobian Matrix.

	DLdchemdc(1,1)=-RK(6)*OH
	DLdchemdc(2,1)=0.D0
	DLdchemdc(3,1)=0.D0
	DLdchemdc(4,1)=0.D0
	DLdchemdc(5,1)=0.D0
	DLdchemdc(6,1)=0.D0
	DLdchemdc(7,1)=-RK(6)*OH
	DLdchemdc(8,1)=0.D0
	DLdchemdc(9,1)=0.D0
	DLdchemdc(10,1)=RK(6)*OH
	DLdchemdc(11,1)=0.D0
	DLdchemdc(12,1)=0.D0
	DLdchemdc(13,1)=0.D0
	DLdchemdc(14,1)=0.D0
	DLdchemdc(15,1)=0.D0
	DLdchemdc(16,1)=0.D0

C       2nd row of Jacobian Matrix.

	DLdchemdc(1,2)=0.D0
	DLdchemdc(2,2)=-RK(2)*O3-RK(3)*HO2-RK(9)*RO2-RK(10)*RCO3
	DLdchemdc(3,2)=RK(2)*O3+RK(3)*HO2+RK(9)*RO2+RK(10)*RCO3
	DLdchemdc(4,2)=0.D0
	DLdchemdc(5,2)=RK(9)*RO2
	DLdchemdc(6,2)=-RK(2)*O3
	DLdchemdc(7,2)=RK(3)*HO2
	DLdchemdc(8,2)=-RK(3)*HO2+RK(9)*RO2
	DLdchemdc(9,2)=-RK(10)*RCO3
	DLdchemdc(10,2)=-RK(9)*RO2+RK(10)*RCO3
	DLdchemdc(11,2)=0.D0
	DLdchemdc(12,2)=0.D0
	DLdchemdc(13,2)=0.D0
	DLdchemdc(14,2)=0.D0
	DLdchemdc(15,2)=RK(10)*RCO3
	DLdchemdc(16,2)=0.D0

C       3rd row of Jacobian Matrix.

	DLdchemdc(1,3)=0.D0
	DLdchemdc(2,3)=RK(5)
	DLdchemdc(3,3)=-RK(4)*OH-RK(5)-RK(11)*RCO3
	DLdchemdc(4,3)=RK(11)*RCO3
	DLdchemdc(5,3)=0.D0
	DLdchemdc(6,3)=0.D0
	DLdchemdc(7,3)=-RK(4)*OH
	DLdchemdc(8,3)=0.D0
	DLdchemdc(9,3)=-RK(11)*RCO3
	DLdchemdc(10,3)=0.D0
	DLdchemdc(11,3)=RK(5)
	DLdchemdc(12,3)=0.D0
	DLdchemdc(13,3)=0.D0
	DLdchemdc(14,3)=0.D0
	DLdchemdc(15,3)=0.D0
	DLdchemdc(16,3)=RK(4)*OH

C       4th row of Jacobian Matrix

	DLdchemdc(1,4)=0.D0
	DLdchemdc(2,4)=0.D0
	DLdchemdc(3,4)=RK(12)
	DLdchemdc(4,4)=-RK(12)
	DLdchemdc(5,4)=0.D0
	DLdchemdc(6,4)=0.D0
	DLdchemdc(7,4)=0.D0
	DLdchemdc(8,4)=0.D0
	DLdchemdc(9,4)=RK(12)
	DLdchemdc(10,4)=0.D0
	DLdchemdc(11,4)=0.D0
	DLdchemdc(12,4)=0.D0
	DLdchemdc(13,4)=0.D0
	DLdchemdc(14,4)=0.D0
	DLdchemdc(15,4)=0.D0
	DLdchemdc(16,4)=0.D0

C       5th row of Jacobian Matrix

	DLdchemdc(1,5)=0.D0
	DLdchemdc(2,5)=0.D0
	DLdchemdc(3,5)=0.D0
	DLdchemdc(4,5)=0.D0
	DLdchemdc(5,5)=-RK(7)*OH-RK(8)
	DLdchemdc(6,5)=0.D0
	DLdchemdc(7,5)=-RK(7)*OH
	DLdchemdc(8,5)=RK(8)
	DLdchemdc(9,5)=RK(7)*OH
	DLdchemdc(10,5)=RK(8)
	DLdchemdc(11,5)=0.D0
	DLdchemdc(12,5)=0.D0
	DLdchemdc(13,5)=0.D0
	DLdchemdc(14,5)=RK(8)
	DLdchemdc(15,5)=0.D0
	DLdchemdc(16,5)=0.D0

C       6th row of Jacobian Matrix

	DLdchemdc(1,6)=0.D0
	DLdchemdc(2,6)=-RK(2)*NO
	DLdchemdc(3,6)=RK(2)*NO
	DLdchemdc(4,6)=0.D0
	DLdchemdc(5,6)=0.D0
	DLdchemdc(6,6)=-RK(2)*NO
	DLdchemdc(7,6)=0.D0
	DLdchemdc(8,6)=0.D0
	DLdchemdc(9,6)=0.D0
	DLdchemdc(10,6)=0.D0
	DLdchemdc(11,6)=0.D0
	DLdchemdc(12,6)=0.D0
	DLdchemdc(13,6)=0.D0
	DLdchemdc(14,6)=0.D0
	DLdchemdc(15,6)=0.D0
	DLdchemdc(16,6)=0.D0

C       7th row of Jacobian Matrix

	DLdchemdc(1,7)=-RK(6)*RH
	DLdchemdc(2,7)=0.D0
	DLdchemdc(3,7)=-RK(4)*NO2
	DLdchemdc(4,7)=0.D0
	DLdchemdc(5,7)=-RK(7)*RCHO
	DLdchemdc(6,7)=0.D0
	DLdchemdc(7,7)=-RK(4)*NO2-RK(6)*RH-RK(7)*RCHO
	DLdchemdc(8,7)=0.D0
	DLdchemdc(9,7)=RK(7)*RCHO
	DLdchemdc(10,7)=RK(6)*RH
	DLdchemdc(11,7)=0.D0
	DLdchemdc(12,7)=0.D0
	DLdchemdc(13,7)=0.D0
	DLdchemdc(14,7)=0.D0
	DLdchemdc(15,7)=0.D0
	DLdchemdc(16,7)=RK(4)*NO2

C       8th row of Jacobian Matrix

	DLdchemdc(1,8)=0.D0
	DLdchemdc(2,8)=-RK(3)*NO
	DLdchemdc(3,8)=RK(3)*NO
	DLdchemdc(4,8)=0.D0
	DLdchemdc(5,8)=0.D0
	DLdchemdc(6,8)=0.D0
	DLdchemdc(7,8)=RK(3)*NO
	DLdchemdc(8,8)=-RK(3)*NO
	DLdchemdc(9,8)=0.D0
	DLdchemdc(10,8)=0.D0
	DLdchemdc(11,8)=0.D0
	DLdchemdc(12,8)=0.D0
	DLdchemdc(13,8)=0.D0
	DLdchemdc(14,8)=0.D0
	DLdchemdc(15,8)=0.D0
	DLdchemdc(16,8)=0.D0

C       9th row of Jacobian Matrix

	DLdchemdc(1,9)=0.D0
	DLdchemdc(2,9)=-RK(10)*NO
	DLdchemdc(3,9)=RK(10)*NO-RK(11)*NO2
	DLdchemdc(4,9)=RK(11)*NO2
	DLdchemdc(5,9)=0.D0
	DLdchemdc(6,9)=0.D0
	DLdchemdc(7,9)=0.D0
	DLdchemdc(8,9)=0.D0
	DLdchemdc(9,9)=-RK(10)*NO-RK(11)*NO2
	DLdchemdc(10,9)=RK(10)*NO
	DLdchemdc(11,9)=0.D0
	DLdchemdc(12,9)=0.D0
	DLdchemdc(13,9)=0.D0
	DLdchemdc(14,9)=0.D0
	DLdchemdc(15,9)=RK(10)*NO
	DLdchemdc(16,9)=0.D0

C       10th row of Jacobian Matrix

	DLdchemdc(1,10)=0.D0
	DLdchemdc(2,10)=-RK(9)*NO
	DLdchemdc(3,10)=RK(9)*NO
	DLdchemdc(4,10)=0.D0
	DLdchemdc(5,10)=RK(9)*NO
	DLdchemdc(6,10)=0.D0
	DLdchemdc(7,10)=0.D0
	DLdchemdc(8,10)=RK(9)*NO
	DLdchemdc(9,10)=0.D0
	DLdchemdc(10,10)=-RK(9)*NO
	DLdchemdc(11,10)=0.D0
	DLdchemdc(12,10)=0.D0
	DLdchemdc(13,10)=0.D0
	DLdchemdc(14,10)=0.D0
	DLdchemdc(15,10)=0.D0
	DLdchemdc(16,10)=0.D0

C       11th row of Jacobian Matrix

	DLdchemdc(1,11)=0.D0
	DLdchemdc(2,11)=0.D0
	DLdchemdc(3,11)=0.D0
	DLdchemdc(4,11)=0.D0
	DLdchemdc(5,11)=0.D0
	DLdchemdc(6,11)=RK(1)*AIR*O2
	DLdchemdc(7,11)=0.D0
	DLdchemdc(8,11)=0.D0
	DLdchemdc(9,11)=0.D0
	DLdchemdc(10,11)=0.D0
	DLdchemdc(11,11)=-RK(1)*AIR*O2
	DLdchemdc(12,11)=0.D0
	DLdchemdc(13,11)=0.D0
	DLdchemdc(14,11)=0.D0
	DLdchemdc(15,11)=0.D0
	DLdchemdc(16,11)=0.D0

C       12th row of Jacobian Matrix

	DLdchemdc(1,12)=0.D0
	DLdchemdc(2,12)=0.D0
	DLdchemdc(3,12)=0.D0
	DLdchemdc(4,12)=0.D0
	DLdchemdc(5,12)=0.D0
	DLdchemdc(6,12)=RK(1)*OD*AIR
	DLdchemdc(7,12)=0.D0
	DLdchemdc(8,12)=0.D0
	DLdchemdc(9,12)=0.D0
	DLdchemdc(10,12)=0.D0
	DLdchemdc(11,12)=-RK(1)*OD*AIR
	DLdchemdc(12,12)=0.D0
	DLdchemdc(13,12)=0.D0
	DLdchemdc(14,12)=0.D0
	DLdchemdc(15,12)=0.D0
	DLdchemdc(16,12)=0.D0

C       13th row of Jacobian Matrix

	DLdchemdc(1,13)=0.D0
	DLdchemdc(2,13)=0.D0
	DLdchemdc(3,13)=0.D0
	DLdchemdc(4,13)=0.D0
	DLdchemdc(5,13)=0.D0
	DLdchemdc(6,13)=RK(1)*OD*O2
	DLdchemdc(7,13)=0.D0
	DLdchemdc(8,13)=0.D0
	DLdchemdc(9,13)=0.D0
	DLdchemdc(10,13)=0.D0
	DLdchemdc(11,13)=-RK(1)*OD*O2
	DLdchemdc(12,13)=0.D0
	DLdchemdc(13,13)=0.D0
	DLdchemdc(14,13)=0.D0
	DLdchemdc(15,13)=0.D0
	DLdchemdc(16,13)=0.D0

C       14th row of Jacobian Matrix

	DLdchemdc(1,14)=0.D0
	DLdchemdc(2,14)=0.D0
	DLdchemdc(3,14)=0.D0
	DLdchemdc(4,14)=0.D0
	DLdchemdc(5,14)=0.D0
	DLdchemdc(6,14)=0.D0
	DLdchemdc(7,14)=0.D0
	DLdchemdc(8,14)=0.D0
	DLdchemdc(9,14)=0.D0
	DLdchemdc(10,14)=0.D0
	DLdchemdc(11,14)=0.D0
	DLdchemdc(12,14)=0.D0
	DLdchemdc(13,14)=0.D0
	DLdchemdc(14,14)=0.D0
	DLdchemdc(15,14)=0.D0
	DLdchemdc(16,14)=0.D0

C       15th row of Jacobian Matrix

	DLdchemdc(1,15)=0.D0
	DLdchemdc(2,15)=0.D0
	DLdchemdc(3,15)=0.D0
	DLdchemdc(4,15)=0.D0
	DLdchemdc(5,15)=0.D0
	DLdchemdc(6,15)=0.D0
	DLdchemdc(7,15)=0.D0
	DLdchemdc(8,15)=0.D0
	DLdchemdc(9,15)=0.D0
	DLdchemdc(10,15)=0.D0
	DLdchemdc(11,15)=0.D0
	DLdchemdc(12,15)=0.D0
	DLdchemdc(13,15)=0.D0
	DLdchemdc(14,15)=0.D0
	DLdchemdc(15,15)=0.D0
	DLdchemdc(16,15)=0.D0

C       16th row of Jacobian Matrix

	DLdchemdc(1,16)=0.D0
	DLdchemdc(2,16)=0.D0
	DLdchemdc(3,16)=0.D0
	DLdchemdc(4,16)=0.D0
	DLdchemdc(5,16)=0.D0
	DLdchemdc(6,16)=0.D0
	DLdchemdc(7,16)=0.D0
	DLdchemdc(8,16)=0.D0
	DLdchemdc(9,16)=0.D0
	DLdchemdc(10,16)=0.D0
	DLdchemdc(11,16)=0.D0
	DLdchemdc(12,16)=0.D0
	DLdchemdc(13,16)=0.D0
	DLdchemdc(14,16)=0.D0
	DLdchemdc(15,16)=0.D0
	DLdchemdc(16,16)=0.D0
        
	END
	
