C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE KINETIC (RK)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes the kinetic rates (constant) for the
C     gas-phase mechanism OZONE 16 (12 reactions, 16 species).
C     
C     OD + AIR + O2 --k1--> O3 + AIR + O2
C     O3 + NO       --k2--> NO2
C     NO + HO2      --k3--> NO2 +OH
C     OH + NO2      --k4--> HNO3
C     NO2           --k5--> NO  + OD
C     RH + OH       --k6--> RO2
C     RCHO + OH     --k7--> RCO3
C     RCHO          --k8--> RO2 + CO + HO2
C     NO + RO2      --k9--> RCHO + HO2 + NO2
C     NO + RCO3     --k10-> NO2 + RO2 + CO2
C     NO2 + RCO3    --k11-> PAN
C     PAN           --k12-> RCO3 + NO2
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     RK: kinetic rates.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Denis Qulo, CEREA, February 2002.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of 'chemical' arrays.

      INCLUDE 'PARACHEM.INC'

      DOUBLE PRECISION RK(Nr)

      RK(1)=6.027D-34
      RK(2)=1.872D-14
      RK(3)=8.235D-12
      RK(4)=1.1D-11
      RK(5)=8.88D-3
      RK(6)=2.607D-12
      RK(7)=1.588D-11
      RK(8)=3.18D-6
      RK(9)=7.563D-12
      RK(10)=7.563D-12
      RK(11)=4.7D-12
      RK(12)=4.837D-4

      END
