C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE chem (ts,DLrain,DLhcloud,DLattenuation,DLhumid,DLtemp,
     s     DLpress,DLCsourc,DLCforc2d,DLCphotolysis_rates,
     s     tf,DLrainf,DLhcloudf,DLattenuationf,DLhumidf,DLtempf,
     s     DLpressf,DLCsourcf,DLCforc2df,DLCphotolysis_ratesf,
     s     DLconc)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes one timestep for gas-phase chemistry RADM.
C     Chemical kinetics is solved in each grid cell.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     TS: initial time (GMT, computed from January 1st, [s]).
C     DLRAIN: 2D rain intensity field at initial time ([mm/h]).
C     DLHCLOUD: 2D height of cloud basis ([m])
C     DLATTENUATION: 3D cloud attenuation field at initial time.
C     DLHUMID: 3D relative humidity field at initial time ([%]).
C     DLTEMP: 3D temperature field at initial time ([K]).
C     DLPRESS: 3D pressure field at initial time ([Pa]).
C     DLCFORC: array of 2D forced chemical concentration fields at
C     # initial time ([\mu.g/m^3]).
C     DLCSOURC: array of chemical volumic emissions at initial time
C     # ([\mu.g/m^3/s]).
C     DLCPHOTOLYSIS_RATES: photochemical kinetic rates
C     # at initial time ([s^{-1}]).
C     
C     The same variables are defined at final time of the timestep.
C     'f' is then put at the end of the name.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     DLCONC: array of 3D chemical concentrations ([\mu.g/m^3]). 
C     # Before entry, it is given at initial time of the timestep.
C     # On exit, it is computed at final time of the timestep.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C     2002/02/26: new treatment of sources (Jaouad Boutahar, CEREA).
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Denis Qulo, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMDOM: global variables for mesh and forcing fields. 
C     COMCHEM: global variables for chemical species. 

      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMDOM.INC'  
      INCLUDE 'COMCHEM.INC'
      
      DOUBLE PRECISION ts,tf,Dt

      DOUBLE PRECISION DLconc(NX,NY,NZ,nesp)
      DOUBLE PRECISION DLtemp(NXt,NYt,NZt),DLtempf(NXt,NYt,NZt)
      DOUBLE PRECISION DLrain(NXr,NYr),DLrainf(NXr,NYr)
      DOUBLE PRECISION DLhcloud(NXr,NYr),DLhcloudf(NXr,NYr)
      DOUBLE PRECISION DLattenuation(NXatt,NYatt,NZatt)
      DOUBLE PRECISION DLattenuationf(NXatt,NYatt,NZatt)
      DOUBLE PRECISION DLhumid(NXh,NYh,NZh),DLhumidf(NXh,NYh,NZh)
      DOUBLE PRECISION DLCsourc(Nx,Ny,Nzs,Nsrc)
      DOUBLE PRECISION DLCsourcf(Nx,Ny,Nzs,Nsrc)
      DOUBLE PRECISION ZCsourc(NESP)
      DOUBLE PRECISION ZCsourcf(NESP)
      DOUBLE PRECISION DLpress(NXp,NYp,NZp),DLpressf(NXp,NYp,NZp)
      DOUBLE PRECISION DLCforc2d(Nxf,Nyf,NESPF)
      DOUBLE PRECISION DLCforc2df(Nxf,Nyf,NESPF)
      DOUBLE PRECISION DLCphotolysis_rates(NRphot,Nx,Ny,Nz)
      DOUBLE PRECISION DLCphotolysis_ratesf(NRphot,Nx,Ny,Nz)

      INTEGER Ji,Jj,Jk,Jsp,Jsrc

      Dt = tf - ts

      DO Jsrc=1,Nsrc
         DO Jk=1,Nzs
            DO Jj=1,Ny
               DO Ji=1,Nx
                  Jsp=Nesps(Jsrc)
                  DLconc(Ji,Jj,Jk,Jsp)=DLconc(Ji,Jj,Jk,jsp)
     s                 + Dt*DLCsourc(Ji,Jj,Jk,Jsrc)
               ENDDO
            ENDDO
         ENDDO
      ENDDO

      END
