C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE LU_solve (M, x)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves M * y = x where M is an LU factorization
C     computed by LU_decompose.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     M: LU factorization computed by LU_decompose.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     x: on entry, the right-hand side of the equation. On exit,
C     the solution of the equation.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of 'chemical' arrays.

      INCLUDE 'PARACHEM.INC'

      DOUBLE PRECISION M(Nesp,Nesp)
      DOUBLE PRECISION x(Nesp)
      DOUBLE PRECISION temp


C     Forward substitution.

      x(1) = x(1) / M(1, 1)

      x(2) = x(2) / M(2, 2)

      x(3) = x(3) / M(3, 3)

      x(4) = x(4) / M(4, 4)

      x(5) = x(5) / M(5, 5)

      x(6) = x(6) / M(6, 6)

      x(7) = x(7) / M(7, 7)

      temp = M(8, 1) * x(1)
      x(8) = ( x(8) - temp ) / M(8, 8)

      x(9) = x(9) / M(9, 9)

      x(10) = x(10) / M(10, 10)

      x(11) = x(11) / M(11, 11)

      x(12) = x(12) / M(12, 12)

      x(13) = x(13) / M(13, 13)

      x(14) = x(14) / M(14, 14)

      x(15) = x(15) / M(15, 15)

      x(16) = x(16) / M(16, 16)

      temp = M(17, 5) * x(5)
      x(17) = ( x(17) - temp ) / M(17, 17)

      temp = M(18, 6) * x(6)
      x(18) = ( x(18) - temp ) / M(18, 18)

      x(19) = x(19) / M(19, 19)

      x(20) = x(20) / M(20, 20)

      x(21) = x(21) / M(21, 21)

      x(22) = x(22) / M(22, 22)

      temp = M(23, 17) * x(17)
      temp = temp + M(23, 18) * x(18)
      temp = temp + M(23, 22) * x(22)
      x(23) = ( x(23) - temp ) / M(23, 23)

      temp = M(24, 4) * x(4)
      x(24) = ( x(24) - temp ) / M(24, 24)

      x(25) = x(25) / M(25, 25)

      temp = M(26, 25) * x(25)
      x(26) = ( x(26) - temp ) / M(26, 26)

      temp = M(27, 12) * x(12)
      temp = temp + M(27, 13) * x(13)
      temp = temp + M(27, 14) * x(14)
      temp = temp + M(27, 19) * x(19)
      x(27) = ( x(27) - temp ) / M(27, 27)

      x(28) = x(28) / M(28, 28)

      x(29) = x(29) / M(29, 29)

      temp = M(30, 17) * x(17)
      temp = temp + M(30, 18) * x(18)
      temp = temp + M(30, 22) * x(22)
      temp = temp + M(30, 29) * x(29)
      x(30) = ( x(30) - temp ) / M(30, 30)

      temp = M(31, 17) * x(17)
      x(31) = ( x(31) - temp ) / M(31, 31)

      temp = M(32, 18) * x(18)
      x(32) = ( x(32) - temp ) / M(32, 32)

      temp = M(33, 22) * x(22)
      temp = temp + M(33, 30) * x(30)
      x(33) = ( x(33) - temp ) / M(33, 33)

      temp = M(34, 2) * x(2)
      temp = temp + M(34, 11) * x(11)
      temp = temp + M(34, 12) * x(12)
      temp = temp + M(34, 14) * x(14)
      temp = temp + M(34, 19) * x(19)
      temp = temp + M(34, 25) * x(25)
      x(34) = ( x(34) - temp ) / M(34, 34)

      temp = M(35, 7) * x(7)
      temp = temp + M(35, 12) * x(12)
      temp = temp + M(35, 19) * x(19)
      x(35) = ( x(35) - temp ) / M(35, 35)

      temp = M(36, 3) * x(3)
      x(36) = ( x(36) - temp ) / M(36, 36)

      temp = M(37, 4) * x(4)
      x(37) = ( x(37) - temp ) / M(37, 37)

      temp = M(38, 11) * x(11)
      x(38) = ( x(38) - temp ) / M(38, 38)

      temp = M(39, 12) * x(12)
      temp = temp + M(39, 19) * x(19)
      temp = temp + M(39, 35) * x(35)
      x(39) = ( x(39) - temp ) / M(39, 39)

      temp = M(40, 12) * x(12)
      temp = temp + M(40, 14) * x(14)
      temp = temp + M(40, 19) * x(19)
      temp = temp + M(40, 35) * x(35)
      temp = temp + M(40, 39) * x(39)
      x(40) = ( x(40) - temp ) / M(40, 40)

      temp = M(41, 40) * x(40)
      x(41) = ( x(41) - temp ) / M(41, 41)

      temp = M(42, 13) * x(13)
      x(42) = ( x(42) - temp ) / M(42, 42)

      temp = M(43, 14) * x(14)
      x(43) = ( x(43) - temp ) / M(43, 43)

      temp = M(44, 39) * x(39)
      temp = temp + M(44, 43) * x(43)
      x(44) = ( x(44) - temp ) / M(44, 44)

      temp = M(45, 44) * x(44)
      x(45) = ( x(45) - temp ) / M(45, 45)

      temp = M(46, 11) * x(11)
      temp = temp + M(46, 12) * x(12)
      temp = temp + M(46, 13) * x(13)
      temp = temp + M(46, 14) * x(14)
      temp = temp + M(46, 19) * x(19)
      temp = temp + M(46, 35) * x(35)
      temp = temp + M(46, 40) * x(40)
      temp = temp + M(46, 44) * x(44)
      x(46) = ( x(46) - temp ) / M(46, 46)

      temp = M(47, 11) * x(11)
      temp = temp + M(47, 12) * x(12)
      temp = temp + M(47, 13) * x(13)
      temp = temp + M(47, 14) * x(14)
      temp = temp + M(47, 19) * x(19)
      temp = temp + M(47, 35) * x(35)
      temp = temp + M(47, 40) * x(40)
      temp = temp + M(47, 44) * x(44)
      temp = temp + M(47, 46) * x(46)
      x(47) = ( x(47) - temp ) / M(47, 47)

      temp = M(48, 19) * x(19)
      temp = temp + M(48, 31) * x(31)
      temp = temp + M(48, 32) * x(32)
      temp = temp + M(48, 35) * x(35)
      x(48) = ( x(48) - temp ) / M(48, 48)

      temp = M(49, 12) * x(12)
      temp = temp + M(49, 14) * x(14)
      temp = temp + M(49, 19) * x(19)
      temp = temp + M(49, 35) * x(35)
      temp = temp + M(49, 39) * x(39)
      temp = temp + M(49, 43) * x(43)
      x(49) = ( x(49) - temp ) / M(49, 49)

      temp = M(50, 11) * x(11)
      temp = temp + M(50, 12) * x(12)
      temp = temp + M(50, 13) * x(13)
      temp = temp + M(50, 14) * x(14)
      temp = temp + M(50, 17) * x(17)
      temp = temp + M(50, 18) * x(18)
      temp = temp + M(50, 19) * x(19)
      temp = temp + M(50, 22) * x(22)
      temp = temp + M(50, 25) * x(25)
      temp = temp + M(50, 30) * x(30)
      temp = temp + M(50, 35) * x(35)
      temp = temp + M(50, 40) * x(40)
      temp = temp + M(50, 44) * x(44)
      temp = temp + M(50, 48) * x(48)
      temp = temp + M(50, 49) * x(49)
      x(50) = ( x(50) - temp ) / M(50, 50)

      temp = M(51, 2) * x(2)
      temp = temp + M(51, 31) * x(31)
      temp = temp + M(51, 32) * x(32)
      temp = temp + M(51, 33) * x(33)
      temp = temp + M(51, 48) * x(48)
      temp = temp + M(51, 49) * x(49)
      temp = temp + M(51, 50) * x(50)
      x(51) = ( x(51) - temp ) / M(51, 51)

      temp = M(52, 2) * x(2)
      temp = temp + M(52, 11) * x(11)
      temp = temp + M(52, 12) * x(12)
      temp = temp + M(52, 13) * x(13)
      temp = temp + M(52, 14) * x(14)
      temp = temp + M(52, 19) * x(19)
      temp = temp + M(52, 25) * x(25)
      temp = temp + M(52, 35) * x(35)
      temp = temp + M(52, 40) * x(40)
      temp = temp + M(52, 44) * x(44)
      temp = temp + M(52, 48) * x(48)
      temp = temp + M(52, 49) * x(49)
      temp = temp + M(52, 50) * x(50)
      temp = temp + M(52, 51) * x(51)
      x(52) = ( x(52) - temp ) / M(52, 52)

      temp = M(53, 31) * x(31)
      temp = temp + M(53, 32) * x(32)
      temp = temp + M(53, 33) * x(33)
      temp = temp + M(53, 36) * x(36)
      temp = temp + M(53, 37) * x(37)
      temp = temp + M(53, 38) * x(38)
      temp = temp + M(53, 39) * x(39)
      temp = temp + M(53, 41) * x(41)
      temp = temp + M(53, 42) * x(42)
      temp = temp + M(53, 43) * x(43)
      temp = temp + M(53, 45) * x(45)
      temp = temp + M(53, 49) * x(49)
      temp = temp + M(53, 50) * x(50)
      x(53) = ( x(53) - temp ) / M(53, 53)

      temp = M(54, 24) * x(24)
      temp = temp + M(54, 25) * x(25)
      temp = temp + M(54, 31) * x(31)
      temp = temp + M(54, 32) * x(32)
      temp = temp + M(54, 33) * x(33)
      temp = temp + M(54, 48) * x(48)
      temp = temp + M(54, 49) * x(49)
      temp = temp + M(54, 50) * x(50)
      x(54) = ( x(54) - temp ) / M(54, 54)

      temp = M(55, 30) * x(30)
      temp = temp + M(55, 48) * x(48)
      temp = temp + M(55, 49) * x(49)
      temp = temp + M(55, 50) * x(50)
      temp = temp + M(55, 51) * x(51)
      temp = temp + M(55, 54) * x(54)
      x(55) = ( x(55) - temp ) / M(55, 55)

      temp = M(56, 25) * x(25)
      temp = temp + M(56, 48) * x(48)
      temp = temp + M(56, 49) * x(49)
      temp = temp + M(56, 50) * x(50)
      x(56) = ( x(56) - temp ) / M(56, 56)

      temp = M(57, 14) * x(14)
      temp = temp + M(57, 36) * x(36)
      temp = temp + M(57, 37) * x(37)
      temp = temp + M(57, 38) * x(38)
      temp = temp + M(57, 39) * x(39)
      temp = temp + M(57, 40) * x(40)
      temp = temp + M(57, 41) * x(41)
      temp = temp + M(57, 44) * x(44)
      temp = temp + M(57, 45) * x(45)
      temp = temp + M(57, 46) * x(46)
      temp = temp + M(57, 47) * x(47)
      temp = temp + M(57, 48) * x(48)
      temp = temp + M(57, 49) * x(49)
      temp = temp + M(57, 50) * x(50)
      temp = temp + M(57, 56) * x(56)
      x(57) = ( x(57) - temp ) / M(57, 57)

      temp = M(58, 12) * x(12)
      temp = temp + M(58, 13) * x(13)
      temp = temp + M(58, 14) * x(14)
      temp = temp + M(58, 19) * x(19)
      temp = temp + M(58, 35) * x(35)
      temp = temp + M(58, 40) * x(40)
      temp = temp + M(58, 44) * x(44)
      temp = temp + M(58, 49) * x(49)
      temp = temp + M(58, 50) * x(50)
      temp = temp + M(58, 56) * x(56)
      x(58) = ( x(58) - temp ) / M(58, 58)

      temp = M(59, 3) * x(3)
      temp = temp + M(59, 10) * x(10)
      temp = temp + M(59, 13) * x(13)
      temp = temp + M(59, 36) * x(36)
      temp = temp + M(59, 37) * x(37)
      temp = temp + M(59, 40) * x(40)
      temp = temp + M(59, 41) * x(41)
      temp = temp + M(59, 42) * x(42)
      temp = temp + M(59, 44) * x(44)
      temp = temp + M(59, 45) * x(45)
      temp = temp + M(59, 46) * x(46)
      temp = temp + M(59, 47) * x(47)
      temp = temp + M(59, 48) * x(48)
      temp = temp + M(59, 49) * x(49)
      temp = temp + M(59, 50) * x(50)
      temp = temp + M(59, 53) * x(53)
      temp = temp + M(59, 56) * x(56)
      temp = temp + M(59, 58) * x(58)
      x(59) = ( x(59) - temp ) / M(59, 59)

      temp = M(60, 13) * x(13)
      temp = temp + M(60, 14) * x(14)
      temp = temp + M(60, 21) * x(21)
      temp = temp + M(60, 36) * x(36)
      temp = temp + M(60, 37) * x(37)
      temp = temp + M(60, 40) * x(40)
      temp = temp + M(60, 44) * x(44)
      temp = temp + M(60, 49) * x(49)
      temp = temp + M(60, 50) * x(50)
      temp = temp + M(60, 56) * x(56)
      temp = temp + M(60, 59) * x(59)
      x(60) = ( x(60) - temp ) / M(60, 60)

      temp = M(61, 2) * x(2)
      temp = temp + M(61, 4) * x(4)
      temp = temp + M(61, 10) * x(10)
      temp = temp + M(61, 13) * x(13)
      temp = temp + M(61, 35) * x(35)
      temp = temp + M(61, 36) * x(36)
      temp = temp + M(61, 37) * x(37)
      temp = temp + M(61, 38) * x(38)
      temp = temp + M(61, 40) * x(40)
      temp = temp + M(61, 41) * x(41)
      temp = temp + M(61, 42) * x(42)
      temp = temp + M(61, 44) * x(44)
      temp = temp + M(61, 45) * x(45)
      temp = temp + M(61, 46) * x(46)
      temp = temp + M(61, 47) * x(47)
      temp = temp + M(61, 48) * x(48)
      temp = temp + M(61, 49) * x(49)
      temp = temp + M(61, 50) * x(50)
      temp = temp + M(61, 53) * x(53)
      temp = temp + M(61, 56) * x(56)
      temp = temp + M(61, 58) * x(58)
      temp = temp + M(61, 59) * x(59)
      temp = temp + M(61, 60) * x(60)
      x(61) = ( x(61) - temp ) / M(61, 61)

      temp = M(62, 1) * x(1)
      temp = temp + M(62, 2) * x(2)
      temp = temp + M(62, 3) * x(3)
      temp = temp + M(62, 4) * x(4)
      temp = temp + M(62, 5) * x(5)
      temp = temp + M(62, 6) * x(6)
      temp = temp + M(62, 7) * x(7)
      temp = temp + M(62, 10) * x(10)
      temp = temp + M(62, 11) * x(11)
      temp = temp + M(62, 12) * x(12)
      temp = temp + M(62, 13) * x(13)
      temp = temp + M(62, 14) * x(14)
      temp = temp + M(62, 15) * x(15)
      temp = temp + M(62, 16) * x(16)
      temp = temp + M(62, 17) * x(17)
      temp = temp + M(62, 18) * x(18)
      temp = temp + M(62, 19) * x(19)
      temp = temp + M(62, 20) * x(20)
      temp = temp + M(62, 21) * x(21)
      temp = temp + M(62, 22) * x(22)
      temp = temp + M(62, 23) * x(23)
      temp = temp + M(62, 24) * x(24)
      temp = temp + M(62, 25) * x(25)
      temp = temp + M(62, 26) * x(26)
      temp = temp + M(62, 27) * x(27)
      temp = temp + M(62, 28) * x(28)
      temp = temp + M(62, 30) * x(30)
      temp = temp + M(62, 35) * x(35)
      temp = temp + M(62, 40) * x(40)
      temp = temp + M(62, 44) * x(44)
      temp = temp + M(62, 48) * x(48)
      temp = temp + M(62, 49) * x(49)
      temp = temp + M(62, 50) * x(50)
      temp = temp + M(62, 51) * x(51)
      temp = temp + M(62, 52) * x(52)
      temp = temp + M(62, 53) * x(53)
      temp = temp + M(62, 54) * x(54)
      temp = temp + M(62, 55) * x(55)
      temp = temp + M(62, 56) * x(56)
      temp = temp + M(62, 58) * x(58)
      temp = temp + M(62, 59) * x(59)
      temp = temp + M(62, 60) * x(60)
      temp = temp + M(62, 61) * x(61)
      x(62) = ( x(62) - temp ) / M(62, 62)

      temp = M(63, 12) * x(12)
      temp = temp + M(63, 16) * x(16)
      temp = temp + M(63, 19) * x(19)
      temp = temp + M(63, 20) * x(20)
      temp = temp + M(63, 28) * x(28)
      temp = temp + M(63, 31) * x(31)
      temp = temp + M(63, 32) * x(32)
      temp = temp + M(63, 33) * x(33)
      temp = temp + M(63, 35) * x(35)
      temp = temp + M(63, 36) * x(36)
      temp = temp + M(63, 37) * x(37)
      temp = temp + M(63, 38) * x(38)
      temp = temp + M(63, 39) * x(39)
      temp = temp + M(63, 40) * x(40)
      temp = temp + M(63, 41) * x(41)
      temp = temp + M(63, 42) * x(42)
      temp = temp + M(63, 43) * x(43)
      temp = temp + M(63, 44) * x(44)
      temp = temp + M(63, 45) * x(45)
      temp = temp + M(63, 46) * x(46)
      temp = temp + M(63, 47) * x(47)
      temp = temp + M(63, 48) * x(48)
      temp = temp + M(63, 49) * x(49)
      temp = temp + M(63, 50) * x(50)
      temp = temp + M(63, 56) * x(56)
      temp = temp + M(63, 58) * x(58)
      temp = temp + M(63, 59) * x(59)
      temp = temp + M(63, 60) * x(60)
      temp = temp + M(63, 61) * x(61)
      temp = temp + M(63, 62) * x(62)
      x(63) = ( x(63) - temp ) / M(63, 63)

      temp = M(64, 2) * x(2)
      temp = temp + M(64, 53) * x(53)
      temp = temp + M(64, 56) * x(56)
      temp = temp + M(64, 58) * x(58)
      temp = temp + M(64, 59) * x(59)
      temp = temp + M(64, 60) * x(60)
      temp = temp + M(64, 62) * x(62)
      temp = temp + M(64, 63) * x(63)
      x(64) = ( x(64) - temp ) / M(64, 64)

      temp = M(65, 5) * x(5)
      temp = temp + M(65, 6) * x(6)
      temp = temp + M(65, 12) * x(12)
      temp = temp + M(65, 19) * x(19)
      temp = temp + M(65, 25) * x(25)
      temp = temp + M(65, 26) * x(26)
      temp = temp + M(65, 28) * x(28)
      temp = temp + M(65, 30) * x(30)
      temp = temp + M(65, 35) * x(35)
      temp = temp + M(65, 36) * x(36)
      temp = temp + M(65, 37) * x(37)
      temp = temp + M(65, 48) * x(48)
      temp = temp + M(65, 49) * x(49)
      temp = temp + M(65, 50) * x(50)
      temp = temp + M(65, 53) * x(53)
      temp = temp + M(65, 56) * x(56)
      temp = temp + M(65, 58) * x(58)
      temp = temp + M(65, 59) * x(59)
      temp = temp + M(65, 60) * x(60)
      temp = temp + M(65, 62) * x(62)
      temp = temp + M(65, 63) * x(63)
      temp = temp + M(65, 64) * x(64)
      x(65) = ( x(65) - temp ) / M(65, 65)

      temp = M(66, 2) * x(2)
      temp = temp + M(66, 11) * x(11)
      temp = temp + M(66, 12) * x(12)
      temp = temp + M(66, 14) * x(14)
      temp = temp + M(66, 16) * x(16)
      temp = temp + M(66, 19) * x(19)
      temp = temp + M(66, 24) * x(24)
      temp = temp + M(66, 25) * x(25)
      temp = temp + M(66, 26) * x(26)
      temp = temp + M(66, 28) * x(28)
      temp = temp + M(66, 31) * x(31)
      temp = temp + M(66, 32) * x(32)
      temp = temp + M(66, 33) * x(33)
      temp = temp + M(66, 35) * x(35)
      temp = temp + M(66, 36) * x(36)
      temp = temp + M(66, 37) * x(37)
      temp = temp + M(66, 38) * x(38)
      temp = temp + M(66, 39) * x(39)
      temp = temp + M(66, 40) * x(40)
      temp = temp + M(66, 41) * x(41)
      temp = temp + M(66, 42) * x(42)
      temp = temp + M(66, 43) * x(43)
      temp = temp + M(66, 44) * x(44)
      temp = temp + M(66, 45) * x(45)
      temp = temp + M(66, 46) * x(46)
      temp = temp + M(66, 47) * x(47)
      temp = temp + M(66, 48) * x(48)
      temp = temp + M(66, 49) * x(49)
      temp = temp + M(66, 50) * x(50)
      temp = temp + M(66, 51) * x(51)
      temp = temp + M(66, 56) * x(56)
      temp = temp + M(66, 58) * x(58)
      temp = temp + M(66, 59) * x(59)
      temp = temp + M(66, 60) * x(60)
      temp = temp + M(66, 62) * x(62)
      temp = temp + M(66, 63) * x(63)
      temp = temp + M(66, 64) * x(64)
      temp = temp + M(66, 65) * x(65)
      x(66) = ( x(66) - temp ) / M(66, 66)

      temp = M(67, 23) * x(23)
      temp = temp + M(67, 30) * x(30)
      temp = temp + M(67, 31) * x(31)
      temp = temp + M(67, 32) * x(32)
      temp = temp + M(67, 33) * x(33)
      temp = temp + M(67, 35) * x(35)
      temp = temp + M(67, 36) * x(36)
      temp = temp + M(67, 37) * x(37)
      temp = temp + M(67, 38) * x(38)
      temp = temp + M(67, 39) * x(39)
      temp = temp + M(67, 41) * x(41)
      temp = temp + M(67, 42) * x(42)
      temp = temp + M(67, 43) * x(43)
      temp = temp + M(67, 45) * x(45)
      temp = temp + M(67, 46) * x(46)
      temp = temp + M(67, 47) * x(47)
      temp = temp + M(67, 49) * x(49)
      temp = temp + M(67, 50) * x(50)
      temp = temp + M(67, 56) * x(56)
      temp = temp + M(67, 58) * x(58)
      temp = temp + M(67, 59) * x(59)
      temp = temp + M(67, 60) * x(60)
      temp = temp + M(67, 62) * x(62)
      temp = temp + M(67, 63) * x(63)
      temp = temp + M(67, 64) * x(64)
      temp = temp + M(67, 65) * x(65)
      temp = temp + M(67, 66) * x(66)
      x(67) = ( x(67) - temp ) / M(67, 67)

      temp = M(68, 9) * x(9)
      temp = temp + M(68, 11) * x(11)
      temp = temp + M(68, 12) * x(12)
      temp = temp + M(68, 13) * x(13)
      temp = temp + M(68, 14) * x(14)
      temp = temp + M(68, 15) * x(15)
      temp = temp + M(68, 19) * x(19)
      temp = temp + M(68, 25) * x(25)
      temp = temp + M(68, 26) * x(26)
      temp = temp + M(68, 30) * x(30)
      temp = temp + M(68, 31) * x(31)
      temp = temp + M(68, 32) * x(32)
      temp = temp + M(68, 33) * x(33)
      temp = temp + M(68, 35) * x(35)
      temp = temp + M(68, 36) * x(36)
      temp = temp + M(68, 37) * x(37)
      temp = temp + M(68, 38) * x(38)
      temp = temp + M(68, 39) * x(39)
      temp = temp + M(68, 40) * x(40)
      temp = temp + M(68, 41) * x(41)
      temp = temp + M(68, 42) * x(42)
      temp = temp + M(68, 43) * x(43)
      temp = temp + M(68, 44) * x(44)
      temp = temp + M(68, 45) * x(45)
      temp = temp + M(68, 46) * x(46)
      temp = temp + M(68, 47) * x(47)
      temp = temp + M(68, 48) * x(48)
      temp = temp + M(68, 49) * x(49)
      temp = temp + M(68, 50) * x(50)
      temp = temp + M(68, 51) * x(51)
      temp = temp + M(68, 54) * x(54)
      temp = temp + M(68, 55) * x(55)
      temp = temp + M(68, 56) * x(56)
      temp = temp + M(68, 58) * x(58)
      temp = temp + M(68, 59) * x(59)
      temp = temp + M(68, 60) * x(60)
      temp = temp + M(68, 61) * x(61)
      temp = temp + M(68, 62) * x(62)
      temp = temp + M(68, 63) * x(63)
      temp = temp + M(68, 64) * x(64)
      temp = temp + M(68, 65) * x(65)
      temp = temp + M(68, 66) * x(66)
      temp = temp + M(68, 67) * x(67)
      x(68) = ( x(68) - temp ) / M(68, 68)

      temp = M(69, 12) * x(12)
      temp = temp + M(69, 19) * x(19)
      temp = temp + M(69, 24) * x(24)
      temp = temp + M(69, 25) * x(25)
      temp = temp + M(69, 26) * x(26)
      temp = temp + M(69, 28) * x(28)
      temp = temp + M(69, 31) * x(31)
      temp = temp + M(69, 32) * x(32)
      temp = temp + M(69, 33) * x(33)
      temp = temp + M(69, 35) * x(35)
      temp = temp + M(69, 36) * x(36)
      temp = temp + M(69, 37) * x(37)
      temp = temp + M(69, 38) * x(38)
      temp = temp + M(69, 39) * x(39)
      temp = temp + M(69, 41) * x(41)
      temp = temp + M(69, 42) * x(42)
      temp = temp + M(69, 43) * x(43)
      temp = temp + M(69, 45) * x(45)
      temp = temp + M(69, 46) * x(46)
      temp = temp + M(69, 47) * x(47)
      temp = temp + M(69, 48) * x(48)
      temp = temp + M(69, 49) * x(49)
      temp = temp + M(69, 50) * x(50)
      temp = temp + M(69, 54) * x(54)
      temp = temp + M(69, 56) * x(56)
      temp = temp + M(69, 58) * x(58)
      temp = temp + M(69, 59) * x(59)
      temp = temp + M(69, 60) * x(60)
      temp = temp + M(69, 61) * x(61)
      temp = temp + M(69, 62) * x(62)
      temp = temp + M(69, 63) * x(63)
      temp = temp + M(69, 64) * x(64)
      temp = temp + M(69, 65) * x(65)
      temp = temp + M(69, 66) * x(66)
      temp = temp + M(69, 67) * x(67)
      temp = temp + M(69, 68) * x(68)
      x(69) = ( x(69) - temp ) / M(69, 69)

      temp = M(70, 25) * x(25)
      temp = temp + M(70, 29) * x(29)
      temp = temp + M(70, 30) * x(30)
      temp = temp + M(70, 31) * x(31)
      temp = temp + M(70, 32) * x(32)
      temp = temp + M(70, 36) * x(36)
      temp = temp + M(70, 37) * x(37)
      temp = temp + M(70, 39) * x(39)
      temp = temp + M(70, 42) * x(42)
      temp = temp + M(70, 43) * x(43)
      temp = temp + M(70, 46) * x(46)
      temp = temp + M(70, 47) * x(47)
      temp = temp + M(70, 49) * x(49)
      temp = temp + M(70, 50) * x(50)
      temp = temp + M(70, 56) * x(56)
      temp = temp + M(70, 62) * x(62)
      temp = temp + M(70, 63) * x(63)
      temp = temp + M(70, 64) * x(64)
      temp = temp + M(70, 65) * x(65)
      temp = temp + M(70, 66) * x(66)
      temp = temp + M(70, 67) * x(67)
      temp = temp + M(70, 68) * x(68)
      temp = temp + M(70, 69) * x(69)
      x(70) = ( x(70) - temp ) / M(70, 70)

      temp = M(71, 1) * x(1)
      temp = temp + M(71, 2) * x(2)
      temp = temp + M(71, 3) * x(3)
      temp = temp + M(71, 4) * x(4)
      temp = temp + M(71, 5) * x(5)
      temp = temp + M(71, 6) * x(6)
      temp = temp + M(71, 10) * x(10)
      temp = temp + M(71, 11) * x(11)
      temp = temp + M(71, 12) * x(12)
      temp = temp + M(71, 13) * x(13)
      temp = temp + M(71, 14) * x(14)
      temp = temp + M(71, 15) * x(15)
      temp = temp + M(71, 16) * x(16)
      temp = temp + M(71, 17) * x(17)
      temp = temp + M(71, 18) * x(18)
      temp = temp + M(71, 19) * x(19)
      temp = temp + M(71, 22) * x(22)
      temp = temp + M(71, 24) * x(24)
      temp = temp + M(71, 25) * x(25)
      temp = temp + M(71, 27) * x(27)
      temp = temp + M(71, 28) * x(28)
      temp = temp + M(71, 29) * x(29)
      temp = temp + M(71, 30) * x(30)
      temp = temp + M(71, 31) * x(31)
      temp = temp + M(71, 32) * x(32)
      temp = temp + M(71, 33) * x(33)
      temp = temp + M(71, 35) * x(35)
      temp = temp + M(71, 36) * x(36)
      temp = temp + M(71, 37) * x(37)
      temp = temp + M(71, 38) * x(38)
      temp = temp + M(71, 39) * x(39)
      temp = temp + M(71, 40) * x(40)
      temp = temp + M(71, 41) * x(41)
      temp = temp + M(71, 42) * x(42)
      temp = temp + M(71, 43) * x(43)
      temp = temp + M(71, 44) * x(44)
      temp = temp + M(71, 45) * x(45)
      temp = temp + M(71, 46) * x(46)
      temp = temp + M(71, 47) * x(47)
      temp = temp + M(71, 48) * x(48)
      temp = temp + M(71, 49) * x(49)
      temp = temp + M(71, 50) * x(50)
      temp = temp + M(71, 51) * x(51)
      temp = temp + M(71, 52) * x(52)
      temp = temp + M(71, 53) * x(53)
      temp = temp + M(71, 54) * x(54)
      temp = temp + M(71, 56) * x(56)
      temp = temp + M(71, 58) * x(58)
      temp = temp + M(71, 59) * x(59)
      temp = temp + M(71, 60) * x(60)
      temp = temp + M(71, 61) * x(61)
      temp = temp + M(71, 62) * x(62)
      temp = temp + M(71, 63) * x(63)
      temp = temp + M(71, 64) * x(64)
      temp = temp + M(71, 65) * x(65)
      temp = temp + M(71, 66) * x(66)
      temp = temp + M(71, 67) * x(67)
      temp = temp + M(71, 68) * x(68)
      temp = temp + M(71, 69) * x(69)
      temp = temp + M(71, 70) * x(70)
      x(71) = ( x(71) - temp ) / M(71, 71)

      temp = M(72, 9) * x(9)
      temp = temp + M(72, 15) * x(15)
      temp = temp + M(72, 17) * x(17)
      temp = temp + M(72, 18) * x(18)
      temp = temp + M(72, 22) * x(22)
      temp = temp + M(72, 23) * x(23)
      temp = temp + M(72, 25) * x(25)
      temp = temp + M(72, 26) * x(26)
      temp = temp + M(72, 29) * x(29)
      temp = temp + M(72, 30) * x(30)
      temp = temp + M(72, 31) * x(31)
      temp = temp + M(72, 32) * x(32)
      temp = temp + M(72, 33) * x(33)
      temp = temp + M(72, 35) * x(35)
      temp = temp + M(72, 36) * x(36)
      temp = temp + M(72, 37) * x(37)
      temp = temp + M(72, 38) * x(38)
      temp = temp + M(72, 39) * x(39)
      temp = temp + M(72, 41) * x(41)
      temp = temp + M(72, 42) * x(42)
      temp = temp + M(72, 43) * x(43)
      temp = temp + M(72, 45) * x(45)
      temp = temp + M(72, 46) * x(46)
      temp = temp + M(72, 47) * x(47)
      temp = temp + M(72, 48) * x(48)
      temp = temp + M(72, 49) * x(49)
      temp = temp + M(72, 50) * x(50)
      temp = temp + M(72, 55) * x(55)
      temp = temp + M(72, 56) * x(56)
      temp = temp + M(72, 58) * x(58)
      temp = temp + M(72, 59) * x(59)
      temp = temp + M(72, 60) * x(60)
      temp = temp + M(72, 61) * x(61)
      temp = temp + M(72, 62) * x(62)
      temp = temp + M(72, 63) * x(63)
      temp = temp + M(72, 64) * x(64)
      temp = temp + M(72, 65) * x(65)
      temp = temp + M(72, 66) * x(66)
      temp = temp + M(72, 67) * x(67)
      temp = temp + M(72, 68) * x(68)
      temp = temp + M(72, 69) * x(69)
      temp = temp + M(72, 70) * x(70)
      temp = temp + M(72, 71) * x(71)
      x(72) = ( x(72) - temp ) / M(72, 72)


C     Backward substitution.

      temp = M(71, 72) * x(72)
      x(71) = x(71) - temp

      temp = M(70, 71) * x(71)
      temp = temp + M(70, 72) * x(72)
      x(70) = x(70) - temp

      temp = M(69, 70) * x(70)
      temp = temp + M(69, 71) * x(71)
      temp = temp + M(69, 72) * x(72)
      x(69) = x(69) - temp

      temp = M(68, 69) * x(69)
      temp = temp + M(68, 70) * x(70)
      temp = temp + M(68, 71) * x(71)
      temp = temp + M(68, 72) * x(72)
      x(68) = x(68) - temp

      temp = M(67, 68) * x(68)
      temp = temp + M(67, 69) * x(69)
      temp = temp + M(67, 70) * x(70)
      temp = temp + M(67, 71) * x(71)
      temp = temp + M(67, 72) * x(72)
      x(67) = x(67) - temp

      temp = M(66, 67) * x(67)
      temp = temp + M(66, 68) * x(68)
      temp = temp + M(66, 69) * x(69)
      temp = temp + M(66, 70) * x(70)
      temp = temp + M(66, 71) * x(71)
      temp = temp + M(66, 72) * x(72)
      x(66) = x(66) - temp

      temp = M(65, 66) * x(66)
      temp = temp + M(65, 67) * x(67)
      temp = temp + M(65, 68) * x(68)
      temp = temp + M(65, 69) * x(69)
      temp = temp + M(65, 70) * x(70)
      temp = temp + M(65, 71) * x(71)
      temp = temp + M(65, 72) * x(72)
      x(65) = x(65) - temp

      temp = M(64, 65) * x(65)
      temp = temp + M(64, 66) * x(66)
      temp = temp + M(64, 67) * x(67)
      temp = temp + M(64, 68) * x(68)
      temp = temp + M(64, 69) * x(69)
      temp = temp + M(64, 70) * x(70)
      temp = temp + M(64, 71) * x(71)
      temp = temp + M(64, 72) * x(72)
      x(64) = x(64) - temp

      temp = M(63, 64) * x(64)
      temp = temp + M(63, 65) * x(65)
      temp = temp + M(63, 66) * x(66)
      temp = temp + M(63, 67) * x(67)
      temp = temp + M(63, 68) * x(68)
      temp = temp + M(63, 69) * x(69)
      temp = temp + M(63, 70) * x(70)
      temp = temp + M(63, 71) * x(71)
      temp = temp + M(63, 72) * x(72)
      x(63) = x(63) - temp

      temp = M(62, 63) * x(63)
      temp = temp + M(62, 64) * x(64)
      temp = temp + M(62, 65) * x(65)
      temp = temp + M(62, 66) * x(66)
      temp = temp + M(62, 67) * x(67)
      temp = temp + M(62, 68) * x(68)
      temp = temp + M(62, 69) * x(69)
      temp = temp + M(62, 70) * x(70)
      temp = temp + M(62, 71) * x(71)
      temp = temp + M(62, 72) * x(72)
      x(62) = x(62) - temp

      temp = M(61, 62) * x(62)
      temp = temp + M(61, 63) * x(63)
      temp = temp + M(61, 64) * x(64)
      temp = temp + M(61, 65) * x(65)
      temp = temp + M(61, 67) * x(67)
      temp = temp + M(61, 68) * x(68)
      temp = temp + M(61, 69) * x(69)
      temp = temp + M(61, 70) * x(70)
      temp = temp + M(61, 71) * x(71)
      temp = temp + M(61, 72) * x(72)
      x(61) = x(61) - temp

      temp = M(60, 62) * x(62)
      temp = temp + M(60, 63) * x(63)
      temp = temp + M(60, 64) * x(64)
      temp = temp + M(60, 65) * x(65)
      temp = temp + M(60, 67) * x(67)
      temp = temp + M(60, 68) * x(68)
      temp = temp + M(60, 69) * x(69)
      temp = temp + M(60, 70) * x(70)
      temp = temp + M(60, 71) * x(71)
      temp = temp + M(60, 72) * x(72)
      x(60) = x(60) - temp

      temp = M(59, 60) * x(60)
      temp = temp + M(59, 62) * x(62)
      temp = temp + M(59, 63) * x(63)
      temp = temp + M(59, 64) * x(64)
      temp = temp + M(59, 65) * x(65)
      temp = temp + M(59, 67) * x(67)
      temp = temp + M(59, 68) * x(68)
      temp = temp + M(59, 69) * x(69)
      temp = temp + M(59, 70) * x(70)
      temp = temp + M(59, 71) * x(71)
      temp = temp + M(59, 72) * x(72)
      x(59) = x(59) - temp

      temp = M(58, 59) * x(59)
      temp = temp + M(58, 62) * x(62)
      temp = temp + M(58, 63) * x(63)
      temp = temp + M(58, 67) * x(67)
      temp = temp + M(58, 68) * x(68)
      temp = temp + M(58, 69) * x(69)
      temp = temp + M(58, 71) * x(71)
      temp = temp + M(58, 72) * x(72)
      x(58) = x(58) - temp

      temp = M(57, 58) * x(58)
      temp = temp + M(57, 60) * x(60)
      temp = temp + M(57, 62) * x(62)
      temp = temp + M(57, 63) * x(63)
      temp = temp + M(57, 64) * x(64)
      temp = temp + M(57, 67) * x(67)
      temp = temp + M(57, 68) * x(68)
      temp = temp + M(57, 69) * x(69)
      temp = temp + M(57, 71) * x(71)
      temp = temp + M(57, 72) * x(72)
      x(57) = x(57) - temp

      temp = M(56, 62) * x(62)
      temp = temp + M(56, 63) * x(63)
      temp = temp + M(56, 67) * x(67)
      temp = temp + M(56, 68) * x(68)
      temp = temp + M(56, 69) * x(69)
      temp = temp + M(56, 71) * x(71)
      temp = temp + M(56, 72) * x(72)
      x(56) = x(56) - temp

      temp = M(55, 56) * x(56)
      temp = temp + M(55, 58) * x(58)
      temp = temp + M(55, 61) * x(61)
      temp = temp + M(55, 62) * x(62)
      temp = temp + M(55, 63) * x(63)
      temp = temp + M(55, 64) * x(64)
      temp = temp + M(55, 66) * x(66)
      temp = temp + M(55, 67) * x(67)
      temp = temp + M(55, 68) * x(68)
      temp = temp + M(55, 69) * x(69)
      temp = temp + M(55, 71) * x(71)
      temp = temp + M(55, 72) * x(72)
      x(55) = x(55) - temp

      temp = M(54, 56) * x(56)
      temp = temp + M(54, 58) * x(58)
      temp = temp + M(54, 62) * x(62)
      temp = temp + M(54, 63) * x(63)
      temp = temp + M(54, 64) * x(64)
      temp = temp + M(54, 67) * x(67)
      temp = temp + M(54, 68) * x(68)
      temp = temp + M(54, 69) * x(69)
      temp = temp + M(54, 71) * x(71)
      temp = temp + M(54, 72) * x(72)
      x(54) = x(54) - temp

      temp = M(53, 56) * x(56)
      temp = temp + M(53, 58) * x(58)
      temp = temp + M(53, 60) * x(60)
      temp = temp + M(53, 62) * x(62)
      temp = temp + M(53, 63) * x(63)
      temp = temp + M(53, 64) * x(64)
      temp = temp + M(53, 65) * x(65)
      temp = temp + M(53, 67) * x(67)
      temp = temp + M(53, 68) * x(68)
      temp = temp + M(53, 69) * x(69)
      temp = temp + M(53, 71) * x(71)
      temp = temp + M(53, 72) * x(72)
      x(53) = x(53) - temp

      temp = M(52, 54) * x(54)
      temp = temp + M(52, 56) * x(56)
      temp = temp + M(52, 61) * x(61)
      temp = temp + M(52, 62) * x(62)
      temp = temp + M(52, 63) * x(63)
      temp = temp + M(52, 64) * x(64)
      temp = temp + M(52, 66) * x(66)
      temp = temp + M(52, 67) * x(67)
      temp = temp + M(52, 68) * x(68)
      temp = temp + M(52, 69) * x(69)
      temp = temp + M(52, 71) * x(71)
      temp = temp + M(52, 72) * x(72)
      x(52) = x(52) - temp

      temp = M(51, 56) * x(56)
      temp = temp + M(51, 62) * x(62)
      temp = temp + M(51, 63) * x(63)
      temp = temp + M(51, 64) * x(64)
      temp = temp + M(51, 67) * x(67)
      temp = temp + M(51, 68) * x(68)
      temp = temp + M(51, 69) * x(69)
      temp = temp + M(51, 71) * x(71)
      temp = temp + M(51, 72) * x(72)
      x(51) = x(51) - temp

      temp = M(50, 56) * x(56)
      temp = temp + M(50, 62) * x(62)
      temp = temp + M(50, 63) * x(63)
      temp = temp + M(50, 67) * x(67)
      temp = temp + M(50, 68) * x(68)
      temp = temp + M(50, 69) * x(69)
      temp = temp + M(50, 71) * x(71)
      temp = temp + M(50, 72) * x(72)
      x(50) = x(50) - temp

      temp = M(49, 50) * x(50)
      temp = temp + M(49, 62) * x(62)
      temp = temp + M(49, 63) * x(63)
      temp = temp + M(49, 67) * x(67)
      temp = temp + M(49, 68) * x(68)
      temp = temp + M(49, 69) * x(69)
      temp = temp + M(49, 71) * x(71)
      temp = temp + M(49, 72) * x(72)
      x(49) = x(49) - temp

      temp = M(48, 49) * x(49)
      temp = temp + M(48, 50) * x(50)
      temp = temp + M(48, 62) * x(62)
      temp = temp + M(48, 63) * x(63)
      temp = temp + M(48, 67) * x(67)
      temp = temp + M(48, 68) * x(68)
      temp = temp + M(48, 69) * x(69)
      temp = temp + M(48, 71) * x(71)
      temp = temp + M(48, 72) * x(72)
      x(48) = x(48) - temp

      temp = M(47, 49) * x(49)
      temp = temp + M(47, 50) * x(50)
      temp = temp + M(47, 62) * x(62)
      temp = temp + M(47, 63) * x(63)
      temp = temp + M(47, 67) * x(67)
      temp = temp + M(47, 68) * x(68)
      temp = temp + M(47, 69) * x(69)
      temp = temp + M(47, 71) * x(71)
      temp = temp + M(47, 72) * x(72)
      x(47) = x(47) - temp

      temp = M(46, 47) * x(47)
      temp = temp + M(46, 49) * x(49)
      temp = temp + M(46, 50) * x(50)
      temp = temp + M(46, 62) * x(62)
      temp = temp + M(46, 63) * x(63)
      temp = temp + M(46, 67) * x(67)
      temp = temp + M(46, 68) * x(68)
      temp = temp + M(46, 69) * x(69)
      temp = temp + M(46, 71) * x(71)
      temp = temp + M(46, 72) * x(72)
      x(46) = x(46) - temp

      temp = M(45, 49) * x(49)
      temp = temp + M(45, 50) * x(50)
      temp = temp + M(45, 62) * x(62)
      temp = temp + M(45, 63) * x(63)
      temp = temp + M(45, 67) * x(67)
      temp = temp + M(45, 68) * x(68)
      temp = temp + M(45, 69) * x(69)
      temp = temp + M(45, 71) * x(71)
      temp = temp + M(45, 72) * x(72)
      x(45) = x(45) - temp

      temp = M(44, 49) * x(49)
      temp = temp + M(44, 50) * x(50)
      temp = temp + M(44, 62) * x(62)
      temp = temp + M(44, 63) * x(63)
      temp = temp + M(44, 67) * x(67)
      temp = temp + M(44, 68) * x(68)
      temp = temp + M(44, 69) * x(69)
      temp = temp + M(44, 71) * x(71)
      temp = temp + M(44, 72) * x(72)
      x(44) = x(44) - temp

      temp = M(43, 50) * x(50)
      temp = temp + M(43, 62) * x(62)
      temp = temp + M(43, 63) * x(63)
      temp = temp + M(43, 67) * x(67)
      temp = temp + M(43, 68) * x(68)
      temp = temp + M(43, 69) * x(69)
      temp = temp + M(43, 71) * x(71)
      x(43) = x(43) - temp

      temp = M(42, 50) * x(50)
      temp = temp + M(42, 62) * x(62)
      temp = temp + M(42, 63) * x(63)
      temp = temp + M(42, 67) * x(67)
      temp = temp + M(42, 68) * x(68)
      temp = temp + M(42, 69) * x(69)
      temp = temp + M(42, 71) * x(71)
      x(42) = x(42) - temp

      temp = M(41, 49) * x(49)
      temp = temp + M(41, 50) * x(50)
      temp = temp + M(41, 62) * x(62)
      temp = temp + M(41, 63) * x(63)
      temp = temp + M(41, 67) * x(67)
      temp = temp + M(41, 68) * x(68)
      temp = temp + M(41, 69) * x(69)
      temp = temp + M(41, 71) * x(71)
      temp = temp + M(41, 72) * x(72)
      x(41) = x(41) - temp

      temp = M(40, 49) * x(49)
      temp = temp + M(40, 50) * x(50)
      temp = temp + M(40, 62) * x(62)
      temp = temp + M(40, 63) * x(63)
      temp = temp + M(40, 67) * x(67)
      temp = temp + M(40, 68) * x(68)
      temp = temp + M(40, 69) * x(69)
      temp = temp + M(40, 71) * x(71)
      temp = temp + M(40, 72) * x(72)
      x(40) = x(40) - temp

      temp = M(39, 49) * x(49)
      temp = temp + M(39, 50) * x(50)
      temp = temp + M(39, 62) * x(62)
      temp = temp + M(39, 63) * x(63)
      temp = temp + M(39, 67) * x(67)
      temp = temp + M(39, 68) * x(68)
      temp = temp + M(39, 69) * x(69)
      temp = temp + M(39, 71) * x(71)
      temp = temp + M(39, 72) * x(72)
      x(39) = x(39) - temp

      temp = M(38, 50) * x(50)
      temp = temp + M(38, 62) * x(62)
      temp = temp + M(38, 63) * x(63)
      temp = temp + M(38, 67) * x(67)
      temp = temp + M(38, 68) * x(68)
      temp = temp + M(38, 69) * x(69)
      temp = temp + M(38, 71) * x(71)
      x(38) = x(38) - temp

      temp = M(37, 62) * x(62)
      temp = temp + M(37, 63) * x(63)
      temp = temp + M(37, 67) * x(67)
      temp = temp + M(37, 68) * x(68)
      temp = temp + M(37, 69) * x(69)
      temp = temp + M(37, 71) * x(71)
      x(37) = x(37) - temp

      temp = M(36, 62) * x(62)
      temp = temp + M(36, 63) * x(63)
      temp = temp + M(36, 67) * x(67)
      temp = temp + M(36, 68) * x(68)
      temp = temp + M(36, 69) * x(69)
      temp = temp + M(36, 71) * x(71)
      x(36) = x(36) - temp

      temp = M(35, 49) * x(49)
      temp = temp + M(35, 50) * x(50)
      temp = temp + M(35, 62) * x(62)
      temp = temp + M(35, 67) * x(67)
      temp = temp + M(35, 68) * x(68)
      temp = temp + M(35, 72) * x(72)
      x(35) = x(35) - temp

      temp = M(34, 35) * x(35)
      temp = temp + M(34, 40) * x(40)
      temp = temp + M(34, 48) * x(48)
      temp = temp + M(34, 49) * x(49)
      temp = temp + M(34, 50) * x(50)
      temp = temp + M(34, 56) * x(56)
      temp = temp + M(34, 62) * x(62)
      temp = temp + M(34, 68) * x(68)
      temp = temp + M(34, 72) * x(72)
      x(34) = x(34) - temp

      temp = M(33, 50) * x(50)
      temp = temp + M(33, 62) * x(62)
      temp = temp + M(33, 63) * x(63)
      temp = temp + M(33, 67) * x(67)
      temp = temp + M(33, 68) * x(68)
      temp = temp + M(33, 69) * x(69)
      temp = temp + M(33, 71) * x(71)
      temp = temp + M(33, 72) * x(72)
      x(33) = x(33) - temp

      temp = M(32, 50) * x(50)
      temp = temp + M(32, 62) * x(62)
      temp = temp + M(32, 63) * x(63)
      temp = temp + M(32, 67) * x(67)
      temp = temp + M(32, 68) * x(68)
      temp = temp + M(32, 69) * x(69)
      temp = temp + M(32, 71) * x(71)
      temp = temp + M(32, 72) * x(72)
      x(32) = x(32) - temp

      temp = M(31, 50) * x(50)
      temp = temp + M(31, 62) * x(62)
      temp = temp + M(31, 63) * x(63)
      temp = temp + M(31, 67) * x(67)
      temp = temp + M(31, 68) * x(68)
      temp = temp + M(31, 69) * x(69)
      temp = temp + M(31, 71) * x(71)
      temp = temp + M(31, 72) * x(72)
      x(31) = x(31) - temp

      temp = M(30, 50) * x(50)
      temp = temp + M(30, 62) * x(62)
      temp = temp + M(30, 68) * x(68)
      temp = temp + M(30, 71) * x(71)
      temp = temp + M(30, 72) * x(72)
      x(30) = x(30) - temp

      temp = M(29, 30) * x(30)
      temp = temp + M(29, 62) * x(62)
      temp = temp + M(29, 68) * x(68)
      temp = temp + M(29, 71) * x(71)
      temp = temp + M(29, 72) * x(72)
      x(29) = x(29) - temp

      temp = M(28, 48) * x(48)
      temp = temp + M(28, 50) * x(50)
      temp = temp + M(28, 62) * x(62)
      temp = temp + M(28, 69) * x(69)
      temp = temp + M(28, 71) * x(71)
      x(28) = x(28) - temp

      temp = M(27, 35) * x(35)
      temp = temp + M(27, 40) * x(40)
      temp = temp + M(27, 44) * x(44)
      temp = temp + M(27, 50) * x(50)
      temp = temp + M(27, 62) * x(62)
      temp = temp + M(27, 68) * x(68)
      temp = temp + M(27, 71) * x(71)
      x(27) = x(27) - temp

      temp = M(26, 50) * x(50)
      temp = temp + M(26, 56) * x(56)
      temp = temp + M(26, 62) * x(62)
      temp = temp + M(26, 68) * x(68)
      temp = temp + M(26, 69) * x(69)
      temp = temp + M(26, 72) * x(72)
      x(26) = x(26) - temp

      temp = M(25, 50) * x(50)
      temp = temp + M(25, 56) * x(56)
      temp = temp + M(25, 62) * x(62)
      temp = temp + M(25, 68) * x(68)
      temp = temp + M(25, 72) * x(72)
      x(25) = x(25) - temp

      temp = M(24, 25) * x(25)
      temp = temp + M(24, 49) * x(49)
      temp = temp + M(24, 58) * x(58)
      temp = temp + M(24, 62) * x(62)
      temp = temp + M(24, 63) * x(63)
      x(24) = x(24) - temp

      temp = M(23, 30) * x(30)
      temp = temp + M(23, 50) * x(50)
      temp = temp + M(23, 62) * x(62)
      temp = temp + M(23, 67) * x(67)
      temp = temp + M(23, 72) * x(72)
      x(23) = x(23) - temp

      temp = M(22, 30) * x(30)
      temp = temp + M(22, 50) * x(50)
      temp = temp + M(22, 62) * x(62)
      temp = temp + M(22, 72) * x(72)
      x(22) = x(22) - temp

      temp = M(21, 40) * x(40)
      temp = temp + M(21, 44) * x(44)
      temp = temp + M(21, 50) * x(50)
      temp = temp + M(21, 62) * x(62)
      x(21) = x(21) - temp

      temp = M(20, 40) * x(40)
      temp = temp + M(20, 44) * x(44)
      temp = temp + M(20, 50) * x(50)
      temp = temp + M(20, 62) * x(62)
      x(20) = x(20) - temp

      temp = M(19, 35) * x(35)
      temp = temp + M(19, 50) * x(50)
      temp = temp + M(19, 62) * x(62)
      temp = temp + M(19, 68) * x(68)
      x(19) = x(19) - temp

      temp = M(18, 50) * x(50)
      temp = temp + M(18, 62) * x(62)
      temp = temp + M(18, 72) * x(72)
      x(18) = x(18) - temp

      temp = M(17, 50) * x(50)
      temp = temp + M(17, 62) * x(62)
      temp = temp + M(17, 72) * x(72)
      x(17) = x(17) - temp

      temp = M(16, 62) * x(62)
      temp = temp + M(16, 63) * x(63)
      temp = temp + M(16, 71) * x(71)
      x(16) = x(16) - temp

      temp = M(15, 62) * x(62)
      temp = temp + M(15, 71) * x(71)
      temp = temp + M(15, 72) * x(72)
      x(15) = x(15) - temp

      temp = M(14, 50) * x(50)
      temp = temp + M(14, 62) * x(62)
      temp = temp + M(14, 68) * x(68)
      x(14) = x(14) - temp

      temp = M(13, 50) * x(50)
      temp = temp + M(13, 62) * x(62)
      temp = temp + M(13, 68) * x(68)
      x(13) = x(13) - temp

      temp = M(12, 50) * x(50)
      temp = temp + M(12, 62) * x(62)
      temp = temp + M(12, 68) * x(68)
      x(12) = x(12) - temp

      temp = M(11, 50) * x(50)
      temp = temp + M(11, 62) * x(62)
      temp = temp + M(11, 68) * x(68)
      x(11) = x(11) - temp

      temp = M(10, 48) * x(48)
      temp = temp + M(10, 62) * x(62)
      x(10) = x(10) - temp

      temp = M(9, 68) * x(68)
      temp = temp + M(9, 72) * x(72)
      x(9) = x(9) - temp

      temp = M(8, 62) * x(62)
      x(8) = x(8) - temp

      temp = M(7, 50) * x(50)
      x(7) = x(7) - temp

      temp = M(6, 62) * x(62)
      x(6) = x(6) - temp

      temp = M(5, 62) * x(62)
      x(5) = x(5) - temp

      temp = M(4, 62) * x(62)
      x(4) = x(4) - temp

      temp = M(3, 62) * x(62)
      x(3) = x(3) - temp

      temp = M(2, 62) * x(62)
      x(2) = x(2) - temp

      temp = M(1, 62) * x(62)
      x(1) = x(1) - temp


      END
