C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE LU_decompose (M)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes an LU factorization of M.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     M: on entry, an invertible matrix. On exit, an LU factorization
C     of M.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of 'chemical' arrays.

      INCLUDE 'PARACHEM.INC'

      DOUBLE PRECISION M(Nesp,Nesp)
      DOUBLE PRECISION temp




C     Upper part.
      M(3, 54) = M(3, 54) / M(3, 3)

C     Upper part.
      M(4, 54) = M(4, 54) / M(4, 4)

C     Upper part.
      M(5, 54) = M(5, 54) / M(5, 5)

C     Upper part.
      M(6, 54) = M(6, 54) / M(6, 6)

C     Upper part.
      M(7, 54) = M(7, 54) / M(7, 7)

C     Upper part.
      M(8, 54) = M(8, 54) / M(8, 8)

C     Upper part.
      M(9, 54) = M(9, 54) / M(9, 9)

C     Upper part.
      temp = M(10, 9) * M(9, 54)
      M(10, 54) = ( M(10, 54) - temp ) / M(10, 10)

C     Upper part.
      M(11, 29) = M(11, 29) / M(11, 11)

C     Upper part.
      M(12, 54) = M(12, 54) / M(12, 12)
C     Upper part.
      M(12, 59) = M(12, 59) / M(12, 12)

C     Upper part.
      M(13, 57) = M(13, 57) / M(13, 13)
C     Upper part.
      M(13, 61) = M(13, 61) / M(13, 13)

C     Upper part.
      M(14, 54) = M(14, 54) / M(14, 14)
C     Upper part.
      M(14, 58) = M(14, 58) / M(14, 14)

C     Upper part.
      temp = M(15, 4) * M(4, 54)
      temp = temp + M(15, 5) * M(5, 54)
      M(15, 54) = ( M(15, 54) - temp ) / M(15, 15)
C     Upper part.
      M(15, 55) = M(15, 55) / M(15, 15)

C     Upper part.
      M(16, 55) = M(16, 55) / M(16, 16)
C     Upper part.
      M(16, 61) = M(16, 61) / M(16, 16)

C     Upper part.
      M(17, 29) = M(17, 29) / M(17, 17)
C     Upper part.
      M(17, 54) = M(17, 54) / M(17, 17)
C     Upper part.
      M(17, 55) = M(17, 55) / M(17, 17)

C     Upper part.
      M(18, 29) = M(18, 29) / M(18, 18)
C     Upper part.
      M(18, 54) = M(18, 54) / M(18, 18)
C     Upper part.
      M(18, 55) = M(18, 55) / M(18, 18)

C     Upper part.
      temp = M(19, 17) * M(17, 29)
      temp = temp + M(19, 18) * M(18, 29)
      M(19, 29) = ( M(19, 29) - temp ) / M(19, 19)
C     Upper part.
      temp = M(19, 17) * M(17, 54)
      temp = temp + M(19, 18) * M(18, 54)
      M(19, 54) = ( M(19, 54) - temp ) / M(19, 19)
C     Upper part.
      temp = M(19, 17) * M(17, 55)
      temp = temp + M(19, 18) * M(18, 55)
      M(19, 55) = ( M(19, 55) - temp ) / M(19, 19)

C     Upper part.
      M(20, 54) = M(20, 54) / M(20, 20)
C     Upper part.
      M(20, 59) = M(20, 59) / M(20, 20)
C     Upper part.
      M(20, 61) = M(20, 61) / M(20, 20)

C     Upper part.
      M(21, 29) = M(21, 29) / M(21, 21)
C     Upper part.
      M(21, 54) = M(21, 54) / M(21, 21)
C     Upper part.
      M(21, 55) = M(21, 55) / M(21, 21)

C     Upper part.
      M(22, 23) = M(22, 23) / M(22, 22)
C     Upper part.
      temp = M(22, 17) * M(17, 29)
      temp = temp + M(22, 18) * M(18, 29)
      temp = temp + M(22, 21) * M(21, 29)
      M(22, 29) = ( M(22, 29) - temp ) / M(22, 22)
C     Upper part.
      temp = M(22, 17) * M(17, 54)
      temp = temp + M(22, 18) * M(18, 54)
      temp = temp + M(22, 21) * M(21, 54)
      M(22, 54) = ( M(22, 54) - temp ) / M(22, 22)
C     Upper part.
      temp = M(22, 17) * M(17, 55)
      temp = temp + M(22, 18) * M(18, 55)
      temp = temp + M(22, 21) * M(21, 55)
      M(22, 55) = ( M(22, 55) - temp ) / M(22, 22)

C     Upper part.
      M(23, 29) = M(23, 29) / M(23, 23)
C     Upper part.
      M(23, 54) = M(23, 54) / M(23, 23)
C     Upper part.
      M(23, 55) = M(23, 55) / M(23, 23)

C     Upper part.
      M(24, 49) = M(24, 49) / M(24, 24)
C     Upper part.
      M(24, 54) = M(24, 54) / M(24, 24)
C     Upper part.
      M(24, 59) = M(24, 59) / M(24, 24)

C     Upper part.
      M(25, 54) = M(25, 54) / M(25, 25)
C     Upper part.
      M(25, 59) = M(25, 59) / M(25, 25)
C     Upper part.
      M(25, 60) = M(25, 60) / M(25, 25)

C     Upper part.
      temp = M(26, 25) * M(25, 54)
      M(26, 54) = ( M(26, 54) - temp ) / M(26, 26)
C     Upper part.
      M(26, 56) = M(26, 56) / M(26, 26)
C     Upper part.
      temp = M(26, 25) * M(25, 59)
      M(26, 59) = ( M(26, 59) - temp ) / M(26, 26)
C     Upper part.
      temp = M(26, 25) * M(25, 60)
      M(26, 60) = ( M(26, 60) - temp ) / M(26, 26)

C     Upper part.
      M(27, 54) = M(27, 54) / M(27, 27)
C     Upper part.
      M(27, 60) = M(27, 60) / M(27, 27)
C     Upper part.
      M(27, 61) = M(27, 61) / M(27, 27)

C     Upper part.
      temp = M(28, 11) * M(11, 29)
      M(28, 29) = ( M(28, 29) - temp ) / M(28, 28)
C     Upper part.
      M(28, 55) = M(28, 55) / M(28, 28)
C     Upper part.
      M(28, 61) = M(28, 61) / M(28, 28)

C     Lower part.
      temp = M(29, 17) * M(17, 29)
      temp = temp + M(29, 18) * M(18, 29)
      temp = temp + M(29, 21) * M(21, 29)
      temp = temp + M(29, 23) * M(23, 29)
      temp = temp + M(29, 28) * M(28, 29)
      M(29, 29) = M(29, 29) - temp
C     Lower part.
      temp = M(32, 21) * M(21, 29)
      M(32, 29) = M(32, 29) - temp
C     Lower part.
      temp = M(33, 17) * M(17, 29)
      temp = temp + M(33, 23) * M(23, 29)
      M(33, 29) = M(33, 29) - temp
C     Lower part.
      temp = M(34, 18) * M(18, 29)
      M(34, 29) = M(34, 29) - temp
C     Lower part.
      temp = M(38, 17) * M(17, 29)
      temp = temp + M(38, 18) * M(18, 29)
      temp = temp + M(38, 21) * M(21, 29)
      temp = temp + M(38, 23) * M(23, 29)
      M(38, 29) = M(38, 29) - temp
C     Lower part.
      temp = M(41, 18) * M(18, 29)
      M(41, 29) = M(41, 29) - temp
C     Lower part.
      temp = M(44, 17) * M(17, 29)
      temp = temp + M(44, 18) * M(18, 29)
      temp = temp + M(44, 23) * M(23, 29)
      M(44, 29) = M(44, 29) - temp
C     Lower part.
      temp = M(47, 17) * M(17, 29)
      temp = temp + M(47, 18) * M(18, 29)
      temp = temp + M(47, 23) * M(23, 29)
      M(47, 29) = M(47, 29) - temp
C     Lower part.
      temp = M(49, 17) * M(17, 29)
      temp = temp + M(49, 18) * M(18, 29)
      temp = temp + M(49, 19) * M(19, 29)
      temp = temp + M(49, 23) * M(23, 29)
      M(49, 29) = M(49, 29) - temp
C     Lower part.
      temp = M(52, 17) * M(17, 29)
      temp = temp + M(52, 18) * M(18, 29)
      temp = temp + M(52, 21) * M(21, 29)
      temp = temp + M(52, 23) * M(23, 29)
      M(52, 29) = M(52, 29) - temp
C     Lower part.
      temp = M(54, 11) * M(11, 29)
      temp = temp + M(54, 17) * M(17, 29)
      temp = temp + M(54, 18) * M(18, 29)
      temp = temp + M(54, 19) * M(19, 29)
      temp = temp + M(54, 21) * M(21, 29)
      temp = temp + M(54, 23) * M(23, 29)
      M(54, 29) = M(54, 29) - temp
C     Lower part.
      temp = M(55, 17) * M(17, 29)
      temp = temp + M(55, 18) * M(18, 29)
      temp = temp + M(55, 21) * M(21, 29)
      temp = temp + M(55, 23) * M(23, 29)
      M(55, 29) = M(55, 29) - temp
C     Lower part.
      temp = M(56, 17) * M(17, 29)
      temp = temp + M(56, 18) * M(18, 29)
      temp = temp + M(56, 21) * M(21, 29)
      temp = temp + M(56, 23) * M(23, 29)
      M(56, 29) = M(56, 29) - temp
C     Lower part.
      temp = M(58, 28) * M(28, 29)
      M(58, 29) = M(58, 29) - temp
C     Lower part.
      temp = M(59, 17) * M(17, 29)
      temp = temp + M(59, 18) * M(18, 29)
      temp = temp + M(59, 21) * M(21, 29)
      temp = temp + M(59, 23) * M(23, 29)
      M(59, 29) = M(59, 29) - temp
C     Lower part.
      temp = M(61, 28) * M(28, 29)
      M(61, 29) = M(61, 29) - temp
C     Upper part.
      temp = M(29, 17) * M(17, 54)
      temp = temp + M(29, 18) * M(18, 54)
      temp = temp + M(29, 21) * M(21, 54)
      temp = temp + M(29, 23) * M(23, 54)
      M(29, 54) = ( M(29, 54) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 17) * M(17, 55)
      temp = temp + M(29, 18) * M(18, 55)
      temp = temp + M(29, 21) * M(21, 55)
      temp = temp + M(29, 23) * M(23, 55)
      temp = temp + M(29, 28) * M(28, 55)
      M(29, 55) = ( M(29, 55) - temp ) / M(29, 29)
C     Upper part.
      M(29, 58) = M(29, 58) / M(29, 29)
C     Upper part.
      M(29, 59) = M(29, 59) / M(29, 29)
C     Upper part.
      temp = M(29, 28) * M(28, 61)
      M(29, 61) = ( M(29, 61) - temp ) / M(29, 29)

C     Upper part.
      M(30, 49) = M(30, 49) / M(30, 30)
C     Upper part.
      temp = M(30, 7) * M(7, 54)
      M(30, 54) = ( M(30, 54) - temp ) / M(30, 30)
C     Upper part.
      M(30, 58) = M(30, 58) / M(30, 30)
C     Upper part.
      M(30, 59) = M(30, 59) / M(30, 30)
C     Upper part.
      M(30, 60) = M(30, 60) / M(30, 30)

C     Upper part.
      M(31, 49) = M(31, 49) / M(31, 31)
C     Upper part.
      temp = M(31, 8) * M(8, 54)
      M(31, 54) = ( M(31, 54) - temp ) / M(31, 31)
C     Upper part.
      M(31, 58) = M(31, 58) / M(31, 31)
C     Upper part.
      M(31, 59) = M(31, 59) / M(31, 31)
C     Upper part.
      M(31, 60) = M(31, 60) / M(31, 31)

C     Upper part.
      M(32, 49) = M(32, 49) / M(32, 32)
C     Upper part.
      temp = M(32, 21) * M(21, 54)
      temp = temp + M(32, 29) * M(29, 54)
      M(32, 54) = ( M(32, 54) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 21) * M(21, 55)
      temp = temp + M(32, 29) * M(29, 55)
      M(32, 55) = ( M(32, 55) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 29) * M(29, 58)
      M(32, 58) = ( M(32, 58) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 29) * M(29, 59)
      M(32, 59) = ( M(32, 59) - temp ) / M(32, 32)
C     Upper part.
      M(32, 60) = M(32, 60) / M(32, 32)
C     Upper part.
      temp = M(32, 29) * M(29, 61)
      M(32, 61) = ( M(32, 61) - temp ) / M(32, 32)

C     Upper part.
      M(33, 49) = M(33, 49) / M(33, 33)
C     Upper part.
      temp = M(33, 17) * M(17, 54)
      temp = temp + M(33, 23) * M(23, 54)
      temp = temp + M(33, 29) * M(29, 54)
      M(33, 54) = ( M(33, 54) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 17) * M(17, 55)
      temp = temp + M(33, 23) * M(23, 55)
      temp = temp + M(33, 29) * M(29, 55)
      M(33, 55) = ( M(33, 55) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 29) * M(29, 58)
      M(33, 58) = ( M(33, 58) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 29) * M(29, 59)
      M(33, 59) = ( M(33, 59) - temp ) / M(33, 33)
C     Upper part.
      M(33, 60) = M(33, 60) / M(33, 33)
C     Upper part.
      temp = M(33, 29) * M(29, 61)
      M(33, 61) = ( M(33, 61) - temp ) / M(33, 33)

C     Upper part.
      M(34, 49) = M(34, 49) / M(34, 34)
C     Upper part.
      temp = M(34, 18) * M(18, 54)
      temp = temp + M(34, 29) * M(29, 54)
      M(34, 54) = ( M(34, 54) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 18) * M(18, 55)
      temp = temp + M(34, 29) * M(29, 55)
      M(34, 55) = ( M(34, 55) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 29) * M(29, 58)
      M(34, 58) = ( M(34, 58) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 29) * M(29, 59)
      M(34, 59) = ( M(34, 59) - temp ) / M(34, 34)
C     Upper part.
      M(34, 60) = M(34, 60) / M(34, 34)
C     Upper part.
      temp = M(34, 29) * M(29, 61)
      M(34, 61) = ( M(34, 61) - temp ) / M(34, 34)

C     Upper part.
      M(35, 49) = M(35, 49) / M(35, 35)
C     Upper part.
      temp = M(35, 4) * M(4, 54)
      M(35, 54) = ( M(35, 54) - temp ) / M(35, 35)
C     Upper part.
      M(35, 58) = M(35, 58) / M(35, 35)
C     Upper part.
      M(35, 59) = M(35, 59) / M(35, 35)
C     Upper part.
      M(35, 60) = M(35, 60) / M(35, 35)

C     Upper part.
      M(36, 49) = M(36, 49) / M(36, 36)
C     Upper part.
      temp = M(36, 5) * M(5, 54)
      M(36, 54) = ( M(36, 54) - temp ) / M(36, 36)
C     Upper part.
      M(36, 58) = M(36, 58) / M(36, 36)
C     Upper part.
      M(36, 59) = M(36, 59) / M(36, 36)
C     Upper part.
      M(36, 60) = M(36, 60) / M(36, 36)

C     Upper part.
      temp = M(37, 35) * M(35, 49)
      temp = temp + M(37, 36) * M(36, 49)
      M(37, 49) = ( M(37, 49) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 35) * M(35, 54)
      temp = temp + M(37, 36) * M(36, 54)
      M(37, 54) = ( M(37, 54) - temp ) / M(37, 37)
C     Upper part.
      M(37, 55) = M(37, 55) / M(37, 37)
C     Upper part.
      temp = M(37, 35) * M(35, 58)
      temp = temp + M(37, 36) * M(36, 58)
      M(37, 58) = ( M(37, 58) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 35) * M(35, 59)
      temp = temp + M(37, 36) * M(36, 59)
      M(37, 59) = ( M(37, 59) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 35) * M(35, 60)
      temp = temp + M(37, 36) * M(36, 60)
      M(37, 60) = ( M(37, 60) - temp ) / M(37, 37)

C     Upper part.
      M(38, 49) = M(38, 49) / M(38, 38)
C     Upper part.
      temp = M(38, 17) * M(17, 54)
      temp = temp + M(38, 18) * M(18, 54)
      temp = temp + M(38, 21) * M(21, 54)
      temp = temp + M(38, 23) * M(23, 54)
      temp = temp + M(38, 29) * M(29, 54)
      M(38, 54) = ( M(38, 54) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 17) * M(17, 55)
      temp = temp + M(38, 18) * M(18, 55)
      temp = temp + M(38, 21) * M(21, 55)
      temp = temp + M(38, 23) * M(23, 55)
      temp = temp + M(38, 29) * M(29, 55)
      M(38, 55) = ( M(38, 55) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 29) * M(29, 58)
      M(38, 58) = ( M(38, 58) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 29) * M(29, 59)
      M(38, 59) = ( M(38, 59) - temp ) / M(38, 38)
C     Upper part.
      M(38, 60) = M(38, 60) / M(38, 38)
C     Upper part.
      temp = M(38, 29) * M(29, 61)
      M(38, 61) = ( M(38, 61) - temp ) / M(38, 38)

C     Upper part.
      M(39, 49) = M(39, 49) / M(39, 39)
C     Upper part.
      temp = M(39, 15) * M(15, 54)
      M(39, 54) = ( M(39, 54) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 15) * M(15, 55)
      M(39, 55) = ( M(39, 55) - temp ) / M(39, 39)
C     Upper part.
      M(39, 59) = M(39, 59) / M(39, 39)
C     Upper part.
      M(39, 60) = M(39, 60) / M(39, 39)
C     Upper part.
      M(39, 61) = M(39, 61) / M(39, 39)

C     Upper part.
      M(40, 46) = M(40, 46) / M(40, 40)
C     Upper part.
      temp = M(40, 30) * M(30, 49)
      temp = temp + M(40, 31) * M(31, 49)
      temp = temp + M(40, 38) * M(38, 49)
      temp = temp + M(40, 39) * M(39, 49)
      M(40, 49) = ( M(40, 49) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 30) * M(30, 54)
      temp = temp + M(40, 31) * M(31, 54)
      temp = temp + M(40, 38) * M(38, 54)
      temp = temp + M(40, 39) * M(39, 54)
      M(40, 54) = ( M(40, 54) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 38) * M(38, 55)
      temp = temp + M(40, 39) * M(39, 55)
      M(40, 55) = ( M(40, 55) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 30) * M(30, 58)
      temp = temp + M(40, 31) * M(31, 58)
      temp = temp + M(40, 38) * M(38, 58)
      M(40, 58) = ( M(40, 58) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 30) * M(30, 59)
      temp = temp + M(40, 31) * M(31, 59)
      temp = temp + M(40, 38) * M(38, 59)
      temp = temp + M(40, 39) * M(39, 59)
      M(40, 59) = ( M(40, 59) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 30) * M(30, 60)
      temp = temp + M(40, 31) * M(31, 60)
      temp = temp + M(40, 38) * M(38, 60)
      temp = temp + M(40, 39) * M(39, 60)
      M(40, 60) = ( M(40, 60) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 38) * M(38, 61)
      temp = temp + M(40, 39) * M(39, 61)
      M(40, 61) = ( M(40, 61) - temp ) / M(40, 40)

C     Upper part.
      temp = M(41, 40) * M(40, 46)
      M(41, 46) = ( M(41, 46) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 30) * M(30, 49)
      temp = temp + M(41, 31) * M(31, 49)
      temp = temp + M(41, 34) * M(34, 49)
      temp = temp + M(41, 40) * M(40, 49)
      M(41, 49) = ( M(41, 49) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 6) * M(6, 54)
      temp = temp + M(41, 18) * M(18, 54)
      temp = temp + M(41, 29) * M(29, 54)
      temp = temp + M(41, 30) * M(30, 54)
      temp = temp + M(41, 31) * M(31, 54)
      temp = temp + M(41, 34) * M(34, 54)
      temp = temp + M(41, 40) * M(40, 54)
      M(41, 54) = ( M(41, 54) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 18) * M(18, 55)
      temp = temp + M(41, 29) * M(29, 55)
      temp = temp + M(41, 34) * M(34, 55)
      temp = temp + M(41, 40) * M(40, 55)
      M(41, 55) = ( M(41, 55) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 29) * M(29, 58)
      temp = temp + M(41, 30) * M(30, 58)
      temp = temp + M(41, 31) * M(31, 58)
      temp = temp + M(41, 34) * M(34, 58)
      temp = temp + M(41, 40) * M(40, 58)
      M(41, 58) = ( M(41, 58) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 29) * M(29, 59)
      temp = temp + M(41, 30) * M(30, 59)
      temp = temp + M(41, 31) * M(31, 59)
      temp = temp + M(41, 34) * M(34, 59)
      temp = temp + M(41, 40) * M(40, 59)
      M(41, 59) = ( M(41, 59) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 30) * M(30, 60)
      temp = temp + M(41, 31) * M(31, 60)
      temp = temp + M(41, 34) * M(34, 60)
      temp = temp + M(41, 40) * M(40, 60)
      M(41, 60) = ( M(41, 60) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 29) * M(29, 61)
      temp = temp + M(41, 34) * M(34, 61)
      temp = temp + M(41, 40) * M(40, 61)
      M(41, 61) = ( M(41, 61) - temp ) / M(41, 41)

C     Upper part.
      temp = M(42, 41) * M(41, 46)
      M(42, 46) = ( M(42, 46) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 41) * M(41, 49)
      M(42, 49) = ( M(42, 49) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 41) * M(41, 54)
      M(42, 54) = ( M(42, 54) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 41) * M(41, 55)
      M(42, 55) = ( M(42, 55) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 41) * M(41, 58)
      M(42, 58) = ( M(42, 58) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 41) * M(41, 59)
      M(42, 59) = ( M(42, 59) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 41) * M(41, 60)
      M(42, 60) = ( M(42, 60) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 41) * M(41, 61)
      M(42, 61) = ( M(42, 61) - temp ) / M(42, 42)

C     Upper part.
      temp = M(43, 41) * M(41, 46)
      M(43, 46) = ( M(43, 46) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 41) * M(41, 49)
      M(43, 49) = ( M(43, 49) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 3) * M(3, 54)
      temp = temp + M(43, 41) * M(41, 54)
      M(43, 54) = ( M(43, 54) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 41) * M(41, 55)
      M(43, 55) = ( M(43, 55) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 41) * M(41, 58)
      M(43, 58) = ( M(43, 58) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 41) * M(41, 59)
      M(43, 59) = ( M(43, 59) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 41) * M(41, 60)
      M(43, 60) = ( M(43, 60) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 41) * M(41, 61)
      M(43, 61) = ( M(43, 61) - temp ) / M(43, 43)

C     Upper part.
      temp = M(44, 42) * M(42, 46)
      temp = temp + M(44, 43) * M(43, 46)
      M(44, 46) = ( M(44, 46) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 30) * M(30, 49)
      temp = temp + M(44, 31) * M(31, 49)
      temp = temp + M(44, 32) * M(32, 49)
      temp = temp + M(44, 33) * M(33, 49)
      temp = temp + M(44, 34) * M(34, 49)
      temp = temp + M(44, 38) * M(38, 49)
      temp = temp + M(44, 42) * M(42, 49)
      temp = temp + M(44, 43) * M(43, 49)
      M(44, 49) = ( M(44, 49) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 17) * M(17, 54)
      temp = temp + M(44, 18) * M(18, 54)
      temp = temp + M(44, 23) * M(23, 54)
      temp = temp + M(44, 29) * M(29, 54)
      temp = temp + M(44, 30) * M(30, 54)
      temp = temp + M(44, 31) * M(31, 54)
      temp = temp + M(44, 32) * M(32, 54)
      temp = temp + M(44, 33) * M(33, 54)
      temp = temp + M(44, 34) * M(34, 54)
      temp = temp + M(44, 38) * M(38, 54)
      temp = temp + M(44, 42) * M(42, 54)
      temp = temp + M(44, 43) * M(43, 54)
      M(44, 54) = ( M(44, 54) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 17) * M(17, 55)
      temp = temp + M(44, 18) * M(18, 55)
      temp = temp + M(44, 23) * M(23, 55)
      temp = temp + M(44, 29) * M(29, 55)
      temp = temp + M(44, 32) * M(32, 55)
      temp = temp + M(44, 33) * M(33, 55)
      temp = temp + M(44, 34) * M(34, 55)
      temp = temp + M(44, 38) * M(38, 55)
      temp = temp + M(44, 42) * M(42, 55)
      temp = temp + M(44, 43) * M(43, 55)
      M(44, 55) = ( M(44, 55) - temp ) / M(44, 44)
C     Upper part.
      M(44, 57) = M(44, 57) / M(44, 44)
C     Upper part.
      temp = M(44, 29) * M(29, 58)
      temp = temp + M(44, 30) * M(30, 58)
      temp = temp + M(44, 31) * M(31, 58)
      temp = temp + M(44, 32) * M(32, 58)
      temp = temp + M(44, 33) * M(33, 58)
      temp = temp + M(44, 34) * M(34, 58)
      temp = temp + M(44, 38) * M(38, 58)
      temp = temp + M(44, 42) * M(42, 58)
      temp = temp + M(44, 43) * M(43, 58)
      M(44, 58) = ( M(44, 58) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 29) * M(29, 59)
      temp = temp + M(44, 30) * M(30, 59)
      temp = temp + M(44, 31) * M(31, 59)
      temp = temp + M(44, 32) * M(32, 59)
      temp = temp + M(44, 33) * M(33, 59)
      temp = temp + M(44, 34) * M(34, 59)
      temp = temp + M(44, 38) * M(38, 59)
      temp = temp + M(44, 42) * M(42, 59)
      temp = temp + M(44, 43) * M(43, 59)
      M(44, 59) = ( M(44, 59) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 30) * M(30, 60)
      temp = temp + M(44, 31) * M(31, 60)
      temp = temp + M(44, 32) * M(32, 60)
      temp = temp + M(44, 33) * M(33, 60)
      temp = temp + M(44, 34) * M(34, 60)
      temp = temp + M(44, 38) * M(38, 60)
      temp = temp + M(44, 42) * M(42, 60)
      temp = temp + M(44, 43) * M(43, 60)
      M(44, 60) = ( M(44, 60) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 29) * M(29, 61)
      temp = temp + M(44, 32) * M(32, 61)
      temp = temp + M(44, 33) * M(33, 61)
      temp = temp + M(44, 34) * M(34, 61)
      temp = temp + M(44, 38) * M(38, 61)
      temp = temp + M(44, 42) * M(42, 61)
      temp = temp + M(44, 43) * M(43, 61)
      M(44, 61) = ( M(44, 61) - temp ) / M(44, 44)

C     Upper part.
      temp = M(45, 42) * M(42, 46)
      temp = temp + M(45, 43) * M(43, 46)
      M(45, 46) = ( M(45, 46) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 30) * M(30, 49)
      temp = temp + M(45, 31) * M(31, 49)
      temp = temp + M(45, 32) * M(32, 49)
      temp = temp + M(45, 33) * M(33, 49)
      temp = temp + M(45, 34) * M(34, 49)
      temp = temp + M(45, 35) * M(35, 49)
      temp = temp + M(45, 36) * M(36, 49)
      temp = temp + M(45, 39) * M(39, 49)
      temp = temp + M(45, 42) * M(42, 49)
      temp = temp + M(45, 43) * M(43, 49)
      M(45, 49) = ( M(45, 49) - temp ) / M(45, 45)
C     Upper part.
      M(45, 51) = M(45, 51) / M(45, 45)
C     Upper part.
      temp = M(45, 30) * M(30, 54)
      temp = temp + M(45, 31) * M(31, 54)
      temp = temp + M(45, 32) * M(32, 54)
      temp = temp + M(45, 33) * M(33, 54)
      temp = temp + M(45, 34) * M(34, 54)
      temp = temp + M(45, 35) * M(35, 54)
      temp = temp + M(45, 36) * M(36, 54)
      temp = temp + M(45, 39) * M(39, 54)
      temp = temp + M(45, 42) * M(42, 54)
      temp = temp + M(45, 43) * M(43, 54)
      M(45, 54) = ( M(45, 54) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 32) * M(32, 55)
      temp = temp + M(45, 33) * M(33, 55)
      temp = temp + M(45, 34) * M(34, 55)
      temp = temp + M(45, 39) * M(39, 55)
      temp = temp + M(45, 42) * M(42, 55)
      temp = temp + M(45, 43) * M(43, 55)
      M(45, 55) = ( M(45, 55) - temp ) / M(45, 45)
C     Upper part.
      M(45, 57) = M(45, 57) / M(45, 45)
C     Upper part.
      temp = M(45, 30) * M(30, 58)
      temp = temp + M(45, 31) * M(31, 58)
      temp = temp + M(45, 32) * M(32, 58)
      temp = temp + M(45, 33) * M(33, 58)
      temp = temp + M(45, 34) * M(34, 58)
      temp = temp + M(45, 35) * M(35, 58)
      temp = temp + M(45, 36) * M(36, 58)
      temp = temp + M(45, 42) * M(42, 58)
      temp = temp + M(45, 43) * M(43, 58)
      M(45, 58) = ( M(45, 58) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 30) * M(30, 59)
      temp = temp + M(45, 31) * M(31, 59)
      temp = temp + M(45, 32) * M(32, 59)
      temp = temp + M(45, 33) * M(33, 59)
      temp = temp + M(45, 34) * M(34, 59)
      temp = temp + M(45, 35) * M(35, 59)
      temp = temp + M(45, 36) * M(36, 59)
      temp = temp + M(45, 39) * M(39, 59)
      temp = temp + M(45, 42) * M(42, 59)
      temp = temp + M(45, 43) * M(43, 59)
      M(45, 59) = ( M(45, 59) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 30) * M(30, 60)
      temp = temp + M(45, 31) * M(31, 60)
      temp = temp + M(45, 32) * M(32, 60)
      temp = temp + M(45, 33) * M(33, 60)
      temp = temp + M(45, 34) * M(34, 60)
      temp = temp + M(45, 35) * M(35, 60)
      temp = temp + M(45, 36) * M(36, 60)
      temp = temp + M(45, 39) * M(39, 60)
      temp = temp + M(45, 42) * M(42, 60)
      temp = temp + M(45, 43) * M(43, 60)
      M(45, 60) = ( M(45, 60) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 32) * M(32, 61)
      temp = temp + M(45, 33) * M(33, 61)
      temp = temp + M(45, 34) * M(34, 61)
      temp = temp + M(45, 39) * M(39, 61)
      temp = temp + M(45, 42) * M(42, 61)
      temp = temp + M(45, 43) * M(43, 61)
      M(45, 61) = ( M(45, 61) - temp ) / M(45, 45)

C     Lower part.
      temp = M(46, 40) * M(40, 46)
      temp = temp + M(46, 45) * M(45, 46)
      M(46, 46) = M(46, 46) - temp
C     Lower part.
      temp = M(47, 40) * M(40, 46)
      temp = temp + M(47, 43) * M(43, 46)
      temp = temp + M(47, 45) * M(45, 46)
      M(47, 46) = M(47, 46) - temp
C     Lower part.
      temp = M(49, 42) * M(42, 46)
      temp = temp + M(49, 43) * M(43, 46)
      M(49, 46) = M(49, 46) - temp
C     Lower part.
      temp = M(50, 42) * M(42, 46)
      M(50, 46) = M(50, 46) - temp
C     Lower part.
      temp = M(52, 42) * M(42, 46)
      temp = temp + M(52, 43) * M(43, 46)
      M(52, 46) = M(52, 46) - temp
C     Lower part.
      temp = M(54, 40) * M(40, 46)
      temp = temp + M(54, 41) * M(41, 46)
      temp = temp + M(54, 45) * M(45, 46)
      M(54, 46) = M(54, 46) - temp
C     Lower part.
      temp = M(58, 42) * M(42, 46)
      temp = temp + M(58, 43) * M(43, 46)
      M(58, 46) = M(58, 46) - temp
C     Lower part.
      temp = M(59, 40) * M(40, 46)
      temp = temp + M(59, 42) * M(42, 46)
      temp = temp + M(59, 43) * M(43, 46)
      temp = temp + M(59, 45) * M(45, 46)
      M(59, 46) = M(59, 46) - temp
C     Lower part.
      temp = M(60, 41) * M(41, 46)
      temp = temp + M(60, 42) * M(42, 46)
      temp = temp + M(60, 43) * M(43, 46)
      M(60, 46) = M(60, 46) - temp
C     Lower part.
      temp = M(61, 40) * M(40, 46)
      temp = temp + M(61, 42) * M(42, 46)
      temp = temp + M(61, 43) * M(43, 46)
      M(61, 46) = M(61, 46) - temp
C     Upper part.
      temp = M(46, 40) * M(40, 49)
      temp = temp + M(46, 45) * M(45, 49)
      M(46, 49) = ( M(46, 49) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 45) * M(45, 51)
      M(46, 51) = ( M(46, 51) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 6) * M(6, 54)
      temp = temp + M(46, 40) * M(40, 54)
      temp = temp + M(46, 45) * M(45, 54)
      M(46, 54) = ( M(46, 54) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 40) * M(40, 55)
      temp = temp + M(46, 45) * M(45, 55)
      M(46, 55) = ( M(46, 55) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 45) * M(45, 57)
      M(46, 57) = ( M(46, 57) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 40) * M(40, 58)
      temp = temp + M(46, 45) * M(45, 58)
      M(46, 58) = ( M(46, 58) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 40) * M(40, 59)
      temp = temp + M(46, 45) * M(45, 59)
      M(46, 59) = ( M(46, 59) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 40) * M(40, 60)
      temp = temp + M(46, 45) * M(45, 60)
      M(46, 60) = ( M(46, 60) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 40) * M(40, 61)
      temp = temp + M(46, 45) * M(45, 61)
      M(46, 61) = ( M(46, 61) - temp ) / M(46, 46)

C     Upper part.
      temp = M(47, 30) * M(30, 49)
      temp = temp + M(47, 31) * M(31, 49)
      temp = temp + M(47, 32) * M(32, 49)
      temp = temp + M(47, 33) * M(33, 49)
      temp = temp + M(47, 34) * M(34, 49)
      temp = temp + M(47, 38) * M(38, 49)
      temp = temp + M(47, 40) * M(40, 49)
      temp = temp + M(47, 43) * M(43, 49)
      temp = temp + M(47, 45) * M(45, 49)
      temp = temp + M(47, 46) * M(46, 49)
      M(47, 49) = ( M(47, 49) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 45) * M(45, 51)
      temp = temp + M(47, 46) * M(46, 51)
      M(47, 51) = ( M(47, 51) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 6) * M(6, 54)
      temp = temp + M(47, 17) * M(17, 54)
      temp = temp + M(47, 18) * M(18, 54)
      temp = temp + M(47, 23) * M(23, 54)
      temp = temp + M(47, 29) * M(29, 54)
      temp = temp + M(47, 30) * M(30, 54)
      temp = temp + M(47, 31) * M(31, 54)
      temp = temp + M(47, 32) * M(32, 54)
      temp = temp + M(47, 33) * M(33, 54)
      temp = temp + M(47, 34) * M(34, 54)
      temp = temp + M(47, 38) * M(38, 54)
      temp = temp + M(47, 40) * M(40, 54)
      temp = temp + M(47, 43) * M(43, 54)
      temp = temp + M(47, 45) * M(45, 54)
      temp = temp + M(47, 46) * M(46, 54)
      M(47, 54) = ( M(47, 54) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 17) * M(17, 55)
      temp = temp + M(47, 18) * M(18, 55)
      temp = temp + M(47, 23) * M(23, 55)
      temp = temp + M(47, 29) * M(29, 55)
      temp = temp + M(47, 32) * M(32, 55)
      temp = temp + M(47, 33) * M(33, 55)
      temp = temp + M(47, 34) * M(34, 55)
      temp = temp + M(47, 38) * M(38, 55)
      temp = temp + M(47, 40) * M(40, 55)
      temp = temp + M(47, 43) * M(43, 55)
      temp = temp + M(47, 45) * M(45, 55)
      temp = temp + M(47, 46) * M(46, 55)
      M(47, 55) = ( M(47, 55) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 45) * M(45, 57)
      temp = temp + M(47, 46) * M(46, 57)
      M(47, 57) = ( M(47, 57) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 29) * M(29, 58)
      temp = temp + M(47, 30) * M(30, 58)
      temp = temp + M(47, 31) * M(31, 58)
      temp = temp + M(47, 32) * M(32, 58)
      temp = temp + M(47, 33) * M(33, 58)
      temp = temp + M(47, 34) * M(34, 58)
      temp = temp + M(47, 38) * M(38, 58)
      temp = temp + M(47, 40) * M(40, 58)
      temp = temp + M(47, 43) * M(43, 58)
      temp = temp + M(47, 45) * M(45, 58)
      temp = temp + M(47, 46) * M(46, 58)
      M(47, 58) = ( M(47, 58) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 29) * M(29, 59)
      temp = temp + M(47, 30) * M(30, 59)
      temp = temp + M(47, 31) * M(31, 59)
      temp = temp + M(47, 32) * M(32, 59)
      temp = temp + M(47, 33) * M(33, 59)
      temp = temp + M(47, 34) * M(34, 59)
      temp = temp + M(47, 38) * M(38, 59)
      temp = temp + M(47, 40) * M(40, 59)
      temp = temp + M(47, 43) * M(43, 59)
      temp = temp + M(47, 45) * M(45, 59)
      temp = temp + M(47, 46) * M(46, 59)
      M(47, 59) = ( M(47, 59) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 30) * M(30, 60)
      temp = temp + M(47, 31) * M(31, 60)
      temp = temp + M(47, 32) * M(32, 60)
      temp = temp + M(47, 33) * M(33, 60)
      temp = temp + M(47, 34) * M(34, 60)
      temp = temp + M(47, 38) * M(38, 60)
      temp = temp + M(47, 40) * M(40, 60)
      temp = temp + M(47, 43) * M(43, 60)
      temp = temp + M(47, 45) * M(45, 60)
      temp = temp + M(47, 46) * M(46, 60)
      M(47, 60) = ( M(47, 60) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 29) * M(29, 61)
      temp = temp + M(47, 32) * M(32, 61)
      temp = temp + M(47, 33) * M(33, 61)
      temp = temp + M(47, 34) * M(34, 61)
      temp = temp + M(47, 38) * M(38, 61)
      temp = temp + M(47, 40) * M(40, 61)
      temp = temp + M(47, 43) * M(43, 61)
      temp = temp + M(47, 45) * M(45, 61)
      temp = temp + M(47, 46) * M(46, 61)
      M(47, 61) = ( M(47, 61) - temp ) / M(47, 47)

C     Upper part.
      temp = M(48, 35) * M(35, 49)
      M(48, 49) = ( M(48, 49) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 35) * M(35, 54)
      M(48, 54) = ( M(48, 54) - temp ) / M(48, 48)
C     Upper part.
      M(48, 55) = M(48, 55) / M(48, 48)
C     Upper part.
      M(48, 57) = M(48, 57) / M(48, 48)
C     Upper part.
      temp = M(48, 35) * M(35, 58)
      M(48, 58) = ( M(48, 58) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 35) * M(35, 59)
      M(48, 59) = ( M(48, 59) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 35) * M(35, 60)
      M(48, 60) = ( M(48, 60) - temp ) / M(48, 48)

C     Lower part.
      temp = M(49, 24) * M(24, 49)
      temp = temp + M(49, 30) * M(30, 49)
      temp = temp + M(49, 31) * M(31, 49)
      temp = temp + M(49, 32) * M(32, 49)
      temp = temp + M(49, 33) * M(33, 49)
      temp = temp + M(49, 34) * M(34, 49)
      temp = temp + M(49, 35) * M(35, 49)
      temp = temp + M(49, 36) * M(36, 49)
      temp = temp + M(49, 38) * M(38, 49)
      temp = temp + M(49, 39) * M(39, 49)
      temp = temp + M(49, 42) * M(42, 49)
      temp = temp + M(49, 43) * M(43, 49)
      temp = temp + M(49, 46) * M(46, 49)
      temp = temp + M(49, 47) * M(47, 49)
      M(49, 49) = M(49, 49) - temp
C     Lower part.
      temp = M(50, 35) * M(35, 49)
      temp = temp + M(50, 36) * M(36, 49)
      temp = temp + M(50, 42) * M(42, 49)
      temp = temp + M(50, 46) * M(46, 49)
      M(50, 49) = M(50, 49) - temp
C     Lower part.
      temp = M(52, 24) * M(24, 49)
      temp = temp + M(52, 30) * M(30, 49)
      temp = temp + M(52, 31) * M(31, 49)
      temp = temp + M(52, 32) * M(32, 49)
      temp = temp + M(52, 33) * M(33, 49)
      temp = temp + M(52, 34) * M(34, 49)
      temp = temp + M(52, 35) * M(35, 49)
      temp = temp + M(52, 36) * M(36, 49)
      temp = temp + M(52, 38) * M(38, 49)
      temp = temp + M(52, 39) * M(39, 49)
      temp = temp + M(52, 42) * M(42, 49)
      temp = temp + M(52, 43) * M(43, 49)
      temp = temp + M(52, 46) * M(46, 49)
      temp = temp + M(52, 48) * M(48, 49)
      M(52, 49) = M(52, 49) - temp
C     Lower part.
      temp = M(53, 37) * M(37, 49)
      temp = temp + M(53, 47) * M(47, 49)
      temp = temp + M(53, 48) * M(48, 49)
      M(53, 49) = M(53, 49) - temp
C     Lower part.
      temp = M(54, 24) * M(24, 49)
      temp = temp + M(54, 37) * M(37, 49)
      temp = temp + M(54, 40) * M(40, 49)
      temp = temp + M(54, 41) * M(41, 49)
      temp = temp + M(54, 45) * M(45, 49)
      temp = temp + M(54, 46) * M(46, 49)
      temp = temp + M(54, 47) * M(47, 49)
      temp = temp + M(54, 48) * M(48, 49)
      M(54, 49) = M(54, 49) - temp
C     Lower part.
      temp = M(55, 37) * M(37, 49)
      temp = temp + M(55, 47) * M(47, 49)
      temp = temp + M(55, 48) * M(48, 49)
      M(55, 49) = M(55, 49) - temp
C     Lower part.
      temp = M(56, 47) * M(47, 49)
      temp = temp + M(56, 48) * M(48, 49)
      M(56, 49) = M(56, 49) - temp
C     Lower part.
      temp = M(57, 37) * M(37, 49)
      M(57, 49) = M(57, 49) - temp
C     Lower part.
      temp = M(58, 30) * M(30, 49)
      temp = temp + M(58, 31) * M(31, 49)
      temp = temp + M(58, 32) * M(32, 49)
      temp = temp + M(58, 33) * M(33, 49)
      temp = temp + M(58, 34) * M(34, 49)
      temp = temp + M(58, 35) * M(35, 49)
      temp = temp + M(58, 36) * M(36, 49)
      temp = temp + M(58, 38) * M(38, 49)
      temp = temp + M(58, 42) * M(42, 49)
      temp = temp + M(58, 43) * M(43, 49)
      temp = temp + M(58, 46) * M(46, 49)
      M(58, 49) = M(58, 49) - temp
C     Lower part.
      temp = M(59, 24) * M(24, 49)
      temp = temp + M(59, 30) * M(30, 49)
      temp = temp + M(59, 31) * M(31, 49)
      temp = temp + M(59, 32) * M(32, 49)
      temp = temp + M(59, 33) * M(33, 49)
      temp = temp + M(59, 34) * M(34, 49)
      temp = temp + M(59, 35) * M(35, 49)
      temp = temp + M(59, 36) * M(36, 49)
      temp = temp + M(59, 37) * M(37, 49)
      temp = temp + M(59, 38) * M(38, 49)
      temp = temp + M(59, 39) * M(39, 49)
      temp = temp + M(59, 40) * M(40, 49)
      temp = temp + M(59, 42) * M(42, 49)
      temp = temp + M(59, 43) * M(43, 49)
      temp = temp + M(59, 45) * M(45, 49)
      temp = temp + M(59, 46) * M(46, 49)
      temp = temp + M(59, 47) * M(47, 49)
      temp = temp + M(59, 48) * M(48, 49)
      M(59, 49) = M(59, 49) - temp
C     Lower part.
      temp = M(60, 30) * M(30, 49)
      temp = temp + M(60, 31) * M(31, 49)
      temp = temp + M(60, 32) * M(32, 49)
      temp = temp + M(60, 33) * M(33, 49)
      temp = temp + M(60, 34) * M(34, 49)
      temp = temp + M(60, 35) * M(35, 49)
      temp = temp + M(60, 36) * M(36, 49)
      temp = temp + M(60, 37) * M(37, 49)
      temp = temp + M(60, 38) * M(38, 49)
      temp = temp + M(60, 39) * M(39, 49)
      temp = temp + M(60, 41) * M(41, 49)
      temp = temp + M(60, 42) * M(42, 49)
      temp = temp + M(60, 43) * M(43, 49)
      temp = temp + M(60, 46) * M(46, 49)
      temp = temp + M(60, 47) * M(47, 49)
      M(60, 49) = M(60, 49) - temp
C     Lower part.
      temp = M(61, 30) * M(30, 49)
      temp = temp + M(61, 31) * M(31, 49)
      temp = temp + M(61, 32) * M(32, 49)
      temp = temp + M(61, 33) * M(33, 49)
      temp = temp + M(61, 34) * M(34, 49)
      temp = temp + M(61, 35) * M(35, 49)
      temp = temp + M(61, 36) * M(36, 49)
      temp = temp + M(61, 38) * M(38, 49)
      temp = temp + M(61, 39) * M(39, 49)
      temp = temp + M(61, 40) * M(40, 49)
      temp = temp + M(61, 42) * M(42, 49)
      temp = temp + M(61, 43) * M(43, 49)
      temp = temp + M(61, 46) * M(46, 49)
      M(61, 49) = M(61, 49) - temp
C     Upper part.
      temp = M(49, 46) * M(46, 51)
      temp = temp + M(49, 47) * M(47, 51)
      M(49, 51) = ( M(49, 51) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 17) * M(17, 54)
      temp = temp + M(49, 18) * M(18, 54)
      temp = temp + M(49, 19) * M(19, 54)
      temp = temp + M(49, 23) * M(23, 54)
      temp = temp + M(49, 24) * M(24, 54)
      temp = temp + M(49, 25) * M(25, 54)
      temp = temp + M(49, 29) * M(29, 54)
      temp = temp + M(49, 30) * M(30, 54)
      temp = temp + M(49, 31) * M(31, 54)
      temp = temp + M(49, 32) * M(32, 54)
      temp = temp + M(49, 33) * M(33, 54)
      temp = temp + M(49, 34) * M(34, 54)
      temp = temp + M(49, 35) * M(35, 54)
      temp = temp + M(49, 36) * M(36, 54)
      temp = temp + M(49, 38) * M(38, 54)
      temp = temp + M(49, 39) * M(39, 54)
      temp = temp + M(49, 42) * M(42, 54)
      temp = temp + M(49, 43) * M(43, 54)
      temp = temp + M(49, 46) * M(46, 54)
      temp = temp + M(49, 47) * M(47, 54)
      M(49, 54) = ( M(49, 54) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 17) * M(17, 55)
      temp = temp + M(49, 18) * M(18, 55)
      temp = temp + M(49, 19) * M(19, 55)
      temp = temp + M(49, 23) * M(23, 55)
      temp = temp + M(49, 29) * M(29, 55)
      temp = temp + M(49, 32) * M(32, 55)
      temp = temp + M(49, 33) * M(33, 55)
      temp = temp + M(49, 34) * M(34, 55)
      temp = temp + M(49, 38) * M(38, 55)
      temp = temp + M(49, 39) * M(39, 55)
      temp = temp + M(49, 42) * M(42, 55)
      temp = temp + M(49, 43) * M(43, 55)
      temp = temp + M(49, 46) * M(46, 55)
      temp = temp + M(49, 47) * M(47, 55)
      M(49, 55) = ( M(49, 55) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 46) * M(46, 57)
      temp = temp + M(49, 47) * M(47, 57)
      M(49, 57) = ( M(49, 57) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 29) * M(29, 58)
      temp = temp + M(49, 30) * M(30, 58)
      temp = temp + M(49, 31) * M(31, 58)
      temp = temp + M(49, 32) * M(32, 58)
      temp = temp + M(49, 33) * M(33, 58)
      temp = temp + M(49, 34) * M(34, 58)
      temp = temp + M(49, 35) * M(35, 58)
      temp = temp + M(49, 36) * M(36, 58)
      temp = temp + M(49, 38) * M(38, 58)
      temp = temp + M(49, 42) * M(42, 58)
      temp = temp + M(49, 43) * M(43, 58)
      temp = temp + M(49, 46) * M(46, 58)
      temp = temp + M(49, 47) * M(47, 58)
      M(49, 58) = ( M(49, 58) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 24) * M(24, 59)
      temp = temp + M(49, 25) * M(25, 59)
      temp = temp + M(49, 29) * M(29, 59)
      temp = temp + M(49, 30) * M(30, 59)
      temp = temp + M(49, 31) * M(31, 59)
      temp = temp + M(49, 32) * M(32, 59)
      temp = temp + M(49, 33) * M(33, 59)
      temp = temp + M(49, 34) * M(34, 59)
      temp = temp + M(49, 35) * M(35, 59)
      temp = temp + M(49, 36) * M(36, 59)
      temp = temp + M(49, 38) * M(38, 59)
      temp = temp + M(49, 39) * M(39, 59)
      temp = temp + M(49, 42) * M(42, 59)
      temp = temp + M(49, 43) * M(43, 59)
      temp = temp + M(49, 46) * M(46, 59)
      temp = temp + M(49, 47) * M(47, 59)
      M(49, 59) = ( M(49, 59) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 25) * M(25, 60)
      temp = temp + M(49, 30) * M(30, 60)
      temp = temp + M(49, 31) * M(31, 60)
      temp = temp + M(49, 32) * M(32, 60)
      temp = temp + M(49, 33) * M(33, 60)
      temp = temp + M(49, 34) * M(34, 60)
      temp = temp + M(49, 35) * M(35, 60)
      temp = temp + M(49, 36) * M(36, 60)
      temp = temp + M(49, 38) * M(38, 60)
      temp = temp + M(49, 39) * M(39, 60)
      temp = temp + M(49, 42) * M(42, 60)
      temp = temp + M(49, 43) * M(43, 60)
      temp = temp + M(49, 46) * M(46, 60)
      temp = temp + M(49, 47) * M(47, 60)
      M(49, 60) = ( M(49, 60) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 29) * M(29, 61)
      temp = temp + M(49, 32) * M(32, 61)
      temp = temp + M(49, 33) * M(33, 61)
      temp = temp + M(49, 34) * M(34, 61)
      temp = temp + M(49, 38) * M(38, 61)
      temp = temp + M(49, 39) * M(39, 61)
      temp = temp + M(49, 42) * M(42, 61)
      temp = temp + M(49, 43) * M(43, 61)
      temp = temp + M(49, 46) * M(46, 61)
      temp = temp + M(49, 47) * M(47, 61)
      M(49, 61) = ( M(49, 61) - temp ) / M(49, 49)

C     Upper part.
      temp = M(50, 46) * M(46, 51)
      temp = temp + M(50, 49) * M(49, 51)
      M(50, 51) = ( M(50, 51) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 35) * M(35, 54)
      temp = temp + M(50, 36) * M(36, 54)
      temp = temp + M(50, 42) * M(42, 54)
      temp = temp + M(50, 46) * M(46, 54)
      temp = temp + M(50, 49) * M(49, 54)
      M(50, 54) = ( M(50, 54) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 42) * M(42, 55)
      temp = temp + M(50, 46) * M(46, 55)
      temp = temp + M(50, 49) * M(49, 55)
      M(50, 55) = ( M(50, 55) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 46) * M(46, 57)
      temp = temp + M(50, 49) * M(49, 57)
      M(50, 57) = ( M(50, 57) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 35) * M(35, 58)
      temp = temp + M(50, 36) * M(36, 58)
      temp = temp + M(50, 42) * M(42, 58)
      temp = temp + M(50, 46) * M(46, 58)
      temp = temp + M(50, 49) * M(49, 58)
      M(50, 58) = ( M(50, 58) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 35) * M(35, 59)
      temp = temp + M(50, 36) * M(36, 59)
      temp = temp + M(50, 42) * M(42, 59)
      temp = temp + M(50, 46) * M(46, 59)
      temp = temp + M(50, 49) * M(49, 59)
      M(50, 59) = ( M(50, 59) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 35) * M(35, 60)
      temp = temp + M(50, 36) * M(36, 60)
      temp = temp + M(50, 42) * M(42, 60)
      temp = temp + M(50, 46) * M(46, 60)
      temp = temp + M(50, 49) * M(49, 60)
      M(50, 60) = ( M(50, 60) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 42) * M(42, 61)
      temp = temp + M(50, 46) * M(46, 61)
      temp = temp + M(50, 49) * M(49, 61)
      M(50, 61) = ( M(50, 61) - temp ) / M(50, 50)

C     Lower part.
      temp = M(51, 49) * M(49, 51)
      M(51, 51) = M(51, 51) - temp
C     Lower part.
      temp = M(52, 46) * M(46, 51)
      temp = temp + M(52, 49) * M(49, 51)
      M(52, 51) = M(52, 51) - temp
C     Lower part.
      temp = M(53, 47) * M(47, 51)
      temp = temp + M(53, 49) * M(49, 51)
      temp = temp + M(53, 50) * M(50, 51)
      M(53, 51) = M(53, 51) - temp
C     Lower part.
      temp = M(54, 45) * M(45, 51)
      temp = temp + M(54, 46) * M(46, 51)
      temp = temp + M(54, 47) * M(47, 51)
      temp = temp + M(54, 49) * M(49, 51)
      temp = temp + M(54, 50) * M(50, 51)
      M(54, 51) = M(54, 51) - temp
C     Lower part.
      temp = M(55, 47) * M(47, 51)
      temp = temp + M(55, 49) * M(49, 51)
      temp = temp + M(55, 50) * M(50, 51)
      M(55, 51) = M(55, 51) - temp
C     Lower part.
      temp = M(56, 47) * M(47, 51)
      temp = temp + M(56, 49) * M(49, 51)
      temp = temp + M(56, 50) * M(50, 51)
      M(56, 51) = M(56, 51) - temp
C     Lower part.
      temp = M(57, 49) * M(49, 51)
      M(57, 51) = M(57, 51) - temp
C     Lower part.
      temp = M(58, 46) * M(46, 51)
      temp = temp + M(58, 49) * M(49, 51)
      M(58, 51) = M(58, 51) - temp
C     Lower part.
      temp = M(59, 45) * M(45, 51)
      temp = temp + M(59, 46) * M(46, 51)
      temp = temp + M(59, 47) * M(47, 51)
      temp = temp + M(59, 49) * M(49, 51)
      temp = temp + M(59, 50) * M(50, 51)
      M(59, 51) = M(59, 51) - temp
C     Lower part.
      temp = M(60, 46) * M(46, 51)
      temp = temp + M(60, 47) * M(47, 51)
      temp = temp + M(60, 49) * M(49, 51)
      temp = temp + M(60, 50) * M(50, 51)
      M(60, 51) = M(60, 51) - temp
C     Lower part.
      temp = M(61, 46) * M(46, 51)
      temp = temp + M(61, 49) * M(49, 51)
      M(61, 51) = M(61, 51) - temp
C     Upper part.
      temp = M(51, 7) * M(7, 54)
      temp = temp + M(51, 8) * M(8, 54)
      temp = temp + M(51, 15) * M(15, 54)
      temp = temp + M(51, 27) * M(27, 54)
      temp = temp + M(51, 49) * M(49, 54)
      M(51, 54) = ( M(51, 54) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 15) * M(15, 55)
      temp = temp + M(51, 49) * M(49, 55)
      M(51, 55) = ( M(51, 55) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 49) * M(49, 57)
      M(51, 57) = ( M(51, 57) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 49) * M(49, 58)
      M(51, 58) = ( M(51, 58) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 49) * M(49, 59)
      M(51, 59) = ( M(51, 59) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 27) * M(27, 60)
      temp = temp + M(51, 49) * M(49, 60)
      M(51, 60) = ( M(51, 60) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 27) * M(27, 61)
      temp = temp + M(51, 49) * M(49, 61)
      M(51, 61) = ( M(51, 61) - temp ) / M(51, 51)

C     Upper part.
      temp = M(52, 6) * M(6, 54)
      temp = temp + M(52, 17) * M(17, 54)
      temp = temp + M(52, 18) * M(18, 54)
      temp = temp + M(52, 21) * M(21, 54)
      temp = temp + M(52, 23) * M(23, 54)
      temp = temp + M(52, 24) * M(24, 54)
      temp = temp + M(52, 27) * M(27, 54)
      temp = temp + M(52, 29) * M(29, 54)
      temp = temp + M(52, 30) * M(30, 54)
      temp = temp + M(52, 31) * M(31, 54)
      temp = temp + M(52, 32) * M(32, 54)
      temp = temp + M(52, 33) * M(33, 54)
      temp = temp + M(52, 34) * M(34, 54)
      temp = temp + M(52, 35) * M(35, 54)
      temp = temp + M(52, 36) * M(36, 54)
      temp = temp + M(52, 38) * M(38, 54)
      temp = temp + M(52, 39) * M(39, 54)
      temp = temp + M(52, 42) * M(42, 54)
      temp = temp + M(52, 43) * M(43, 54)
      temp = temp + M(52, 46) * M(46, 54)
      temp = temp + M(52, 48) * M(48, 54)
      temp = temp + M(52, 49) * M(49, 54)
      temp = temp + M(52, 51) * M(51, 54)
      M(52, 54) = ( M(52, 54) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 17) * M(17, 55)
      temp = temp + M(52, 18) * M(18, 55)
      temp = temp + M(52, 21) * M(21, 55)
      temp = temp + M(52, 23) * M(23, 55)
      temp = temp + M(52, 29) * M(29, 55)
      temp = temp + M(52, 32) * M(32, 55)
      temp = temp + M(52, 33) * M(33, 55)
      temp = temp + M(52, 34) * M(34, 55)
      temp = temp + M(52, 38) * M(38, 55)
      temp = temp + M(52, 39) * M(39, 55)
      temp = temp + M(52, 42) * M(42, 55)
      temp = temp + M(52, 43) * M(43, 55)
      temp = temp + M(52, 46) * M(46, 55)
      temp = temp + M(52, 48) * M(48, 55)
      temp = temp + M(52, 49) * M(49, 55)
      temp = temp + M(52, 51) * M(51, 55)
      M(52, 55) = ( M(52, 55) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 46) * M(46, 57)
      temp = temp + M(52, 48) * M(48, 57)
      temp = temp + M(52, 49) * M(49, 57)
      temp = temp + M(52, 51) * M(51, 57)
      M(52, 57) = ( M(52, 57) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 29) * M(29, 58)
      temp = temp + M(52, 30) * M(30, 58)
      temp = temp + M(52, 31) * M(31, 58)
      temp = temp + M(52, 32) * M(32, 58)
      temp = temp + M(52, 33) * M(33, 58)
      temp = temp + M(52, 34) * M(34, 58)
      temp = temp + M(52, 35) * M(35, 58)
      temp = temp + M(52, 36) * M(36, 58)
      temp = temp + M(52, 38) * M(38, 58)
      temp = temp + M(52, 42) * M(42, 58)
      temp = temp + M(52, 43) * M(43, 58)
      temp = temp + M(52, 46) * M(46, 58)
      temp = temp + M(52, 48) * M(48, 58)
      temp = temp + M(52, 49) * M(49, 58)
      temp = temp + M(52, 51) * M(51, 58)
      M(52, 58) = ( M(52, 58) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 24) * M(24, 59)
      temp = temp + M(52, 29) * M(29, 59)
      temp = temp + M(52, 30) * M(30, 59)
      temp = temp + M(52, 31) * M(31, 59)
      temp = temp + M(52, 32) * M(32, 59)
      temp = temp + M(52, 33) * M(33, 59)
      temp = temp + M(52, 34) * M(34, 59)
      temp = temp + M(52, 35) * M(35, 59)
      temp = temp + M(52, 36) * M(36, 59)
      temp = temp + M(52, 38) * M(38, 59)
      temp = temp + M(52, 39) * M(39, 59)
      temp = temp + M(52, 42) * M(42, 59)
      temp = temp + M(52, 43) * M(43, 59)
      temp = temp + M(52, 46) * M(46, 59)
      temp = temp + M(52, 48) * M(48, 59)
      temp = temp + M(52, 49) * M(49, 59)
      temp = temp + M(52, 51) * M(51, 59)
      M(52, 59) = ( M(52, 59) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 27) * M(27, 60)
      temp = temp + M(52, 30) * M(30, 60)
      temp = temp + M(52, 31) * M(31, 60)
      temp = temp + M(52, 32) * M(32, 60)
      temp = temp + M(52, 33) * M(33, 60)
      temp = temp + M(52, 34) * M(34, 60)
      temp = temp + M(52, 35) * M(35, 60)
      temp = temp + M(52, 36) * M(36, 60)
      temp = temp + M(52, 38) * M(38, 60)
      temp = temp + M(52, 39) * M(39, 60)
      temp = temp + M(52, 42) * M(42, 60)
      temp = temp + M(52, 43) * M(43, 60)
      temp = temp + M(52, 46) * M(46, 60)
      temp = temp + M(52, 48) * M(48, 60)
      temp = temp + M(52, 49) * M(49, 60)
      temp = temp + M(52, 51) * M(51, 60)
      M(52, 60) = ( M(52, 60) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 27) * M(27, 61)
      temp = temp + M(52, 29) * M(29, 61)
      temp = temp + M(52, 32) * M(32, 61)
      temp = temp + M(52, 33) * M(33, 61)
      temp = temp + M(52, 34) * M(34, 61)
      temp = temp + M(52, 38) * M(38, 61)
      temp = temp + M(52, 39) * M(39, 61)
      temp = temp + M(52, 42) * M(42, 61)
      temp = temp + M(52, 43) * M(43, 61)
      temp = temp + M(52, 46) * M(46, 61)
      temp = temp + M(52, 49) * M(49, 61)
      temp = temp + M(52, 51) * M(51, 61)
      M(52, 61) = ( M(52, 61) - temp ) / M(52, 52)

C     Upper part.
      temp = M(53, 15) * M(15, 54)
      temp = temp + M(53, 37) * M(37, 54)
      temp = temp + M(53, 47) * M(47, 54)
      temp = temp + M(53, 48) * M(48, 54)
      temp = temp + M(53, 49) * M(49, 54)
      temp = temp + M(53, 50) * M(50, 54)
      temp = temp + M(53, 51) * M(51, 54)
      temp = temp + M(53, 52) * M(52, 54)
      M(53, 54) = ( M(53, 54) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 15) * M(15, 55)
      temp = temp + M(53, 16) * M(16, 55)
      temp = temp + M(53, 37) * M(37, 55)
      temp = temp + M(53, 47) * M(47, 55)
      temp = temp + M(53, 48) * M(48, 55)
      temp = temp + M(53, 49) * M(49, 55)
      temp = temp + M(53, 50) * M(50, 55)
      temp = temp + M(53, 51) * M(51, 55)
      temp = temp + M(53, 52) * M(52, 55)
      M(53, 55) = ( M(53, 55) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 47) * M(47, 57)
      temp = temp + M(53, 48) * M(48, 57)
      temp = temp + M(53, 49) * M(49, 57)
      temp = temp + M(53, 50) * M(50, 57)
      temp = temp + M(53, 51) * M(51, 57)
      temp = temp + M(53, 52) * M(52, 57)
      M(53, 57) = ( M(53, 57) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 37) * M(37, 58)
      temp = temp + M(53, 47) * M(47, 58)
      temp = temp + M(53, 48) * M(48, 58)
      temp = temp + M(53, 49) * M(49, 58)
      temp = temp + M(53, 50) * M(50, 58)
      temp = temp + M(53, 51) * M(51, 58)
      temp = temp + M(53, 52) * M(52, 58)
      M(53, 58) = ( M(53, 58) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 37) * M(37, 59)
      temp = temp + M(53, 47) * M(47, 59)
      temp = temp + M(53, 48) * M(48, 59)
      temp = temp + M(53, 49) * M(49, 59)
      temp = temp + M(53, 50) * M(50, 59)
      temp = temp + M(53, 51) * M(51, 59)
      temp = temp + M(53, 52) * M(52, 59)
      M(53, 59) = ( M(53, 59) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 37) * M(37, 60)
      temp = temp + M(53, 47) * M(47, 60)
      temp = temp + M(53, 48) * M(48, 60)
      temp = temp + M(53, 49) * M(49, 60)
      temp = temp + M(53, 50) * M(50, 60)
      temp = temp + M(53, 51) * M(51, 60)
      temp = temp + M(53, 52) * M(52, 60)
      M(53, 60) = ( M(53, 60) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 16) * M(16, 61)
      temp = temp + M(53, 47) * M(47, 61)
      temp = temp + M(53, 49) * M(49, 61)
      temp = temp + M(53, 50) * M(50, 61)
      temp = temp + M(53, 51) * M(51, 61)
      temp = temp + M(53, 52) * M(52, 61)
      M(53, 61) = ( M(53, 61) - temp ) / M(53, 53)

C     Lower part.
      temp = M(54, 3) * M(3, 54)
      temp = temp + M(54, 4) * M(4, 54)
      temp = temp + M(54, 5) * M(5, 54)
      temp = temp + M(54, 6) * M(6, 54)
      temp = temp + M(54, 7) * M(7, 54)
      temp = temp + M(54, 8) * M(8, 54)
      temp = temp + M(54, 9) * M(9, 54)
      temp = temp + M(54, 12) * M(12, 54)
      temp = temp + M(54, 14) * M(14, 54)
      temp = temp + M(54, 15) * M(15, 54)
      temp = temp + M(54, 17) * M(17, 54)
      temp = temp + M(54, 18) * M(18, 54)
      temp = temp + M(54, 19) * M(19, 54)
      temp = temp + M(54, 20) * M(20, 54)
      temp = temp + M(54, 21) * M(21, 54)
      temp = temp + M(54, 23) * M(23, 54)
      temp = temp + M(54, 24) * M(24, 54)
      temp = temp + M(54, 25) * M(25, 54)
      temp = temp + M(54, 27) * M(27, 54)
      temp = temp + M(54, 29) * M(29, 54)
      temp = temp + M(54, 37) * M(37, 54)
      temp = temp + M(54, 40) * M(40, 54)
      temp = temp + M(54, 41) * M(41, 54)
      temp = temp + M(54, 45) * M(45, 54)
      temp = temp + M(54, 46) * M(46, 54)
      temp = temp + M(54, 47) * M(47, 54)
      temp = temp + M(54, 48) * M(48, 54)
      temp = temp + M(54, 49) * M(49, 54)
      temp = temp + M(54, 50) * M(50, 54)
      temp = temp + M(54, 51) * M(51, 54)
      temp = temp + M(54, 52) * M(52, 54)
      temp = temp + M(54, 53) * M(53, 54)
      M(54, 54) = M(54, 54) - temp
C     Lower part.
      temp = M(55, 15) * M(15, 54)
      temp = temp + M(55, 17) * M(17, 54)
      temp = temp + M(55, 18) * M(18, 54)
      temp = temp + M(55, 21) * M(21, 54)
      temp = temp + M(55, 23) * M(23, 54)
      temp = temp + M(55, 27) * M(27, 54)
      temp = temp + M(55, 29) * M(29, 54)
      temp = temp + M(55, 37) * M(37, 54)
      temp = temp + M(55, 47) * M(47, 54)
      temp = temp + M(55, 48) * M(48, 54)
      temp = temp + M(55, 49) * M(49, 54)
      temp = temp + M(55, 50) * M(50, 54)
      temp = temp + M(55, 51) * M(51, 54)
      temp = temp + M(55, 52) * M(52, 54)
      temp = temp + M(55, 53) * M(53, 54)
      M(55, 54) = M(55, 54) - temp
C     Lower part.
      temp = M(56, 17) * M(17, 54)
      temp = temp + M(56, 18) * M(18, 54)
      temp = temp + M(56, 21) * M(21, 54)
      temp = temp + M(56, 23) * M(23, 54)
      temp = temp + M(56, 29) * M(29, 54)
      temp = temp + M(56, 47) * M(47, 54)
      temp = temp + M(56, 48) * M(48, 54)
      temp = temp + M(56, 49) * M(49, 54)
      temp = temp + M(56, 50) * M(50, 54)
      temp = temp + M(56, 51) * M(51, 54)
      temp = temp + M(56, 52) * M(52, 54)
      M(56, 54) = M(56, 54) - temp
C     Lower part.
      temp = M(57, 15) * M(15, 54)
      temp = temp + M(57, 37) * M(37, 54)
      temp = temp + M(57, 49) * M(49, 54)
      temp = temp + M(57, 51) * M(51, 54)
      M(57, 54) = M(57, 54) - temp
C     Lower part.
      temp = M(58, 14) * M(14, 54)
      temp = temp + M(58, 29) * M(29, 54)
      temp = temp + M(58, 30) * M(30, 54)
      temp = temp + M(58, 31) * M(31, 54)
      temp = temp + M(58, 32) * M(32, 54)
      temp = temp + M(58, 33) * M(33, 54)
      temp = temp + M(58, 34) * M(34, 54)
      temp = temp + M(58, 35) * M(35, 54)
      temp = temp + M(58, 36) * M(36, 54)
      temp = temp + M(58, 38) * M(38, 54)
      temp = temp + M(58, 42) * M(42, 54)
      temp = temp + M(58, 43) * M(43, 54)
      temp = temp + M(58, 46) * M(46, 54)
      temp = temp + M(58, 49) * M(49, 54)
      temp = temp + M(58, 51) * M(51, 54)
      M(58, 54) = M(58, 54) - temp
C     Lower part.
      temp = M(59, 4) * M(4, 54)
      temp = temp + M(59, 5) * M(5, 54)
      temp = temp + M(59, 6) * M(6, 54)
      temp = temp + M(59, 9) * M(9, 54)
      temp = temp + M(59, 12) * M(12, 54)
      temp = temp + M(59, 15) * M(15, 54)
      temp = temp + M(59, 17) * M(17, 54)
      temp = temp + M(59, 18) * M(18, 54)
      temp = temp + M(59, 20) * M(20, 54)
      temp = temp + M(59, 21) * M(21, 54)
      temp = temp + M(59, 23) * M(23, 54)
      temp = temp + M(59, 24) * M(24, 54)
      temp = temp + M(59, 29) * M(29, 54)
      temp = temp + M(59, 30) * M(30, 54)
      temp = temp + M(59, 31) * M(31, 54)
      temp = temp + M(59, 32) * M(32, 54)
      temp = temp + M(59, 33) * M(33, 54)
      temp = temp + M(59, 34) * M(34, 54)
      temp = temp + M(59, 35) * M(35, 54)
      temp = temp + M(59, 36) * M(36, 54)
      temp = temp + M(59, 37) * M(37, 54)
      temp = temp + M(59, 38) * M(38, 54)
      temp = temp + M(59, 39) * M(39, 54)
      temp = temp + M(59, 40) * M(40, 54)
      temp = temp + M(59, 42) * M(42, 54)
      temp = temp + M(59, 43) * M(43, 54)
      temp = temp + M(59, 45) * M(45, 54)
      temp = temp + M(59, 46) * M(46, 54)
      temp = temp + M(59, 47) * M(47, 54)
      temp = temp + M(59, 48) * M(48, 54)
      temp = temp + M(59, 49) * M(49, 54)
      temp = temp + M(59, 50) * M(50, 54)
      temp = temp + M(59, 51) * M(51, 54)
      temp = temp + M(59, 52) * M(52, 54)
      M(59, 54) = M(59, 54) - temp
C     Lower part.
      temp = M(60, 25) * M(25, 54)
      temp = temp + M(60, 27) * M(27, 54)
      temp = temp + M(60, 30) * M(30, 54)
      temp = temp + M(60, 31) * M(31, 54)
      temp = temp + M(60, 32) * M(32, 54)
      temp = temp + M(60, 33) * M(33, 54)
      temp = temp + M(60, 34) * M(34, 54)
      temp = temp + M(60, 35) * M(35, 54)
      temp = temp + M(60, 36) * M(36, 54)
      temp = temp + M(60, 37) * M(37, 54)
      temp = temp + M(60, 38) * M(38, 54)
      temp = temp + M(60, 39) * M(39, 54)
      temp = temp + M(60, 41) * M(41, 54)
      temp = temp + M(60, 42) * M(42, 54)
      temp = temp + M(60, 43) * M(43, 54)
      temp = temp + M(60, 46) * M(46, 54)
      temp = temp + M(60, 47) * M(47, 54)
      temp = temp + M(60, 49) * M(49, 54)
      temp = temp + M(60, 50) * M(50, 54)
      temp = temp + M(60, 51) * M(51, 54)
      M(60, 54) = M(60, 54) - temp
C     Lower part.
      temp = M(61, 20) * M(20, 54)
      temp = temp + M(61, 27) * M(27, 54)
      temp = temp + M(61, 29) * M(29, 54)
      temp = temp + M(61, 30) * M(30, 54)
      temp = temp + M(61, 31) * M(31, 54)
      temp = temp + M(61, 32) * M(32, 54)
      temp = temp + M(61, 33) * M(33, 54)
      temp = temp + M(61, 34) * M(34, 54)
      temp = temp + M(61, 35) * M(35, 54)
      temp = temp + M(61, 36) * M(36, 54)
      temp = temp + M(61, 38) * M(38, 54)
      temp = temp + M(61, 39) * M(39, 54)
      temp = temp + M(61, 40) * M(40, 54)
      temp = temp + M(61, 42) * M(42, 54)
      temp = temp + M(61, 43) * M(43, 54)
      temp = temp + M(61, 46) * M(46, 54)
      temp = temp + M(61, 49) * M(49, 54)
      temp = temp + M(61, 51) * M(51, 54)
      temp = temp + M(61, 53) * M(53, 54)
      M(61, 54) = M(61, 54) - temp
C     Upper part.
      temp = M(54, 15) * M(15, 55)
      temp = temp + M(54, 17) * M(17, 55)
      temp = temp + M(54, 18) * M(18, 55)
      temp = temp + M(54, 19) * M(19, 55)
      temp = temp + M(54, 21) * M(21, 55)
      temp = temp + M(54, 23) * M(23, 55)
      temp = temp + M(54, 29) * M(29, 55)
      temp = temp + M(54, 37) * M(37, 55)
      temp = temp + M(54, 40) * M(40, 55)
      temp = temp + M(54, 41) * M(41, 55)
      temp = temp + M(54, 45) * M(45, 55)
      temp = temp + M(54, 46) * M(46, 55)
      temp = temp + M(54, 47) * M(47, 55)
      temp = temp + M(54, 48) * M(48, 55)
      temp = temp + M(54, 49) * M(49, 55)
      temp = temp + M(54, 50) * M(50, 55)
      temp = temp + M(54, 51) * M(51, 55)
      temp = temp + M(54, 52) * M(52, 55)
      temp = temp + M(54, 53) * M(53, 55)
      M(54, 55) = ( M(54, 55) - temp ) / M(54, 54)
C     Upper part.
      M(54, 56) = M(54, 56) / M(54, 54)
C     Upper part.
      temp = M(54, 45) * M(45, 57)
      temp = temp + M(54, 46) * M(46, 57)
      temp = temp + M(54, 47) * M(47, 57)
      temp = temp + M(54, 48) * M(48, 57)
      temp = temp + M(54, 49) * M(49, 57)
      temp = temp + M(54, 50) * M(50, 57)
      temp = temp + M(54, 51) * M(51, 57)
      temp = temp + M(54, 52) * M(52, 57)
      temp = temp + M(54, 53) * M(53, 57)
      M(54, 57) = ( M(54, 57) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 14) * M(14, 58)
      temp = temp + M(54, 29) * M(29, 58)
      temp = temp + M(54, 37) * M(37, 58)
      temp = temp + M(54, 40) * M(40, 58)
      temp = temp + M(54, 41) * M(41, 58)
      temp = temp + M(54, 45) * M(45, 58)
      temp = temp + M(54, 46) * M(46, 58)
      temp = temp + M(54, 47) * M(47, 58)
      temp = temp + M(54, 48) * M(48, 58)
      temp = temp + M(54, 49) * M(49, 58)
      temp = temp + M(54, 50) * M(50, 58)
      temp = temp + M(54, 51) * M(51, 58)
      temp = temp + M(54, 52) * M(52, 58)
      temp = temp + M(54, 53) * M(53, 58)
      M(54, 58) = ( M(54, 58) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 12) * M(12, 59)
      temp = temp + M(54, 20) * M(20, 59)
      temp = temp + M(54, 24) * M(24, 59)
      temp = temp + M(54, 25) * M(25, 59)
      temp = temp + M(54, 29) * M(29, 59)
      temp = temp + M(54, 37) * M(37, 59)
      temp = temp + M(54, 40) * M(40, 59)
      temp = temp + M(54, 41) * M(41, 59)
      temp = temp + M(54, 45) * M(45, 59)
      temp = temp + M(54, 46) * M(46, 59)
      temp = temp + M(54, 47) * M(47, 59)
      temp = temp + M(54, 48) * M(48, 59)
      temp = temp + M(54, 49) * M(49, 59)
      temp = temp + M(54, 50) * M(50, 59)
      temp = temp + M(54, 51) * M(51, 59)
      temp = temp + M(54, 52) * M(52, 59)
      temp = temp + M(54, 53) * M(53, 59)
      M(54, 59) = ( M(54, 59) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 25) * M(25, 60)
      temp = temp + M(54, 27) * M(27, 60)
      temp = temp + M(54, 37) * M(37, 60)
      temp = temp + M(54, 40) * M(40, 60)
      temp = temp + M(54, 41) * M(41, 60)
      temp = temp + M(54, 45) * M(45, 60)
      temp = temp + M(54, 46) * M(46, 60)
      temp = temp + M(54, 47) * M(47, 60)
      temp = temp + M(54, 48) * M(48, 60)
      temp = temp + M(54, 49) * M(49, 60)
      temp = temp + M(54, 50) * M(50, 60)
      temp = temp + M(54, 51) * M(51, 60)
      temp = temp + M(54, 52) * M(52, 60)
      temp = temp + M(54, 53) * M(53, 60)
      M(54, 60) = ( M(54, 60) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 20) * M(20, 61)
      temp = temp + M(54, 27) * M(27, 61)
      temp = temp + M(54, 29) * M(29, 61)
      temp = temp + M(54, 40) * M(40, 61)
      temp = temp + M(54, 41) * M(41, 61)
      temp = temp + M(54, 45) * M(45, 61)
      temp = temp + M(54, 46) * M(46, 61)
      temp = temp + M(54, 47) * M(47, 61)
      temp = temp + M(54, 49) * M(49, 61)
      temp = temp + M(54, 50) * M(50, 61)
      temp = temp + M(54, 51) * M(51, 61)
      temp = temp + M(54, 52) * M(52, 61)
      temp = temp + M(54, 53) * M(53, 61)
      M(54, 61) = ( M(54, 61) - temp ) / M(54, 54)

C     Lower part.
      temp = M(55, 15) * M(15, 55)
      temp = temp + M(55, 16) * M(16, 55)
      temp = temp + M(55, 17) * M(17, 55)
      temp = temp + M(55, 18) * M(18, 55)
      temp = temp + M(55, 21) * M(21, 55)
      temp = temp + M(55, 23) * M(23, 55)
      temp = temp + M(55, 29) * M(29, 55)
      temp = temp + M(55, 37) * M(37, 55)
      temp = temp + M(55, 47) * M(47, 55)
      temp = temp + M(55, 48) * M(48, 55)
      temp = temp + M(55, 49) * M(49, 55)
      temp = temp + M(55, 50) * M(50, 55)
      temp = temp + M(55, 51) * M(51, 55)
      temp = temp + M(55, 52) * M(52, 55)
      temp = temp + M(55, 53) * M(53, 55)
      temp = temp + M(55, 54) * M(54, 55)
      M(55, 55) = M(55, 55) - temp
C     Lower part.
      temp = M(56, 17) * M(17, 55)
      temp = temp + M(56, 18) * M(18, 55)
      temp = temp + M(56, 21) * M(21, 55)
      temp = temp + M(56, 23) * M(23, 55)
      temp = temp + M(56, 29) * M(29, 55)
      temp = temp + M(56, 47) * M(47, 55)
      temp = temp + M(56, 48) * M(48, 55)
      temp = temp + M(56, 49) * M(49, 55)
      temp = temp + M(56, 50) * M(50, 55)
      temp = temp + M(56, 51) * M(51, 55)
      temp = temp + M(56, 52) * M(52, 55)
      temp = temp + M(56, 54) * M(54, 55)
      M(56, 55) = M(56, 55) - temp
C     Lower part.
      temp = M(57, 15) * M(15, 55)
      temp = temp + M(57, 37) * M(37, 55)
      temp = temp + M(57, 49) * M(49, 55)
      temp = temp + M(57, 51) * M(51, 55)
      temp = temp + M(57, 54) * M(54, 55)
      M(57, 55) = M(57, 55) - temp
C     Lower part.
      temp = M(58, 28) * M(28, 55)
      temp = temp + M(58, 29) * M(29, 55)
      temp = temp + M(58, 32) * M(32, 55)
      temp = temp + M(58, 33) * M(33, 55)
      temp = temp + M(58, 34) * M(34, 55)
      temp = temp + M(58, 38) * M(38, 55)
      temp = temp + M(58, 42) * M(42, 55)
      temp = temp + M(58, 43) * M(43, 55)
      temp = temp + M(58, 46) * M(46, 55)
      temp = temp + M(58, 49) * M(49, 55)
      temp = temp + M(58, 51) * M(51, 55)
      temp = temp + M(58, 54) * M(54, 55)
      M(58, 55) = M(58, 55) - temp
C     Lower part.
      temp = M(59, 15) * M(15, 55)
      temp = temp + M(59, 17) * M(17, 55)
      temp = temp + M(59, 18) * M(18, 55)
      temp = temp + M(59, 21) * M(21, 55)
      temp = temp + M(59, 23) * M(23, 55)
      temp = temp + M(59, 29) * M(29, 55)
      temp = temp + M(59, 32) * M(32, 55)
      temp = temp + M(59, 33) * M(33, 55)
      temp = temp + M(59, 34) * M(34, 55)
      temp = temp + M(59, 37) * M(37, 55)
      temp = temp + M(59, 38) * M(38, 55)
      temp = temp + M(59, 39) * M(39, 55)
      temp = temp + M(59, 40) * M(40, 55)
      temp = temp + M(59, 42) * M(42, 55)
      temp = temp + M(59, 43) * M(43, 55)
      temp = temp + M(59, 45) * M(45, 55)
      temp = temp + M(59, 46) * M(46, 55)
      temp = temp + M(59, 47) * M(47, 55)
      temp = temp + M(59, 48) * M(48, 55)
      temp = temp + M(59, 49) * M(49, 55)
      temp = temp + M(59, 50) * M(50, 55)
      temp = temp + M(59, 51) * M(51, 55)
      temp = temp + M(59, 52) * M(52, 55)
      temp = temp + M(59, 54) * M(54, 55)
      M(59, 55) = M(59, 55) - temp
C     Lower part.
      temp = M(60, 32) * M(32, 55)
      temp = temp + M(60, 33) * M(33, 55)
      temp = temp + M(60, 34) * M(34, 55)
      temp = temp + M(60, 37) * M(37, 55)
      temp = temp + M(60, 38) * M(38, 55)
      temp = temp + M(60, 39) * M(39, 55)
      temp = temp + M(60, 41) * M(41, 55)
      temp = temp + M(60, 42) * M(42, 55)
      temp = temp + M(60, 43) * M(43, 55)
      temp = temp + M(60, 46) * M(46, 55)
      temp = temp + M(60, 47) * M(47, 55)
      temp = temp + M(60, 49) * M(49, 55)
      temp = temp + M(60, 50) * M(50, 55)
      temp = temp + M(60, 51) * M(51, 55)
      temp = temp + M(60, 54) * M(54, 55)
      M(60, 55) = M(60, 55) - temp
C     Lower part.
      temp = M(61, 16) * M(16, 55)
      temp = temp + M(61, 28) * M(28, 55)
      temp = temp + M(61, 29) * M(29, 55)
      temp = temp + M(61, 32) * M(32, 55)
      temp = temp + M(61, 33) * M(33, 55)
      temp = temp + M(61, 34) * M(34, 55)
      temp = temp + M(61, 38) * M(38, 55)
      temp = temp + M(61, 39) * M(39, 55)
      temp = temp + M(61, 40) * M(40, 55)
      temp = temp + M(61, 42) * M(42, 55)
      temp = temp + M(61, 43) * M(43, 55)
      temp = temp + M(61, 46) * M(46, 55)
      temp = temp + M(61, 49) * M(49, 55)
      temp = temp + M(61, 51) * M(51, 55)
      temp = temp + M(61, 53) * M(53, 55)
      temp = temp + M(61, 54) * M(54, 55)
      M(61, 55) = M(61, 55) - temp
C     Upper part.
      temp = M(55, 54) * M(54, 56)
      M(55, 56) = ( M(55, 56) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 47) * M(47, 57)
      temp = temp + M(55, 48) * M(48, 57)
      temp = temp + M(55, 49) * M(49, 57)
      temp = temp + M(55, 50) * M(50, 57)
      temp = temp + M(55, 51) * M(51, 57)
      temp = temp + M(55, 52) * M(52, 57)
      temp = temp + M(55, 53) * M(53, 57)
      temp = temp + M(55, 54) * M(54, 57)
      M(55, 57) = ( M(55, 57) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 29) * M(29, 58)
      temp = temp + M(55, 37) * M(37, 58)
      temp = temp + M(55, 47) * M(47, 58)
      temp = temp + M(55, 48) * M(48, 58)
      temp = temp + M(55, 49) * M(49, 58)
      temp = temp + M(55, 50) * M(50, 58)
      temp = temp + M(55, 51) * M(51, 58)
      temp = temp + M(55, 52) * M(52, 58)
      temp = temp + M(55, 53) * M(53, 58)
      temp = temp + M(55, 54) * M(54, 58)
      M(55, 58) = ( M(55, 58) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 29) * M(29, 59)
      temp = temp + M(55, 37) * M(37, 59)
      temp = temp + M(55, 47) * M(47, 59)
      temp = temp + M(55, 48) * M(48, 59)
      temp = temp + M(55, 49) * M(49, 59)
      temp = temp + M(55, 50) * M(50, 59)
      temp = temp + M(55, 51) * M(51, 59)
      temp = temp + M(55, 52) * M(52, 59)
      temp = temp + M(55, 53) * M(53, 59)
      temp = temp + M(55, 54) * M(54, 59)
      M(55, 59) = ( M(55, 59) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 27) * M(27, 60)
      temp = temp + M(55, 37) * M(37, 60)
      temp = temp + M(55, 47) * M(47, 60)
      temp = temp + M(55, 48) * M(48, 60)
      temp = temp + M(55, 49) * M(49, 60)
      temp = temp + M(55, 50) * M(50, 60)
      temp = temp + M(55, 51) * M(51, 60)
      temp = temp + M(55, 52) * M(52, 60)
      temp = temp + M(55, 53) * M(53, 60)
      temp = temp + M(55, 54) * M(54, 60)
      M(55, 60) = ( M(55, 60) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 16) * M(16, 61)
      temp = temp + M(55, 27) * M(27, 61)
      temp = temp + M(55, 29) * M(29, 61)
      temp = temp + M(55, 47) * M(47, 61)
      temp = temp + M(55, 49) * M(49, 61)
      temp = temp + M(55, 50) * M(50, 61)
      temp = temp + M(55, 51) * M(51, 61)
      temp = temp + M(55, 52) * M(52, 61)
      temp = temp + M(55, 53) * M(53, 61)
      temp = temp + M(55, 54) * M(54, 61)
      M(55, 61) = ( M(55, 61) - temp ) / M(55, 55)

C     Lower part.
      temp = M(56, 54) * M(54, 56)
      temp = temp + M(56, 55) * M(55, 56)
      M(56, 56) = M(56, 56) - temp
C     Lower part.
      temp = M(57, 54) * M(54, 56)
      temp = temp + M(57, 55) * M(55, 56)
      M(57, 56) = M(57, 56) - temp
C     Lower part.
      temp = M(58, 54) * M(54, 56)
      temp = temp + M(58, 55) * M(55, 56)
      M(58, 56) = M(58, 56) - temp
C     Lower part.
      temp = M(59, 54) * M(54, 56)
      temp = temp + M(59, 55) * M(55, 56)
      M(59, 56) = M(59, 56) - temp
C     Lower part.
      temp = M(60, 54) * M(54, 56)
      temp = temp + M(60, 55) * M(55, 56)
      M(60, 56) = M(60, 56) - temp
C     Lower part.
      temp = M(61, 54) * M(54, 56)
      temp = temp + M(61, 55) * M(55, 56)
      M(61, 56) = M(61, 56) - temp
C     Upper part.
      temp = M(56, 47) * M(47, 57)
      temp = temp + M(56, 48) * M(48, 57)
      temp = temp + M(56, 49) * M(49, 57)
      temp = temp + M(56, 50) * M(50, 57)
      temp = temp + M(56, 51) * M(51, 57)
      temp = temp + M(56, 52) * M(52, 57)
      temp = temp + M(56, 54) * M(54, 57)
      temp = temp + M(56, 55) * M(55, 57)
      M(56, 57) = ( M(56, 57) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 29) * M(29, 58)
      temp = temp + M(56, 47) * M(47, 58)
      temp = temp + M(56, 48) * M(48, 58)
      temp = temp + M(56, 49) * M(49, 58)
      temp = temp + M(56, 50) * M(50, 58)
      temp = temp + M(56, 51) * M(51, 58)
      temp = temp + M(56, 52) * M(52, 58)
      temp = temp + M(56, 54) * M(54, 58)
      temp = temp + M(56, 55) * M(55, 58)
      M(56, 58) = ( M(56, 58) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 29) * M(29, 59)
      temp = temp + M(56, 47) * M(47, 59)
      temp = temp + M(56, 48) * M(48, 59)
      temp = temp + M(56, 49) * M(49, 59)
      temp = temp + M(56, 50) * M(50, 59)
      temp = temp + M(56, 51) * M(51, 59)
      temp = temp + M(56, 52) * M(52, 59)
      temp = temp + M(56, 54) * M(54, 59)
      temp = temp + M(56, 55) * M(55, 59)
      M(56, 59) = ( M(56, 59) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 47) * M(47, 60)
      temp = temp + M(56, 48) * M(48, 60)
      temp = temp + M(56, 49) * M(49, 60)
      temp = temp + M(56, 50) * M(50, 60)
      temp = temp + M(56, 51) * M(51, 60)
      temp = temp + M(56, 52) * M(52, 60)
      temp = temp + M(56, 54) * M(54, 60)
      temp = temp + M(56, 55) * M(55, 60)
      M(56, 60) = ( M(56, 60) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 29) * M(29, 61)
      temp = temp + M(56, 47) * M(47, 61)
      temp = temp + M(56, 49) * M(49, 61)
      temp = temp + M(56, 50) * M(50, 61)
      temp = temp + M(56, 51) * M(51, 61)
      temp = temp + M(56, 52) * M(52, 61)
      temp = temp + M(56, 54) * M(54, 61)
      temp = temp + M(56, 55) * M(55, 61)
      M(56, 61) = ( M(56, 61) - temp ) / M(56, 56)

C     Lower part.
      temp = M(57, 13) * M(13, 57)
      temp = temp + M(57, 49) * M(49, 57)
      temp = temp + M(57, 51) * M(51, 57)
      temp = temp + M(57, 54) * M(54, 57)
      temp = temp + M(57, 55) * M(55, 57)
      temp = temp + M(57, 56) * M(56, 57)
      M(57, 57) = M(57, 57) - temp
C     Lower part.
      temp = M(58, 46) * M(46, 57)
      temp = temp + M(58, 49) * M(49, 57)
      temp = temp + M(58, 51) * M(51, 57)
      temp = temp + M(58, 54) * M(54, 57)
      temp = temp + M(58, 55) * M(55, 57)
      temp = temp + M(58, 56) * M(56, 57)
      M(58, 57) = M(58, 57) - temp
C     Lower part.
      temp = M(59, 45) * M(45, 57)
      temp = temp + M(59, 46) * M(46, 57)
      temp = temp + M(59, 47) * M(47, 57)
      temp = temp + M(59, 48) * M(48, 57)
      temp = temp + M(59, 49) * M(49, 57)
      temp = temp + M(59, 50) * M(50, 57)
      temp = temp + M(59, 51) * M(51, 57)
      temp = temp + M(59, 52) * M(52, 57)
      temp = temp + M(59, 54) * M(54, 57)
      temp = temp + M(59, 55) * M(55, 57)
      temp = temp + M(59, 56) * M(56, 57)
      M(59, 57) = M(59, 57) - temp
C     Lower part.
      temp = M(60, 46) * M(46, 57)
      temp = temp + M(60, 47) * M(47, 57)
      temp = temp + M(60, 49) * M(49, 57)
      temp = temp + M(60, 50) * M(50, 57)
      temp = temp + M(60, 51) * M(51, 57)
      temp = temp + M(60, 54) * M(54, 57)
      temp = temp + M(60, 55) * M(55, 57)
      temp = temp + M(60, 56) * M(56, 57)
      M(60, 57) = M(60, 57) - temp
C     Lower part.
      temp = M(61, 13) * M(13, 57)
      temp = temp + M(61, 46) * M(46, 57)
      temp = temp + M(61, 49) * M(49, 57)
      temp = temp + M(61, 51) * M(51, 57)
      temp = temp + M(61, 53) * M(53, 57)
      temp = temp + M(61, 54) * M(54, 57)
      temp = temp + M(61, 55) * M(55, 57)
      temp = temp + M(61, 56) * M(56, 57)
      M(61, 57) = M(61, 57) - temp
C     Upper part.
      temp = M(57, 37) * M(37, 58)
      temp = temp + M(57, 49) * M(49, 58)
      temp = temp + M(57, 51) * M(51, 58)
      temp = temp + M(57, 54) * M(54, 58)
      temp = temp + M(57, 55) * M(55, 58)
      temp = temp + M(57, 56) * M(56, 58)
      M(57, 58) = ( M(57, 58) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 37) * M(37, 59)
      temp = temp + M(57, 49) * M(49, 59)
      temp = temp + M(57, 51) * M(51, 59)
      temp = temp + M(57, 54) * M(54, 59)
      temp = temp + M(57, 55) * M(55, 59)
      temp = temp + M(57, 56) * M(56, 59)
      M(57, 59) = ( M(57, 59) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 37) * M(37, 60)
      temp = temp + M(57, 49) * M(49, 60)
      temp = temp + M(57, 51) * M(51, 60)
      temp = temp + M(57, 54) * M(54, 60)
      temp = temp + M(57, 55) * M(55, 60)
      temp = temp + M(57, 56) * M(56, 60)
      M(57, 60) = ( M(57, 60) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 13) * M(13, 61)
      temp = temp + M(57, 49) * M(49, 61)
      temp = temp + M(57, 51) * M(51, 61)
      temp = temp + M(57, 54) * M(54, 61)
      temp = temp + M(57, 55) * M(55, 61)
      temp = temp + M(57, 56) * M(56, 61)
      M(57, 61) = ( M(57, 61) - temp ) / M(57, 57)

C     Lower part.
      temp = M(58, 14) * M(14, 58)
      temp = temp + M(58, 29) * M(29, 58)
      temp = temp + M(58, 30) * M(30, 58)
      temp = temp + M(58, 31) * M(31, 58)
      temp = temp + M(58, 32) * M(32, 58)
      temp = temp + M(58, 33) * M(33, 58)
      temp = temp + M(58, 34) * M(34, 58)
      temp = temp + M(58, 35) * M(35, 58)
      temp = temp + M(58, 36) * M(36, 58)
      temp = temp + M(58, 38) * M(38, 58)
      temp = temp + M(58, 42) * M(42, 58)
      temp = temp + M(58, 43) * M(43, 58)
      temp = temp + M(58, 46) * M(46, 58)
      temp = temp + M(58, 49) * M(49, 58)
      temp = temp + M(58, 51) * M(51, 58)
      temp = temp + M(58, 54) * M(54, 58)
      temp = temp + M(58, 55) * M(55, 58)
      temp = temp + M(58, 56) * M(56, 58)
      temp = temp + M(58, 57) * M(57, 58)
      M(58, 58) = M(58, 58) - temp
C     Lower part.
      temp = M(59, 29) * M(29, 58)
      temp = temp + M(59, 30) * M(30, 58)
      temp = temp + M(59, 31) * M(31, 58)
      temp = temp + M(59, 32) * M(32, 58)
      temp = temp + M(59, 33) * M(33, 58)
      temp = temp + M(59, 34) * M(34, 58)
      temp = temp + M(59, 35) * M(35, 58)
      temp = temp + M(59, 36) * M(36, 58)
      temp = temp + M(59, 37) * M(37, 58)
      temp = temp + M(59, 38) * M(38, 58)
      temp = temp + M(59, 40) * M(40, 58)
      temp = temp + M(59, 42) * M(42, 58)
      temp = temp + M(59, 43) * M(43, 58)
      temp = temp + M(59, 45) * M(45, 58)
      temp = temp + M(59, 46) * M(46, 58)
      temp = temp + M(59, 47) * M(47, 58)
      temp = temp + M(59, 48) * M(48, 58)
      temp = temp + M(59, 49) * M(49, 58)
      temp = temp + M(59, 50) * M(50, 58)
      temp = temp + M(59, 51) * M(51, 58)
      temp = temp + M(59, 52) * M(52, 58)
      temp = temp + M(59, 54) * M(54, 58)
      temp = temp + M(59, 55) * M(55, 58)
      temp = temp + M(59, 56) * M(56, 58)
      temp = temp + M(59, 57) * M(57, 58)
      M(59, 58) = M(59, 58) - temp
C     Lower part.
      temp = M(60, 30) * M(30, 58)
      temp = temp + M(60, 31) * M(31, 58)
      temp = temp + M(60, 32) * M(32, 58)
      temp = temp + M(60, 33) * M(33, 58)
      temp = temp + M(60, 34) * M(34, 58)
      temp = temp + M(60, 35) * M(35, 58)
      temp = temp + M(60, 36) * M(36, 58)
      temp = temp + M(60, 37) * M(37, 58)
      temp = temp + M(60, 38) * M(38, 58)
      temp = temp + M(60, 41) * M(41, 58)
      temp = temp + M(60, 42) * M(42, 58)
      temp = temp + M(60, 43) * M(43, 58)
      temp = temp + M(60, 46) * M(46, 58)
      temp = temp + M(60, 47) * M(47, 58)
      temp = temp + M(60, 49) * M(49, 58)
      temp = temp + M(60, 50) * M(50, 58)
      temp = temp + M(60, 51) * M(51, 58)
      temp = temp + M(60, 54) * M(54, 58)
      temp = temp + M(60, 55) * M(55, 58)
      temp = temp + M(60, 56) * M(56, 58)
      temp = temp + M(60, 57) * M(57, 58)
      M(60, 58) = M(60, 58) - temp
C     Lower part.
      temp = M(61, 29) * M(29, 58)
      temp = temp + M(61, 30) * M(30, 58)
      temp = temp + M(61, 31) * M(31, 58)
      temp = temp + M(61, 32) * M(32, 58)
      temp = temp + M(61, 33) * M(33, 58)
      temp = temp + M(61, 34) * M(34, 58)
      temp = temp + M(61, 35) * M(35, 58)
      temp = temp + M(61, 36) * M(36, 58)
      temp = temp + M(61, 38) * M(38, 58)
      temp = temp + M(61, 40) * M(40, 58)
      temp = temp + M(61, 42) * M(42, 58)
      temp = temp + M(61, 43) * M(43, 58)
      temp = temp + M(61, 46) * M(46, 58)
      temp = temp + M(61, 49) * M(49, 58)
      temp = temp + M(61, 51) * M(51, 58)
      temp = temp + M(61, 53) * M(53, 58)
      temp = temp + M(61, 54) * M(54, 58)
      temp = temp + M(61, 55) * M(55, 58)
      temp = temp + M(61, 56) * M(56, 58)
      temp = temp + M(61, 57) * M(57, 58)
      M(61, 58) = M(61, 58) - temp
C     Upper part.
      temp = M(58, 29) * M(29, 59)
      temp = temp + M(58, 30) * M(30, 59)
      temp = temp + M(58, 31) * M(31, 59)
      temp = temp + M(58, 32) * M(32, 59)
      temp = temp + M(58, 33) * M(33, 59)
      temp = temp + M(58, 34) * M(34, 59)
      temp = temp + M(58, 35) * M(35, 59)
      temp = temp + M(58, 36) * M(36, 59)
      temp = temp + M(58, 38) * M(38, 59)
      temp = temp + M(58, 42) * M(42, 59)
      temp = temp + M(58, 43) * M(43, 59)
      temp = temp + M(58, 46) * M(46, 59)
      temp = temp + M(58, 49) * M(49, 59)
      temp = temp + M(58, 51) * M(51, 59)
      temp = temp + M(58, 54) * M(54, 59)
      temp = temp + M(58, 55) * M(55, 59)
      temp = temp + M(58, 56) * M(56, 59)
      temp = temp + M(58, 57) * M(57, 59)
      M(58, 59) = ( M(58, 59) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 30) * M(30, 60)
      temp = temp + M(58, 31) * M(31, 60)
      temp = temp + M(58, 32) * M(32, 60)
      temp = temp + M(58, 33) * M(33, 60)
      temp = temp + M(58, 34) * M(34, 60)
      temp = temp + M(58, 35) * M(35, 60)
      temp = temp + M(58, 36) * M(36, 60)
      temp = temp + M(58, 38) * M(38, 60)
      temp = temp + M(58, 42) * M(42, 60)
      temp = temp + M(58, 43) * M(43, 60)
      temp = temp + M(58, 46) * M(46, 60)
      temp = temp + M(58, 49) * M(49, 60)
      temp = temp + M(58, 51) * M(51, 60)
      temp = temp + M(58, 54) * M(54, 60)
      temp = temp + M(58, 55) * M(55, 60)
      temp = temp + M(58, 56) * M(56, 60)
      temp = temp + M(58, 57) * M(57, 60)
      M(58, 60) = ( M(58, 60) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 28) * M(28, 61)
      temp = temp + M(58, 29) * M(29, 61)
      temp = temp + M(58, 32) * M(32, 61)
      temp = temp + M(58, 33) * M(33, 61)
      temp = temp + M(58, 34) * M(34, 61)
      temp = temp + M(58, 38) * M(38, 61)
      temp = temp + M(58, 42) * M(42, 61)
      temp = temp + M(58, 43) * M(43, 61)
      temp = temp + M(58, 46) * M(46, 61)
      temp = temp + M(58, 49) * M(49, 61)
      temp = temp + M(58, 51) * M(51, 61)
      temp = temp + M(58, 54) * M(54, 61)
      temp = temp + M(58, 55) * M(55, 61)
      temp = temp + M(58, 56) * M(56, 61)
      temp = temp + M(58, 57) * M(57, 61)
      M(58, 61) = ( M(58, 61) - temp ) / M(58, 58)

C     Lower part.
      temp = M(59, 12) * M(12, 59)
      temp = temp + M(59, 20) * M(20, 59)
      temp = temp + M(59, 24) * M(24, 59)
      temp = temp + M(59, 29) * M(29, 59)
      temp = temp + M(59, 30) * M(30, 59)
      temp = temp + M(59, 31) * M(31, 59)
      temp = temp + M(59, 32) * M(32, 59)
      temp = temp + M(59, 33) * M(33, 59)
      temp = temp + M(59, 34) * M(34, 59)
      temp = temp + M(59, 35) * M(35, 59)
      temp = temp + M(59, 36) * M(36, 59)
      temp = temp + M(59, 37) * M(37, 59)
      temp = temp + M(59, 38) * M(38, 59)
      temp = temp + M(59, 39) * M(39, 59)
      temp = temp + M(59, 40) * M(40, 59)
      temp = temp + M(59, 42) * M(42, 59)
      temp = temp + M(59, 43) * M(43, 59)
      temp = temp + M(59, 45) * M(45, 59)
      temp = temp + M(59, 46) * M(46, 59)
      temp = temp + M(59, 47) * M(47, 59)
      temp = temp + M(59, 48) * M(48, 59)
      temp = temp + M(59, 49) * M(49, 59)
      temp = temp + M(59, 50) * M(50, 59)
      temp = temp + M(59, 51) * M(51, 59)
      temp = temp + M(59, 52) * M(52, 59)
      temp = temp + M(59, 54) * M(54, 59)
      temp = temp + M(59, 55) * M(55, 59)
      temp = temp + M(59, 56) * M(56, 59)
      temp = temp + M(59, 57) * M(57, 59)
      temp = temp + M(59, 58) * M(58, 59)
      M(59, 59) = M(59, 59) - temp
C     Lower part.
      temp = M(60, 25) * M(25, 59)
      temp = temp + M(60, 30) * M(30, 59)
      temp = temp + M(60, 31) * M(31, 59)
      temp = temp + M(60, 32) * M(32, 59)
      temp = temp + M(60, 33) * M(33, 59)
      temp = temp + M(60, 34) * M(34, 59)
      temp = temp + M(60, 35) * M(35, 59)
      temp = temp + M(60, 36) * M(36, 59)
      temp = temp + M(60, 37) * M(37, 59)
      temp = temp + M(60, 38) * M(38, 59)
      temp = temp + M(60, 39) * M(39, 59)
      temp = temp + M(60, 41) * M(41, 59)
      temp = temp + M(60, 42) * M(42, 59)
      temp = temp + M(60, 43) * M(43, 59)
      temp = temp + M(60, 46) * M(46, 59)
      temp = temp + M(60, 47) * M(47, 59)
      temp = temp + M(60, 49) * M(49, 59)
      temp = temp + M(60, 50) * M(50, 59)
      temp = temp + M(60, 51) * M(51, 59)
      temp = temp + M(60, 54) * M(54, 59)
      temp = temp + M(60, 55) * M(55, 59)
      temp = temp + M(60, 56) * M(56, 59)
      temp = temp + M(60, 57) * M(57, 59)
      temp = temp + M(60, 58) * M(58, 59)
      M(60, 59) = M(60, 59) - temp
C     Lower part.
      temp = M(61, 20) * M(20, 59)
      temp = temp + M(61, 29) * M(29, 59)
      temp = temp + M(61, 30) * M(30, 59)
      temp = temp + M(61, 31) * M(31, 59)
      temp = temp + M(61, 32) * M(32, 59)
      temp = temp + M(61, 33) * M(33, 59)
      temp = temp + M(61, 34) * M(34, 59)
      temp = temp + M(61, 35) * M(35, 59)
      temp = temp + M(61, 36) * M(36, 59)
      temp = temp + M(61, 38) * M(38, 59)
      temp = temp + M(61, 39) * M(39, 59)
      temp = temp + M(61, 40) * M(40, 59)
      temp = temp + M(61, 42) * M(42, 59)
      temp = temp + M(61, 43) * M(43, 59)
      temp = temp + M(61, 46) * M(46, 59)
      temp = temp + M(61, 49) * M(49, 59)
      temp = temp + M(61, 51) * M(51, 59)
      temp = temp + M(61, 53) * M(53, 59)
      temp = temp + M(61, 54) * M(54, 59)
      temp = temp + M(61, 55) * M(55, 59)
      temp = temp + M(61, 56) * M(56, 59)
      temp = temp + M(61, 57) * M(57, 59)
      temp = temp + M(61, 58) * M(58, 59)
      M(61, 59) = M(61, 59) - temp
C     Upper part.
      temp = M(59, 30) * M(30, 60)
      temp = temp + M(59, 31) * M(31, 60)
      temp = temp + M(59, 32) * M(32, 60)
      temp = temp + M(59, 33) * M(33, 60)
      temp = temp + M(59, 34) * M(34, 60)
      temp = temp + M(59, 35) * M(35, 60)
      temp = temp + M(59, 36) * M(36, 60)
      temp = temp + M(59, 37) * M(37, 60)
      temp = temp + M(59, 38) * M(38, 60)
      temp = temp + M(59, 39) * M(39, 60)
      temp = temp + M(59, 40) * M(40, 60)
      temp = temp + M(59, 42) * M(42, 60)
      temp = temp + M(59, 43) * M(43, 60)
      temp = temp + M(59, 45) * M(45, 60)
      temp = temp + M(59, 46) * M(46, 60)
      temp = temp + M(59, 47) * M(47, 60)
      temp = temp + M(59, 48) * M(48, 60)
      temp = temp + M(59, 49) * M(49, 60)
      temp = temp + M(59, 50) * M(50, 60)
      temp = temp + M(59, 51) * M(51, 60)
      temp = temp + M(59, 52) * M(52, 60)
      temp = temp + M(59, 54) * M(54, 60)
      temp = temp + M(59, 55) * M(55, 60)
      temp = temp + M(59, 56) * M(56, 60)
      temp = temp + M(59, 57) * M(57, 60)
      temp = temp + M(59, 58) * M(58, 60)
      M(59, 60) = ( M(59, 60) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 20) * M(20, 61)
      temp = temp + M(59, 29) * M(29, 61)
      temp = temp + M(59, 32) * M(32, 61)
      temp = temp + M(59, 33) * M(33, 61)
      temp = temp + M(59, 34) * M(34, 61)
      temp = temp + M(59, 38) * M(38, 61)
      temp = temp + M(59, 39) * M(39, 61)
      temp = temp + M(59, 40) * M(40, 61)
      temp = temp + M(59, 42) * M(42, 61)
      temp = temp + M(59, 43) * M(43, 61)
      temp = temp + M(59, 45) * M(45, 61)
      temp = temp + M(59, 46) * M(46, 61)
      temp = temp + M(59, 47) * M(47, 61)
      temp = temp + M(59, 49) * M(49, 61)
      temp = temp + M(59, 50) * M(50, 61)
      temp = temp + M(59, 51) * M(51, 61)
      temp = temp + M(59, 52) * M(52, 61)
      temp = temp + M(59, 54) * M(54, 61)
      temp = temp + M(59, 55) * M(55, 61)
      temp = temp + M(59, 56) * M(56, 61)
      temp = temp + M(59, 57) * M(57, 61)
      temp = temp + M(59, 58) * M(58, 61)
      M(59, 61) = ( M(59, 61) - temp ) / M(59, 59)

C     Lower part.
      temp = M(60, 25) * M(25, 60)
      temp = temp + M(60, 27) * M(27, 60)
      temp = temp + M(60, 30) * M(30, 60)
      temp = temp + M(60, 31) * M(31, 60)
      temp = temp + M(60, 32) * M(32, 60)
      temp = temp + M(60, 33) * M(33, 60)
      temp = temp + M(60, 34) * M(34, 60)
      temp = temp + M(60, 35) * M(35, 60)
      temp = temp + M(60, 36) * M(36, 60)
      temp = temp + M(60, 37) * M(37, 60)
      temp = temp + M(60, 38) * M(38, 60)
      temp = temp + M(60, 39) * M(39, 60)
      temp = temp + M(60, 41) * M(41, 60)
      temp = temp + M(60, 42) * M(42, 60)
      temp = temp + M(60, 43) * M(43, 60)
      temp = temp + M(60, 46) * M(46, 60)
      temp = temp + M(60, 47) * M(47, 60)
      temp = temp + M(60, 49) * M(49, 60)
      temp = temp + M(60, 50) * M(50, 60)
      temp = temp + M(60, 51) * M(51, 60)
      temp = temp + M(60, 54) * M(54, 60)
      temp = temp + M(60, 55) * M(55, 60)
      temp = temp + M(60, 56) * M(56, 60)
      temp = temp + M(60, 57) * M(57, 60)
      temp = temp + M(60, 58) * M(58, 60)
      temp = temp + M(60, 59) * M(59, 60)
      M(60, 60) = M(60, 60) - temp
C     Lower part.
      temp = M(61, 27) * M(27, 60)
      temp = temp + M(61, 30) * M(30, 60)
      temp = temp + M(61, 31) * M(31, 60)
      temp = temp + M(61, 32) * M(32, 60)
      temp = temp + M(61, 33) * M(33, 60)
      temp = temp + M(61, 34) * M(34, 60)
      temp = temp + M(61, 35) * M(35, 60)
      temp = temp + M(61, 36) * M(36, 60)
      temp = temp + M(61, 38) * M(38, 60)
      temp = temp + M(61, 39) * M(39, 60)
      temp = temp + M(61, 40) * M(40, 60)
      temp = temp + M(61, 42) * M(42, 60)
      temp = temp + M(61, 43) * M(43, 60)
      temp = temp + M(61, 46) * M(46, 60)
      temp = temp + M(61, 49) * M(49, 60)
      temp = temp + M(61, 51) * M(51, 60)
      temp = temp + M(61, 53) * M(53, 60)
      temp = temp + M(61, 54) * M(54, 60)
      temp = temp + M(61, 55) * M(55, 60)
      temp = temp + M(61, 56) * M(56, 60)
      temp = temp + M(61, 57) * M(57, 60)
      temp = temp + M(61, 58) * M(58, 60)
      temp = temp + M(61, 59) * M(59, 60)
      M(61, 60) = M(61, 60) - temp
C     Upper part.
      temp = M(60, 27) * M(27, 61)
      temp = temp + M(60, 32) * M(32, 61)
      temp = temp + M(60, 33) * M(33, 61)
      temp = temp + M(60, 34) * M(34, 61)
      temp = temp + M(60, 38) * M(38, 61)
      temp = temp + M(60, 39) * M(39, 61)
      temp = temp + M(60, 41) * M(41, 61)
      temp = temp + M(60, 42) * M(42, 61)
      temp = temp + M(60, 43) * M(43, 61)
      temp = temp + M(60, 46) * M(46, 61)
      temp = temp + M(60, 47) * M(47, 61)
      temp = temp + M(60, 49) * M(49, 61)
      temp = temp + M(60, 50) * M(50, 61)
      temp = temp + M(60, 51) * M(51, 61)
      temp = temp + M(60, 54) * M(54, 61)
      temp = temp + M(60, 55) * M(55, 61)
      temp = temp + M(60, 56) * M(56, 61)
      temp = temp + M(60, 57) * M(57, 61)
      temp = temp + M(60, 58) * M(58, 61)
      temp = temp + M(60, 59) * M(59, 61)
      M(60, 61) = ( M(60, 61) - temp ) / M(60, 60)

C     Lower part.
      temp = M(61, 13) * M(13, 61)
      temp = temp + M(61, 16) * M(16, 61)
      temp = temp + M(61, 20) * M(20, 61)
      temp = temp + M(61, 27) * M(27, 61)
      temp = temp + M(61, 28) * M(28, 61)
      temp = temp + M(61, 29) * M(29, 61)
      temp = temp + M(61, 32) * M(32, 61)
      temp = temp + M(61, 33) * M(33, 61)
      temp = temp + M(61, 34) * M(34, 61)
      temp = temp + M(61, 38) * M(38, 61)
      temp = temp + M(61, 39) * M(39, 61)
      temp = temp + M(61, 40) * M(40, 61)
      temp = temp + M(61, 42) * M(42, 61)
      temp = temp + M(61, 43) * M(43, 61)
      temp = temp + M(61, 46) * M(46, 61)
      temp = temp + M(61, 49) * M(49, 61)
      temp = temp + M(61, 51) * M(51, 61)
      temp = temp + M(61, 53) * M(53, 61)
      temp = temp + M(61, 54) * M(54, 61)
      temp = temp + M(61, 55) * M(55, 61)
      temp = temp + M(61, 56) * M(56, 61)
      temp = temp + M(61, 57) * M(57, 61)
      temp = temp + M(61, 58) * M(58, 61)
      temp = temp + M(61, 59) * M(59, 61)
      temp = temp + M(61, 60) * M(60, 61)
      M(61, 61) = M(61, 61) - temp


      END
