C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE LU_solve (M, x)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves M * y = x where M is an LU factorization
C     computed by LU_decompose.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     M: LU factorization computed by LU_decompose.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     x: on entry, the right-hand side of the equation. On exit,
C     the solution of the equation.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of 'chemical' arrays.

      INCLUDE 'PARACHEM.INC'

      DOUBLE PRECISION M(Nesp,Nesp)
      DOUBLE PRECISION x(Nesp)
      DOUBLE PRECISION temp


C     Forward substitution.

      x(1) = x(1) / M(1, 1)

      x(2) = x(2) / M(2, 2)

      x(3) = x(3) / M(3, 3)

      x(4) = x(4) / M(4, 4)

      x(5) = x(5) / M(5, 5)

      x(6) = x(6) / M(6, 6)

      x(7) = x(7) / M(7, 7)

      x(8) = x(8) / M(8, 8)

      x(9) = x(9) / M(9, 9)

      temp = M(10, 9) * x(9)
      x(10) = ( x(10) - temp ) / M(10, 10)

      x(11) = x(11) / M(11, 11)

      x(12) = x(12) / M(12, 12)

      x(13) = x(13) / M(13, 13)

      x(14) = x(14) / M(14, 14)

      temp = M(15, 4) * x(4)
      temp = temp + M(15, 5) * x(5)
      x(15) = ( x(15) - temp ) / M(15, 15)

      x(16) = x(16) / M(16, 16)

      x(17) = x(17) / M(17, 17)

      x(18) = x(18) / M(18, 18)

      temp = M(19, 17) * x(17)
      temp = temp + M(19, 18) * x(18)
      x(19) = ( x(19) - temp ) / M(19, 19)

      x(20) = x(20) / M(20, 20)

      x(21) = x(21) / M(21, 21)

      temp = M(22, 17) * x(17)
      temp = temp + M(22, 18) * x(18)
      temp = temp + M(22, 21) * x(21)
      x(22) = ( x(22) - temp ) / M(22, 22)

      x(23) = x(23) / M(23, 23)

      x(24) = x(24) / M(24, 24)

      x(25) = x(25) / M(25, 25)

      temp = M(26, 25) * x(25)
      x(26) = ( x(26) - temp ) / M(26, 26)

      x(27) = x(27) / M(27, 27)

      temp = M(28, 11) * x(11)
      x(28) = ( x(28) - temp ) / M(28, 28)

      temp = M(29, 17) * x(17)
      temp = temp + M(29, 18) * x(18)
      temp = temp + M(29, 21) * x(21)
      temp = temp + M(29, 23) * x(23)
      temp = temp + M(29, 28) * x(28)
      x(29) = ( x(29) - temp ) / M(29, 29)

      temp = M(30, 7) * x(7)
      x(30) = ( x(30) - temp ) / M(30, 30)

      temp = M(31, 8) * x(8)
      x(31) = ( x(31) - temp ) / M(31, 31)

      temp = M(32, 21) * x(21)
      temp = temp + M(32, 29) * x(29)
      x(32) = ( x(32) - temp ) / M(32, 32)

      temp = M(33, 17) * x(17)
      temp = temp + M(33, 23) * x(23)
      temp = temp + M(33, 29) * x(29)
      x(33) = ( x(33) - temp ) / M(33, 33)

      temp = M(34, 18) * x(18)
      temp = temp + M(34, 29) * x(29)
      x(34) = ( x(34) - temp ) / M(34, 34)

      temp = M(35, 4) * x(4)
      x(35) = ( x(35) - temp ) / M(35, 35)

      temp = M(36, 5) * x(5)
      x(36) = ( x(36) - temp ) / M(36, 36)

      temp = M(37, 35) * x(35)
      temp = temp + M(37, 36) * x(36)
      x(37) = ( x(37) - temp ) / M(37, 37)

      temp = M(38, 17) * x(17)
      temp = temp + M(38, 18) * x(18)
      temp = temp + M(38, 21) * x(21)
      temp = temp + M(38, 23) * x(23)
      temp = temp + M(38, 29) * x(29)
      x(38) = ( x(38) - temp ) / M(38, 38)

      temp = M(39, 15) * x(15)
      x(39) = ( x(39) - temp ) / M(39, 39)

      temp = M(40, 30) * x(30)
      temp = temp + M(40, 31) * x(31)
      temp = temp + M(40, 38) * x(38)
      temp = temp + M(40, 39) * x(39)
      x(40) = ( x(40) - temp ) / M(40, 40)

      temp = M(41, 6) * x(6)
      temp = temp + M(41, 18) * x(18)
      temp = temp + M(41, 29) * x(29)
      temp = temp + M(41, 30) * x(30)
      temp = temp + M(41, 31) * x(31)
      temp = temp + M(41, 34) * x(34)
      temp = temp + M(41, 40) * x(40)
      x(41) = ( x(41) - temp ) / M(41, 41)

      temp = M(42, 41) * x(41)
      x(42) = ( x(42) - temp ) / M(42, 42)

      temp = M(43, 3) * x(3)
      temp = temp + M(43, 41) * x(41)
      x(43) = ( x(43) - temp ) / M(43, 43)

      temp = M(44, 17) * x(17)
      temp = temp + M(44, 18) * x(18)
      temp = temp + M(44, 23) * x(23)
      temp = temp + M(44, 29) * x(29)
      temp = temp + M(44, 30) * x(30)
      temp = temp + M(44, 31) * x(31)
      temp = temp + M(44, 32) * x(32)
      temp = temp + M(44, 33) * x(33)
      temp = temp + M(44, 34) * x(34)
      temp = temp + M(44, 38) * x(38)
      temp = temp + M(44, 42) * x(42)
      temp = temp + M(44, 43) * x(43)
      x(44) = ( x(44) - temp ) / M(44, 44)

      temp = M(45, 30) * x(30)
      temp = temp + M(45, 31) * x(31)
      temp = temp + M(45, 32) * x(32)
      temp = temp + M(45, 33) * x(33)
      temp = temp + M(45, 34) * x(34)
      temp = temp + M(45, 35) * x(35)
      temp = temp + M(45, 36) * x(36)
      temp = temp + M(45, 39) * x(39)
      temp = temp + M(45, 42) * x(42)
      temp = temp + M(45, 43) * x(43)
      x(45) = ( x(45) - temp ) / M(45, 45)

      temp = M(46, 6) * x(6)
      temp = temp + M(46, 40) * x(40)
      temp = temp + M(46, 45) * x(45)
      x(46) = ( x(46) - temp ) / M(46, 46)

      temp = M(47, 6) * x(6)
      temp = temp + M(47, 17) * x(17)
      temp = temp + M(47, 18) * x(18)
      temp = temp + M(47, 23) * x(23)
      temp = temp + M(47, 29) * x(29)
      temp = temp + M(47, 30) * x(30)
      temp = temp + M(47, 31) * x(31)
      temp = temp + M(47, 32) * x(32)
      temp = temp + M(47, 33) * x(33)
      temp = temp + M(47, 34) * x(34)
      temp = temp + M(47, 38) * x(38)
      temp = temp + M(47, 40) * x(40)
      temp = temp + M(47, 43) * x(43)
      temp = temp + M(47, 45) * x(45)
      temp = temp + M(47, 46) * x(46)
      x(47) = ( x(47) - temp ) / M(47, 47)

      temp = M(48, 35) * x(35)
      x(48) = ( x(48) - temp ) / M(48, 48)

      temp = M(49, 17) * x(17)
      temp = temp + M(49, 18) * x(18)
      temp = temp + M(49, 19) * x(19)
      temp = temp + M(49, 23) * x(23)
      temp = temp + M(49, 24) * x(24)
      temp = temp + M(49, 25) * x(25)
      temp = temp + M(49, 29) * x(29)
      temp = temp + M(49, 30) * x(30)
      temp = temp + M(49, 31) * x(31)
      temp = temp + M(49, 32) * x(32)
      temp = temp + M(49, 33) * x(33)
      temp = temp + M(49, 34) * x(34)
      temp = temp + M(49, 35) * x(35)
      temp = temp + M(49, 36) * x(36)
      temp = temp + M(49, 38) * x(38)
      temp = temp + M(49, 39) * x(39)
      temp = temp + M(49, 42) * x(42)
      temp = temp + M(49, 43) * x(43)
      temp = temp + M(49, 46) * x(46)
      temp = temp + M(49, 47) * x(47)
      x(49) = ( x(49) - temp ) / M(49, 49)

      temp = M(50, 35) * x(35)
      temp = temp + M(50, 36) * x(36)
      temp = temp + M(50, 42) * x(42)
      temp = temp + M(50, 46) * x(46)
      temp = temp + M(50, 49) * x(49)
      x(50) = ( x(50) - temp ) / M(50, 50)

      temp = M(51, 7) * x(7)
      temp = temp + M(51, 8) * x(8)
      temp = temp + M(51, 15) * x(15)
      temp = temp + M(51, 27) * x(27)
      temp = temp + M(51, 49) * x(49)
      x(51) = ( x(51) - temp ) / M(51, 51)

      temp = M(52, 6) * x(6)
      temp = temp + M(52, 17) * x(17)
      temp = temp + M(52, 18) * x(18)
      temp = temp + M(52, 21) * x(21)
      temp = temp + M(52, 23) * x(23)
      temp = temp + M(52, 24) * x(24)
      temp = temp + M(52, 27) * x(27)
      temp = temp + M(52, 29) * x(29)
      temp = temp + M(52, 30) * x(30)
      temp = temp + M(52, 31) * x(31)
      temp = temp + M(52, 32) * x(32)
      temp = temp + M(52, 33) * x(33)
      temp = temp + M(52, 34) * x(34)
      temp = temp + M(52, 35) * x(35)
      temp = temp + M(52, 36) * x(36)
      temp = temp + M(52, 38) * x(38)
      temp = temp + M(52, 39) * x(39)
      temp = temp + M(52, 42) * x(42)
      temp = temp + M(52, 43) * x(43)
      temp = temp + M(52, 46) * x(46)
      temp = temp + M(52, 48) * x(48)
      temp = temp + M(52, 49) * x(49)
      temp = temp + M(52, 51) * x(51)
      x(52) = ( x(52) - temp ) / M(52, 52)

      temp = M(53, 15) * x(15)
      temp = temp + M(53, 16) * x(16)
      temp = temp + M(53, 37) * x(37)
      temp = temp + M(53, 47) * x(47)
      temp = temp + M(53, 48) * x(48)
      temp = temp + M(53, 49) * x(49)
      temp = temp + M(53, 50) * x(50)
      temp = temp + M(53, 51) * x(51)
      temp = temp + M(53, 52) * x(52)
      x(53) = ( x(53) - temp ) / M(53, 53)

      temp = M(54, 3) * x(3)
      temp = temp + M(54, 4) * x(4)
      temp = temp + M(54, 5) * x(5)
      temp = temp + M(54, 6) * x(6)
      temp = temp + M(54, 7) * x(7)
      temp = temp + M(54, 8) * x(8)
      temp = temp + M(54, 9) * x(9)
      temp = temp + M(54, 11) * x(11)
      temp = temp + M(54, 12) * x(12)
      temp = temp + M(54, 14) * x(14)
      temp = temp + M(54, 15) * x(15)
      temp = temp + M(54, 17) * x(17)
      temp = temp + M(54, 18) * x(18)
      temp = temp + M(54, 19) * x(19)
      temp = temp + M(54, 20) * x(20)
      temp = temp + M(54, 21) * x(21)
      temp = temp + M(54, 23) * x(23)
      temp = temp + M(54, 24) * x(24)
      temp = temp + M(54, 25) * x(25)
      temp = temp + M(54, 27) * x(27)
      temp = temp + M(54, 29) * x(29)
      temp = temp + M(54, 37) * x(37)
      temp = temp + M(54, 40) * x(40)
      temp = temp + M(54, 41) * x(41)
      temp = temp + M(54, 45) * x(45)
      temp = temp + M(54, 46) * x(46)
      temp = temp + M(54, 47) * x(47)
      temp = temp + M(54, 48) * x(48)
      temp = temp + M(54, 49) * x(49)
      temp = temp + M(54, 50) * x(50)
      temp = temp + M(54, 51) * x(51)
      temp = temp + M(54, 52) * x(52)
      temp = temp + M(54, 53) * x(53)
      x(54) = ( x(54) - temp ) / M(54, 54)

      temp = M(55, 15) * x(15)
      temp = temp + M(55, 16) * x(16)
      temp = temp + M(55, 17) * x(17)
      temp = temp + M(55, 18) * x(18)
      temp = temp + M(55, 21) * x(21)
      temp = temp + M(55, 23) * x(23)
      temp = temp + M(55, 27) * x(27)
      temp = temp + M(55, 29) * x(29)
      temp = temp + M(55, 37) * x(37)
      temp = temp + M(55, 47) * x(47)
      temp = temp + M(55, 48) * x(48)
      temp = temp + M(55, 49) * x(49)
      temp = temp + M(55, 50) * x(50)
      temp = temp + M(55, 51) * x(51)
      temp = temp + M(55, 52) * x(52)
      temp = temp + M(55, 53) * x(53)
      temp = temp + M(55, 54) * x(54)
      x(55) = ( x(55) - temp ) / M(55, 55)

      temp = M(56, 17) * x(17)
      temp = temp + M(56, 18) * x(18)
      temp = temp + M(56, 21) * x(21)
      temp = temp + M(56, 23) * x(23)
      temp = temp + M(56, 29) * x(29)
      temp = temp + M(56, 47) * x(47)
      temp = temp + M(56, 48) * x(48)
      temp = temp + M(56, 49) * x(49)
      temp = temp + M(56, 50) * x(50)
      temp = temp + M(56, 51) * x(51)
      temp = temp + M(56, 52) * x(52)
      temp = temp + M(56, 54) * x(54)
      temp = temp + M(56, 55) * x(55)
      x(56) = ( x(56) - temp ) / M(56, 56)

      temp = M(57, 13) * x(13)
      temp = temp + M(57, 15) * x(15)
      temp = temp + M(57, 37) * x(37)
      temp = temp + M(57, 49) * x(49)
      temp = temp + M(57, 51) * x(51)
      temp = temp + M(57, 54) * x(54)
      temp = temp + M(57, 55) * x(55)
      temp = temp + M(57, 56) * x(56)
      x(57) = ( x(57) - temp ) / M(57, 57)

      temp = M(58, 14) * x(14)
      temp = temp + M(58, 28) * x(28)
      temp = temp + M(58, 29) * x(29)
      temp = temp + M(58, 30) * x(30)
      temp = temp + M(58, 31) * x(31)
      temp = temp + M(58, 32) * x(32)
      temp = temp + M(58, 33) * x(33)
      temp = temp + M(58, 34) * x(34)
      temp = temp + M(58, 35) * x(35)
      temp = temp + M(58, 36) * x(36)
      temp = temp + M(58, 38) * x(38)
      temp = temp + M(58, 42) * x(42)
      temp = temp + M(58, 43) * x(43)
      temp = temp + M(58, 46) * x(46)
      temp = temp + M(58, 49) * x(49)
      temp = temp + M(58, 51) * x(51)
      temp = temp + M(58, 54) * x(54)
      temp = temp + M(58, 55) * x(55)
      temp = temp + M(58, 56) * x(56)
      temp = temp + M(58, 57) * x(57)
      x(58) = ( x(58) - temp ) / M(58, 58)

      temp = M(59, 4) * x(4)
      temp = temp + M(59, 5) * x(5)
      temp = temp + M(59, 6) * x(6)
      temp = temp + M(59, 9) * x(9)
      temp = temp + M(59, 12) * x(12)
      temp = temp + M(59, 15) * x(15)
      temp = temp + M(59, 17) * x(17)
      temp = temp + M(59, 18) * x(18)
      temp = temp + M(59, 20) * x(20)
      temp = temp + M(59, 21) * x(21)
      temp = temp + M(59, 23) * x(23)
      temp = temp + M(59, 24) * x(24)
      temp = temp + M(59, 29) * x(29)
      temp = temp + M(59, 30) * x(30)
      temp = temp + M(59, 31) * x(31)
      temp = temp + M(59, 32) * x(32)
      temp = temp + M(59, 33) * x(33)
      temp = temp + M(59, 34) * x(34)
      temp = temp + M(59, 35) * x(35)
      temp = temp + M(59, 36) * x(36)
      temp = temp + M(59, 37) * x(37)
      temp = temp + M(59, 38) * x(38)
      temp = temp + M(59, 39) * x(39)
      temp = temp + M(59, 40) * x(40)
      temp = temp + M(59, 42) * x(42)
      temp = temp + M(59, 43) * x(43)
      temp = temp + M(59, 45) * x(45)
      temp = temp + M(59, 46) * x(46)
      temp = temp + M(59, 47) * x(47)
      temp = temp + M(59, 48) * x(48)
      temp = temp + M(59, 49) * x(49)
      temp = temp + M(59, 50) * x(50)
      temp = temp + M(59, 51) * x(51)
      temp = temp + M(59, 52) * x(52)
      temp = temp + M(59, 54) * x(54)
      temp = temp + M(59, 55) * x(55)
      temp = temp + M(59, 56) * x(56)
      temp = temp + M(59, 57) * x(57)
      temp = temp + M(59, 58) * x(58)
      x(59) = ( x(59) - temp ) / M(59, 59)

      temp = M(60, 25) * x(25)
      temp = temp + M(60, 27) * x(27)
      temp = temp + M(60, 30) * x(30)
      temp = temp + M(60, 31) * x(31)
      temp = temp + M(60, 32) * x(32)
      temp = temp + M(60, 33) * x(33)
      temp = temp + M(60, 34) * x(34)
      temp = temp + M(60, 35) * x(35)
      temp = temp + M(60, 36) * x(36)
      temp = temp + M(60, 37) * x(37)
      temp = temp + M(60, 38) * x(38)
      temp = temp + M(60, 39) * x(39)
      temp = temp + M(60, 41) * x(41)
      temp = temp + M(60, 42) * x(42)
      temp = temp + M(60, 43) * x(43)
      temp = temp + M(60, 46) * x(46)
      temp = temp + M(60, 47) * x(47)
      temp = temp + M(60, 49) * x(49)
      temp = temp + M(60, 50) * x(50)
      temp = temp + M(60, 51) * x(51)
      temp = temp + M(60, 54) * x(54)
      temp = temp + M(60, 55) * x(55)
      temp = temp + M(60, 56) * x(56)
      temp = temp + M(60, 57) * x(57)
      temp = temp + M(60, 58) * x(58)
      temp = temp + M(60, 59) * x(59)
      x(60) = ( x(60) - temp ) / M(60, 60)

      temp = M(61, 13) * x(13)
      temp = temp + M(61, 16) * x(16)
      temp = temp + M(61, 20) * x(20)
      temp = temp + M(61, 27) * x(27)
      temp = temp + M(61, 28) * x(28)
      temp = temp + M(61, 29) * x(29)
      temp = temp + M(61, 30) * x(30)
      temp = temp + M(61, 31) * x(31)
      temp = temp + M(61, 32) * x(32)
      temp = temp + M(61, 33) * x(33)
      temp = temp + M(61, 34) * x(34)
      temp = temp + M(61, 35) * x(35)
      temp = temp + M(61, 36) * x(36)
      temp = temp + M(61, 38) * x(38)
      temp = temp + M(61, 39) * x(39)
      temp = temp + M(61, 40) * x(40)
      temp = temp + M(61, 42) * x(42)
      temp = temp + M(61, 43) * x(43)
      temp = temp + M(61, 46) * x(46)
      temp = temp + M(61, 49) * x(49)
      temp = temp + M(61, 51) * x(51)
      temp = temp + M(61, 53) * x(53)
      temp = temp + M(61, 54) * x(54)
      temp = temp + M(61, 55) * x(55)
      temp = temp + M(61, 56) * x(56)
      temp = temp + M(61, 57) * x(57)
      temp = temp + M(61, 58) * x(58)
      temp = temp + M(61, 59) * x(59)
      temp = temp + M(61, 60) * x(60)
      x(61) = ( x(61) - temp ) / M(61, 61)


C     Backward substitution.

      temp = M(60, 61) * x(61)
      x(60) = x(60) - temp

      temp = M(59, 60) * x(60)
      temp = temp + M(59, 61) * x(61)
      x(59) = x(59) - temp

      temp = M(58, 59) * x(59)
      temp = temp + M(58, 60) * x(60)
      temp = temp + M(58, 61) * x(61)
      x(58) = x(58) - temp

      temp = M(57, 58) * x(58)
      temp = temp + M(57, 59) * x(59)
      temp = temp + M(57, 60) * x(60)
      temp = temp + M(57, 61) * x(61)
      x(57) = x(57) - temp

      temp = M(56, 57) * x(57)
      temp = temp + M(56, 58) * x(58)
      temp = temp + M(56, 59) * x(59)
      temp = temp + M(56, 60) * x(60)
      temp = temp + M(56, 61) * x(61)
      x(56) = x(56) - temp

      temp = M(55, 56) * x(56)
      temp = temp + M(55, 57) * x(57)
      temp = temp + M(55, 58) * x(58)
      temp = temp + M(55, 59) * x(59)
      temp = temp + M(55, 60) * x(60)
      temp = temp + M(55, 61) * x(61)
      x(55) = x(55) - temp

      temp = M(54, 55) * x(55)
      temp = temp + M(54, 56) * x(56)
      temp = temp + M(54, 57) * x(57)
      temp = temp + M(54, 58) * x(58)
      temp = temp + M(54, 59) * x(59)
      temp = temp + M(54, 60) * x(60)
      temp = temp + M(54, 61) * x(61)
      x(54) = x(54) - temp

      temp = M(53, 54) * x(54)
      temp = temp + M(53, 55) * x(55)
      temp = temp + M(53, 57) * x(57)
      temp = temp + M(53, 58) * x(58)
      temp = temp + M(53, 59) * x(59)
      temp = temp + M(53, 60) * x(60)
      temp = temp + M(53, 61) * x(61)
      x(53) = x(53) - temp

      temp = M(52, 54) * x(54)
      temp = temp + M(52, 55) * x(55)
      temp = temp + M(52, 57) * x(57)
      temp = temp + M(52, 58) * x(58)
      temp = temp + M(52, 59) * x(59)
      temp = temp + M(52, 60) * x(60)
      temp = temp + M(52, 61) * x(61)
      x(52) = x(52) - temp

      temp = M(51, 54) * x(54)
      temp = temp + M(51, 55) * x(55)
      temp = temp + M(51, 57) * x(57)
      temp = temp + M(51, 58) * x(58)
      temp = temp + M(51, 59) * x(59)
      temp = temp + M(51, 60) * x(60)
      temp = temp + M(51, 61) * x(61)
      x(51) = x(51) - temp

      temp = M(50, 51) * x(51)
      temp = temp + M(50, 54) * x(54)
      temp = temp + M(50, 55) * x(55)
      temp = temp + M(50, 57) * x(57)
      temp = temp + M(50, 58) * x(58)
      temp = temp + M(50, 59) * x(59)
      temp = temp + M(50, 60) * x(60)
      temp = temp + M(50, 61) * x(61)
      x(50) = x(50) - temp

      temp = M(49, 51) * x(51)
      temp = temp + M(49, 54) * x(54)
      temp = temp + M(49, 55) * x(55)
      temp = temp + M(49, 57) * x(57)
      temp = temp + M(49, 58) * x(58)
      temp = temp + M(49, 59) * x(59)
      temp = temp + M(49, 60) * x(60)
      temp = temp + M(49, 61) * x(61)
      x(49) = x(49) - temp

      temp = M(48, 49) * x(49)
      temp = temp + M(48, 54) * x(54)
      temp = temp + M(48, 55) * x(55)
      temp = temp + M(48, 57) * x(57)
      temp = temp + M(48, 58) * x(58)
      temp = temp + M(48, 59) * x(59)
      temp = temp + M(48, 60) * x(60)
      x(48) = x(48) - temp

      temp = M(47, 49) * x(49)
      temp = temp + M(47, 51) * x(51)
      temp = temp + M(47, 54) * x(54)
      temp = temp + M(47, 55) * x(55)
      temp = temp + M(47, 57) * x(57)
      temp = temp + M(47, 58) * x(58)
      temp = temp + M(47, 59) * x(59)
      temp = temp + M(47, 60) * x(60)
      temp = temp + M(47, 61) * x(61)
      x(47) = x(47) - temp

      temp = M(46, 49) * x(49)
      temp = temp + M(46, 51) * x(51)
      temp = temp + M(46, 54) * x(54)
      temp = temp + M(46, 55) * x(55)
      temp = temp + M(46, 57) * x(57)
      temp = temp + M(46, 58) * x(58)
      temp = temp + M(46, 59) * x(59)
      temp = temp + M(46, 60) * x(60)
      temp = temp + M(46, 61) * x(61)
      x(46) = x(46) - temp

      temp = M(45, 46) * x(46)
      temp = temp + M(45, 49) * x(49)
      temp = temp + M(45, 51) * x(51)
      temp = temp + M(45, 54) * x(54)
      temp = temp + M(45, 55) * x(55)
      temp = temp + M(45, 57) * x(57)
      temp = temp + M(45, 58) * x(58)
      temp = temp + M(45, 59) * x(59)
      temp = temp + M(45, 60) * x(60)
      temp = temp + M(45, 61) * x(61)
      x(45) = x(45) - temp

      temp = M(44, 46) * x(46)
      temp = temp + M(44, 49) * x(49)
      temp = temp + M(44, 54) * x(54)
      temp = temp + M(44, 55) * x(55)
      temp = temp + M(44, 57) * x(57)
      temp = temp + M(44, 58) * x(58)
      temp = temp + M(44, 59) * x(59)
      temp = temp + M(44, 60) * x(60)
      temp = temp + M(44, 61) * x(61)
      x(44) = x(44) - temp

      temp = M(43, 46) * x(46)
      temp = temp + M(43, 49) * x(49)
      temp = temp + M(43, 54) * x(54)
      temp = temp + M(43, 55) * x(55)
      temp = temp + M(43, 58) * x(58)
      temp = temp + M(43, 59) * x(59)
      temp = temp + M(43, 60) * x(60)
      temp = temp + M(43, 61) * x(61)
      x(43) = x(43) - temp

      temp = M(42, 46) * x(46)
      temp = temp + M(42, 49) * x(49)
      temp = temp + M(42, 54) * x(54)
      temp = temp + M(42, 55) * x(55)
      temp = temp + M(42, 58) * x(58)
      temp = temp + M(42, 59) * x(59)
      temp = temp + M(42, 60) * x(60)
      temp = temp + M(42, 61) * x(61)
      x(42) = x(42) - temp

      temp = M(41, 46) * x(46)
      temp = temp + M(41, 49) * x(49)
      temp = temp + M(41, 54) * x(54)
      temp = temp + M(41, 55) * x(55)
      temp = temp + M(41, 58) * x(58)
      temp = temp + M(41, 59) * x(59)
      temp = temp + M(41, 60) * x(60)
      temp = temp + M(41, 61) * x(61)
      x(41) = x(41) - temp

      temp = M(40, 46) * x(46)
      temp = temp + M(40, 49) * x(49)
      temp = temp + M(40, 54) * x(54)
      temp = temp + M(40, 55) * x(55)
      temp = temp + M(40, 58) * x(58)
      temp = temp + M(40, 59) * x(59)
      temp = temp + M(40, 60) * x(60)
      temp = temp + M(40, 61) * x(61)
      x(40) = x(40) - temp

      temp = M(39, 49) * x(49)
      temp = temp + M(39, 54) * x(54)
      temp = temp + M(39, 55) * x(55)
      temp = temp + M(39, 59) * x(59)
      temp = temp + M(39, 60) * x(60)
      temp = temp + M(39, 61) * x(61)
      x(39) = x(39) - temp

      temp = M(38, 49) * x(49)
      temp = temp + M(38, 54) * x(54)
      temp = temp + M(38, 55) * x(55)
      temp = temp + M(38, 58) * x(58)
      temp = temp + M(38, 59) * x(59)
      temp = temp + M(38, 60) * x(60)
      temp = temp + M(38, 61) * x(61)
      x(38) = x(38) - temp

      temp = M(37, 49) * x(49)
      temp = temp + M(37, 54) * x(54)
      temp = temp + M(37, 55) * x(55)
      temp = temp + M(37, 58) * x(58)
      temp = temp + M(37, 59) * x(59)
      temp = temp + M(37, 60) * x(60)
      x(37) = x(37) - temp

      temp = M(36, 49) * x(49)
      temp = temp + M(36, 54) * x(54)
      temp = temp + M(36, 58) * x(58)
      temp = temp + M(36, 59) * x(59)
      temp = temp + M(36, 60) * x(60)
      x(36) = x(36) - temp

      temp = M(35, 49) * x(49)
      temp = temp + M(35, 54) * x(54)
      temp = temp + M(35, 58) * x(58)
      temp = temp + M(35, 59) * x(59)
      temp = temp + M(35, 60) * x(60)
      x(35) = x(35) - temp

      temp = M(34, 49) * x(49)
      temp = temp + M(34, 54) * x(54)
      temp = temp + M(34, 55) * x(55)
      temp = temp + M(34, 58) * x(58)
      temp = temp + M(34, 59) * x(59)
      temp = temp + M(34, 60) * x(60)
      temp = temp + M(34, 61) * x(61)
      x(34) = x(34) - temp

      temp = M(33, 49) * x(49)
      temp = temp + M(33, 54) * x(54)
      temp = temp + M(33, 55) * x(55)
      temp = temp + M(33, 58) * x(58)
      temp = temp + M(33, 59) * x(59)
      temp = temp + M(33, 60) * x(60)
      temp = temp + M(33, 61) * x(61)
      x(33) = x(33) - temp

      temp = M(32, 49) * x(49)
      temp = temp + M(32, 54) * x(54)
      temp = temp + M(32, 55) * x(55)
      temp = temp + M(32, 58) * x(58)
      temp = temp + M(32, 59) * x(59)
      temp = temp + M(32, 60) * x(60)
      temp = temp + M(32, 61) * x(61)
      x(32) = x(32) - temp

      temp = M(31, 49) * x(49)
      temp = temp + M(31, 54) * x(54)
      temp = temp + M(31, 58) * x(58)
      temp = temp + M(31, 59) * x(59)
      temp = temp + M(31, 60) * x(60)
      x(31) = x(31) - temp

      temp = M(30, 49) * x(49)
      temp = temp + M(30, 54) * x(54)
      temp = temp + M(30, 58) * x(58)
      temp = temp + M(30, 59) * x(59)
      temp = temp + M(30, 60) * x(60)
      x(30) = x(30) - temp

      temp = M(29, 54) * x(54)
      temp = temp + M(29, 55) * x(55)
      temp = temp + M(29, 58) * x(58)
      temp = temp + M(29, 59) * x(59)
      temp = temp + M(29, 61) * x(61)
      x(29) = x(29) - temp

      temp = M(28, 29) * x(29)
      temp = temp + M(28, 55) * x(55)
      temp = temp + M(28, 61) * x(61)
      x(28) = x(28) - temp

      temp = M(27, 54) * x(54)
      temp = temp + M(27, 60) * x(60)
      temp = temp + M(27, 61) * x(61)
      x(27) = x(27) - temp

      temp = M(26, 54) * x(54)
      temp = temp + M(26, 56) * x(56)
      temp = temp + M(26, 59) * x(59)
      temp = temp + M(26, 60) * x(60)
      x(26) = x(26) - temp

      temp = M(25, 54) * x(54)
      temp = temp + M(25, 59) * x(59)
      temp = temp + M(25, 60) * x(60)
      x(25) = x(25) - temp

      temp = M(24, 49) * x(49)
      temp = temp + M(24, 54) * x(54)
      temp = temp + M(24, 59) * x(59)
      x(24) = x(24) - temp

      temp = M(23, 29) * x(29)
      temp = temp + M(23, 54) * x(54)
      temp = temp + M(23, 55) * x(55)
      x(23) = x(23) - temp

      temp = M(22, 23) * x(23)
      temp = temp + M(22, 29) * x(29)
      temp = temp + M(22, 54) * x(54)
      temp = temp + M(22, 55) * x(55)
      x(22) = x(22) - temp

      temp = M(21, 29) * x(29)
      temp = temp + M(21, 54) * x(54)
      temp = temp + M(21, 55) * x(55)
      x(21) = x(21) - temp

      temp = M(20, 54) * x(54)
      temp = temp + M(20, 59) * x(59)
      temp = temp + M(20, 61) * x(61)
      x(20) = x(20) - temp

      temp = M(19, 29) * x(29)
      temp = temp + M(19, 54) * x(54)
      temp = temp + M(19, 55) * x(55)
      x(19) = x(19) - temp

      temp = M(18, 29) * x(29)
      temp = temp + M(18, 54) * x(54)
      temp = temp + M(18, 55) * x(55)
      x(18) = x(18) - temp

      temp = M(17, 29) * x(29)
      temp = temp + M(17, 54) * x(54)
      temp = temp + M(17, 55) * x(55)
      x(17) = x(17) - temp

      temp = M(16, 55) * x(55)
      temp = temp + M(16, 61) * x(61)
      x(16) = x(16) - temp

      temp = M(15, 54) * x(54)
      temp = temp + M(15, 55) * x(55)
      x(15) = x(15) - temp

      temp = M(14, 54) * x(54)
      temp = temp + M(14, 58) * x(58)
      x(14) = x(14) - temp

      temp = M(13, 57) * x(57)
      temp = temp + M(13, 61) * x(61)
      x(13) = x(13) - temp

      temp = M(12, 54) * x(54)
      temp = temp + M(12, 59) * x(59)
      x(12) = x(12) - temp

      temp = M(11, 29) * x(29)
      x(11) = x(11) - temp

      temp = M(10, 54) * x(54)
      x(10) = x(10) - temp

      temp = M(9, 54) * x(54)
      x(9) = x(9) - temp

      temp = M(8, 54) * x(54)
      x(8) = x(8) - temp

      temp = M(7, 54) * x(54)
      x(7) = x(7) - temp

      temp = M(6, 54) * x(54)
      x(6) = x(6) - temp

      temp = M(5, 54) * x(54)
      x(5) = x(5) - temp

      temp = M(4, 54) * x(54)
      x(4) = x(4) - temp

      temp = M(3, 54) * x(54)
      x(3) = x(3) - temp


      END
