C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      subroutine kinetic(rk,temp,xlw,Press)
      
C------------------------------------------------------------------------
C     
C     -- DESCRIPTION
C     
C     This routine computes the kinetic rates for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: RADM                
C     Species: _ciRADM             
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     TEMP: temperature ([K]).
C     XLW: water massic fraction.
C     PRESS: pressure ([Pa]).
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     RK: kinetic rates.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     SPACK.
C     
C------------------------------------------------------------------------
      
      implicit none
      
C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of chemical arrays.
C     COMUSE: flags and parameters for numerics.
      
      include 'PARACHEM.INC' 
      include 'COMUSE.INC' 
      INCLUDE 'PARADOM.INC'  
      
      double precision rk(nr),temp,xlw,Press
      double precision Effko,Rapk,facteur,SumM
      double precision YlH2O
      
C     Compute third body.
C     Conversion = Avogadro*1d-6/Perfect gas constant.
C     PRESS in Pascal, SUMM in molecules/cm3, TEMP in Kelvin
      
      SumM = Press * 7.243D16 / temp
      
C     Number of water molecules computed from the massic fraction
C     (absolute humidity)
      
      YlH2O = 29.d0*SumM*xlw/(18.d0+11.d0*xlw)
      
C------------------------------------------------------------------------
C     1 - Photolytic reactions.

C     Photolysis rates are not read.

      If(.NOT.LREAD_PHOTOLYSIS) then
         rk(  1) =  0.7720000000000000D-02
         rk(  2) =  0.1700000000000000D-04
         rk(  3) =  0.4220000000000000D-03
         rk(  4) =  0.1390000000000000D-02
         rk(  5) =  0.2750000000000000D-06
         rk(  6) =  0.4580000000000000D-05
         rk(  7) =  0.2020000000000000D-01
         rk(  8) =  0.1640000000000000D+00
         rk(  9) =  0.5670000000000000D-05
         rk( 10) =  0.3320000000000000D-04
         rk( 11) =  0.2180000000000000D-04
         rk( 12) =  0.3550000000000000D-05
         rk( 13) =  0.5570000000000000D-05
         rk( 14) =  0.5570000000000000D-05
         rk( 15) =  0.1590000000000000D-05
         rk( 16) =  0.6070000000000000D-06
         rk( 17) =  0.4980000000000000D-04
         rk( 18) =  0.5170000000000000D-04
         rk( 19) =  0.1440000000000000D-03
         rk( 20) =  0.4300000000000000D-03
         rk( 21) =  0.7950000000000000D-06
      ENDIF

C------------------------------------------------------------------------
C     2 - Thermal reactions.

      rk( 22) =  DEXP(-0.2575921893902696D+02
     &     - ( -0.1200000000000000D+03 )/temp)
      rk( 23) =  DEXP(-0.2474064935803238D+02
     &     - ( -0.1100000000000000D+03 )/temp)
      rk( 23) = rk( 23) * SumM * 0.8d0
      rk( 24) =  DEXP(-0.2416528521312882D+02
     &     - ( -0.7000000000000000D+02 )/temp)
      rk( 24) = rk( 24) * SumM * 0.2d0
      rk( 25) =  0.2200000000000000D-09
      rk( 25) = rk( 25) * YlH2O
      rk( 26) =  DEXP(-0.2693787393536860D+02
     &     - (  0.1400000000000000D+04 )/temp)
      rk( 27) =  DEXP(-0.2716101748668281D+02
     &     - (  0.9400000000000000D+03 )/temp)
      rk( 28) =  DEXP(-0.3214088112211231D+02
     &     - (  0.5000000000000000D+03 )/temp)
      rk( 29) =  DEXP(-0.2632268829627837D+02
     &     - ( -0.2400000000000000D+03 )/temp)
      rk( 30) =  DEXP(-0.2643709864745611D+02
     &     - (  0.2000000000000000D+03 )/temp)
      rk( 31) =  DEXP(-0.8860689615829534D+02
     &     - ( -0.5300000000000000D+03 )/temp)
      rk( 31) = rk( 31) * SumM * 0.2d0
      rk( 32) =  DEXP(-0.2959713397230138D+02
     &     - (  0.2500000000000000D+04 )/temp)
      rk( 33) =  DEXP(-0.2479780777187233D+02
     &     - ( -0.1500000000000000D+03 )/temp)
      rk( 34) =  DEXP(-0.3131990057004248D+02
     &     - (  0.1230000000000000D+04 )/temp)
      rk( 35) =  0.2500000000000000D-11
      rk( 36) =  0.2000000000000000D-20
      rk( 36) = rk( 36) * YlH2O
      rk( 37) =  DEXP(-0.2736865685146106D+02
     &     - ( -0.3800000000000000D+03 )/temp)
      rk( 38) =  DEXP(-0.2380237971943945D+02
     &     - ( -0.2300000000000000D+03 )/temp)
      rk( 39) =  DEXP(-0.3950779001431612D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     -  0.1280000000000000D+04/temp)
      rk( 40) =  DEXP(-0.3882913584105874D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     -  0.4440000000000000D+03/temp)
      rk( 41) =  DEXP(-0.2486470200670236D+02
     &     - (  0.5400000000000000D+03 )/temp)
      rk( 42) =  DEXP(-0.2478031461442481D+02
     &     - (  0.3800000000000000D+03 )/temp)
      rk( 43) =  DEXP(-0.2403645234128585D+02
     &     - (  0.3800000000000000D+03 )/temp)
      rk( 44) =  DEXP(-0.2686555327378898D+02
     &     - ( -0.4110000000000000D+03 )/temp)
      rk( 45) =  DEXP(-0.2595954781257500D+02
     &     - ( -0.5040000000000000D+03 )/temp)
      rk( 46) =  DEXP(-0.2526077737446069D+02
     &     - ( -0.5490000000000000D+03 )/temp)
      rk( 47) =  DEXP(-0.2688908377119917D+02
     &     - ( -0.3220000000000000D+03 )/temp)
      rk( 48) =  DEXP(-0.2469185919386295D+02
     &     - ( -0.1160000000000000D+03 )/temp)
      rk( 49) =  0.4000000000000000D-10
      rk( 50) =  0.9000000000000000D-11
      rk( 51) =  DEXP(-0.2570385700969429D+02
     &     - ( -0.2560000000000000D+03 )/temp)
      rk( 52) =  DEXP(-0.2514611446614055D+02
     &     - (  0.7450000000000000D+03 )/temp)
      rk( 53) =  0.1150000000000000D-10
      rk( 54) =  0.1700000000000000D-10
      rk( 55) =  0.2800000000000000D-10
      rk( 56) =  0.9999999999999999D-11
      rk( 57) =  0.9999999999999999D-11
      rk( 58) =  0.9999999999999999D-11
      rk( 59) =  DEXP(-0.3952228302161869D+02
     &     + ( 0.2000000000000000D+01 * DLOG(temp))
     &     -  0.4440000000000000D+03/temp)
      rk( 60) =  DEXP(-0.2489018109200335D+02
     &     - (  0.5400000000000000D+03 )/temp)
      rk( 61) =  DEXP(-0.2439234266376417D+02
     &     - ( -0.4090000000000000D+03 )/temp)
      rk( 62) =  DEXP(-0.2660140169874739D+02
     &     - ( -0.1810000000000000D+03 )/temp)
      rk( 63) =  DEXP( 0.3750919086048039D+02
     &     - (  0.1354300000000000D+05 )/temp)
      rk( 64) =  0.4700000000000000D-11
      rk( 65) =  DEXP( 0.3750919086048039D+02
     &     - (  0.1354300000000000D+05 )/temp)
      rk( 66) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 67) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 68) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 69) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 70) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 71) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 72) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 73) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 74) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 75) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 76) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 77) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 78) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 79) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk( 80) =  DEXP(-0.2814184673969454D+02
     &     - (  0.2058000000000000D+04 )/temp)
      rk( 81) =  DEXP(-0.2729454887930734D+02
     &     - (  0.1900000000000000D+04 )/temp)
      rk( 82) =  DEXP(-0.2814184673969454D+02
     &     - (  0.2058000000000000D+04 )/temp)
      rk( 83) =  DEXP(-0.2729454887930734D+02
     &     - (  0.1900000000000000D+04 )/temp)
      rk( 84) =  DEXP(-0.2729454887930734D+02
     &     - (  0.1900000000000000D+04 )/temp)
      rk( 85) =  0.2200000000000000D-10
      rk( 86) =  DEXP(-0.2693787393536860D+02
     &     - (  0.2923000000000000D+04 )/temp)
      rk( 87) =  DEXP(-0.2532843602293450D+02
     &     - (  0.1895000000000000D+04 )/temp)
      rk( 88) =  DEXP(-0.2415595388569994D+02
     &     - (  0.9750000000000000D+03 )/temp)
      rk( 89) =  0.5810000000000000D-12
      rk( 90) =  DEXP(-0.3205386974512268D+02
     &     - (  0.2633000000000000D+04 )/temp)
      rk( 91) =  DEXP(-0.3195855956531836D+02
     &     - (  0.2105000000000000D+04 )/temp)
      rk( 92) =  DEXP(-0.3255227284889012D+02
     &     - (  0.1136000000000000D+04 )/temp)
      rk( 93) =  DEXP(-0.3202917713253231D+02
     &     - (  0.2013000000000000D+04 )/temp)
      rk( 94) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk( 95) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk( 96) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk( 97) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk( 98) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk( 99) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(100) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(101) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(102) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(103) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(104) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(105) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(106) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(107) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(108) =  DEXP(-0.2929175232275020D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(109) =  DEXP(-0.2959713397230138D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(110) =  DEXP(-0.3080110677662732D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(111) =  DEXP(-0.3101241587029453D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(112) =  DEXP(-0.3117148056492421D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(113) =  DEXP(-0.2959713397230138D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(114) =  DEXP(-0.2959713397230138D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(115) =  DEXP(-0.3170556305085447D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(116) =  DEXP(-0.3170556305085447D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(117) =  DEXP(-0.2767184311044880D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(118) =  DEXP(-0.3170556305085447D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(119) =  DEXP(-0.3170556305085447D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(120) =  DEXP(-0.2767184311044880D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(121) =  DEXP(-0.3170556305085447D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(122) =  DEXP(-0.2870983077730048D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(123) =  DEXP(-0.2993360620892259D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(124) =  DEXP(-0.3010795959606737D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(125) =  DEXP(-0.3026211027589463D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(126) =  DEXP(-0.2870983077730048D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(127) =  DEXP(-0.2870983077730048D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(128) =  DEXP(-0.3080110677662732D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(129) =  DEXP(-0.3080110677662732D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(130) =  DEXP(-0.2745706780880511D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(131) =  DEXP(-0.3080110677662732D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(132) =  DEXP(-0.3080110677662732D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(133) =  DEXP(-0.2745706780880511D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(134) =  DEXP(-0.3080110677662732D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(135) =  DEXP(-0.3556042764244267D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(136) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(137) =  DEXP(-0.3170556305085447D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(138) =  DEXP(-0.3080110677662732D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(139) =  DEXP(-0.3556042764244267D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(140) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk(141) =  DEXP(-0.2619593659063922D+02
     &     - ( -0.1800000000000000D+03 )/temp)
      rk(142) =  DEXP(-0.3019497097305700D+02
     &     - ( -0.1300000000000000D+04 )/temp)
      rk(143) =  DEXP(-0.3170556305085447D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(144) =  DEXP(-0.3080110677662732D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      rk(145) =  DEXP(-0.3556042764244267D+02
     &     - ( -0.2200000000000000D+03 )/temp)
      
C------------------------------------------------------------------------
C     3 - TROE/Fall-off reactions.
      
      Effko =  0.1800000000000000D-30* (temp / 3.d2)
     &     **(- ( 0.3200000000000000D+01))
      Rapk =  0.4700000000000000D-11* (temp / 3.d2)
     &     **(- ( 0.1400000000000000D+01))
      rk(146) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.6000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      Effko =  0.7000000000000000D-30* (temp / 3.d2)
     &     **(- ( 0.2600000000000000D+01))
      Rapk =  0.1500000000000000D-10* (temp / 3.d2)
     &     **(- ( 0.5000000000000000D+00))
      rk(147) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.6000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      Effko =  0.2200000000000000D-29* (temp / 3.d2)
     &     **(- ( 0.4300000000000000D+01))
      Rapk =  0.1500000000000000D-11* (temp / 3.d2)
     &     **(- ( 0.5000000000000000D+00))
      rk(148) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.6000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      Effko =  0.2600000000000000D-29* (temp / 3.d2)
     &     **(- ( 0.3200000000000000D+01))
      Rapk =  0.2400000000000000D-10* (temp / 3.d2)
     &     **(- ( 0.1300000000000000D+01))
      rk(149) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.6000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      Effko =  0.3000000000000000D-30* (temp / 3.d2)
     &     **(- ( 0.3300000000000000D+01))
      Rapk =  0.1500000000000000D-11* (temp / 3.d2)
     &     **(- ( 0.0000000000000000D+00))
      rk(150) = (Effko * SumM / 
     &     ( 1.0d0 + Effko * SumM / Rapk)) *
     &     0.6000D+00** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk(151) =  DEXP( 0.6142746008608852D+02
     &     - (  0.1090000000000000D+05 )/temp)
      Effko =  0.1800000000000000D-30* (temp / 3.d2)
     &     **(- ( 0.3200000000000000D+01))
      Rapk =  0.4700000000000000D-11* (temp / 3.d2)
     &     **(- ( 0.1400000000000000D+01))
      facteur = (Effko * SumM / ( 1.0d0 + Effko * SumM / 
     &     Rapk)) * 0.6d0 ** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk(151) = facteur * rk(151)
      rk(152) =  DEXP( 0.6207438732603458D+02
     &     - (  0.1120000000000000D+05 )/temp)
      Effko =  0.2200000000000000D-29* (temp / 3.d2)
     &     **(- ( 0.4300000000000000D+01))
      Rapk =  0.1500000000000000D-11* (temp / 3.d2)
     &     **(- ( 0.5000000000000000D+00))
      facteur = (Effko * SumM / ( 1.0d0 + Effko * SumM / 
     &     Rapk)) * 0.6d0 ** (1.0d0 / (1.0d0 + 
     &     (dlog10(Effko * SumM / Rapk))**2))
      rk(152) = facteur * rk(152)
      rk(153) = SumM * 6.0d-34 * (temp/3.d2) ** (-2.3d0)
      rk(153) = rk(153) * SumM * 0.2d0
      rk(154) = 2.3d-13 * dexp(600.0d0 / temp)
     &     + 1.73d-33* SumM * dexp(1000.0d0 / temp)
      rk(155) = 3.22d-34 * dexp(2800.0d0 / temp) + 
     &     2.38d-54 * SumM * dexp(3200.0d0 / temp)
      rk(155) = rk(155) * YlH2O
      Effko = 7.2d-15 * dexp(785.0d0 / temp)
      Rapk = 4.1d-16 * dexp(1440.0d0 / temp)
      facteur =1.9d-33 * dexp(725.0d0 / temp) * SumM
      rk(156) = Effko + facteur/(1.0d0 + facteur / Rapk)
      rk(157) = 1.5d-13 * (1.0d0 + 2.439d-20 * SumM)
      
      RETURN
      END
      
