C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE DIFF_X(ts,tf,ZC)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves diffusion along X for one timestep.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     TS: initial time.
C     TF: final time.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     ZC: 3D field of concentrations.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------
      
      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     COMKDIFX: global variables for diffusion along X.

      INCLUDE 'PARADOM.INC' 
      INCLUDE 'COMKDIFX.INC' 

      DOUBLE PRECISION ZC(NX,NY,NZ),ZCx(NX),Zkx(Nx)
      DOUBLE PRECISION ts,tf
      INTEGER Ji,Jj,Jk


      IF (Nx.NE.1) Then

         LITERDIFFX=.TRUE.

         DO Jk=1,NZ
            DO Jj=1,Ny

               DO Ji=1,Nx
                  ZCx(Ji)=ZC(Ji,Jj,Jk)
                  Zkx(Ji)=Dkx(Ji,Jj)
               ENDDO

               CALL rosdiff_x (Zkx,ZCx,ts,tf)

               LITERDIFFX=.FALSE.

               DO Ji=1,Nx
                  ZC(Ji,Jj,Jk)=ZCx(Ji)
               ENDDO

            ENDDO
         ENDDO

      ENDIF

      END
