C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE DIFF_Y (DLtstart,DLtend,C)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves diffusion along Y for one timestep.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     DLTSTART: initial time.
C     DLTEND: final time.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     C: 3D field of concentrations.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     COMKDIFY: global variables for diffusion along Y.

      INCLUDE 'PARADOM.INC'
      INCLUDE 'COMKDIFY.INC'

      DOUBLE PRECISION C(NX,NY,NZ),ZCy(NY),Zky(NY)
      DOUBLE PRECISION DLtstart,DLtend
      INTEGER i,j,k
      

C     DQ : 1D

      IF (NY.NE.1) THEN 

         LITERDIFFY=.TRUE.

         DO k=1,NZ
            DO i=1,NX

               DO j=1,NY
                  ZCy(j)=C(i,j,k)
                  Zky(j)=Dky(i,j)
               ENDDO

               CALL rosdiff_y (Zky,ZCy,DLtstart,DLtend)

               LITERDIFFY=.FALSE.

               DO j=1,Ny
                  C(i,j,k)=ZCy(j)
               ENDDO

            ENDDO
         ENDDO

      ENDIF

      END
