C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE DIFF_Z (ts,tf,Rkz,Cdep,Cemis,
     s     Rkzf,Cdepf,Cemisf,C)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves diffusion along Z for one timestep.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     TS: initial time.
C     TF: final time.
C     RKZ: 3D Kz field at initial time.
C     CDEP: 2D deposition velocities.
C     CEMIS: .
C     RKZF: 3D Kz field at final time.
C     CDEPF: .
C     CEMISF: .
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     C: 3D field of concentrations.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     COMDOM: global variables for mesh.

      INCLUDE 'PARADOM.INC'
      INCLUDE 'COMDOM.INC'

      DOUBLE PRECISION C(NX,NY,NZ),ZCz(NZ)
      DOUBLE PRECISION Rkz(NX,NY,NZ+1),Rkzf(NX,NY,NZ+1)
      DOUBLE PRECISION Cdep(Nx,Ny),Cdepf(Nx,Ny)
      DOUBLE PRECISION Cemis(Nx,Ny),Cemisf(Nx,Ny)

      DOUBLE PRECISION Zdm(Nz)
      DOUBLE PRECISION Zdc(Nz)
      DOUBLE PRECISION Dkz(Nz+1),Dkzf(Nz+1)
      DOUBLE PRECISION Dcdep,Dcdepf
      DOUBLE PRECISION Dcemis,Dcemisf
      DOUBLE PRECISION ts,tf

      INTEGER Ji,Jj,Jk
      

      DO Jj=1,NY
         DO Ji=1,NX

            DO Jk=1,NZ
               ZCz(Jk)=C(Ji,Jj,Jk)
            ENDDO

            DO Jk=1,NZ+1
               Dkz(Jk)=Rkz(Ji,Jj,Jk)
               Dkzf(Jk)=Rkzf(Ji,Jj,Jk)
            ENDDO

            Dcdep=Cdep(Ji,Jj)
            Dcdepf=Cdepf(Ji,Jj)
            Dcemis=Cemis(Ji,Jj)
            Dcemisf=Cemisf(Ji,Jj)

            DO Jk=1,Nz
               Zdm(Jk)=Dmz(Ji,Jj,Jk)
               Zdc(Jk)=Dcz(Ji,Jj,Jk)
            ENDDO

            CALL rosdiff_z (ZCz,ts,tf,Dkz,Dkzf,Zdm,Zdc,
     s           Dcdep,Dcemis,Dcdepf,Dcemisf)

            DO Jk=1,NZ
               C(Ji,Jj,Jk)=ZCz(Jk)
            ENDDO

         ENDDO
      ENDDO

      END
