C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE FEXDIFF_X(DLconc,DLkx,DLr)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes div(K_x \partial_x c) with a three point
C     scheme.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     DLCONC: array of chemical concentrations along X.
C     DLKX: array of K_x (diffusion coefficient) along X.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     DLR: div(K_x \partial_x c).
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Denis Qulo, Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE 

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     COMDOM: global variables for mesh.

      INCLUDE 'PARADOM.INC'
      INCLUDE 'COMDOM.INC'

      INTEGER Jk
      DOUBLE PRECISION DLconc(Nx), DLr(Nx),DLkx(Nx)
      DOUBLE PRECISION DPLUS,DMOINS

      DO Jk=1,Nx

         IF (Jk.EQ.1) THEN      ! Boundary condition (left).
            DMOINS=0.D0
         ELSE
            DMOINS=DLkx(Jk)*(DLconc(Jk)-DLconc(Jk-1))/Dcx(Jk)
         ENDIF

         IF (Jk.EQ.Nx) THEN     ! Boundary condition (right).
            DPLUS=0.D0
         ELSE
            DPLUS=DLkx(Jk+1)*(DLconc(Jk+1)-DLconc(Jk))/Dcx(Jk+1)
         ENDIF

         DLr(Jk)=(DPLUS-DMOINS)/Dmx(Jk)

      ENDDO

      END
