C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE FEXDIFF_Z (DLconc,DLr,DLk,Zdm,Zdc,Dcdep,Dcemis)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes div(K_z \partial_z c) with a three point
C     scheme.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     DLCONC: array of chemical concentrations along Z.
C     DLK: array of K_z (diffusion coefficient) along Z.
C     ZDM: array of distances between cell interfaces along Z.
C     ZDC: array of distances between nodes along Z.
C     DCDEP: deposition velocity.
C     DCEMIS: surfacic emission.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     DLR: div(K_z \partial_z c).
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Denis Qulo, Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE 

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.

      INCLUDE 'PARADOM.INC'

      INTEGER Jk
      DOUBLE PRECISION DLconc(Nz), DLr(Nz)
      DOUBLE PRECISION Zdm(Nz)
      DOUBLE PRECISION Zdc(Nz)
      DOUBLE PRECISION DPLUS,DMOINS
      DOUBLE PRECISION DLk(Nz+1)
      DOUBLE PRECISION Dcdep,Dcemis
      
      DO Jk=1,Nz

         IF (Jk.EQ.1) THEN      ! Boundary condition (ground).
            DMOINS=Dcdep*DLconc(Jk)-Dcemis
         ELSE
            DMOINS=DLk(Jk)*(DLconc(Jk)-DLconc(Jk-1))/Zdc(Jk)
         ENDIF
         
         IF (Jk.EQ.Nz) THEN     ! Boundary condition (top).
            DPLUS=0.D0
         ELSE
            DPLUS=DLk(Jk+1)*(DLconc(Jk+1)-DLconc(Jk))/Zdc(Jk+1)
         ENDIF
         
         DLr(Jk)=(DPLUS-DMOINS)/Zdm(Jk)

      ENDDO

      END
