C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE jacddiffdc_x(DLkx)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes the jacobian matrix of the diffusion
C     scheme.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     DLKX: array of K_x (diffusion coefficient) along X.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C     The jacobian matrix is a tridiagonal matrix. This routine
C     computes the three diagonals DLDXL (low), DLDX (main diagonal)
C     and DLDXU (up).
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Denis Qulo, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     COMKDIFX: global variables for diffusion along X.
C     COMDOM: global variables for mesh.

      INCLUDE 'PARADOM.INC'
      INCLUDE 'COMKDIFX.INC'
      INCLUDE 'COMDOM.INC'

      DOUBLE PRECISION DLkx(Nx)
      INTEGER Ji
      

      IF (Nx.NE.1) THEN

         DO Ji = 1,Nx

            IF (Ji.EQ.1) THEN  
               DLdxu(Ji)=DLkx(Ji+1)/Dcx(Ji+1)/Dmx(Ji)
               DLdx(Ji)=-DLdxu(Ji)

            ELSE IF (Ji.EQ.Nx) THEN  
               DLdxl(Ji-1)=DLkx(Ji)/Dcx(Ji)/Dmx(Ji)
               DLdx(Ji)=-DLdxl(Ji-1)

            ELSE
               DLdxl(Ji-1)=DLkx(Ji)/Dcx(Ji)/Dmx(Ji)
               DLdxu(Ji)=DLkx(Ji+1)/Dcx(Ji+1)/Dmx(Ji)
               DLdx(Ji)=-(DLdxl(Ji-1)+DLdxu(Ji))

            ENDIF

         ENDDO
         
      ELSE
         DLdx(1)=0.D0

      ENDIF

      END
