C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE jacddiffdc_y(DLky)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes the jacobian matrix of the diffusion
C     scheme.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     DLKY: array of K_y (diffusion coefficient) along Y.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C     The jacobian matrix is a tridiagonal matrix. This routine
C     computes the three diagonals DLDYL (low), DLDY (main diagonal)
C     and DLDYU (up).
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Denis Qulo, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     COMKDIFY: global variables for diffusion along Y.
C     COMDOM: global variables for mesh.

      INCLUDE 'PARADOM.INC'
      INCLUDE 'COMKDIFY.INC'
      INCLUDE 'COMDOM.INC'

      DOUBLE PRECISION DLky(Ny)
      INTEGER Ji
      

      IF (Ny.NE.1) THEN

         DO Ji = 1,Ny

            IF (Ji.EQ.1) THEN  
               DLdyu(Ji)=DLky(Ji+1)/Dcy(Ji+1)/Dmy(Ji)
               DLdy(Ji)=-DLdyu(Ji)

            ELSE IF (Ji.EQ.Ny) THEN  
               DLdyl(Ji-1)=DLky(Ji)/Dcy(Ji)/Dmy(Ji)
               DLdy(Ji)=-DLdyl(Ji-1)

            ELSE
               DLdyl(Ji-1)=DLky(Ji)/Dcy(Ji)/Dmy(Ji)
               DLdyu(Ji)=DLky(Ji+1)/Dcy(Ji+1)/Dmy(Ji)
               DLdy(Ji)=-(DLdyl(Ji-1)+DLdyu(Ji))

            ENDIF

         ENDDO
         
      ELSE
         DLdy(1)=0.D0

      ENDIF

      END
