C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE jacddiffdc_z (DLdz,DLdzu,DLdzl,DLk,Zdm,Zdc,Dcdep)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes the jacobian matrix of the diffusion
C     scheme.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     DLK: array of K_z (diffusion coefficient) along Z.
C     ZDM: array of distances between cell interfaces along Z.
C     ZDC: array of distances between nodes along Z.
C     DCDEP: deposition velocity.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     DLDZ: main diagonal elements of the jacobian matrix.
C     DLDZU: super-diagonal elements of the jacobian matrix.
C     DLDZL: sub-diagonal elements of the jacobian matrix.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C     The jacobian matrix is a tridiagonal matrix. This routine
C     computes the three diagonals DLDZL (low), DLDZ (main diagonal)
C     and DLDZU (up).
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Denis Qulo, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.

      INCLUDE 'PARADOM.INC'

      INTEGER Ji
      DOUBLE PRECISION DLdz(Nz)
      DOUBLE PRECISION DLdzu(Nz)
      DOUBLE PRECISION DLdzl(Nz)
      DOUBLE PRECISION Zdm(Nz)
      DOUBLE PRECISION Zdc(Nz)
      DOUBLE PRECISION DLk(Nz+1)
      DOUBLE PRECISION Dcdep
      

      IF (Nz.NE.1) THEN

         DO Ji = 1,Nz

            IF (Ji.EQ.1) THEN
               DLdzu(Ji)=DLk(Ji+1)/Zdc(Ji+1)/Zdm(Ji)
               DLdz(Ji)=-DLdzu(Ji)-Dcdep/Zdm(Ji)

            ELSE IF (Ji.EQ.Nz) THEN
               DLdzl(Ji-1)=DLk(Ji)/Zdc(Ji)/Zdm(Ji)
               DLdz(Ji)=-DLdzl(Ji-1)

            ELSE
               DLdzl(Ji-1)=DLk(Ji)/Zdc(Ji)/Zdm(Ji)
               DLdzu(Ji)=DLk(Ji+1)/Zdc(Ji+1)/Zdm(Ji)
               DLdz(Ji)=-(DLdzl(Ji-1)+DLdzu(Ji))

            ENDIF

         ENDDO
         
      ELSE
         DLdz(1)=-Dcdep/Zdm(1)

      ENDIF

      END
