C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE kdiffh

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine initializes the horizontal diffusion coefficient.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     DKx: 2D field of diffusion coefficient along x.
C     DKy: 2D field of diffusion coefficient along y.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     CONST: constants.
C     PARADOM: parameters for all forced fields.
C     COMDOM: global variables for mesh.
C     COMUSE: flags and parameters for numerics. 
C     COMKDIFX: global variables for diffusion along X.
C     COMKDIFY: global variables for diffusion along Y.

      INCLUDE 'CONST.INC'
      INCLUDE 'PARADOM.INC'
      INCLUDE 'COMDOM.INC'
      INCLUDE 'COMUSE.INC'
      INCLUDE 'COMKDIFX.INC'
      INCLUDE 'COMKDIFY.INC'

      INTEGER Ji,Jj

      IF(CGRILLE.EQ.'LALON')THEN

         DO Jj=1,NY
            DO Ji=1,NX
               DKx(Ji,Jj)=KH/(1.D0-(Dyy(Ji,Jj,1)/Ray)**2)
            ENDDO
         ENDDO

         DO Jj=1,NY
            DO Ji=1,NX
               DKy(Ji,Jj)=KH*(1.D0-(Dyy(Ji,Jj,1)/Ray)**2)
            ENDDO
         ENDDO

      ELSEIF(CGRILLE.EQ.'LCART')THEN

         DO Jj=1,NY
            DO Ji=1,NX
               DKx(Ji,Jj)=KH
            ENDDO
         ENDDO

         DO Jj=1,NY
            DO Ji=1,NX
               DKy(Ji,Jj)=KH
            ENDDO
         ENDDO

      ENDIF

      END
