C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE ustar (DLRich,modwind,DLzr,DLz0,DLz0t,DLustar)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This function describes the effect of wind stability. 
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     DLRICH: Richardson number
C     MODWIND: Wind module ([m/s])
C     DLZR: ([m])
C     DLZ0: dynamical rugosity ([m])
C     DLZ0t: thermal rugosity ([m])
C     
C     -- OUTPUT VARIABLES
C     
C     DLustar: friction velocity ([m/s])
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C     Parameterization used in this subroutine is presented in
C     " Paramtrisation de la vitesse de dpt sec dans
C     un code de transport diffusion de polluants " (A. Boudrot and
C     L. Musson Genon, Tech. Report CEREVE 2001 )
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C     2001/01/06, by A. BOUDROT, change to DOUBLE PRECISION
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Luc Muson-Genon, CEREA.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     CONST: constants.

      INCLUDE 'CONST.INC'

C     Constants of J.F. LOUIS's formulas.
      DOUBLE PRECISION DPb,DLc,DPd,DPc1
      PARAMETER (DPb=5.d0,DPc1=DPb,DPd=DPb)      

      DOUBLE PRECISION DLRich,DLzr,DLz0,DLz0t,DLzsz0t
      DOUBLE PRECISION DLrii
      DOUBLE PRECISION DLfd,DLau0,DLau0t
      DOUBLE PRECISION modwind,DLustar
      
C------------------------------------------------------------------------
C     0. Setup

      DLzsz0t=(DLzr+DLz0t)/DLz0t

      DLau0 = PKa / DLOG( (DLzr+DLz0)/DLz0 )
      DLau0t = PKa / DLOG( DLzsz0t )

      DLc=DPc1*dsqrt(1.d0-1.d0/DLzsz0t)*((DLzsz0t**1.5d0-1.d0)**1.5D0)
      DLrii=dabs(DLRich)

C------------------------------------------------------------------------
C     1. Dynamical stability function

      IF(DLRich.LE.0.D0)THEN
         DLfd=1.d0+2.d0*DPb*DLrii
     &        /(1.d0+3.d0*DPb*DLc*DLau0*DLau0t*DLrii**.5d0)
      ELSE
         DLfd=1.d0/(1.d0+2.d0*DPb*DLrii/(1.d0+DPd*DLrii)**.5d0)
      ENDIF

C------------------------------------------------------------------------
C     2. Friction velocity

      DLustar=DLau0*modwind*DSQRT(DLfd)
      
      END
