C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE  CTM

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes chemical concentration for all timesteps.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMUSE: flags and parameters for numerics. 
C     COMDATA: data on forced fields.

      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMUSE.INC'
      INCLUDE 'COMDATA.INC'

      DOUBLE PRECISION Ui(NX+1,NY,NZ),Uf(NX+1,NY,NZ)
      DOUBLE PRECISION Vi(NX,NY+1,NZ),Vf(NX,NY+1,NZ)
      DOUBLE PRECISION Wi(NX,NY,NZ+1),Wf(NX,NY,NZ+1)
      DOUBLE PRECISION DRkz(NX,NY,NZ+1),DRkzf(NX,NY,NZ+1)
      DOUBLE PRECISION DLtemp(NXt,NYt,NZt),DLtempf(NXt,NYt,NZt)
      DOUBLE PRECISION DLrain(NXr,NYr),DLrainf(NXr,NYr)
      DOUBLE PRECISION DLhcloud(NXr,NYr),DLhcloudf(NXr,NYr)
      DOUBLE PRECISION DLattenuation(NXatt,NYatt,NZatt)
      DOUBLE PRECISION DLattenuationf(NXatt,NYatt,NZatt)
      DOUBLE PRECISION DLhumid(NXh,NYh,NZh),DLhumidf(NXh,NYh,NZh)
      DOUBLE PRECISION DLpress(NXp,NYp,NZp),DLpressf(NXp,NYp,NZp)
      DOUBLE PRECISION DLtempsurf(NXdd,NYdd),DLtempsurff(NXdd,NYdd)
      DOUBLE PRECISION DLpresurf(NXdd,NYdd),DLpresurff(NXdd,NYdd)
      DOUBLE PRECISION DLsnow(NXdd,NYdd),DLsnowf(NXdd,NYdd)
      DOUBLE PRECISION DLraysoli(NXdd,NYdd),DLraysolif(NXdd,NYdd)
      DOUBLE PRECISION DLlhflux(NXdd,NYdd),DLlhfluxf(NXdd,NYdd)
      DOUBLE PRECISION DLswat(NXdd,NYdd,Nlayer)
      DOUBLE PRECISION DLswatf(NXdd,NYdd,Nlayer)
      DOUBLE PRECISION DLmodwind(NXdd,NYdd),DLmodwindf(NXdd,NYdd)

      DOUBLE PRECISION DLCforc2d(Nxf,Nyf,NESPF)
      DOUBLE PRECISION DLCforc2df(Nxf,Nyf,NESPF)
      DOUBLE PRECISION DLCsourc(Nx,Ny,Nzs,Nsrc)
      DOUBLE PRECISION DLCsourcf(Nx,Ny,Nzs,Nsrc)
      DOUBLE PRECISION DLCemis(Nx,Ny,Nemi),DLCemisf(Nx,Ny,Nemi)
      DOUBLE PRECISION DLVdep(Nxdd,Nydd,Ndep),DLVdepf(Nxdd,Nydd,Ndep)
      DOUBLE PRECISION DLscavg(NXr,NYr,NZ,Nscav)
      DOUBLE PRECISION DLscavgf(NXr,NYr,NZ,Nscav)

      DOUBLE PRECISION DLCclx(2,Nyl,Nzl,Nspcl)
      DOUBLE PRECISION DLCclxf(2,Nyl,Nzl,Nspcl)

      DOUBLE PRECISION DLCcly(Nxl,2,Nzl,Nspcl)
      DOUBLE PRECISION DLCclyf(Nxl,2,Nzl,Nspcl)

      DOUBLE PRECISION DLCclz(Nxl,Nyl,Nspcl)
      DOUBLE PRECISION DLCclzf(Nxl,Nyl,Nspcl)
      DOUBLE PRECISION DLCphotolysis_rates(NRphot,Nx,Ny,Nz)
      DOUBLE PRECISION DLCphotolysis_ratesf(NRphot,Nx,Ny,Nz)

      DOUBLE PRECISION ALFAmeteo,ALFAmeteof
      DOUBLE PRECISION alpha_Kz,alpha_Kz_f
      DOUBLE PRECISION ALFACforc2d,ALFACforc2df
      DOUBLE PRECISION ALFAvdep,ALFAvdepf  
      DOUBLE PRECISION ALFAsourc,ALFAsourcf
      DOUBLE PRECISION ALFAemis,ALFAemisf
      DOUBLE PRECISION ALFAcl,ALFAclf
C     
      REAL DGUi(NX+1,NY,NZ),DGUf(NX+1,NY,NZ)
      REAL DGVi(NX,NY+1,NZ),DGVf(NX,NY+1,NZ)
      REAL DGWi(NX,NY,NZ+1),DGWf(NX,NY,NZ+1)
      REAL DGKz(NX,NY,NZ+1),DGKzf(NX,NY,NZ+1)
      REAL DGtemp(NXt,NYt,NZt),DGtempf(NXt,NYt,NZt)
      REAL DGrain(NXr,NYr),DGrainf(NXr,NYr)
      REAL DGhcloud(NXr,NYr),DGhcloudf(NXr,NYr)
      REAL DGattenuation(NXatt,NYatt,NZatt)
      REAL DGattenuationf(NXatt,NYatt,NZatt)
      REAL DGhumid(NXh,NYh,NZh),DGhumidf(NXh,NYh,NZh)
      REAL DGpress(NXp,NYp,NZp),DGpressf(NXp,NYp,NZp)
      REAL DGtempsurf(NXdd,NYdd),DGtempsurff(NXdd,NYdd)
      REAL DGpresurf(NXdd,NYdd),DGpresurff(NXdd,NYdd)
      REAL DGsnow(NXdd,NYdd),DGsnowf(NXdd,NYdd)
      REAL DGraysoli(NXdd,NYdd),DGraysolif(NXdd,NYdd)
      REAL DGlhflux(NXdd,NYdd),DGlhfluxf(NXdd,NYdd)
      REAL DGswat(NXdd,NYdd,Nlayer),DGswatf(NXdd,NYdd,Nlayer)
      REAL DGmodwind(NXdd,NYdd),DGmodwindf(NXdd,NYdd)

      REAL DGCforc2d(Nxf,Nyf,NESPF),DGCforc2df(Nxf,Nyf,NESPF)
      REAL DGVdep(NXdd,NYdd,Ndep),DGVdepf(NXdd,NYdd,Ndep)
      REAL DGCsourc(Nx,Ny,Nzs,Nsrc),DGCsourcf(Nx,Ny,Nzs,Nsrc)
      REAL DGCemis(Nx,Ny,Nemi),DGCemisf(Nx,Ny,Nemi)
      REAL DGCclx(2,Nyl,Nzl,Nspcl),DGCclxf(2,Nyl,Nzl,Nspcl)
      REAL DGCcly(Nxl,2,Nzl,Nspcl),DGCclyf(Nxl,2,Nzl,Nspcl)
      REAL DGCclz(Nxl,Nyl,Nspcl),DGCclzf(Nxl,Nyl,Nspcl)
C     
      INTEGER Nmeteo,Nmeteof
      INTEGER NKz,NKzf
      INTEGER NCforc2d,NCforc2df
      INTEGER Nvdep,Nvdepf
      INTEGER Nsourc,Nsourcf
      INTEGER Nemis,Nemisf
      INTEGER Ncl,Nclf
C     
      DOUBLE PRECISION ts,tf
      DOUBLE PRECISION DLCG(Nx,Ny,Nz,NESP)
      INTEGER Ji,Jj,Jk,Jt,Jsp
      
      
C------------------------------------------------------------------------
C     1 - Initial concentrations

      DO Jsp=1,NESP
         DO Jk=1,Nz
            DO Jj=1,Ny
               DO Ji=1,Nx
                  DLCG(Ji,Jj,Jk,Jsp)=DLCG0(Ji,Jj,Jk,Jsp)
               ENDDO
            ENDDO
         ENDDO
      ENDDO

C------------------------------------------------------------------------
C     2 - Loop on time

      LITER=.TRUE.
C     
      DO Jt=1,Nstop

         ts=Dstart+(Jt-1)*Dtstep
         tf=ts+Dtstep
         
         WRITE(*,*) 'Iteration ', Jt
         
C     2.1 - Read input data at time Ts and time Tf

C     Each kind of data is read at two timesteps and interpolation
C     coefficients are computed.

C     Meteorological data.
         Nmeteo=INT((ts-Dtmet0)/Dtmeteo)+1
         Nmeteof=INT((tf-Dtmet0)/Dtmeteo)+2
         ALFAmeteo=(Dtmet0+Nmeteo*Dtmeteo-ts)/Dtmeteo
         ALFAmeteof=(Dtmet0+(Nmeteof-1)*Dtmeteo-tf)/Dtmeteo

         IF(Nmeteof.EQ.NECHMET+1) THEN
            Nmeteof=NECHMET
            ALFAmeteof=1.D0
         ENDIF

         IF(Nmeteo.GE.NECHMET) THEN
            write(*,*) 'Overstack for meteorological data!'
            write(*,*) 'Nmeteo > NECHMET'
            write(*,*) Nmeteo,' > ',NECHMET
            stop
         ENDIF

C     Vertical diffusion.
         NKz=INT((ts-DtKz0)/DtKz)+1
         NKzf=INT((tf-DtKz0)/DtKz)+2
         alpha_Kz=(DtKz0+NKz*DtKz-ts)/DtKz
         alpha_Kz_f=(DtKz0+(NKzf-1)*DtKz-tf)/DtKz

         IF(NKzf.EQ.NECHKZ+1) THEN
            NKzf=NECHKZ
            alpha_Kz_f=1.D0
         ENDIF

         IF(NKz.GE.NECHKZ) THEN
            write(*,*) 'Overstack for vertical diffusion!'
            write(*,*) 'NKz > NECHKZ'
            write(*,*) NKz,' > ',NECHKZ
            stop
         ENDIF

C     Forced concentrations.
         IF (LCFORC2D) THEN
            NCforc2d=INT((ts-Dtconcf0)/Dtconcf)+1
            NCforc2df=INT((tf-Dtconcf0)/Dtconcf)+2
            ALFACforc2d=(Dtconcf0+NCforc2d*Dtconcf-ts)/Dtconcf
            ALFACforc2df=(Dtconcf0+(NCforc2df-1)*Dtconcf-tf)/Dtconcf

            IF(NCforc2df.EQ.NECHCONCF+1) THEN
               NCforc2df=NECHCONCF
               ALFACforc2df=1.D0  
            ENDIF

            IF(NCforc2d.GE.NECHCONCF) THEN
               write(*,*) 'Overstack for forced concentrations!'
               write(*,*) 'NCforc2d > NECHCONCF'
               write(*,*) NCforc2d,' > ',NECHCONCF
               stop
            ENDIF
         ENDIF

C     Deposition velocities.
         IF(LVdepo)THEN
            Nvdep=INT((ts-Dtvdep0)/Dtvdep)+1
            Nvdepf=INT((tf-Dtvdep0)/Dtvdep)+2
            ALFAvdep=(Dtvdep0+Nvdep*Dtvdep-ts)/Dtvdep
            ALFAvdepf=(Dtvdep0+(Nvdepf-1)*Dtvdep-tf)/Dtvdep

            IF(Nvdepf.EQ.NECHVDEP+1) THEN
               Nvdepf=NECHVDEP
               ALFAvdepf=1.D0
            ENDIF 

            IF(Nvdep.GE.NECHVDEP) THEN
               write(*,*) 'Overstack for deposition velocities!'
               write(*,*) 'Nvdep > NECHVDEP'
               write(*,*) Nvdep,' > ',NECHVDEP
               stop
            ENDIF
         ENDIF 

C     Volumic emissions.
         IF(LSOURC)THEN
            Nsourc=INT((ts-Dtsourc0)/Dtsourc)+1
            Nsourcf=INT((tf-Dtsourc0)/Dtsourc)+2
            ALFAsourc=(Dtsourc0+Nsourc*Dtsourc-ts)/Dtsourc
            ALFAsourcf=(Dtsourc0+(Nsourcf-1)*Dtsourc-tf)/Dtsourc

            IF(Nsourcf.EQ.NECHSOURC+1) THEN
               Nsourcf=NECHSOURC
               ALFAsourcf=1.D0
            ENDIF

            IF(Nsourc.GE.NECHSOURC) THEN
               write(*,*) 'Overstack for volumic emissions!'
               write(*,*) 'Nsourc > NECHSOURC'
               write(*,*) Nsourc,' > ',NECHSOURC
               stop
            ENDIF
         ENDIF

C     Surfacic emissions.
         IF(LEMISS)THEN
            Nemis=INT((ts-Dtemis0)/Dtemis)+1
            Nemisf=INT((tf-Dtemis0)/Dtemis)+2
            ALFAemis=(Dtemis0+Nemis*Dtemis-ts)/Dtemis
            ALFAemisf=(Dtemis0+(Nemisf-1)*Dtemis-tf)/Dtemis

            IF(Nemisf.EQ.NECHEMIS+1) THEN
               Nemisf=NECHEMIS
               ALFAemisf=1.D0
            ENDIF

            IF(Nemis.GE.NECHEMIS) THEN
               write(*,*) 'Overstack for surfacic emissions!'
               write(*,*) 'Nemis > NECHEMIS'
               write(*,*) Nemis,' > ',NECHEMIS
               stop
            ENDIF
         ENDIF

C     Boundary conditions.
         IF(LCBC)THEN

            Ncl=INT((ts-Dtcl0)/Dtcl)+1
            Nclf=INT((tf-Dtcl0)/Dtcl)+2
            ALFAcl=(Dtcl0+Ncl*Dtcl-ts)/Dtcl
            ALFAclf=(Dtcl0+(Nclf-1)*Dtcl-tf)/Dtcl

            IF(Nclf.EQ.NECHCL+1) THEN
               Nclf=NECHCL
               ALFAclf=1.D0
            ENDIF

            IF(Ncl.GE.NECHCL) THEN
               write(*,*) 'Overstack for boundary conditions!'
               write(*,*) 'Ncl > NECHCL'
               write(*,*) Ncl,' > ',NECHCL
               stop
            ENDIF

         ENDIF

C     Initializations.
         CALL INITCTM2(
     s        ts,tf,Nmeteo,Nmeteof,ALFAmeteo,ALFAmeteof,
     s        NKz,NKzf,alpha_Kz,alpha_Kz_f,
     s        NCforc2d,NCforc2df,ALFACforc2d,ALFACforc2df,
     s        Nvdep,Nvdepf,ALFAvdep,ALFAvdepf,
     s        Nsourc,Nsourcf,ALFAsourc,ALFAsourcf,
     s        Nemis,Nemisf,ALFAemis,ALFAemisf,
     s        Ncl,Nclf,ALFAcl,ALFAclf,
     s        Ui,Vi,Wi,DRKz,DLrain,DLhcloud,DLattenuation,DLhumid,
     $        DLtemp,DLpress,DLtempsurf,DLpresurf,DLsnow,
     $        DLraysoli,DLlhflux,DLswat,DLmodwind,
     s        Uf,Vf,Wf,DRKzf,DLrainf,DLhcloudf,DLattenuationf,DLhumidf,
     $        DLtempf,DLpressf,DLtempsurff,DLpresurff,DLsnowf,
     $        DLraysolif,DLlhfluxf,DLswatf,DLmodwindf,
     s        DLCforc2d,DLCforc2df,DLCemis,DLCemisf,
     s        DLVdep,DLVdepf,DLCsourc,DLCsourcf,DLscavg,DLscavgf,
     s        DLCclx,DLCclxf,DLCcly,DLCclyf,DLCclz,DLCclzf,
     s        DLCphotolysis_rates,DLCphotolysis_ratesf,
     s        DGUi,DGVi,DGWi,DGKz,DGattenuation,DGhumid,DGtemp,DGrain,
     $        DGhcloud,DGpress,DGtempsurf,DGpresurf,DGsnow,DGraysoli,
     $        DGlhflux,DGswat,DGmodwind,
     s        DGUf,DGVf,DGWf,DGKzf,DGattenuationf,DGhumidf,DGtempf,
     s        DGrainf,DGhcloudf,DGpressf,DGtempsurff,DGpresurff,DGsnowf,
     $        DGraysolif,DGlhfluxf,DGswatf,DGmodwindf,
     s        DGCforc2d,DGCforc2df,DGCemis,DGCemisf,
     s        DGVdep,DGVdepf,DGCsourc,DGCsourcf,
     s        DGCclx,DGCclxf,DGCcly,DGCclyf,DGCclz,DGCclzf)

C     Save initial data.
         IF((Jt.EQ.1).AND.LPOST)THEN
            CALL POSTREAT((Jt-1),DLCG,DLVdep,DLScavg)
         ENDIF

C     2.2 - Compute chemical concentrations for one timestep

         IF(Jt.EQ.1.AND.LCOMMENT)THEN
            write(*,*)'--------------------'
            write(*,*)' RUNNING SIMULATION'
            write(*,*)'--------------------'
         ENDIF

         CALL CALC_CONC(ts,
     s        Ui,Vi,Wi,DRkz,DLrain,DLhcloud,DLattenuation,DLhumid,
     s        DLtemp,DLpress,DLCforc2d,DLVdep,DLCsourc,DLCemis,
     s        DLCclx,DLCcly,DLCclz,DLCphotolysis_rates,DLscavg,
     s        Uf,Vf,Wf,DRkzf,DLrainf,DLhcloudf,DLattenuationf,DLhumidf,
     s        DLtempf,DLpressf,DLCforc2df,DLVdepf,DLCsourcf,DLCemisf,
     s        DLCclxf,DLCclyf,DLCclzf,DLCphotolysis_ratesf,DLscavgf,
     s        DLCG)

C     2.3 - Post treatment

         IF (LPOST) CALL POSTREAT(Jt,DLCG,DLvdepf,DLscavgf)

         LITER=.FALSE.          ! The next step is not
                                ! the first iteration.

      ENDDO                     ! Loop on time.

      END
