C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE POSTREAT (Jt,DLCG,DLVdep,DLscavg)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes chemical concentration for all timesteps.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     ITER: iteration number.
C     DLCG: array of 3D chemical concentration fields.
C     DLVDEP: 2D dry deposition velocity field.
C     DLSCAVG: 3D below cloud scavenging coefficient field.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C     2002/03: Added wind, temperature and rain fields among saved
C     #  fields. (Paul-Antoine Michelangeli)
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMUSE: flags and parameters for numerics. 
C     COMPOST: global variables for post treatment.
C     COMDOM: global variables for the domain.
C     COMLUN: global variables for unit numbers.
C     COMFILES: global variables for files names.

      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMUSE.INC'
      INCLUDE 'COMPOST.INC'
      INCLUDE 'COMLUN.INC'
      INCLUDE 'COMFILES.INC'

      DOUBLE PRECISION DLCG(Nx,Ny,Nz,NESP)
      DOUBLE PRECISION DLScavg(Nxr,Nyr,Nz,Nscav)
      DOUBLE PRECISION DLVdep(Nxdd,Nydd,Ndep)

      INTEGER Ji,Jj,Jk,Jsp,Jt,Jdep,Jsca
      INTEGER size_real

      REAL integration_factor

C------------------------------------------------------------------------
C     1 - Save concentrations

      IF (LCespec) THEN

C     1.1 Save integrated concentrations

         IF (L_POST_INTEGRATION) THEN
            
            I_post_int = I_post_int + 1
            
C     Integration factor, for a trapezoidal integration.
C     Approximation of the integral of C over [0, N*t],
C     where C(i), i in [[0, N]], is know:
C     integral = C(0)/2 + sum_{i=1, N-1} C(i) + C(N)/2
C     Notice: here, N is N_post_int.
            
            IF (i_post_int.eq.N_post_int) THEN
               integration_factor = 0.5
            ELSE
               integration_factor = 1.0
            ENDIF
            
C     Integration.
            DO Jsp = 1,Nesp
               DO Jk = 1,Nz
                  DO Jj = 1,Ny
                     DO Ji = 1,Nx
                        S_conc_int(Ji, Jj, Jk, Jsp) =
     $                       S_conc_int(Ji, Jj, Jk, Jsp) +
     $                       REAL(DLCG(Ji, Jj, Jk, Jsp))
     $                       * integration_factor
                     ENDDO
                  ENDDO
               ENDDO
            ENDDO
            
C     At the end of the integration period, concentrations are saved.
            IF (I_post_int.eq.N_post_int) THEN
               
               DO Jsp=1,Nespos
                  
                  OPEN(unit=NULRES,file=file_res(Jsp),
     s                 access='direct',form='unformatted',recl=4*Nx*Ny)

                  DO Jk=1,Nlevpos
                     WRITE(unit=NULRES,
     $                    rec=Nlevpos*(Jt/N_post_int)+Jk)
     s                    (((S_conc_int(Ji,Jj,lev_espec(Jk),
     $                    Nespec(Jsp))/REAL(N_post_int)),
     s                    Ji=1,Nx),Jj=1,Ny)
                  ENDDO
                  
                  CLOSE(NULRES)
                  
               ENDDO            ! Loop on species.
               
C     Reinitializations.
               I_post_int = 0
               
               DO Jsp = 1,Nesp
                  DO Jk = 1,Nz
                     DO Jj = 1,Ny
                        DO Ji = 1,Nx
                           S_conc_int(Ji, Jj, Jk, Jsp) = 0.5
     $                          * REAL(DLCG(Ji, Jj, Jk, Jsp))
                        ENDDO
                     ENDDO
                  ENDDO
               ENDDO
               
            ENDIF
            
C     1.2 Save concentrations (not integrated)

         ELSEIF (MOD(Jt,NFsav).EQ.0) THEN
            
            DO Jsp=1,Nespos
               
               IF (PREC.EQ.'SINGLE') THEN ! Single precision.
                  size_real=4
               ELSE IF (PREC.EQ.'DOUBLE') THEN ! Double precision.
                  size_real=8
               ELSE
                  write(*,*) 'Precision should be'
                  write(*,*) 'SINGLE or DOUBLE in CONTROL/NAMPOST'
                  stop
               ENDIF
               
               OPEN(unit=NULRES,file=file_res(Jsp),
     s              access='direct',form='unformatted',
     s              recl=size_real*Nx*Ny)
               
               IF (PREC.EQ.'SINGLE') THEN ! Single precision.
                  DO Jk=1,Nlevpos
                     WRITE(unit=NULRES,rec=Nlevpos*(Jt/NFsav)+Jk)
     s                    ((REAL(DLCG(Ji,Jj,lev_espec(Jk),
     $                    Nespec(Jsp))),Ji=1,Nx),Jj=1,Ny)
                  ENDDO

               ELSE IF (PREC.EQ.'DOUBLE') THEN ! Double precision.
                  DO Jk=1,Nlevpos
                     WRITE(unit=NULRES,rec=Nlevpos*(Jt/NFsav)+Jk)
     s                    ((DLCG(Ji,Jj,lev_espec(Jk),
     $                    Nespec(Jsp)),Ji=1,Nx),Jj=1,Ny)
                  ENDDO
               ENDIF
               
               CLOSE(NULRES)
               
            ENDDO               ! Loop on species.
            
         ENDIF

      ENDIF

C------------------------------------------------------------------------
C     2 - Save dry deposition velocity and scavenging coefficient.

C     2.1 - Save dry deposition velocity.

      IF((MOD(Jt,NFsav).EQ.0).AND.LVD.AND.LVDEPOCOMP)THEN

         DO Jdep=1,Ndep
            
            open(nulres,file=file_res_vdep(Jdep),form='unformatted',
     &           access='direct',recl=4*Nxdd*Nydd)
            
            WRITE(unit=NULRES,rec=(Jt/NFsav)+1)
     s           ((real(DLvdep(Ji,Jj,Jdep)),Ji=1,nxdd),Jj=1,nydd)
            
            close(nulres)
            
         ENDDO
         
      ENDIF
      
C     2.2 - Save below cloud scavenging coefficient.

      IF((MOD(Jt,NFsav).EQ.0).AND.LSCAVG.AND.LSCAV)THEN

         DO Jsca=1,Nscav

            open(nulres,file=file_res_scavg(Jsca),form='unformatted',
     &           access='direct',recl=4*Nxr*Nyr*Nz)

            WRITE(unit=NULRES,rec=(Jt/NFsav)+1)
     s           (((real(DLscavg(Ji,Jj,Jk,Jsca)),
     $           Ji=1,nxr),Jj=1,nyr),Jk=1,nz)
            
            close(nulres)

         ENDDO

      ENDIF

      END   
