C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE SCAVENGING(ts,tf,DLscavg,DLscavgf,DLconc)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes below-cloud scavenging.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     DLSCAVG: gas below-cloud scavenging ([s^{-1}])
C     
C     The same variables are defined at final time of the timestep.
C     'f' is then put at the end of the name.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     DLCONC: array of 3D chemical concentrations ([\mu.g/m^3]). 
C     # Before entry, it is given at initial time of the timestep.
C     # On exit, it is computed at final time of the timestep.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C     Parameterization used in this subroutine is presented and 
C     justified in " Numerical and theoretical investigation of a 
C     simplified model for the parameterization of below-cloud 
C     scavenging by falling raindrops " (B. Sportisse and L. Du Bois,
C     Atmospheric Environment, Vol. 36, pp 5719-5727, 2002 )
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Yelva Roustan, CEREA, February 2003.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMCHEM: global variables for chemical species.

      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMCHEM.INC'

      INTEGER i,j,k,l,Jsca

      DOUBLE PRECISION ts,tf

      DOUBLE PRECISION DLscavg(NXr,NYr,NZ,Nscav)
      DOUBLE PRECISION DLscavgf(NXr,NYr,NZ,Nscav)

      DOUBLE PRECISION DLconc(NX,NY,NZ,nesp)

      DO Jsca=1,Nscav
         l=Nespsca(Jsca)
         DO k=1,NZ
            DO j=1,NYr
               DO i=1,NXr
                  DLconc(i,j,k,l) = DLconc(i,j,k,l)
     $                 * DEXP(-(DLscavg(i,j,k,Jsca)
     $                 +DLscavgf(i,j,k,Jsca))/2.d0*(tf-ts))
               ENDDO
            ENDDO
         ENDDO
      ENDDO

      END
