C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE INITCL(Ncl,Nclf,ALFAcl,ALFAclf,
     s     DLCclx,DLCclxf,DGCclx,DGCclxf,
     s     DLCcly,DLCclyf,DGCcly,DGCclyf,
     s     DLCclz,DLCclzf,DGCclz,DGCclzf)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine sets boundary conditions.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     NCL, NCLF: interpolation is performed between iterations NCL and
C     # NCLF.
C     ALFACL, ALFACLF: interpolation coefficients.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     DLCCLX, DLCCLXF: interpolated boundary-conditions along X.
C     DGCCLX, DGCCLXF: boundary conditions along X from input file.
C     DLCCLY, DLCCLYF: interpolated boundary-conditions along Y.
C     DGCCLY, DGCCLYF: boundary conditions along Y from input file.
C     DLCCLZ, DLCCLZF: interpolated boundary-conditions along Z.
C     DGCCLZ, DGCCLZF: boundary conditions along Z from input file.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMDATA: data on forced fields.
C     COMLUN: global variables for unit numbers.
C     COMFILES: global variables for files names.

      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMDATA.INC'
      INCLUDE 'COMLUN.INC'
      INCLUDE 'COMFILES.INC'

      DOUBLE PRECISION DLCclx(2,Nyl,Nzl,Nspcl)
      DOUBLE PRECISION DLCclxf(2,Nyl,Nzl,Nspcl)

      DOUBLE PRECISION DLCcly(Nxl,2,Nzl,Nspcl)
      DOUBLE PRECISION DLCclyf(Nxl,2,Nzl,Nspcl)

      DOUBLE PRECISION DLCclz(Nxl,Nyl,Nspcl)
      DOUBLE PRECISION DLCclzf(Nxl,Nyl,Nspcl)

      REAL DGCclx(2,Nyl,Nzl,Nspcl),DGCclxf(2,Nyl,Nzl,Nspcl)
      REAL DGCcly(Nxl,2,Nzl,Nspcl),DGCclyf(Nxl,2,Nzl,Nspcl)
      REAL DGCclz(Nxl,Nyl,Nspcl),DGCclzf(Nxl,Nyl,Nspcl)

      INTEGER Ncl,Nclf
      DOUBLE PRECISION ALFAcl,ALFAclf

      INTEGER Jsp,Ji,Jj,Jl


      IF (LITER) THEN           ! First iteration.

         DO Jsp=1,Nspcl

C     Along X.
            OPEN(unit=NULCL,file=file_clx(Jsp),
     s           access='direct',form='unformatted',
     $           recl=4*(2)*(Nyl)*(Nzl))

            READ(NULCL,rec=Ncl)
     s           (((DGCclx(Jl,Ji,Jj,Jsp),Jl=1,2),Ji=1,Nyl),Jj=1,Nzl)

            IF (iabs(Ncl-Nclf).NE.1) THEN
               READ(NULCL,rec=(Ncl+Nclf)/2)
     s              (((DGCclxf(Jl,Ji,Jj,Jsp),Jl=1,2),Ji=1,Nyl),Jj=1,Nzl)
            ELSE
               READ(NULCL,rec=Nclf)
     s              (((DGCclxf(Jl,Ji,Jj,Jsp),Jl=1,2),Ji=1,Nyl),Jj=1,Nzl)
            ENDIF

            CLOSE (NULCL)

C     Along Y.
            OPEN(unit=NULCL,file=file_cly(Jsp),
     s           access='direct',form='unformatted',
     $           recl=4*(2)*(Nxl)*(Nzl))

            READ(NULCL,rec=Ncl)
     s           (((DGCcly(Ji,Jl,Jj,Jsp),Ji=1,Nxl),Jl=1,2),Jj=1,Nzl)

            IF (iabs(Ncl-Nclf).NE.1) THEN
               READ(NULCL,rec=(Ncl+Nclf)/2)
     s              (((DGCclyf(Ji,Jl,Jj,Jsp),Ji=1,Nxl),Jl=1,2),Jj=1,Nzl)
            ELSE
               READ(NULCL,rec=Nclf)
     s              (((DGCclyf(Ji,Jl,Jj,Jsp),Ji=1,Nxl),Jl=1,2),Jj=1,Nzl)
            ENDIF

            CLOSE (NULCL)

C     Along Z.
            OPEN(unit=NULCL,file=file_clz(Jsp),
     s           access='direct',form='unformatted',recl=4*(Nxl)*(Nyl))

            READ(NULCL,rec=Ncl)
     s           ((DGCclz(Ji,Jj,Jsp),Ji=1,Nxl),Jj=1,Nyl)

            IF (iabs(Ncl-Nclf).NE.1) THEN
               READ(NULCL,rec=(Ncl+Nclf)/2)
     s              ((DGCclzf(Ji,Jj,Jsp),Ji=1,Nxl),Jj=1,Nyl)
            ELSE
               READ(NULCL,rec=Nclf)
     s              ((DGCclzf(Ji,Jj,Jsp),Ji=1,Nxl),Jj=1,Nyl)
            ENDIF

            CLOSE (NULCL)

         ENDDO
         
C     Interpolation for DLCclx, DLCcly and DLCclz.
         DO Jsp=1,Nspcl

            DO Jj=1,Nzl

               DO Ji=1,Nyl
                  DO Jl=1,2
                     DLCclx(Jl,Ji,Jj,Jsp)=
     $                    ALFAcl*DBLE(DGCclx(Jl,Ji,Jj,Jsp))+
     s                    (1.D0-ALFAcl)*DBLE(DGCclxf(Jl,Ji,Jj,Jsp))
                  ENDDO
               ENDDO

               DO Jl=1,2
                  DO Ji=1,Nxl
                     DLCcly(Ji,Jl,Jj,Jsp)=
     $                    ALFAcl*DBLE(DGCcly(Ji,Jl,Jj,Jsp))+
     s                    (1.D0-ALFAcl)*DBLE(DGCclyf(Ji,Jl,Jj,Jsp))
                  ENDDO
               ENDDO

            ENDDO

            DO Jj=1,Nyl
               DO Ji=1,Nxl
                  DLCclz(Ji,Jj,Jsp)=ALFAcl*DBLE(DGCclz(Ji,Jj,Jsp))+
     s                 (1.D0-ALFAcl)*DBLE(DGCclzf(Ji,Jj,Jsp))
               ENDDO
            ENDDO

         ENDDO

      ENDIF                     ! End of first iteration test.

      IF (iabs(Ncl-Nclf).NE.1) THEN
         
C     Set DGCclx, DGCcly and DGCclz.
         DO Jsp=1,Nspcl

            DO Jj=1,Nzl

               DO Ji=1,Nyl
                  DO Jl=1,2
                     DGCclx(Jl,Ji,Jj,Jsp)=DGCclxf(Jl,Ji,Jj,Jsp)
                  ENDDO
               ENDDO

               DO Jl=1,2
                  DO Ji=1,Nxl
                     DGCcly(Ji,Jl,Jj,Jsp)=DGCclyf(Ji,Jl,Jj,Jsp)
                  ENDDO
               ENDDO

            ENDDO

            DO Jj=1,Nyl
               DO Ji=1,Nxl
                  DGCclz(Ji,Jj,Jsp)=DGCclzf(Ji,Jj,Jsp)
               ENDDO
            ENDDO

         ENDDO

         DO Jsp=1,Nspcl

C     Along X.
            OPEN(unit=NULCL,file=file_clx(Jsp),
     s           access='direct',form='unformatted',
     $           recl=4*(2)*(Nyl)*(Nzl))

            READ(NULCL,rec=Nclf)
     s           (((DGCclxf(Jl,Ji,Jj,Jsp),Jl=1,2),
     $           Ji=1,Nyl),Jj=1,Nzl)

            CLOSE (NULCL)

C     Along Y.
            OPEN(unit=NULCL,file=file_cly(Jsp),
     s           access='direct',form='unformatted',
     $           recl=4*(2)*(Nxl)*(Nzl))

            READ(NULCL,rec=Nclf)
     s           (((DGCclyf(Ji,Jl,Jj,Jsp),Ji=1,Nxl),
     $           Jl=1,2),Jj=1,Nzl)

            CLOSE (NULCL)

C     Along Z.
            OPEN(unit=NULCL,file=file_clz(Jsp),
     s           access='direct',form='unformatted',
     $           recl=4*(Nxl)*(Nyl))
            READ(NULCL,rec=Nclf)
     s           ((DGCclzf(Ji,Jj,Jsp),Ji=1,Nxl),Jj=1,Nyl)
            CLOSE (NULCL)


         ENDDO

      ENDIF

C     Set DLCclx, DLCcly and DLCclz.
      DO Jsp=1,Nspcl

         DO Jj=1,Nzl 

            DO Ji=1,Nyl
               DO Jl=1,2
                  IF (.NOT.LITER) 
     s                 DLCclx(Jl,Ji,Jj,Jsp)=DLCclxf(Jl,Ji,Jj,Jsp)
               ENDDO
            ENDDO

            DO Jl=1,2
               DO Ji=1,Nxl
                  IF (.NOT.LITER)
     s                 DLCcly(Ji,Jl,Jj,Jsp)=DLCclyf(Ji,Jl,Jj,Jsp)
               ENDDO
            ENDDO

         ENDDO

         DO Jj=1,Nyl
            DO Ji=1,Nxl
               IF (.NOT.LITER) DLCclz(Ji,Jj,Jsp)=DLCclzf(Ji,Jj,Jsp)
            ENDDO
         ENDDO

      ENDDO

C     Interpolation for DLCclxf, DLCclyf and DLCclzf.

      DO Jsp=1,Nspcl

         DO Jj=1,Nzl

            DO Ji=1,Nyl
               DO Jl=1,2
                  DLCclxf(Jl,Ji,Jj,Jsp)=
     $                 ALFAclf*DBLE(DGCclx(Jl,Ji,Jj,Jsp))+
     s                 (1.D0-ALFAclf)*DBLE(DGCclxf(Jl,Ji,Jj,Jsp))
               ENDDO
            ENDDO

            DO Jl=1,2
               DO Ji=1,Nxl
                  DLCclyf(Ji,Jl,Jj,Jsp)=
     $                 ALFAclf*DBLE(DGCcly(Ji,Jl,Jj,Jsp))+
     s                 (1.D0-ALFAclf)*DBLE(DGCclyf(Ji,Jl,Jj,Jsp))
               ENDDO
            ENDDO

         ENDDO

         DO Jj=1,Nyl
            DO Ji=1,Nxl
               DLCclzf(Ji,Jj,Jsp)=ALFAclf*DBLE(DGCclz(Ji,Jj,Jsp))+
     s              (1.D0-ALFAclf)*DBLE(DGCclzf(Ji,Jj,Jsp))
            ENDDO
         ENDDO

      ENDDO

      END
