C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE INITCONCF(NCforc2d,NCforc2df,ALFACforc2d,ALFACforc2df,
     s     DLCforc2d,DLCforc2df,DGCforc2d,DGCforc2df)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine sets forced concentrations.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     NCFORC2D, NCFORC2DF: interpolation is performed between iterations
C     # NCFORC2D and NCFORC2DF.
C     ALFACFORC2D, ALFACFORC2DF: interpolation coefficients.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     DLCFORC2D, DLCFORC2DF: interpolated forced concentrations.
C     DGCFORC2D, DGCFORC2DF: forced concentrations from input file.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMDATA: data on forced fields.
C     COMLUN: global variables for unit numbers.

      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMDATA.INC'
      INCLUDE 'COMLUN.INC'

      DOUBLE PRECISION DLCforc2d(Nxf,Nyf,NESPF)
      DOUBLE PRECISION DLCforc2df(Nxf,Nyf,NESPF)
      REAL DGCforc2d(Nxf,Nyf,NESPF),DGCforc2df(Nxf,Nyf,NESPF)

      INTEGER NCforc2d,NCforc2df
      DOUBLE PRECISION ALFACforc2d,ALFACforc2df

      CHARACTER*200 file_concf(NESPF)
      INTEGER NUC,i,j,Ji,Jj,Jsp


      IF (LITER) THEN           ! First iteration.

         NUC=4
         OPEN(NUC,FILE ='CONTROL/NAMCONCF',STATUS ='OLD')
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

C     Read data.
         DO Jsp=1,NESPF
            READ(NUC,*)file_concf(Jsp)

            open(unit=NULCONF,file=file_concf(Jsp),access='direct',
     s           form='unformatted',recl=4*(Nx)*(Ny))

            read(NULCONF,rec=NCforc2d)
     s           ((DGCforc2d(Ji,Jj,Jsp),Ji=1,Nx),Jj=1,Ny)
            
            IF (iabs(NCforc2d-NCforc2df).NE.1) THEN
               read(NULCONF,rec=(NCforc2d+NCforc2df)/2)
     s              ((DGCforc2df(Ji,Jj,Jsp),Ji=1,Nx),Jj=1,Ny)
            ELSE
               read(NULCONF,rec=NCforc2df)
     s              ((DGCforc2df(Ji,Jj,Jsp),Ji=1,Nx),Jj=1,Ny)
            ENDIF
            
            CLOSE(NULCONF)
         ENDDO

         CLOSE(NUC)

C     Interpolation for DLCforc2d.
         DO Jsp=1,NESPF
            DO Jj=1,Ny
               DO Ji=1,Nx
                  DLCforc2d(Ji,Jj,Jsp)=
     s                 ALFACforc2d*DBLE(DGCforc2d(Ji,Jj,Jsp))+
     s                 (1.D0-ALFACforc2d)*DBLE(DGCforc2df(Ji,Jj,Jsp))
               ENDDO
            ENDDO
         ENDDO

      ENDIF                     ! End of first iteration test.

      IF (iabs(NCforc2d-NCforc2df).NE.1) THEN

         DO Jsp=1,NESPF
            DO Jj=1,Ny
               DO Ji=1,Nx
                  DGCforc2d(Ji,Jj,Jsp)=DGCforc2df(Ji,Jj,Jsp)
               ENDDO
            ENDDO
         ENDDO

         NUC=4
         OPEN(NUC,FILE ='CONTROL/NAMCONCF',STATUS ='OLD')
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

C     Read data.
         DO Jsp=1,NESPF
            READ(NUC,*)file_concf(Jsp)

            OPEN(unit=NULCONF,file=file_concf(Jsp),
     s           access='direct',form='unformatted',
     $           recl=4*(Nx)*(Ny))

            READ(NULCONF,rec=1+(NCforc2df-1))
     s           ((DGCforc2df(i,j,Jsp),i=1,Nx),j=1,Ny)

            CLOSE(NULCONF)
         ENDDO

         CLOSE(NUC)

      ENDIF

      DO Jsp=1,NESPF
         DO Jj=1,Ny
            DO Ji=1,Nx
               IF(.NOT.LITER) DLCforc2d(Ji,Jj,Jsp)=DLCforc2df(Ji,Jj,Jsp)
            ENDDO
         ENDDO
      ENDDO

C     Interpolation for DLCforc2df.
      DO Jsp=1,NESPF
         DO Jj=1,Ny
            DO Ji=1,Nx
               DLCforc2df(Ji,Jj,Jsp)=
     s              ALFACforc2df*DBLE(DGCforc2d(Ji,Jj,Jsp))+
     s              (1.D0-ALFACforc2df)*DBLE(DGCforc2df(Ji,Jj,Jsp))
            ENDDO
         ENDDO
      ENDDO

      END
