C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE INITCONCI
      
C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine sets initial concentrations.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------
      
      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMLUN: global variables for unit numbers.
C     COMCHEM: global variables for chemical species. 
C     COMFILES: global variables for files names.
C     COMDATA: data on forced fields.
C     COMUSE: flags and parameters for numerics. 

      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMLUN.INC'
      INCLUDE 'COMCHEM.INC'
      INCLUDE 'COMFILES.INC'
      INCLUDE 'COMDATA.INC'
      INCLUDE 'COMUSE.INC'

      REAL ZCG(Nx,Ny,Nz)
      INTEGER Jisp,i,j,k,Jk,ind


C     If initial concentrations are available.
      IF (LCONC0) THEN

         ind = 1
         DO Jisp=1,NESP
            
C     If initial concentrations are available for species #Jisp.
            IF (Nespconc0(ind).eq.Jisp) THEN

               If (LSTART) THEN ! Read from results
                                ! of previous simulations
                  OPEN(unit=NULCON,file=file_conc0(ind),
     s                 access='direct',form='unformatted',
     s                 recl=4*Nx*Ny)
                  Do Jk=1,Nz
                     READ(NULCON,rec=Nstart*Nz+Jk)
     s                    ((ZCG(i,j,Jk),i=1,Nx),j=1,Ny)
                  Enddo
               Else
                  OPEN(unit=NULCON,file=file_conc0(ind),
     s                 access='direct',form='unformatted',
     s                 recl=4*Nx*Ny*Nz)
                  READ(NULCON,rec=1)
     s                 (((ZCG(i,j,k),i=1,Nx),j=1,Ny),k=1,Nz)
               Endif

               CLOSE(NULCON)

               ind = ind + 1

C     Clipping.
               DO k=1,NZ
                  DO j=1,Ny
                     DO i=1,Nx
                        IF (ZCG(i,j,k).LT.0.) THEN
                           DLCG0(i,j,k,Jisp)=0.D0
                        ELSE
                           DLCG0(i,j,k,Jisp)=DBLE(ZCG(i,j,k))
                        ENDIF
                     ENDDO
                  ENDDO
               ENDDO

C     Initial concentrations are no available.
            ELSE

               DO k = 1, Nz
                  DO j = 1, Ny
                     DO i = 1, Nx
                        DLCG0(i, j, k, Jisp) = 0.D0
                     ENDDO
                  ENDDO
               ENDDO
               
            ENDIF

         ENDDO

      ELSE                      ! If initial concentrations are
                                ! not available, concentrations are
                                ! set to zero.

         DO Jisp=1,Nesp
            DO k=1,NZ
               DO j=1,Ny
                  DO i=1,Nx
                     DLCG0(i,j,k,Jisp)=0.D0
                  ENDDO
               ENDDO
            ENDDO
         ENDDO

      ENDIF

      END
