C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE INITCONSOURC(Nsourc,Nsourcf,ALFAsourc,ALFAsourcf,
     s     Csourc,Csourcf,DGCsourc,DGCsourcf)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine sets volumic emissions.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     NSOURC, NSOURCF: interpolation is performed between iterations
C     # NSOURC and NSOURCF.
C     ALFASOURC, ALFASOURCF: interpolation coefficients.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     CSOURC, CSOURCF: interpolated volumic emissions.
C     DGCSOURC, DGCSOURCF: volumic emissions from input file.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMDATA: data on forced fields.
C     COMLUN: global variables for unit numbers.
C     COMFILES: global variables for files names.

      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMDATA.INC'
      INCLUDE 'COMLUN.INC'
      INCLUDE 'COMFILES.INC'

      DOUBLE PRECISION Csourc(Nx,Ny,Nzs,Nsrc)
      DOUBLE PRECISION Csourcf(Nx,Ny,Nzs,Nsrc)

      REAL DGCsourc(Nx,Ny,Nzs,Nsrc)
      REAL DGCsourcf(Nx,Ny,Nzs,Nsrc)

      INTEGER Nsourc,Nsourcf
      DOUBLE PRECISION ALFAsourc,ALFAsourcf

      INTEGER Ji,Jj,Jk,Jsp


      IF (LITER) THEN           ! First iteration.

C     Read data.
         DO Jsp=1,Nsrc

            OPEN(unit=NULSOURC,file=file_SOURC(Jsp),
     s           access='direct',form='unformatted',recl=4*(Nx)*(Ny))

            DO Jk=1,Nzs

               READ(NULSOURC,rec=Jk+Nzs*(Nsourc-1))
     s              ((DGCsourc(Ji,Jj,Jk,Jsp),Ji=1,Nx),Jj=1,Ny)

               IF (iabs(Nsourc-Nsourcf).NE.1) THEN
                  READ(NULSOURC,rec=Jk+Nzs*(Nsourc+Nsourcf-2)/2)
     s                 ((DGCsourcf(Ji,Jj,Jk,Jsp),Ji=1,Nx),Jj=1,Ny)
               ELSE
                  READ(NULSOURC,rec=Jk+Nzs*(Nsourcf-1))
     s                 ((DGCsourcf(Ji,Jj,Jk,Jsp),Ji=1,Nx),Jj=1,Ny)
               ENDIF
            ENDDO

            CLOSE (NULSOURC)
         ENDDO

C     Interpolation for Csourc.
         DO Jsp=1,Nsrc
            DO Jk=1,Nzs
               DO Jj=1,Ny
                  DO Ji=1,Nx
                     Csourc(Ji,Jj,Jk,Jsp)=
     s                    ALFAsourc*DBLE(DGCsourc(Ji,Jj,Jk,Jsp))+
     s                    (1.D0-ALFAsourc)*
     $                    DBLE(DGCsourcf(Ji,Jj,Jk,Jsp))
                  ENDDO
               ENDDO
            ENDDO
         ENDDO

      ENDIF                     ! End of first iteration test.

      IF (iabs(Nsourc-Nsourcf).NE.1) THEN

         DO Jsp=1,Nsrc
            DO Jk=1,Nzs
               DO Jj=1,Ny
                  DO Ji=1,Nx
                     DGCsourc(Ji,Jj,Jk,Jsp)=DGCsourcf(Ji,Jj,Jk,Jsp)
                  ENDDO
               ENDDO
            ENDDO
         ENDDO

C     Read data.
         DO Jsp=1,Nsrc

            OPEN(unit=NULSOURC,file=file_SOURC(Jsp),
     s           access='direct',form='unformatted',
     $           recl=4*(Nx)*(Ny))

            DO Jk=1,Nzs

               READ(NULSOURC,rec=Jk+Nzs*(Nsourcf-1))
     s              ((DGCsourcf(Ji,Jj,Jk,Jsp),Ji=1,Nx),Jj=1,Ny)

            ENDDO
            
            CLOSE(NULSOURC)
         ENDDO

      ENDIF

      DO Jsp=1,Nsrc
         DO Jk=1,Nzs
            DO Jj=1,Ny
               DO Ji=1,Nx
                  IF(.NOT.LITER) 
     s                 Csourc(Ji,Jj,Jk,Jsp)=Csourcf(Ji,Jj,Jk,Jsp)
               ENDDO
            ENDDO
         ENDDO
      ENDDO

C     Interpolation for Csourcf.
      DO Jsp=1,Nsrc
         DO Jk=1,Nzs
            DO Jj=1,Ny
               DO Ji=1,Nx
                  Csourcf(Ji,Jj,Jk,Jsp)=
     s                 ALFAsourcf*DBLE(DGCsourc(Ji,Jj,Jk,Jsp))+
     s                 (1.D0-ALFAsourcf)*DBLE(DGCsourcf(Ji,Jj,Jk,Jsp))
               ENDDO
            ENDDO
         ENDDO
      ENDDO

      END
