C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE INITCTM0

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine displays main simulation parameters.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C     2002/10/17: Added a test on NFSAV (Denis Qulo).
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMDOM: global variables for the domain.
C     COMUSE: flags and parameters for numerics. 

      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMDOM.INC'
      INCLUDE 'COMUSE.INC'

      DOUBLE PRECISION Zdx,Zdy,Zdlon,Zdlat
      INTEGER NUC,Ji,Jj

      
      NUC=4 
      OPEN(NUC,FILE ='CONTROL/NAMUSE',STATUS ='OLD')

      Write(*,*)
     s     '=============== Configuration =============='

      Write(*,*)

      Write(*,*)'Nx:',Nx
      Write(*,*)'Ny:',Ny
      Write(*,*)'Nz:',Nz

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)

C------------------------------------------------------------------------
C     1 - Time

      Write(*,*)

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*) DSTART
      Write(*,*)'Initial time:',DSTART

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*) Dtstep
      Write(*,*)'Timestep:',Dtstep

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*) NSTOP
      Write(*,*)'Number of iterations:',NSTOP

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*) NFSAV
      IF (NFSAV.GT.NSTOP) THEN
         WRITE(*,*) 'Warning: only initial and final',
     $        'concentrations will be saved.'
         NFSAV = NSTOP
      ENDIF
      Write(*,*)'Nsav:',NFSAV


C------------------------------------------------------------------------
C     2 - Mesh

      Write(*,*)

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*) CGRILLE
      Write(*,*) 'Grid type:',CGRILLE
      IF(CGRILLE.NE.'LALON'.AND.CGRILLE.NE.'LCART')THEN
         WRITE(*,*) 'Error: grid type is incorrect (see NAMUSE).'
         WRITE(*,*) '-- Terminates execution of Polair.'
         stop
      ENDIF

      READ(NUC,*)
      READ(NUC,*)
      IF(CGRILLE.EQ.'LCART')THEN
         READ(NUC,*)Dx0
         Write(*,*)'Abscissa of southwestern-most point:',Dx0
      ELSEIF(CGRILLE.EQ.'LALON')THEN
         READ(NUC,*)DLON0
         Write(*,*)'Longitude of southwestern-most point:',DLON0
      ENDIF

      READ(NUC,*)
      READ(NUC,*)
      IF(CGRILLE.EQ.'LCART')THEN
         READ(NUC,*)Dy0
         Write(*,*)'Ordinate of southwestern-most point:',Dy0
      ELSEIF(CGRILLE.EQ.'LALON')THEN
         READ(NUC,*)DLAT0
         Write(*,*)'Latitude of southwestern-most point:',DLAT0
      ENDIF

      READ(NUC,*)
      READ(NUC,*)
      IF(CGRILLE.EQ.'LCART')THEN
         READ(NUC,*)Zdx
         Write(*,*)'Spacestep along X:',Zdx
         DO Ji=1,Nx+1
            Ddx(Ji)=Zdx
         ENDDO
      ELSEIF(CGRILLE.EQ.'LALON')THEN
         READ(NUC,*)Zdlon
         Write(*,*)'Spacestep along longitude:',Zdlon
         DO Ji=1,Nx+1
            Ddlon(Ji)=Zdlon
         ENDDO
      ENDIF

      READ(NUC,*)
      READ(NUC,*)
      IF(CGRILLE.EQ.'LCART')THEN
         READ(NUC,*)Zdy
         Write(*,*)'Spacestep along Y:',Zdy
         DO Jj=1,Ny+1
            Ddy(Jj)=Zdy
         ENDDO
      ELSEIF(CGRILLE.EQ.'LALON')THEN
         READ(NUC,*)Zdlat
         Write(*,*)'Spacestep along latitude:',Zdlat
         DO Jj=1,Ny+1
            Ddlat(Jj)=Zdlat
         ENDDO
      ENDIF

C------------------------------------------------------------------------
C     3 - Physical processes

      Write(*,*)

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LCHIM
      Write(*,*)'With chemistry?',LCHIM

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LADVEC
      Write(*,*)'With advection?',LADVEC

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LDIFF
      Write(*,*)'With diffusion?',LDIFF

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LEMISS
      Write(*,*)'With surfacic emissions?',LEMISS

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LSOURC
      Write(*,*)'With volumic emissions?',LSOURC

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LVDEPO
      Write(*,*)'With dry deposition?',LVDEPO

      IF(LVDEPO)THEN
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)LVDEPOCOMP
         Write(*,*)'Computed dry deposition?',LVDEPOCOMP
      ELSE
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
      ENDIF

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LSCAV
      Write(*,*)'With scavenging?',LSCAV

C------------------------------------------------------------------------
C     4 - Inputs

      Write(*,*)

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LCBC
      Write(*,*)'With boundary conditions?',LCBC

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LCFORC2D
      Write(*,*)'With forced concentrations?',LCFORC2D

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LCONC0
      Write(*,*)'Initial concentrations?',LCONC0

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LREAD_PHOTOLYSIS
      Write(*,*)'Photolytic constants?',LREAD_PHOTOLYSIS

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LREAD_VERTICAL_WIND
      Write(*,*)'Vertical wind?',LREAD_VERTICAL_WIND

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LTEMPU
      write(*,*)'Temperature?',ltempu

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LPRESSU
      Write(*,*)'Pression?',LPRESSU

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LATTENUATION
      Write(*,*)'Cloud attenuation?',LATTENUATION

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LHUMU
      Write(*,*)'Humidity?',LHUMU

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LRAINU
      Write(*,*)'Precipitations?',LRAINU

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LCLOUDU
      Write(*,*)'Cloud basis?',LCLOUDU
      IF ((.NOT.LCLOUDU).AND.LSCAV) THEN
         PRINT *,'!!!  ERROR  !!!'
         PRINT *,'Heights of cloud basis data needed!'
         STOP
      ENDIF

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)KH
      Write(*,*)'Horizontal diffusion coefficient ([m^2/s]):',KH

C------------------------------------------------------------------------
C     5 - Remaining options

      Write(*,*)

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LCOMMENT
      Write(*,*)'Comments?',LCOMMENT

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LPOST
      Write(*,*)'Post treatment?',LPOST
      IF(LPOST)THEN
         CALL INITPOST
      ELSE
         WRITE(*,*)'Without post treatment'
      ENDIF

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)LSTART
      Write(*,*)'Restarting from a previous simulation?',LSTART

      READ(NUC,*)
      READ(NUC,*)
      If(LSTART) THEN
         READ(NUC,*)NSTART
         Write(*,*)'From:',NSTART
      Else
         READ(NUC,*)
      Endif

      Write(*,*)

      Write(*,*)
     s     '=============== End configuration =============='

      CLOSE(NUC)

      END
