C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE INITCTM2 (
     s     ts,tf,Nmeteo,Nmeteof,ALFAmeteo,ALFAmeteof,
     s     NKz,NKzf,alpha_Kz,alpha_Kz_f,
     s     NCforc2d,NCforc2df,ALFACforc2d,ALFACforc2df,
     s     Nvdep,Nvdepf,ALFAvdep,ALFAvdepf,
     s     Nsourc,Nsourcf,ALFAsourc,ALFAsourcf,
     s     Nemis,Nemisf,ALFAemis,ALFAemisf,
     s     Ncl,Nclf,ALFAcl,ALFAclf,
     s     Ui,Vi,Wi,DRKz,DLrain,DLhcloud,DLattenuation,DLhumid,DLtemp,
     s     DLpress,DLtempsurf,DLpresurf,DLsnow,DLraysoli,DLlhflux,
     $     DLswat,DLmodwind,
     s     Uf,Vf,Wf,DRKzf,DLrainf,DLhcloudf,DLattenuationf,DLhumidf,
     s     DLtempf,DLpressf,DLtempsurff,DLpresurff,DLsnowf,DLraysolif,
     $     DLlhfluxf,DLswatf,DLmodwindf,
     s     DLCforc2d,DLCforc2df,DLCemis,DLCemisf,
     s     DLVdep,DLVdepf,DLCsourc,DLCsourcf,DLscavg,DLscavgf,
     s     DLCclx,DLCclxf,DLCcly,DLCclyf,DLCclz,DLCclzf,
     s     DLCphotolysis_rates,DLCphotolysis_ratesf,
     s     DGUi,DGVi,DGWi,DGKz,DGattenuation,DGhumid,DGtemp,DGrain,
     $     DGhcloud,DGpress,DGtempsurf,DGpresurf,DGsnow,DGraysoli,
     $     DGlhflux,DGswat,DGmodwind,
     s     DGUf,DGVf,DGWf,DGKzf,DGattenuationf,DGhumidf,DGtempf,DGrainf,
     s     DGhcloudf,DGpressf,DGtempsurff,DGpresurff,DGsnowf,DGraysolif,
     $     DGlhfluxf,DGswatf,DGmodwindf,
     s     DGCforc2d,DGCforc2df,DGCemis,DGCemisf,
     s     DGVdep,DGVdepf,DGCsourc,DGCsourcf,
     s     DGCclx,DGCclxf,DGCcly,DGCclyf,DGCclz,DGCclzf)


C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine initializes the CTM. It computes all fields by
C     interpolating.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     NMETEO, NMETEOF: interpolation (for meteorological data) is
C     # performed between iterations NMETEO and NMETEOF.
C     ALFAMETEO, ALFAMETEOF: interpolation coefficients
C     # (for meteorological data).
C     NKZ, NKZF: interpolation (for vertical diffusion) is
C     # performed between iterations NKZ and NKZF.
C     ALPHA_KZ, ALPHA_KZ_F: interpolation coefficients
C     # (for vertical diffusion).
C     NCFORC2D, NCFORC2DF: interpolation (for forced concentrations) is
C     # performed between iterations NCFORC2D and NCFORC2DF.
C     ALFACFORC2D, ALFACFORC2DF: interpolation coefficients
C     # (for forced concentrations).
C     NVDEP, NVDEPF: interpolation (for deposition velocities) is
C     # performed between iterations NVDEP and NVDEPF.
C     ALFAVDEP, ALFAVDEPF: interpolation coefficients
C     # (for deposition velocities).
C     NSOURC, NSOURCF: interpolation (for volumic emissions) is
C     # performed between iterations NSOURC and NSOURCF.
C     ALFASOURC, ALFASOURCF: interpolation coefficients
C     # (for volumic emissions).
C     NEMIS, NEMISF: interpolation (for surfacic emissions) is
C     # performed between iterations NEMIS and NEMISF.
C     ALFAEMIS, ALFAEMISF: interpolation coefficients
C     # (for surfacic emissions).
C     NCL, NCLF: interpolation (for boundary conditions) is
C     # performed between iterations NCL and NCLF.
C     ALFANCL, ALFANCLF: interpolation coefficients
C     # (for boundary conditions).
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     UI, VI, WI: 3D wind fields at initial time along X, Y, Z.
C     DRKZ: 3D Kz field at initial time.
C     DLRAIN: 2D rain intensity field at initial time.
C     DLHCLOUD: 2D height of cloud basis at initial time.
C     DLATTENUATION: 3D cloud attenuation field at initial time.
C     DLHUMID: 3D specific humidity field at initial time.
C     DLTEMP: 3D temperature field at initial time.
C     DLPRESS: 3D pressure field at initial time.
C     DLCFORC2D: forced concentrations at initial time.
C     DLVDEP: deposition velocities at initial time.
C     DLCSOURC: volumic emissions at initial time.
C     DLCEMIS: surfacic emissions at initial time.
C     DLSCAV: Scavenging coefficient.
C     DLCPHOTOLYSIS_RATES: photolysis rates at initial time.
C     DLCCLX, DLCCLY, DLCCLZ: boundary conditions at initial time
C     # along X, Y and Z.
C     
C     The same variables are defined at final time of the timestep.
C     'f' is then put at the end of the name.
C     
C     In the same way, variables are defined with respect to the
C     timestep of input data.
C     
C     DGUI, DGVI, DGWI: 3D wind fields at initial time along X, Y, Z.
C     DGKZ: 3D Kz field at initial time.
C     DGRAIN: 2D rain intensity field at initial time.
C     DGCLOUD: 2D height of cloud basis at initial time.
C     DGATTENUATION: 3D cloud attenuation field at initial time.
C     DGHUMID: 3D specific humidity field at initial time.
C     DGTEMP: 3D temperature field at initial time.
C     DGPRESS: 3D pressure field at initial time.
C     DGCFORC2D: forced concentrations at initial time.
C     DGVDEP: deposition velocities at initial time.
C     DGCSOURC: volumic emissions at initial time.
C     DGCEMIS: surfacic emissions at initial time.
C     DGCCLX, DGCCLY, DGCCLZ: boundary conditions at initial time
C     # along X, Y and Z.
C     
C     The same variables are defined at final time of the timestep.
C     'f' is then put at the end of the name.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMUSE: flags and parameters for numerics. 

      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMUSE.INC'

C     Points de la  grille des donnees

      DOUBLE PRECISION Ui(NX+1,NY,NZ),Uf(NX+1,NY,NZ)
      DOUBLE PRECISION Vi(NX,NY+1,NZ),Vf(NX,NY+1,NZ)
      DOUBLE PRECISION Wi(NX,NY,NZ+1),Wf(NX,NY,NZ+1)
      DOUBLE PRECISION DRkz(NX,NY,NZ+1),DRkzf(NX,NY,NZ+1)
      DOUBLE PRECISION DLtemp(NXt,NYt,NZt),DLtempf(NXt,NYt,NZt)
      DOUBLE PRECISION DLrain(NXr,NYr),DLrainf(NXr,NYr)
      DOUBLE PRECISION DLhcloud(NXr,NYr),DLhcloudf(NXr,NYr)
      DOUBLE PRECISION DLattenuation(NXatt,NYatt,NZatt)
      DOUBLE PRECISION DLattenuationf(NXatt,NYatt,NZatt)
      DOUBLE PRECISION DLhumid(NXh,NYh,NZh),DLhumidf(NXh,NYh,NZh)
      DOUBLE PRECISION DLpress(NXp,NYp,NZp),DLpressf(NXp,NYp,NZp)
      DOUBLE PRECISION DLtempsurf(NXdd,NYdd),DLtempsurff(NXdd,NYdd)
      DOUBLE PRECISION DLpresurf(NXdd,NYdd),DLpresurff(NXdd,NYdd)
      DOUBLE PRECISION DLsnow(NXdd,NYdd),DLsnowf(NXdd,NYdd)
      DOUBLE PRECISION DLraysoli(NXdd,NYdd),DLraysolif(NXdd,NYdd)
      DOUBLE PRECISION DLlhflux(NXdd,NYdd),DLlhfluxf(NXdd,NYdd)
      DOUBLE PRECISION DLswat(NXdd,NYdd,Nlayer)
      DOUBLE PRECISION DLswatf(NXdd,NYdd,Nlayer)
      DOUBLE PRECISION DLmodwind(NXdd,NYdd),DLmodwindf(NXdd,NYdd)
      
      DOUBLE PRECISION DLCforc2d(Nxf,Nyf,NESPF)
      DOUBLE PRECISION DLCforc2df(Nxf,Nyf,NESPF)
      DOUBLE PRECISION DLCsourc(Nx,Ny,Nzs,Nsrc)
      DOUBLE PRECISION DLCsourcf(Nx,Ny,Nzs,Nsrc)
      DOUBLE PRECISION DLCemis(Nx,Ny,Nemi),DLCemisf(Nx,Ny,Nemi)
      DOUBLE PRECISION DLVdep(Nxdd,Nydd,Ndep),DLVdepf(Nxdd,Nydd,Ndep)
      DOUBLE PRECISION DLscavg(NXr,NYr,NZ,Nscav)
      DOUBLE PRECISION DLscavgf(NXr,NYr,NZ,Nscav)

      DOUBLE PRECISION DLCclx(2,Nyl,Nzl,Nspcl)
      DOUBLE PRECISION DLCclxf(2,Nyl,Nzl,Nspcl)

      DOUBLE PRECISION DLCcly(Nxl,2,Nzl,Nspcl)
      DOUBLE PRECISION DLCclyf(Nxl,2,Nzl,Nspcl)

      DOUBLE PRECISION DLCclz(Nxl,Nyl,Nspcl)
      DOUBLE PRECISION DLCclzf(Nxl,Nyl,Nspcl)
      DOUBLE PRECISION DLCphotolysis_rates(NRphot,Nx,Ny,Nz)
      DOUBLE PRECISION DLCphotolysis_ratesf(NRphot,Nx,Ny,Nz)

      REAL DGUi(NX+1,NY,NZ),DGUf(NX+1,NY,NZ)
      REAL DGVi(NX,NY+1,NZ),DGVf(NX,NY+1,NZ)
      REAL DGWi(NX,NY,NZ+1),DGWf(NX,NY,NZ+1)
      REAL DGKz(NX,NY,NZ+1),DGKzf(NX,NY,NZ+1)
      REAL DGtemp(NXt,NYt,NZt),DGtempf(NXt,NYt,NZt)
      REAL DGrain(NXr,NYr),DGrainf(NXr,NYr)
      REAL DGhcloud(NXr,NYr),DGhcloudf(NXr,NYr)
      REAL DGattenuation(NXatt,NYatt,NZatt)
      REAL DGattenuationf(NXatt,NYatt,NZatt)
      REAL DGhumid(NXh,NYh,NZh),DGhumidf(NXh,NYh,NZh)
      REAL DGpress(NXp,NYp,NZp),DGpressf(NXp,NYp,NZp)
      REAL DGtempsurf(NXdd,NYdd),DGtempsurff(NXdd,NYdd)
      REAL DGpresurf(NXdd,NYdd),DGpresurff(NXdd,NYdd)
      REAL DGsnow(NXdd,NYdd),DGsnowf(NXdd,NYdd)
      REAL DGraysoli(NXdd,NYdd),DGraysolif(NXdd,NYdd)
      REAL DGlhflux(NXdd,NYdd),DGlhfluxf(NXdd,NYdd)
      REAL DGswat(NXdd,NYdd,Nlayer),DGswatf(NXdd,NYdd,Nlayer)
      REAL DGmodwind(NXdd,NYdd),DGmodwindf(NXdd,NYdd)

      REAL DGCforc2d(Nxf,Nyf,NESPF),DGCforc2df(Nxf,Nyf,NESPF)
      REAL DGVdep(NXdd,NYdd,Ndep),DGVdepf(NXdd,NYdd,Ndep)
      REAL DGCsourc(Nx,Ny,Nzs,Nsrc),DGCsourcf(Nx,Ny,Nzs,Nsrc)
      REAL DGCemis(Nx,Ny,Nemi),DGCemisf(Nx,Ny,Nemi)
      REAL DGCclx(2,Nyl,Nzl,Nspcl),DGCclxf(2,Nyl,Nzl,Nspcl)
      REAL DGCcly(Nxl,2,Nzl,Nspcl),DGCclyf(Nxl,2,Nzl,Nspcl)
      REAL DGCclz(Nxl,Nyl,Nspcl),DGCclzf(Nxl,Nyl,Nspcl)

      INTEGER Nmeteo,Nmeteof
      INTEGER NKz,NKzf
      INTEGER NCforc2d,NCforc2df
      INTEGER Nvdep,Nvdepf
      INTEGER Nsourc,Nsourcf
      INTEGER Nemis,Nemisf
      INTEGER Ncl,Nclf

      DOUBLE PRECISION ts,tf
      DOUBLE PRECISION ALFAmeteo,ALFAmeteof
      DOUBLE PRECISION alpha_Kz,alpha_Kz_f
      DOUBLE PRECISION ALFACforc2d,ALFACforc2df
      DOUBLE PRECISION ALFAvdep,ALFAvdepf
      DOUBLE PRECISION ALFAsourc,ALFAsourcf
      DOUBLE PRECISION ALFAemis,ALFAemisf
      DOUBLE PRECISION ALFAcl,ALFAclf

      DOUBLE PRECISION temp(Nxdd,Nydd),tempf(Nxdd,Nydd)
      DOUBLE PRECISION press(Nxdd,Nydd),pressf(Nxdd,Nydd)
      DOUBLE PRECISION humid(Nxdd,Nydd),humidf(Nxdd,Nydd)

      INTEGER Jj,Ji

C------------------------------------------------------------------------
C     1 - Meteorological data

C     1.1 - Wind, K_z, precipitations, cloud attenuation,
C     humidity, temperature and pression

      CALL INITMETEO(Nmeteo,Nmeteof,ALFAmeteo,ALFAmeteof,
     $     NKz,NKzf,alpha_Kz,alpha_Kz_f,
     s     Ui,Vi,Wi,DRKz,DLrain,DLhcloud,DLattenuation,DLhumid,DLtemp,
     $     DLpress,DLtempsurf,DLpresurf,DLsnow,DLraysoli,DLlhflux,
     $     DLswat,DLmodwind,
     s     Uf,Vf,Wf,DRKzf,DLrainf,DLhcloudf,DLattenuationf,DLhumidf,
     $     DLtempf,DLpressf,DLtempsurff,DLpresurff,DLsnowf,DLraysolif,
     $     DLlhfluxf,DLswatf,DLmodwindf,
     s     DGUi,DGVi,DGWi,DGKz,DGattenuation,DGhumid,DGtemp,DGrain,
     $     DGhcloud,DGpress,DGtempsurf,DGpresurf,DGsnow,DGraysoli,
     $     DGlhflux,DGswat,DGmodwind,
     s     DGUf,DGVf,DGWf,DGKzf,DGattenuationf,DGhumidf,DGtempf,
     s     DGrainf,DGhcloudf,DGpressf,DGtempsurff,DGpresurff,DGsnowf,
     $     DGraysolif,DGlhfluxf,DGswatf,DGmodwindf)

C     1.2 -  Horizontal diffusion

      IF (LDIFF) CALL KDIFFH

C------------------------------------------------------------------------
C     2 - Forced concentrations

      IF (LCHIM.AND.LCFORC2D) THEN
         CALL INITCONCF(NCforc2d,NCforc2df,ALFACforc2d,ALFACforc2df,
     s        DLCforc2d,DLCforc2df,DGCforc2d,DGCforc2df)
      ENDIF

C------------------------------------------------------------------------
C     3 - Deposition velocities

      IF(LDIFF.AND.LVDEPO)THEN

         IF (LVDEPOCOMP) THEN
            DO Jj=1,Nydd
               DO Ji=1,Nxdd
                  temp(Ji,Jj)=DLtemp(Ji,Jj,1)
                  tempf(Ji,Jj)=DLtempf(Ji,Jj,1)
                  press(Ji,Jj)=DLpress(Ji,Jj,1)
                  pressf(Ji,Jj)=DLpressf(Ji,Jj,1)
                  humid(Ji,Jj)=DLhumid(Ji,Jj,1)
                  humidf(Ji,Jj)=DLhumidf(Ji,Jj,1)
               ENDDO
            ENDDO
         ENDIF

         CALL INITVDEPO(ts,tf,Nvdep,Nvdepf,ALFAvdep,ALFAvdepf,
     s        DLmodwind,DLmodwindf,DLrain,DLrainf,humid,humidf,
     $        temp,tempf,DLtempsurf,DLtempsurff,press,pressf,
     $        DLpresurf,DLpresurff,DLsnow,DLsnowf,DLraysoli,DLraysolif,
     $        DLlhflux,DLlhfluxf,DLswat,DLswatf,DLVdep,DLVdepf,
     $        DGVdep,DGVdepf)
      ENDIF 
      
C------------------------------------------------------------------------
C     4 - Surfacic emissions

      IF (LDIFF.AND.LEMISS) THEN
         CALL INITEMIS(Nemis,Nemisf,ALFAemis,ALFAemisf,
     s        DLCemis,DLCemisf,DGCemis,DGCemisf)
      ENDIF

C------------------------------------------------------------------------
C     5 - Photolytic constants

      IF (LCHIM.AND.LREAD_PHOTOLYSIS) THEN
         CALL INITPHOTOLYSIS(ts, tf, DLCphotolysis_rates,
     $        DLCphotolysis_ratesf)
      ENDIF

      
C------------------------------------------------------------------------
C     6 - Volumic emissions

      IF(LCHIM.AND.LSOURC)THEN
         CALL INITCONSOURC(Nsourc,Nsourcf,ALFAsourc,ALFAsourcf,
     s        DLCsourc,DLCsourcf,DGCsourc,DGCsourcf)
      ENDIF

C------------------------------------------------------------------------
C     7 - Boundary conditions

      IF(LADVEC.AND.LCBC)THEN
         CALL INITCL(Ncl,Nclf,ALFAcl,ALFAclf,
     s        DLCclx,DLCclxf,DGCclx,DGCclxf,
     s        DLCcly,DLCclyf,DGCcly,DGCclyf,
     s        DLCclz,DLCclzf,DGCclz,DGCclzf)
      ENDIF

C------------------------------------------------------------------------
C     8 - Scavenging coefficient

      IF (LSCAV) THEN
         CALL INITSCAV(DLrain,DLtemp,DLpress,DLhcloud,DLscavg,
     &        DLrainf,DLtempf,DLpressf,DLhcloudf,DLscavgf)
      ENDIF

      END
