C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE INITDOM

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine sets the mesh.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C     Grid node is a common point between four interfaces, and node is
C     a cell center.
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     CONST: physical constants.
C     PARADOM: parameters for all forced fields.
C     COMDOM: global variables for the domain.
C     COMUSE: flags and parameters for numerics. 

      INCLUDE 'CONST.INC'
      INCLUDE 'PARADOM.INC'
      INCLUDE 'COMDOM.INC'
      INCLUDE 'COMUSE.INC'
      
      DOUBLE PRECISION Zx(Nx+1,Ny+1,Nz+1),Zy(Nx+1,Ny+1,Nz+1)
      DOUBLE PRECISION Zz(Nx+1,Ny+1,Nz+1)
      DOUBLE PRECISION Zlon(Nx+1,Ny+1,Nz+1),Zlat(Nx+1,Ny+1,Nz+1)
      DOUBLE PRECISION Dxx(Nx,Ny,Nz)
      INTEGER Ji,Jj,Jk


C------------------------------------------------------------------------
C     1 - Vertical grid

      CALL READMAILLAGE

C------------------------------------------------------------------------
C     2 - Horizontal grid

C     2.1 - Grid nodes coordinates

      IF(CGRILLE.EQ.'LALON')THEN ! Latitude/longitude coordinates.

         DO Jk=1,Nz+1
            DO Jj=1,Ny+1

C     Grid nodes coordinates (longitudes and abscissae).

               DO Ji=1,Nx+1

                  IF(Ji.EQ.1)THEN
                     Zlon(Ji,Jj,Jk)=Dlon0
                     Zx(Ji,Jj,Jk)=Ray*Zlon(Ji,Jj,Jk)*PI/180.D0
                  ELSE
                     Zlon(Ji,Jj,Jk)=Zlon(Ji-1,Jj,Jk)+Ddlon(Ji)
                     Zx(Ji,Jj,Jk)=Ray*Zlon(Ji,Jj,Jk)*PI/180.D0
                  ENDIF

               ENDDO

            ENDDO
         ENDDO

         DO Jk=1,Nz+1
            DO Ji=1,Nx+1

C     Grid nodes coordinates (latitudes and ordinates).

               DO Jj=1,Ny+1

                  IF(Jj.EQ.1)THEN
                     Zlat(Ji,Jj,Jk)=Dlat0
                     Zy(Ji,Jj,Jk)=Ray*sin(Zlat(Ji,Jj,Jk)*PI/180.D0)
                  ELSE
                     Zlat(Ji,Jj,Jk)=Zlat(Ji,Jj-1,Jk)+Ddlat(Jj)
                     Zy(Ji,Jj,Jk)=Ray*sin(Zlat(Ji,Jj,Jk)*PI/180.D0)
                  ENDIF

               ENDDO

            ENDDO
         ENDDO

      ELSEIF(CGRILLE.EQ.'LCART')THEN ! cartesian coordinates.


         DO Jk=1,Nz+1
            DO Jj=1,Ny+1

C     Grid nodes abscissae.

               Zx(1,Jj,Jk)=Dx0

               DO Ji=2,Nx+1
                  Zx(Ji,Jj,Jk)=Zx(Ji-1,Jj,Jk)+Ddx(Ji)
               ENDDO

            ENDDO
         ENDDO

         DO Jk=1,Nz+1
            DO Ji=1,Nx+1

C     Grid nodes ordinates.

               DO Jj=1,Ny+1

                  IF(Jj.EQ.1)THEN
                     Zy(Ji,Jj,Jk)=Dy0
                  ELSE
                     Zy(Ji,Jj,Jk)=Zy(Ji,Jj-1,Jk)+Ddy(Jj)
                  ENDIF

               ENDDO
            ENDDO
         ENDDO

      ENDIF

      DO Jk=1,Nz+1
         DO Jj=1,Ny+1
            DO Ji=1,Nx+1
               Zz(Ji,Jj,Jk)=Maillage(Jk)
            ENDDO
         ENDDO
      ENDDO

C     2.2 - Cells centers coordinates.

      DO Jk=1,Nz
         DO Jj=1,Ny
            DO Ji=1,Nx
               Dxx(Ji,Jj,Jk)=DBLE(Zx(Ji,Jj,Jk)+Zx(Ji+1,Jj,Jk))/2.D0
               Dyy(Ji,Jj,Jk)=DBLE(Zy(Ji,Jj,Jk)+Zy(Ji,Jj+1,Jk))/2.D0
               Dzz(Ji,Jj,Jk)=DBLE(Zz(Ji,Jj,Jk)+Zz(Ji,Jj,Jk+1))/2.D0
            ENDDO
         ENDDO
      ENDDO

      IF(CGRILLE.EQ.'LALON')THEN

         DO Jk=1,Nz
            DO Jj=1,Ny
               DO Ji=1,Nx
                  Dlon(Ji,Jj,Jk)=Dxx(Ji,Jj,Jk)/Ray/PI*180.D0
                  Dlat(Ji,Jj,Jk)=asin(Dyy(Ji,Jj,Jk)/Ray)*180.D0/PI
               ENDDO
            ENDDO
         ENDDO

      ELSEIF(CGRILLE.EQ.'LCART')THEN
         CALL READLATLON
      ENDIF

C     2.3 - Distances between cells interfaces and between cells centers.

C     Along X.
      DO Ji=1,Nx
         Dmx(Ji)=DBLE(Zx(Ji+1,1,1)-Zx(Ji,1,1))
      ENDDO

      DO Ji=1,Nx
         IF(Ji.EQ.1)THEN
            Dcx(Ji)=Dmx(Ji)
         ELSE
            Dcx(Ji)=Dxx(Ji,1,1)-Dxx(Ji-1,1,1)
         ENDIF
      ENDDO


C     Along Y.
      DO Jj=1,Ny
         Dmy(Jj)=DBLE(Zy(1,Jj+1,1)-Zy(1,Jj,1))
      ENDDO

      DO Jj=1,Ny
         IF(Jj.EQ.1)THEN
            Dcy(Jj)=Dmy(Jj)
         ELSE
            Dcy(Jj)=Dyy(1,Jj,1)-Dyy(1,Jj-1,1)
         ENDIF
      ENDDO


C     Along Z.
      DO Jk=1,Nz
         DO Jj=1,Ny
            DO Ji=1,Nx

               Dmz(Ji,Jj,Jk)=DBLE(Zz(Ji,Jj,Jk+1)-Zz(Ji,Jj,Jk))

               IF(Jk.EQ.1)THEN
                  Dcz(Ji,Jj,Jk)=Dmz(Ji,Jj,Jk)
               ELSE
                  Dcz(Ji,Jj,Jk)=Dzz(Ji,Jj,Jk)-Dzz(Ji,Jj,Jk-1)
               ENDIF

            ENDDO
         ENDDO
      ENDDO

      END
