C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE INITEMIS(Nemis,Nemisf,ALFAemis,ALFAemisf,
     s     Cemis,Cemisf,DGCemis,DGCemisf)


C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine sets surfacic emissions.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     NEMIS, NEMISF: interpolation is performed between iterations NEMIS
C     # and NEMISF.
C     ALFAEMIS, ALFAEMISF: interpolation coefficients.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     CEMIS, CEMISF: interpolated surfacic emissions.
C     DGCEMIS, DGCEMISF: surfacic emissions from input file.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMDATA: data on forced fields.
C     COMLUN: global variables for unit numbers.
C     COMFILES: global variables for files names.

      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMDATA.INC'
      INCLUDE 'COMLUN.INC'
      INCLUDE 'COMFILES.INC'

      DOUBLE PRECISION Cemis(Nx,Ny,Nemi)
      DOUBLE PRECISION Cemisf(Nx,Ny,Nemi)

      REAL DGCemis(NX,NY,Nemi)
      REAL DGCemisf(NX,NY,Nemi)

      INTEGER Nemis,Nemisf
      DOUBLE PRECISION ALFAemis,ALFAemisf

      INTEGER Ji,Jj,Jsp


      IF(LITER)THEN             ! First iteration.

C     Read data.
         DO Jsp=1,Nemi

            OPEN(unit=NULEMIS,file=file_emis(Jsp),
     s           access='direct',form='unformatted',recl=4*(Nx)*(Ny))

            READ(NULEMIS,rec=Nemis)
     s           ((DGCemis(Ji,Jj,Jsp),Ji=1,Nx),Jj=1,Ny)

            IF (Iabs(Nemis-Nemisf).NE.1) THEN
               READ(NULEMIS,rec=(Nemis+Nemisf)/2)
     s              ((DGCemisf(Ji,Jj,Jsp),Ji=1,Nx),Jj=1,Ny)
            ELSE
               READ(NULEMIS,rec=Nemisf)
     s              ((DGCemisf(Ji,Jj,Jsp),Ji=1,Nx),Jj=1,Ny)
            ENDIF

            CLOSE (NULEMIS)
         ENDDO

C     Interpolation for Cemis.
         DO Jsp=1,Nemi
            DO Jj=1,Ny
               DO Ji=1,Nx
                  Cemis(Ji,Jj,Jsp)=ALFAemis*DBLE(DGCemis(Ji,Jj,Jsp))
     s                 +(1.D0-ALFAemis)*DBLE(DGCemisf(Ji,Jj,Jsp))
               ENDDO   
            ENDDO
         ENDDO

      ENDIF                     ! End of first iteration test.

      IF (Iabs(Nemis-Nemisf).NE.1) THEN

         DO Jsp=1,Nemi
            DO Jj=1,Ny
               DO Ji=1,Nx
                  DGCemis(Ji,Jj,Jsp)=DGCemisf(Ji,Jj,Jsp)
               ENDDO
            ENDDO
         ENDDO

C     Read data.
         DO Jsp=1,Nemi

            OPEN(unit=NULEMIS,file=file_emis(Jsp),
     s           access='direct',form='unformatted',
     $           recl=4*(Nx)*(Ny))

            READ(NULEMIS,rec=Nemisf)
     s           ((DGCemisf(Ji,Jj,Jsp),Ji=1,Nx),Jj=1,Ny)

            CLOSE(NULEMIS)
         ENDDO

      ENDIF

      DO Jsp=1,Nemi
         DO Jj=1,Ny
            DO Ji=1,Nx
               IF (.NOT.LITER) Cemis(Ji,Jj,Jsp)=Cemisf(Ji,Jj,Jsp)
            ENDDO 
         ENDDO
      ENDDO

C     Interpolation for Cemisf.
      DO Jsp=1,Nemi
         DO Jj=1,Ny
            DO Ji=1,Nx
               Cemisf(Ji,Jj,Jsp)=ALFAemisf*DBLE(DGCemis(Ji,Jj,Jsp))
     s              +(1.D0-ALFAemisf)*DBLE(DGCemisf(Ji,Jj,Jsp))
            ENDDO
         ENDDO
      ENDDO

      END
