C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE INITPHYS

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine sets physical constants for species.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMDATA: data on forced fields.

      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMPHYS.INC'
      INCLUDE 'COMFILES.INC'
      INCLUDE 'COMUSE.INC'
      INCLUDE 'COMCHEM.INC'

      CHARACTER*200 species_names_input
      INTEGER NUC,i,Ilect,Nesptot
      DOUBLE PRECISION Mm,Dd,Hh,Cr

      Nesptot=Nesp
      IF (LCFORC2D) Nesptot=Nesp+Nespf

      NUC=4
      OPEN(NUC,FILE ='CONTROL/NAMPHYS',STATUS = 'OLD')

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)

C------------------------------------------------------------------------
C     1. Read data for molar mass.

      DO i=1,Nesptot
         Wmol(i)=-1.d0
      ENDDO
      
      Ilect=1
      
      DO WHILE(Ilect.EQ.1)
         
         READ(NUC,*) species_names_input,Mm
         
         IF(species_names_input.EQ.'END')THEN
            Ilect=0
         ELSE
            DO i=1,Nesptot
               IF (species_names_input.EQ.species_names(i)) Wmol(i)=Mm
            ENDDO
         ENDIF
         
      ENDDO
      
      DO i=1,Nesptot
         IF (Wmol(i).LT.0.D0) THEN
            write(*,*) 'ERROR no molecular mass specified for species:',
     s           species_names(i)
            stop
         ENDIF
      ENDDO
      
C------------------------------------------------------------------------
C     2. Read data for gas-phase diffusivity.

      READ(NUC,*)
      READ(NUC,*)

      IF (LVDEPOCOMP.OR.LSCAV) THEN

         DO i=1,Ndep
            Ddifdep(i)=-1.d0
         ENDDO

         DO i=1,Nscav
            Ddifscav(i)=-1.d0
         ENDDO

         Ilect=1

         DO WHILE(Ilect.EQ.1)
            READ(NUC,*) species_names_input,Dd
            IF(species_names_input.EQ.'END')THEN
               Ilect=0
            ELSE
               IF (LVDEPOCOMP) THEN
                  DO i=1,Ndep
                     IF (species_names_input.EQ.
     $                    species_names(Nespd(i))) THEN
                        Ddifdep(i)=Dd
                     ENDIF
                  ENDDO
               ENDIF
               IF (LSCAV) THEN
                  DO i=1,Nscav
                     IF (species_names_input.EQ.
     $                    species_names(Nespsca(i)))
     $                    Ddifscav(i)=Dd
                  ENDDO
               ENDIF
            ENDIF
         ENDDO

      ENDIF         

      IF (LVDEPOCOMP) THEN
         DO i=1,Ndep
            IF (Ddifdep(i).LE.0.d0) THEN
               WRITE(*,*) 'ERROR NO GAS PHASE DIFFUSIVITY FOR:',
     $              species_names(Nespd(i)) 
               STOP
            ENDIF
         ENDDO
      ENDIF

      IF (LSCAV) THEN
         DO i=1,Nscav
            IF (Ddifscav(i).LE.0.d0) THEN
               WRITE(*,*) 'ERROR NO GAS PHASE DIFFUSIVITY FOR:',
     $              species_names(Nespsca(i)) 
               STOP
            ENDIF
         ENDDO
      ENDIF
      
C------------------------------------------------------------------------
C     3. Read data for Henry constant.

      READ(NUC,*)
      READ(NUC,*)
      
      IF (LVDEPOCOMP.OR.LSCAV) THEN 

         DO i=1,Ndep
            Hhenrydep(i)=-1.d0
         ENDDO

         DO i=1,Nscav
            Hhenryscav(i)=-1.d0
         ENDDO

         Ilect=1

         DO WHILE(Ilect.EQ.1)
            READ(NUC,*) species_names_input,Hh
            IF(species_names_input.EQ.'END')THEN
               Ilect=0
            ELSE
               IF (LVDEPOCOMP) THEN
                  DO i=1,Ndep
                     IF (species_names_input.EQ.
     $                    species_names(Nespd(i)))THEN
                        Hhenrydep(i)=Hh
                     ENDIF
                  ENDDO
               ENDIF
               IF (LSCAV) THEN
                  DO i=1,Nscav
                     IF (species_names_input.EQ.
     $                    species_names(Nespsca(i)))
     $                    Hhenryscav(i)=Hh
                  ENDDO
               ENDIF
            ENDIF
         ENDDO
         
      ENDIF

      IF (LVDEPOCOMP) THEN
         DO i=1,Ndep
            IF (Hhenrydep(i).LE.0.d0) THEN
               WRITE(*,*) 'ERROR NO HENRY CONSTANT FOR:',
     $              species_names(Nespd(i))
               STOP
            ENDIF
         ENDDO
      ENDIF
      
      IF (LSCAV) THEN
         DO i=1,Nscav
            IF (Hhenryscav(i).LE.0.d0) THEN
               WRITE(*,*) 'ERROR NO HENRY CONSTANT FOR:',
     $              species_names(Nespsca(i))
               STOP
            ENDIF
         ENDDO
      ENDIF

C------------------------------------------------------------------------
C     4 .Read data for chemical reactivity.
      
      READ(NUC,*)
      READ(NUC,*)
      
      IF (LVDEPOCOMP) THEN

         DO i=1,Ndep
            Freac(i)=-1.d0
         ENDDO

         Ilect=1
         
         DO WHILE(Ilect.EQ.1)
            READ(NUC,*) species_names_input,Cr
            IF(species_names_input.EQ.'END')THEN
               Ilect=0
            ELSE
               DO i=1,Ndep
                  IF (species_names_input.EQ.
     $                 species_names(Nespd(i))) THEN
                     Freac(i)=Cr
                  ENDIF
               ENDDO
            ENDIF
         ENDDO
         
         DO i=1,Ndep
            IF (Freac(i).LT.0.d0) THEN
               WRITE(*,*) 'ERROR NO CHEMICAL REACTIVITY FOR',
     $              species_names(Nespd(i))
               STOP
            ENDIF
         ENDDO
         
      ENDIF
      
      END
