C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE INITPOST

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine initializes variables related to post treatment.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C     This routine reads "NAMPOST".
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, February 2002.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMUSE: flags and parameters for numerics. 
C     COMPOST: global variables for post treatment.

      include 'PARADOM.INC'
      include 'PARACHEM.INC'
      INCLUDE 'COMUSE.INC'
      INCLUDE 'COMPOST.INC'

      INTEGER NUC,Ji

      
      IF(LPOST)THEN             ! If post treatment is required.

         NUC=43
         OPEN(NUC,FILE ='CONTROL/NAMPOST',STATUS ='OLD')

C------------------------------------------------------------------------
C     1 - Dry and wet deposition

         READ(NUC,*)

C     Dry deposition velocities?
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)LVD

C     Scavenging coefficient?
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)LSCAVG

C------------------------------------------------------------------------
C     2 - Chemical concentrations

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

C     Save chemical concentrations?
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*) LCespec

C     Precision (SINGLE or DOUBLE).
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*) PREC

C     Number of vertical levels to be saved.
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*) nlevpos

C     Vertical levels to be saved.
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*) (lev_espec(Ji),Ji=1,Nlevpos)

C     Should chemical concentrations be integrated in time?
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*) L_POST_INTEGRATION

C     Over how many time steps should concentrations be integrated?
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*) N_post_int

         CLOSE(NUC)

      ELSE

         WRITE(*,*)'-----------------'
         WRITE(*,*)'NO POST TREATMENT'
         WRITE(*,*)'-----------------'

      ENDIF


      END
