C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE INITSCAV (DLrain,DLtemp,DLpress,DLhcloud,DLscavg,
     &     DLrainf,DLtempf,DLpressf,DLhcloudf,DLscavgf)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine initializes below-cloud scavenging.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     DLRAIN: 2D rain intensity field at initial time. ([mm/h])
C     DLTEMP: 3D temperature field at initial time. ([K])
C     DLPRESS: 3D pressure field at initial time. ([K])
C     DLHCLOUD: 2D height of cloud basis at initial time. ([m])
C     
C     The same variables are defined at final time of the timestep.
C     'f' is then put at the end of the name.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     DLSCAVG: gas below-cloud scavenging ([s^{-1}])
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Yelva Roustan, CEREA, February 2003.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     CONST: constants.
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMDATA: data on forced fields.

      INCLUDE 'CONST.INC'
      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMDATA.INC'

      DOUBLE PRECISION DLtemp(NXt,NYt,NZt),DLtempf(NXt,NYt,NZt)
      DOUBLE PRECISION DLpress(NXp,NYp,NZp),DLpressf(NXp,NYp,NZp)
      DOUBLE PRECISION DLrain(NXr,NYr),DLrainf(NXr,NYr)
      DOUBLE PRECISION DLhcloud(NXr,NYr),DLhcloudf(NXr,NYr)

      DOUBLE PRECISION DLscavg(NXr,NYr,NZ,Nscav)
      DOUBLE PRECISION DLscavgf(NXr,NYr,NZ,Nscav)

      INTEGER i,j,k,Jsca

C-----------------------------------------------------------------------
C     1 - Compute DLscavg

      IF (LITER) THEN           ! First iteration.
         CALL COMP_SCAV(DLtemp,DLpress,DLrain,DLhcloud,DLscavg)
         
      ELSE
         DO Jsca=1,Nscav
            DO k=1,NZ
               DO j=1,NYr
                  DO i=1,NXr
                     DLscavg(i,j,k,Jsca)=DLscavgf(i,j,k,Jsca)
                  ENDDO
               ENDDO
            ENDDO
         ENDDO

      ENDIF

      CALL COMP_SCAV(DLtempf,DLpressf,DLrainf,DLhcloudf,DLscavgf)

      END
