C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE INITVDEPO1

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes cuticular, mesophyllic and ground resistances.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     -- OUTPUT VARIABLES (IN COMVDEPO.INC)
C     
C     DLrstcut: cuticular resistance ([s/m])
C     DLrstmes: mesophyllic resistance ([s/m])
C     DLrstsol: ground resistance ([s/m])
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C     Parameterization used in this subroutine is presented in
C     " Paramtrisation de la vitesse de dpt sec dans
C     un code de transport diffusion de polluants " (A. Boudrot and
C     L. Musson Genon, Tech. Report CEREVE 2001 )
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C     2001/01/06, by A. BOUDROT, change to DOUBLE PRECISION
c     change in declaration of parameters
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Luc Muson-Genon, CEREA.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     CONST: constants.
C     PARADOM: parameters for all forced fields.
C     COMCHEM: global variables for chemical species. 
C     COMPHYS: physical data for chemical species (molar mass). 
C     COMVDEPO: global variables for dry deposition velocities.

      INCLUDE 'PARACHEM.INC'
      INCLUDE 'CONST.INC'
      INCLUDE 'PARADOM.INC'
      INCLUDE 'COMCHEM.INC'
      INCLUDE 'COMPHYS.INC'
      INCLUDE 'COMVDEPO.INC'

C     Henry's constant and cuticular resistance for SO2.
      DOUBLE PRECISION PHenrySO2, DLrstcutSO2

      INTEGER Ji,Jj,Jdepot

C-----------------------------------------------------------------------
C     0 - Setup

      CALL readdrydep

      PHenrySO2 = 1.D5
      DLrstcutSO2 = 3500.D0

C-----------------------------------------------------------------------
C     1 - Computation of cuticular resistance for all species

      DO Jdepot = 1,Ndep
         DLrstcut(Jdepot) = DLrstcutSO2 / 
     &        ( Hhenrydep(Jdepot) / PHenrySO2 + Freac(Jdepot) )
      ENDDO

C-----------------------------------------------------------------------
C     2 - Computation of mesophyllic resistance for all species

      DO Jdepot = 1,Ndep
         DLrstmes(Jdepot) =
     &        1.d0/(Hhenrydep(Jdepot)/3000.d0 + 100.d0*Freac(Jdepot))
      ENDDO

C-----------------------------------------------------------------------
C     3 - Computation of ground resistance for all species

      DO Jj=1,Nseason
         DO Ji=1,Nland

            DO Jdepot = 1,Ndep
               DLrstsol(Jdepot,Ji,Jj)=1.d0/(Hhenrydep(Jdepot)/
     &              ( PHenrySO2 * DLrslso2(Ji,Jj))
     $              + Freac(Jdepot)/DLrslo3(Ji,Jj))
            ENDDO

         ENDDO
      ENDDO

      END
