C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE readdrydep

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine reads Land Use Category for each cells.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Roustan Yelva, CEREA, March 2003.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     CONST: constants.
C     PARADOM: parameters parameters for sizes of 'chemical' arrays.
C     COMVDEPO: global variable for dry deposition. 
C     COMLUN: global variables for unit numbers.

      INCLUDE 'PARADOM.INC'
      INCLUDE 'CONST.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMVDEPO.INC'
      INCLUDE 'COMLUN.INC'

      INTEGER Ji,Jj,Jk,NUC
      REAL Ztyp(NXdd,NYdd,Nland)
      CHARACTER*200 file_luc
      CHARACTER*200 file_zo
      CHARACTER*200 file_hdep
      CHARACTER*200 file_lai
      CHARACTER*200 file_rslso2
      CHARACTER*200 file_rslo3
      CHARACTER*200 file_stom

      NUC=4
      OPEN(NUC,FILE='CONTROL/NAMVDEPO',STATUS='OLD')

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)

      DO Jk=1,Ndep
         READ(NUC,*)
      ENDDO

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)

C     Reading LUC percentage in each cell.
      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)file_luc

      OPEN(unit=NULVDEP,file=file_luc
     s     ,access='direct'
     s     ,form='unformatted'
     s     ,recl=(NXdd*NYdd*Nland*4))
      READ(NULVDEP,rec=1)
     $     (((Ztyp(Ji,Jj,Jk),Ji=1,NXdd),Jj=1,NYdd),Jk=1,Nland)
      CLOSE(NULVDEP)

      DO Jk=1,Nland
         DO Jj=1,Nydd
            DO Ji=1,Nxdd
               DLtyp(Ji,Jj,Jk)=DBLE(Ztyp(Ji,Jj,Jk)) 
            ENDDO
         ENDDO
      ENDDO

C     Reading sea LUC number.
      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)Ilandsea

C     Reading dynamical roughness.
      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)file_zo

      OPEN(NULVDEP,file=file_zo)
      READ(NULVDEP,*)
     $     ((DLrugdyn(Ji,Jj),Ji=1,Nland),Jj=1,Nseason)
      CLOSE(NULVDEP)

C     Computing thermal roughness.
      
      DO Jj=1,Nseason
         DO Ji=1,Nland
            DLrugthe(Ji,Jj)=DLrugdyn(Ji,Jj)*DEXP(-2.d0)
         ENDDO
      ENDDO

C     Reading displacement height.
      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)file_hdep

      OPEN(NULVDEP,file=file_hdep)
      READ(NULVDEP,*)
     $     ((DLhdep(Ji,Jj),Ji=1,Nland),Jj=1,Nseason)
      CLOSE(NULVDEP)

C     Reading Leaf Aera Index.
      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)file_lai

      OPEN(NULVDEP,file=file_lai)
      READ(NULVDEP,*)
     $     ((DLlai(Ji,Jj),Ji=1,Nland),Jj=1,Nseason)
      CLOSE(NULVDEP)

C     Reading SO2 soil surface resistance.
      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)file_rslso2

      OPEN(NULVDEP,file=file_rslso2)
      READ(NULVDEP,*)
     $     ((DLrslso2(Ji,Jj),Ji=1,Nland),Jj=1,Nseason)
      CLOSE(NULVDEP)

C     Reading O3 soil surface resistance.
      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)file_rslo3

      OPEN(NULVDEP,file=file_rslo3)
      READ(NULVDEP,*)
     $     ((DLrslo3(Ji,Jj),Ji=1,Nland),Jj=1,Nseason)
      CLOSE(NULVDEP)

C     Reading data about stomatal resistance.
      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)file_stom
      
      OPEN(NULVDEP,file=file_stom)
      READ(NULVDEP,*) (DLb1(Ji),Ji=1,Nland)
      READ(NULVDEP,*) (DLrstmin(Ji),Ji=1,Nland)
      READ(NULVDEP,*) (DLtze(Ji),Ji=1,Nland)
      READ(NULVDEP,*) (DLtmin(Ji),Ji=1,Nland)
      READ(NULVDEP,*) (DLtmax(Ji),Ji=1,Nland)
      CLOSE(NULVDEP)
      
C     C to Kelvin.
      DO Ji=1,Nland
         DLtze(Ji)=DLtze(Ji)+Ptkelvin
         DLtmin(Ji)=DLtmin(Ji)+Ptkelvin
         DLtmax(Ji)=DLtmax(Ji)+Ptkelvin
      ENDDO

      END
