C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE READFILES

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine reads input/output files names.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C     Yelva Roustan, CEREA, March 2003: Added below cloud scavenging.
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Vivien Mallet, CEREA, March 2003.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMCHEM: global variables for chemical species. 
C     COMFILES: global variables for files names.
C     COMUSE: flags and parameters for numerics. 
C     COMPOST: global variables for post treatment.
C     COMDATA: data on forced fields.

      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMCHEM.INC'
      INCLUDE 'COMFILES.INC'
      INCLUDE 'COMUSE.INC'
      INCLUDE 'COMPOST.INC'
      INCLUDE 'COMDATA.INC'

      INTEGER NUC,i
      INTEGER Nesptot

      INTEGER permutation(nesp)

      CHARACTER*30 species_names_input(nesp)
      CHARACTER*30 tmp_string

      Nesptot=Nesp
      IF (LCFORC2D) Nesptot=Nesp+Nespf

C------------------------------------------------------------------------
C     1 - Species names

      NUC=2
      OPEN(NUC,FILE ='CONTROL/NAMSPECIES',STATUS ='OLD')

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)

      DO i=1,Nesptot
         READ(NUC,*) species_names(i)
      ENDDO

      CLOSE(NUC)
      
C------------------------------------------------------------------------
C     2 - Files for initial concentration

      IF (LCONC0) THEN
         
         OPEN(NUC,FILE ='CONTROL/NAMCONCI',STATUS ='OLD')

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

         DO i=1,Nconc0
            READ(NUC,*) species_names_input(i), file_conc0(i)
         ENDDO

         CLOSE(NUC)

         CALL species_names_to_numbers(species_names, Nesp,
     $        species_names_input, Nconc0,
     $        permutation, Nespconc0)

         CALL apply_perm(permutation, Nconc0, file_conc0)

      ENDIF

C------------------------------------------------------------------------
C     2 - Files for boundary conditions

      IF (LCBC) THEN

         OPEN(NUC,FILE ='CONTROL/NAMCL',STATUS ='OLD')

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

         DO i=1,Nspcl
            READ(NUC,*) species_names_input(i), file_clx(i)
            READ(NUC,*) file_cly(i)
            READ(NUC,*) file_clz(i)
         ENDDO
         
         CLOSE(NUC)

         CALL species_names_to_numbers(species_names, Nesp,
     $        species_names_input, Nspcl,
     $        permutation, Nespcl)

         CALL apply_perm(permutation, Nspcl, file_clx)
         CALL apply_perm(permutation, Nspcl, file_cly)
         CALL apply_perm(permutation, Nspcl, file_clz)

      ENDIF

C------------------------------------------------------------------------
C     3 - Files for surfacic emissions

      IF (LEMISS) THEN

         OPEN(NUC,FILE ='CONTROL/NAMEMIS',STATUS ='OLD')

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

         DO i=1,Nemi
            READ(NUC,*) species_names_input(i), file_emis(i)
         ENDDO

         CLOSE(NUC)

         CALL species_names_to_numbers(species_names, Nesp,
     $        species_names_input,
     $        Nemi, permutation, Nespem)

         CALL apply_perm(permutation, Nemi, file_emis)

      ENDIF

C------------------------------------------------------------------------
C     4 - Files for volumic emissions

      IF (LSOURC) THEN

         OPEN(NUC,FILE ='CONTROL/NAMSOURC',STATUS ='OLD')

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

         DO i=1,Nsrc
            READ(NUC,*) species_names_input(i), file_sourc(i)
         ENDDO

         CLOSE(NUC)

         CALL species_names_to_numbers(species_names, Nesp,
     $        species_names_input,
     $        Nsrc, permutation, Nesps)

         CALL apply_perm(permutation, Nsrc, file_sourc)

      ENDIF

C------------------------------------------------------------------------
C     5 - Files for dry deposition velocities

      IF (LVDEPO) THEN

         OPEN(NUC,FILE ='CONTROL/NAMVDEPO',STATUS ='OLD')

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

         DO i=1,Ndep
            READ(NUC,*) species_names_input(i), file_vdep(i)
         ENDDO

         CLOSE(NUC)

         CALL species_names_to_numbers(species_names, Nesp,
     $        species_names_input,
     $        Ndep, permutation, Nespd)

         CALL apply_perm(permutation, Ndep, file_vdep)

      ENDIF

C------------------------------------------------------------------------
C     6 - Files for below cloud scavenging

      IF (LSCAV) THEN

         OPEN(NUC,FILE ='CONTROL/NAMSCAV',STATUS ='OLD')

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

         DO i=1,Nscav
            READ(NUC,*) species_names_input(i)
         ENDDO

         CLOSE(NUC)

         CALL species_names_to_numbers(species_names, Nesp,
     $        species_names_input,
     $        Nscav, permutation, Nespsca)

      ENDIF

C------------------------------------------------------------------------
C     7 - Files for photolysis rates

      IF (LCHIM.AND.LREAD_PHOTOLYSIS) THEN

         OPEN(NUC,FILE ='CONTROL/NAMPHOTOLYSIS',STATUS ='OLD')

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

         DO i=1,Nrphot
            READ(NUC,*) tmp_string, Nreactphot(i),
     $           file_photolysis_rates(i)
         ENDDO

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

C     7.1 - Time

C     Time step.
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*) Dttimephot

C     Initial time.
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*) Dttimephot0

C     Number of time steps.
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*) Nechtimephot

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

C     7.2 - Time angle

C     Step.
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*) Dtanglephot

C     First time angle.
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*) Dtanglephot0

C     Number of angle times.
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*) Nanglephot

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

C     7.3 - Latitudes

C     Step.
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*) Dtlatphot

C     First latitude.
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*) Dtlatphot0

C     Number of latitudes.
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*) Nlatphot

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

C     7.4 - Heights

C     Heights.
         READ(NUC,*)
         READ(NUC,*)
         DO i=1, Nzphot
            READ(NUC,*) Dzphot(i)
         ENDDO

         CLOSE(NUC)

      ENDIF

C------------------------------------------------------------------------
C     8 - Files for outputs

      IF (LPOST) THEN

         OPEN(NUC,FILE ='CONTROL/NAMRES',STATUS ='OLD')

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

         READ(NUC,*) Nespos

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

         DO i=1,Nespos
            READ(NUC,*) species_names_input(i), file_res(i)
         ENDDO

         CLOSE(NUC)

         CALL species_names_to_numbers(species_names, Nesp,
     $        species_names_input, Nespos,
     $        permutation, Nespec)

         CALL apply_perm(permutation, Nespos, file_res)

      ENDIF

C------------------------------------------------------------------------
C     10 - Files for outputs

      IF (LPOST.AND.LVD) THEN

         OPEN(NUC,FILE ='CONTROL/NAMRESVD',STATUS ='OLD')

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

         DO i=1,Ndep
            READ(NUC,*) species_names_input(i), file_res_vdep(i)
         ENDDO

         CLOSE(NUC)
         CALL species_names_to_numbers(species_names, Nesp,
     $        species_names_input, Ndep,
     $        permutation, Nespd)

         CALL apply_perm(permutation, Ndep, file_res_vdep)

      ENDIF

C------------------------------------------------------------------------
C     11 - Files for outputs

      IF (LPOST.AND.LSCAVG) THEN

         OPEN(NUC,FILE ='CONTROL/NAMRESCAV',STATUS ='OLD')

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)

         DO i=1,Nscav
            READ(NUC,*) species_names_input(i), file_res_scavg(i)
         ENDDO

         CLOSE(NUC)

         CALL species_names_to_numbers(species_names, Nesp,
     $        species_names_input, Nscav,
     $        permutation, Nespsca)

         CALL apply_perm(permutation, Nscav, file_res_scavg)

      ENDIF

      END
