C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE READMETEO(irr,DGUf,DGVf,DGWf,DGattenuationf,
     $     DGhumidf,DGtempf,DGrainf,DGhcloudf,DGpressf,DGtempsurff,
     $     DGpresurff,DGsnowf,DGraysolif,DGlhfluxf,DGswatf,DGmodwindf)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine reads meteorological data.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     IRR: iteration.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     DGUF, DGVF, DGWF: 3D wind fields along X, Y, Z.
C     DGATTENUATIONF: 3D cloud attenuation field.
C     DGHUMIDF: 3D specific humidity field.([-])
C     DGTEMPF: 3D temperature field.([K])
C     DGRAINF: 2D rain intensity field.([mm/h])
C     DGHCLOUDF: 2D height of cloud basis.([m])
C     DGPRESSF: 3D pressure field.([Pa])
C     DGTEMPSURFF: 2D surface temperature field.([K])
C     DGPRESURFF: 2D surface pression field.([Pa])
C     DGSNOWF: 2D snow height field.([m])
C     DGRAYSOLIF: 2D surface solar irradiance field.([W/m^2])
C     DGLHFLUXF: 2D latent heat flux field.([W/m^2])
C     DGSWATF: 3D soil water content field (3 level).([m])
C     DGMODWINDF: 2D wind module in first level.([m/s])
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Jaouad Boutahar, CEREA, June 2001.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARADOM: parameters for all forced fields.
C     PARACHEM: parameters for sizes of 'chemical' arrays.
C     COMLUN: global variables for unit numbers.
C     COMUSE: flags and parameters for numerics. 
C     COMDATA: data on forced fields.

      INCLUDE 'PARADOM.INC'
      INCLUDE 'PARACHEM.INC'
      INCLUDE 'COMLUN.INC'
      INCLUDE 'COMUSE.INC'
      INCLUDE 'COMDATA.INC'

      REAL DGUf(NX+1,NY,NZ)
      REAL DGVf(NX,NY+1,NZ)
      REAL DGWf(NX,NY,NZ+1)
      REAL DGattenuationf(NXatt,NYatt,NZatt)
      REAL DGhumidf(NXh,NYh,NZh)
      REAL DGtempf(NXt,NYt,NZt)
      REAL DGrainf(NXr,NYr)
      REAL DGhcloudf(NXr,NYr)
      REAL DGpressf(NXp,NYp,NZp)
      REAL DGtempsurff(NXdd,NYdd)
      REAL DGpresurff(NXdd,NYdd)
      REAL DGsnowf(NXdd,NYdd)
      REAL DGraysolif(NXdd,NYdd)
      REAL DGlhfluxf(NXdd,NYdd)
      REAL DGswatf(NXdd,NYdd,Nlayer)
      REAL DGmodwindf(NXdd,NYdd)

      CHARACTER*200 file_u
      CHARACTER*200 file_v
      CHARACTER*200 file_w
      CHARACTER*200 file_temp
      CHARACTER*200 file_attenuation
      CHARACTER*200 file_hum
      CHARACTER*200 file_rain
      CHARACTER*200 file_hcloud
      CHARACTER*200 file_press
      CHARACTER*200 file_presurf
      CHARACTER*200 file_snow
      CHARACTER*200 file_tempsurf
      CHARACTER*200 file_raysol
      CHARACTER*200 file_lhflux
      CHARACTER*200 file_swat
      CHARACTER*200 file_modwind

      INTEGER NUC,i,j,k,irr


      NUC=2
      OPEN(NUC,FILE ='CONTROL/NAMETEO',STATUS ='OLD')

      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)

C     Wind.
      IF (LADVEC) THEN          ! With advection.

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)file_u

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)file_v

         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)file_w

         OPEN(unit=NULMETEO,file=file_u,access='direct',
     s        form='unformatted',recl=4*(Nx+1)*(Ny)*(Nz))
         READ(NULMETEO,rec=1+(irr-1))
     s        (((DGUf(i,j,k),i=1,Nx+1),j=1,Ny),k=1,Nz)
         CLOSE (NULMETEO)

         OPEN(unit=NULMETEO,file=file_v,access='direct',
     s        form='unformatted',recl=4*(Nx)*(Ny+1)*(Nz))
         READ(NULMETEO,rec=1+(irr-1))
     s        (((DGVf(i,j,k),i=1,Nx),j=1,Ny+1),k=1,Nz)
         CLOSE (NULMETEO)

         IF (LREAD_VERTICAL_WIND) THEN
            OPEN(unit=NULMETEO,file=file_w,access='direct',
     s           form='unformatted',recl=4*(Nx)*(Ny)*(Nz+1))
            READ(NULMETEO,rec=1+(irr-1))
     s           (((DGWf(i,j,k),i=1,Nx),j=1,Ny),k=1,Nz+1)
            CLOSE (NULMETEO)
         ENDIF

      Else
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
      ENDIF 


C     Kz.
      READ(NUC,*)
      READ(NUC,*)
      READ(NUC,*)

      IF (LCHIM) THEN
C     Temperature.
         READ(NUC,*)
         READ(NUC,*)

         If (LTEMPU) THEN
            READ(NUC,*)file_temp
            OPEN(unit=NULMETEO,file=file_temp,access='direct',
     s           form='unformatted',recl=4*(Nxt)*(Nyt)*(Nzt))
            READ(NULMETEO,rec=1+(irr-1))
     s           (((DGTempf(i,j,k),i=1,Nxt),j=1,Nyt),k=1,Nzt)
            CLOSE (NULMETEO)
         Else
            READ(NUC,*)
         Endif

C     Cloud attenuation.
         READ(NUC,*)
         READ(NUC,*)

         If (LATTENUATION) THEN
            READ(NUC,*)file_attenuation

            OPEN(unit=NULMETEO,file=file_attenuation,access='direct',
     s           form='unformatted',recl=4*(Nxatt)*(Nyatt)*(Nzatt))
            READ(NULMETEO,rec=1+1*(irr-1))
     s           (((DGattenuationf(i,j,k),i=1,Nxatt),
     $           j=1,Nyatt),k=1,Nzatt)
            CLOSE (NULMETEO)
         Else 
            READ(NUC,*)
         Endif

C     Humidity.
         READ(NUC,*)
         READ(NUC,*)

         If (LHUMU) THEN
            READ(NUC,*)file_hum

            OPEN(unit=NULMETEO,file=file_hum,access='direct',
     s           form='unformatted',recl=4*(Nxh)*(Nyh)*(Nzh))
            READ(NULMETEO,rec=1+1*(irr-1))
     s           (((DGhumidf(i,j,k),i=1,Nxh),j=1,Nyh),k=1,Nzh)
            CLOSE (NULMETEO)
         Else
            READ(NUC,*)
         Endif

C     Rain.
         READ(NUC,*)
         READ(NUC,*)

         If (LRAINU) THEN
            READ(NUC,*)file_rain

            OPEN(unit=NULMETEO,file=file_rain,access='direct',
     s           form='unformatted',recl=4*(Nxr)*(NYr))
            READ(NULMETEO,rec=1+(irr-1))((DGRainf(i,j),i=1,Nxr),j=1,Nyr)
            CLOSE (NULMETEO)
         Else
            READ(NUC,*)
         Endif

C     Height of cloud basis.
         READ(NUC,*)
         READ(NUC,*)

         If (LCLOUDU.OR.LSCAV) THEN
            READ(NUC,*)file_hcloud

            OPEN(unit=NULMETEO,file=file_hcloud,access='direct',
     s           form='unformatted',recl=4*(Nxr)*(NYr))
            READ(NULMETEO,rec=1+(irr-1))
     s           ((DGHcloudf(i,j),i=1,Nxr),j=1,Nyr)
            CLOSE (NULMETEO)
         Else
            READ(NUC,*)
         Endif

C     Pression.
         READ(NUC,*)
         READ(NUC,*)
         
         If (LPRESSU) THEN
            READ(NUC,*)file_press

            OPEN(unit=NULMETEO,file=file_press,access='direct',
     s           form='unformatted',recl=4*(Nxp)*(Nyp)*(Nzp))
            READ(NULMETEO,rec=1+(irr-1))
     s           (((DGpressf(i,j,k),i=1,Nxp),j=1,Nyp),k=1,Nzp)
            CLOSE (NULMETEO)
         Else
            READ(NUC,*)
         Endif

      ENDIF

C     Dry deposition.
      IF (LVDEPOCOMP) THEN

         READ(NUC,*)
         READ(NUC,*)

C     Surface pressure.
         READ(NUC,*)file_presurf
         OPEN(unit=NULMETEO,file=file_presurf,access='direct',
     s        form='unformatted',recl=4*Nxdd*Nydd)
         READ(NULMETEO,rec=1+(irr-1))
     s        ((DGpresurff(i,j),i=1,Nxdd),j=1,Nydd)
         CLOSE (NULMETEO)

C     Snow depth.
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)file_snow
         OPEN(unit=NULMETEO,file=file_snow,access='direct',
     s        form='unformatted',recl=4*Nxdd*Nydd)
         READ(NULMETEO,rec=1+(irr-1))
     s        ((DGsnowf(i,j),i=1,Nxdd),j=1,Nydd)
         CLOSE (NULMETEO)

C     Surface temperature.
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)file_tempsurf
         OPEN(unit=NULMETEO,file=file_tempsurf,access='direct',
     s        form='unformatted',recl=4*Nxdd*Nydd)
         READ(NULMETEO,rec=1+(irr-1))
     s        ((DGtempsurff(i,j),i=1,Nxdd),j=1,Nydd)
         CLOSE (NULMETEO)

C     Surface solar radiation.
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)file_raysol
         OPEN(unit=NULMETEO,file=file_raysol,access='direct',
     s        form='unformatted',recl=4*Nxdd*Nydd)
         READ(NULMETEO,rec=1+(irr-1))
     s        ((DGraysolif(i,j),i=1,Nxdd),j=1,Nydd)
         CLOSE (NULMETEO)

C     Latent heat flux.
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)file_lhflux
         OPEN(unit=NULMETEO,file=file_lhflux,access='direct',
     s        form='unformatted',recl=4*Nxdd*Nydd)
         READ(NULMETEO,rec=1+(irr-1))
     s        ((DGlhfluxf(i,j),i=1,Nxdd),j=1,Nydd)
         CLOSE (NULMETEO)

C     Soil water content.
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)file_swat
         OPEN(unit=NULMETEO,file=file_swat,access='direct',
     s        form='unformatted',recl=4*Nxdd*Nydd*Nlayer)
         READ(NULMETEO,rec=1+(irr-1))
     s        (((DGswatf(i,j,k),i=1,Nxdd),j=1,Nydd),k=1,Nlayer)
         CLOSE (NULMETEO)

C     Wind module at the first level.
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)file_modwind
         OPEN(unit=NULMETEO,file=file_modwind,access='direct',
     s        form='unformatted',recl=4*Nxdd*Nydd)
         READ(NULMETEO,rec=1+(irr-1))
     s        ((DGmodwindf(i,j),i=1,Nxdd),j=1,Nydd)
         CLOSE (NULMETEO)

      ELSE
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
         READ(NUC,*)
      ENDIF

      CLOSE(NUC)

      END
