C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE species_names_to_numbers(species_names, nb_species,
     $     species_names_input, nb_input,
     $     permutation, numbers)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine associates numbers to species names, and sort the
C     result in increasing order.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     SPECIES_NAMES: names of species, which gives numbers to which
C     each species is associated.
C     NB_SPECIES: length of SPECIES_NAMES.
C     SPECIES_NAMES_INPUT: names to be associated to numbers.
C     NB_INPUT: length of SPECIES_NAMES_INPUT.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     PERMUTATION: permutation related to the sort.
C     NUMBERS: numbers of input species (SPECIES_NAMES_INPUT), in
C     increasing order.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     Vivien Mallet, CEREA, March 2003.
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

      INTEGER i, j, k
      INTEGER nb_species, nb_input
      
      CHARACTER*30 species_names(nb_species)
      CHARACTER*30 species_names_input(nb_input)
      INTEGER permutation(nb_input)
      INTEGER numbers(nb_input)

      LOGICAL found_species(nb_input)


      DO i = 1, nb_input
         found_species(i) = .false.
      ENDDO

      i = 1
      DO j = 1, nb_species

         k = 1
         DO WHILE ((k.le.nb_input).and.
     $        (.not.(species_names(j).eq.species_names_input(k))))
            k = k + 1
         ENDDO

         IF (k.le.nb_input) THEN
            numbers(i) = j
            permutation(i) = k
            found_species(k) = .true.
            i = i + 1
         ENDIF

      ENDDO
      
      DO i = 1, nb_input
         IF (.not.found_species(i)) THEN
            write(*, *) 'Error'
            write(*, *) 'Unknown species: ',
     $           species_names_input(i)
            stop
         ENDIF
      ENDDO
      
      END
