C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE LU_decompose (M)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes an LU factorization of M.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     M: on entry, an invertible matrix. On exit, an LU factorization
C     of M.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of 'chemical' arrays.

      INCLUDE 'PARACHEM.INC'

      DOUBLE PRECISION M(Nesp,Nesp)
      DOUBLE PRECISION temp


C     Upper part.
      M(1, 75) = M(1, 75) / M(1, 1)

C     Upper part.
      temp = M(2, 1) * M(1, 75)
      M(2, 75) = ( M(2, 75) - temp ) / M(2, 2)

C     Upper part.
      M(3, 58) = M(3, 58) / M(3, 3)

C     Upper part.
      M(4, 75) = M(4, 75) / M(4, 4)

C     Upper part.
      M(5, 75) = M(5, 75) / M(5, 5)

C     Upper part.
      M(6, 75) = M(6, 75) / M(6, 6)

C     Upper part.
      M(7, 75) = M(7, 75) / M(7, 7)

C     Upper part.
      M(8, 75) = M(8, 75) / M(8, 8)

C     Upper part.
      M(9, 75) = M(9, 75) / M(9, 9)

C     Upper part.
      M(10, 75) = M(10, 75) / M(10, 10)

C     Upper part.
      M(11, 75) = M(11, 75) / M(11, 11)

C     Upper part.
      M(12, 75) = M(12, 75) / M(12, 12)

C     Upper part.
      M(13, 75) = M(13, 75) / M(13, 13)

C     Upper part.
      M(14, 75) = M(14, 75) / M(14, 14)
C     Upper part.
      M(14, 80) = M(14, 80) / M(14, 14)

C     Upper part.
      M(15, 73) = M(15, 73) / M(15, 15)
C     Upper part.
      M(15, 81) = M(15, 81) / M(15, 15)

C     Upper part.
      M(16, 73) = M(16, 73) / M(16, 16)
C     Upper part.
      temp = M(16, 12) * M(12, 75)
      temp = temp + M(16, 13) * M(13, 75)
      M(16, 75) = ( M(16, 75) - temp ) / M(16, 16)

C     Upper part.
      M(17, 77) = M(17, 77) / M(17, 17)
C     Upper part.
      M(17, 81) = M(17, 81) / M(17, 17)

C     Upper part.
      M(18, 75) = M(18, 75) / M(18, 18)
C     Upper part.
      M(18, 79) = M(18, 79) / M(18, 18)
C     Upper part.
      M(18, 81) = M(18, 81) / M(18, 18)

C     Upper part.
      M(19, 58) = M(19, 58) / M(19, 19)
C     Upper part.
      M(19, 73) = M(19, 73) / M(19, 19)
C     Upper part.
      M(19, 75) = M(19, 75) / M(19, 19)

C     Upper part.
      M(20, 58) = M(20, 58) / M(20, 20)
C     Upper part.
      M(20, 73) = M(20, 73) / M(20, 20)
C     Upper part.
      M(20, 75) = M(20, 75) / M(20, 20)

C     Upper part.
      M(21, 58) = M(21, 58) / M(21, 21)
C     Upper part.
      M(21, 73) = M(21, 73) / M(21, 21)
C     Upper part.
      M(21, 75) = M(21, 75) / M(21, 21)

C     Upper part.
      M(22, 58) = M(22, 58) / M(22, 22)
C     Upper part.
      M(22, 73) = M(22, 73) / M(22, 22)
C     Upper part.
      M(22, 75) = M(22, 75) / M(22, 22)

C     Upper part.
      temp = M(23, 22) * M(22, 58)
      M(23, 58) = ( M(23, 58) - temp ) / M(23, 23)
C     Upper part.
      temp = M(23, 22) * M(22, 73)
      M(23, 73) = ( M(23, 73) - temp ) / M(23, 23)
C     Upper part.
      temp = M(23, 22) * M(22, 75)
      M(23, 75) = ( M(23, 75) - temp ) / M(23, 23)
C     Upper part.
      M(23, 80) = M(23, 80) / M(23, 23)

C     Upper part.
      M(24, 58) = M(24, 58) / M(24, 24)
C     Upper part.
      M(24, 73) = M(24, 73) / M(24, 24)
C     Upper part.
      M(24, 75) = M(24, 75) / M(24, 24)

C     Upper part.
      M(25, 58) = M(25, 58) / M(25, 25)
C     Upper part.
      M(25, 73) = M(25, 73) / M(25, 25)
C     Upper part.
      M(25, 75) = M(25, 75) / M(25, 25)

C     Upper part.
      M(26, 75) = M(26, 75) / M(26, 26)
C     Upper part.
      M(26, 81) = M(26, 81) / M(26, 26)
C     Upper part.
      M(26, 82) = M(26, 82) / M(26, 26)

C     Upper part.
      M(27, 69) = M(27, 69) / M(27, 27)
C     Upper part.
      M(27, 75) = M(27, 75) / M(27, 27)
C     Upper part.
      M(27, 79) = M(27, 79) / M(27, 27)

C     Upper part.
      M(28, 75) = M(28, 75) / M(28, 28)
C     Upper part.
      M(28, 79) = M(28, 79) / M(28, 28)
C     Upper part.
      M(28, 82) = M(28, 82) / M(28, 28)

C     Upper part.
      temp = M(29, 24) * M(24, 58)
      temp = temp + M(29, 25) * M(25, 58)
      M(29, 58) = ( M(29, 58) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 24) * M(24, 73)
      temp = temp + M(29, 25) * M(25, 73)
      M(29, 73) = ( M(29, 73) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 24) * M(24, 75)
      temp = temp + M(29, 25) * M(25, 75)
      M(29, 75) = ( M(29, 75) - temp ) / M(29, 29)
C     Upper part.
      M(29, 79) = M(29, 79) / M(29, 29)

C     Upper part.
      M(30, 44) = M(30, 44) / M(30, 30)
C     Upper part.
      M(30, 49) = M(30, 49) / M(30, 30)
C     Upper part.
      M(30, 75) = M(30, 75) / M(30, 30)
C     Upper part.
      M(30, 80) = M(30, 80) / M(30, 30)

C     Upper part.
      M(31, 45) = M(31, 45) / M(31, 31)
C     Upper part.
      M(31, 58) = M(31, 58) / M(31, 31)
C     Upper part.
      M(31, 59) = M(31, 59) / M(31, 31)
C     Upper part.
      M(31, 75) = M(31, 75) / M(31, 31)

C     Upper part.
      M(32, 50) = M(32, 50) / M(32, 32)
C     Upper part.
      M(32, 57) = M(32, 57) / M(32, 32)
C     Upper part.
      temp = M(32, 3) * M(3, 58)
      temp = temp + M(32, 22) * M(22, 58)
      M(32, 58) = ( M(32, 58) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 22) * M(22, 73)
      M(32, 73) = ( M(32, 73) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 22) * M(22, 75)
      M(32, 75) = ( M(32, 75) - temp ) / M(32, 32)
C     Upper part.
      M(32, 81) = M(32, 81) / M(32, 32)

C     Upper part.
      M(33, 41) = M(33, 41) / M(33, 33)
C     Upper part.
      M(33, 44) = M(33, 44) / M(33, 33)
C     Upper part.
      M(33, 51) = M(33, 51) / M(33, 33)
C     Upper part.
      M(33, 75) = M(33, 75) / M(33, 33)
C     Upper part.
      M(33, 80) = M(33, 80) / M(33, 33)

C     Upper part.
      M(34, 45) = M(34, 45) / M(34, 34)
C     Upper part.
      M(34, 50) = M(34, 50) / M(34, 34)
C     Upper part.
      M(34, 57) = M(34, 57) / M(34, 34)
C     Upper part.
      temp = M(34, 19) * M(19, 58)
      temp = temp + M(34, 20) * M(20, 58)
      temp = temp + M(34, 21) * M(21, 58)
      temp = temp + M(34, 22) * M(22, 58)
      temp = temp + M(34, 25) * M(25, 58)
      M(34, 58) = ( M(34, 58) - temp ) / M(34, 34)
C     Upper part.
      M(34, 59) = M(34, 59) / M(34, 34)
C     Upper part.
      temp = M(34, 19) * M(19, 73)
      temp = temp + M(34, 20) * M(20, 73)
      temp = temp + M(34, 21) * M(21, 73)
      temp = temp + M(34, 22) * M(22, 73)
      temp = temp + M(34, 25) * M(25, 73)
      M(34, 73) = ( M(34, 73) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 19) * M(19, 75)
      temp = temp + M(34, 20) * M(20, 75)
      temp = temp + M(34, 21) * M(21, 75)
      temp = temp + M(34, 22) * M(22, 75)
      temp = temp + M(34, 25) * M(25, 75)
      M(34, 75) = ( M(34, 75) - temp ) / M(34, 34)

C     Upper part.
      M(35, 69) = M(35, 69) / M(35, 35)
C     Upper part.
      temp = M(35, 6) * M(6, 75)
      M(35, 75) = ( M(35, 75) - temp ) / M(35, 35)
C     Upper part.
      M(35, 79) = M(35, 79) / M(35, 35)
C     Upper part.
      M(35, 80) = M(35, 80) / M(35, 35)
C     Upper part.
      M(35, 82) = M(35, 82) / M(35, 35)

C     Upper part.
      M(36, 69) = M(36, 69) / M(36, 36)
C     Upper part.
      temp = M(36, 7) * M(7, 75)
      M(36, 75) = ( M(36, 75) - temp ) / M(36, 36)
C     Upper part.
      M(36, 79) = M(36, 79) / M(36, 36)
C     Upper part.
      M(36, 80) = M(36, 80) / M(36, 36)
C     Upper part.
      M(36, 82) = M(36, 82) / M(36, 36)

C     Upper part.
      M(37, 69) = M(37, 69) / M(37, 37)
C     Upper part.
      temp = M(37, 8) * M(8, 75)
      M(37, 75) = ( M(37, 75) - temp ) / M(37, 37)
C     Upper part.
      M(37, 79) = M(37, 79) / M(37, 37)
C     Upper part.
      M(37, 80) = M(37, 80) / M(37, 37)
C     Upper part.
      M(37, 82) = M(37, 82) / M(37, 37)

C     Upper part.
      M(38, 69) = M(38, 69) / M(38, 38)
C     Upper part.
      temp = M(38, 9) * M(9, 75)
      M(38, 75) = ( M(38, 75) - temp ) / M(38, 38)
C     Upper part.
      M(38, 79) = M(38, 79) / M(38, 38)
C     Upper part.
      M(38, 80) = M(38, 80) / M(38, 38)
C     Upper part.
      M(38, 82) = M(38, 82) / M(38, 38)

C     Upper part.
      M(39, 69) = M(39, 69) / M(39, 39)
C     Upper part.
      temp = M(39, 10) * M(10, 75)
      M(39, 75) = ( M(39, 75) - temp ) / M(39, 39)
C     Upper part.
      M(39, 79) = M(39, 79) / M(39, 39)
C     Upper part.
      M(39, 80) = M(39, 80) / M(39, 39)
C     Upper part.
      M(39, 82) = M(39, 82) / M(39, 39)

C     Upper part.
      M(40, 69) = M(40, 69) / M(40, 40)
C     Upper part.
      temp = M(40, 11) * M(11, 75)
      M(40, 75) = ( M(40, 75) - temp ) / M(40, 40)
C     Upper part.
      M(40, 79) = M(40, 79) / M(40, 40)
C     Upper part.
      M(40, 80) = M(40, 80) / M(40, 40)
C     Upper part.
      M(40, 82) = M(40, 82) / M(40, 40)

C     Lower part.
      temp = M(69, 33) * M(33, 41)
      M(69, 41) = M(69, 41) - temp
C     Lower part.
      temp = M(71, 33) * M(33, 41)
      M(71, 41) = M(71, 41) - temp
C     Lower part.
      temp = M(74, 33) * M(33, 41)
      M(74, 41) = M(74, 41) - temp
C     Lower part.
      temp = M(75, 33) * M(33, 41)
      M(75, 41) = M(75, 41) - temp
C     Lower part.
      temp = M(76, 33) * M(33, 41)
      M(76, 41) = M(76, 41) - temp
C     Lower part.
      temp = M(79, 33) * M(33, 41)
      M(79, 41) = M(79, 41) - temp
C     Upper part.
      temp = M(41, 19) * M(19, 58)
      M(41, 58) = ( M(41, 58) - temp ) / M(41, 41)
C     Upper part.
      M(41, 69) = M(41, 69) / M(41, 41)
C     Upper part.
      temp = M(41, 19) * M(19, 73)
      M(41, 73) = ( M(41, 73) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 19) * M(19, 75)
      M(41, 75) = ( M(41, 75) - temp ) / M(41, 41)
C     Upper part.
      M(41, 79) = M(41, 79) / M(41, 41)
C     Upper part.
      M(41, 80) = M(41, 80) / M(41, 41)
C     Upper part.
      M(41, 82) = M(41, 82) / M(41, 41)

C     Upper part.
      temp = M(42, 20) * M(20, 58)
      M(42, 58) = ( M(42, 58) - temp ) / M(42, 42)
C     Upper part.
      M(42, 69) = M(42, 69) / M(42, 42)
C     Upper part.
      temp = M(42, 20) * M(20, 73)
      M(42, 73) = ( M(42, 73) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 20) * M(20, 75)
      M(42, 75) = ( M(42, 75) - temp ) / M(42, 42)
C     Upper part.
      M(42, 79) = M(42, 79) / M(42, 42)
C     Upper part.
      M(42, 80) = M(42, 80) / M(42, 42)
C     Upper part.
      M(42, 82) = M(42, 82) / M(42, 42)

C     Upper part.
      temp = M(43, 21) * M(21, 58)
      M(43, 58) = ( M(43, 58) - temp ) / M(43, 43)
C     Upper part.
      M(43, 69) = M(43, 69) / M(43, 43)
C     Upper part.
      temp = M(43, 21) * M(21, 73)
      M(43, 73) = ( M(43, 73) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 21) * M(21, 75)
      M(43, 75) = ( M(43, 75) - temp ) / M(43, 43)
C     Upper part.
      M(43, 79) = M(43, 79) / M(43, 43)
C     Upper part.
      M(43, 80) = M(43, 80) / M(43, 43)
C     Upper part.
      M(43, 82) = M(43, 82) / M(43, 43)

C     Lower part.
      temp = M(68, 30) * M(30, 44)
      M(68, 44) = M(68, 44) - temp
C     Lower part.
      temp = M(69, 30) * M(30, 44)
      temp = temp + M(69, 33) * M(33, 44)
      M(69, 44) = M(69, 44) - temp
C     Lower part.
      temp = M(71, 33) * M(33, 44)
      M(71, 44) = M(71, 44) - temp
C     Lower part.
      temp = M(74, 30) * M(30, 44)
      temp = temp + M(74, 33) * M(33, 44)
      M(74, 44) = M(74, 44) - temp
C     Lower part.
      temp = M(75, 30) * M(30, 44)
      temp = temp + M(75, 33) * M(33, 44)
      M(75, 44) = M(75, 44) - temp
C     Lower part.
      temp = M(76, 33) * M(33, 44)
      M(76, 44) = M(76, 44) - temp
C     Lower part.
      temp = M(79, 30) * M(30, 44)
      temp = temp + M(79, 33) * M(33, 44)
      M(79, 44) = M(79, 44) - temp
C     Lower part.
      temp = M(82, 30) * M(30, 44)
      M(82, 44) = M(82, 44) - temp
C     Upper part.
      M(44, 49) = M(44, 49) / M(44, 44)
C     Upper part.
      M(44, 51) = M(44, 51) / M(44, 44)
C     Upper part.
      temp = M(44, 22) * M(22, 58)
      M(44, 58) = ( M(44, 58) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 22) * M(22, 73)
      M(44, 73) = ( M(44, 73) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 22) * M(22, 75)
      M(44, 75) = ( M(44, 75) - temp ) / M(44, 44)
C     Upper part.
      M(44, 79) = M(44, 79) / M(44, 44)
C     Upper part.
      M(44, 80) = M(44, 80) / M(44, 44)

C     Lower part.
      temp = M(69, 31) * M(31, 45)
      M(69, 45) = M(69, 45) - temp
C     Lower part.
      temp = M(75, 31) * M(31, 45)
      M(75, 45) = M(75, 45) - temp
C     Upper part.
      temp = M(45, 44) * M(44, 49)
      M(45, 49) = ( M(45, 49) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 51)
      M(45, 51) = ( M(45, 51) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 22) * M(22, 58)
      temp = temp + M(45, 25) * M(25, 58)
      temp = temp + M(45, 44) * M(44, 58)
      M(45, 58) = ( M(45, 58) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 22) * M(22, 73)
      temp = temp + M(45, 25) * M(25, 73)
      temp = temp + M(45, 44) * M(44, 73)
      M(45, 73) = ( M(45, 73) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 22) * M(22, 75)
      temp = temp + M(45, 25) * M(25, 75)
      temp = temp + M(45, 44) * M(44, 75)
      M(45, 75) = ( M(45, 75) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 79)
      M(45, 79) = ( M(45, 79) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 80)
      M(45, 80) = ( M(45, 80) - temp ) / M(45, 45)

C     Upper part.
      temp = M(46, 45) * M(45, 49)
      M(46, 49) = ( M(46, 49) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 45) * M(45, 51)
      M(46, 51) = ( M(46, 51) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 45) * M(45, 58)
      M(46, 58) = ( M(46, 58) - temp ) / M(46, 46)
C     Upper part.
      M(46, 69) = M(46, 69) / M(46, 46)
C     Upper part.
      temp = M(46, 45) * M(45, 73)
      M(46, 73) = ( M(46, 73) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 45) * M(45, 75)
      M(46, 75) = ( M(46, 75) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 45) * M(45, 79)
      M(46, 79) = ( M(46, 79) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 45) * M(45, 80)
      M(46, 80) = ( M(46, 80) - temp ) / M(46, 46)
C     Upper part.
      M(46, 82) = M(46, 82) / M(46, 46)

C     Upper part.
      M(47, 69) = M(47, 69) / M(47, 47)
C     Upper part.
      temp = M(47, 12) * M(12, 75)
      M(47, 75) = ( M(47, 75) - temp ) / M(47, 47)
C     Upper part.
      M(47, 79) = M(47, 79) / M(47, 47)
C     Upper part.
      M(47, 80) = M(47, 80) / M(47, 47)
C     Upper part.
      M(47, 82) = M(47, 82) / M(47, 47)

C     Upper part.
      M(48, 69) = M(48, 69) / M(48, 48)
C     Upper part.
      temp = M(48, 13) * M(13, 75)
      M(48, 75) = ( M(48, 75) - temp ) / M(48, 48)
C     Upper part.
      M(48, 79) = M(48, 79) / M(48, 48)
C     Upper part.
      M(48, 80) = M(48, 80) / M(48, 48)
C     Upper part.
      M(48, 82) = M(48, 82) / M(48, 48)

C     Lower part.
      temp = M(49, 44) * M(44, 49)
      M(49, 49) = M(49, 49) - temp
C     Lower part.
      temp = M(50, 44) * M(44, 49)
      M(50, 49) = M(50, 49) - temp
C     Lower part.
      temp = M(51, 44) * M(44, 49)
      M(51, 49) = M(51, 49) - temp
C     Lower part.
      temp = M(52, 44) * M(44, 49)
      M(52, 49) = M(52, 49) - temp
C     Lower part.
      temp = M(57, 44) * M(44, 49)
      M(57, 49) = M(57, 49) - temp
C     Lower part.
      temp = M(58, 45) * M(45, 49)
      M(58, 49) = M(58, 49) - temp
C     Lower part.
      temp = M(59, 44) * M(44, 49)
      M(59, 49) = M(59, 49) - temp
C     Lower part.
      temp = M(60, 45) * M(45, 49)
      M(60, 49) = M(60, 49) - temp
C     Lower part.
      temp = M(61, 44) * M(44, 49)
      M(61, 49) = M(61, 49) - temp
C     Lower part.
      temp = M(65, 44) * M(44, 49)
      temp = temp + M(65, 46) * M(46, 49)
      M(65, 49) = M(65, 49) - temp
C     Lower part.
      temp = M(67, 45) * M(45, 49)
      temp = temp + M(67, 46) * M(46, 49)
      M(67, 49) = M(67, 49) - temp
C     Lower part.
      temp = M(68, 30) * M(30, 49)
      temp = temp + M(68, 44) * M(44, 49)
      temp = temp + M(68, 45) * M(45, 49)
      temp = temp + M(68, 46) * M(46, 49)
      M(68, 49) = M(68, 49) - temp
C     Lower part.
      temp = M(69, 30) * M(30, 49)
      temp = temp + M(69, 44) * M(44, 49)
      temp = temp + M(69, 45) * M(45, 49)
      temp = temp + M(69, 46) * M(46, 49)
      M(69, 49) = M(69, 49) - temp
C     Lower part.
      temp = M(70, 44) * M(44, 49)
      M(70, 49) = M(70, 49) - temp
C     Lower part.
      temp = M(71, 44) * M(44, 49)
      M(71, 49) = M(71, 49) - temp
C     Lower part.
      temp = M(73, 45) * M(45, 49)
      M(73, 49) = M(73, 49) - temp
C     Lower part.
      temp = M(74, 30) * M(30, 49)
      temp = temp + M(74, 44) * M(44, 49)
      temp = temp + M(74, 45) * M(45, 49)
      temp = temp + M(74, 46) * M(46, 49)
      M(74, 49) = M(74, 49) - temp
C     Lower part.
      temp = M(75, 30) * M(30, 49)
      temp = temp + M(75, 44) * M(44, 49)
      temp = temp + M(75, 45) * M(45, 49)
      M(75, 49) = M(75, 49) - temp
C     Lower part.
      temp = M(76, 44) * M(44, 49)
      temp = temp + M(76, 45) * M(45, 49)
      M(76, 49) = M(76, 49) - temp
C     Lower part.
      temp = M(79, 30) * M(30, 49)
      temp = temp + M(79, 44) * M(44, 49)
      temp = temp + M(79, 45) * M(45, 49)
      temp = temp + M(79, 46) * M(46, 49)
      M(79, 49) = M(79, 49) - temp
C     Lower part.
      temp = M(80, 44) * M(44, 49)
      temp = temp + M(80, 46) * M(46, 49)
      M(80, 49) = M(80, 49) - temp
C     Lower part.
      temp = M(81, 44) * M(44, 49)
      temp = temp + M(81, 46) * M(46, 49)
      M(81, 49) = M(81, 49) - temp
C     Lower part.
      temp = M(82, 30) * M(30, 49)
      temp = temp + M(82, 44) * M(44, 49)
      temp = temp + M(82, 46) * M(46, 49)
      M(82, 49) = M(82, 49) - temp
C     Upper part.
      temp = M(49, 44) * M(44, 51)
      M(49, 51) = ( M(49, 51) - temp ) / M(49, 49)
C     Upper part.
      M(49, 57) = M(49, 57) / M(49, 49)
C     Upper part.
      temp = M(49, 44) * M(44, 58)
      M(49, 58) = ( M(49, 58) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 44) * M(44, 73)
      M(49, 73) = ( M(49, 73) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 44) * M(44, 75)
      M(49, 75) = ( M(49, 75) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 44) * M(44, 79)
      M(49, 79) = ( M(49, 79) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 44) * M(44, 80)
      M(49, 80) = ( M(49, 80) - temp ) / M(49, 49)

C     Lower part.
      temp = M(58, 32) * M(32, 50)
      M(58, 50) = M(58, 50) - temp
C     Lower part.
      temp = M(80, 32) * M(32, 50)
      M(80, 50) = M(80, 50) - temp
C     Lower part.
      temp = M(81, 32) * M(32, 50)
      M(81, 50) = M(81, 50) - temp
C     Upper part.
      temp = M(50, 44) * M(44, 51)
      temp = temp + M(50, 49) * M(49, 51)
      M(50, 51) = ( M(50, 51) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 49) * M(49, 57)
      M(50, 57) = ( M(50, 57) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 22) * M(22, 58)
      temp = temp + M(50, 23) * M(23, 58)
      temp = temp + M(50, 44) * M(44, 58)
      temp = temp + M(50, 49) * M(49, 58)
      M(50, 58) = ( M(50, 58) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 22) * M(22, 73)
      temp = temp + M(50, 23) * M(23, 73)
      temp = temp + M(50, 44) * M(44, 73)
      temp = temp + M(50, 49) * M(49, 73)
      M(50, 73) = ( M(50, 73) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 22) * M(22, 75)
      temp = temp + M(50, 23) * M(23, 75)
      temp = temp + M(50, 44) * M(44, 75)
      temp = temp + M(50, 49) * M(49, 75)
      M(50, 75) = ( M(50, 75) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 44) * M(44, 79)
      temp = temp + M(50, 49) * M(49, 79)
      M(50, 79) = ( M(50, 79) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 23) * M(23, 80)
      temp = temp + M(50, 44) * M(44, 80)
      temp = temp + M(50, 49) * M(49, 80)
      M(50, 80) = ( M(50, 80) - temp ) / M(50, 50)

C     Lower part.
      temp = M(51, 44) * M(44, 51)
      temp = temp + M(51, 49) * M(49, 51)
      temp = temp + M(51, 50) * M(50, 51)
      M(51, 51) = M(51, 51) - temp
C     Lower part.
      temp = M(52, 44) * M(44, 51)
      temp = temp + M(52, 49) * M(49, 51)
      M(52, 51) = M(52, 51) - temp
C     Lower part.
      temp = M(57, 44) * M(44, 51)
      temp = temp + M(57, 49) * M(49, 51)
      M(57, 51) = M(57, 51) - temp
C     Lower part.
      temp = M(58, 45) * M(45, 51)
      temp = temp + M(58, 49) * M(49, 51)
      temp = temp + M(58, 50) * M(50, 51)
      M(58, 51) = M(58, 51) - temp
C     Lower part.
      temp = M(59, 44) * M(44, 51)
      temp = temp + M(59, 49) * M(49, 51)
      M(59, 51) = M(59, 51) - temp
C     Lower part.
      temp = M(60, 45) * M(45, 51)
      temp = temp + M(60, 49) * M(49, 51)
      M(60, 51) = M(60, 51) - temp
C     Lower part.
      temp = M(61, 44) * M(44, 51)
      temp = temp + M(61, 49) * M(49, 51)
      M(61, 51) = M(61, 51) - temp
C     Lower part.
      temp = M(65, 44) * M(44, 51)
      temp = temp + M(65, 46) * M(46, 51)
      temp = temp + M(65, 49) * M(49, 51)
      M(65, 51) = M(65, 51) - temp
C     Lower part.
      temp = M(67, 45) * M(45, 51)
      temp = temp + M(67, 46) * M(46, 51)
      temp = temp + M(67, 49) * M(49, 51)
      temp = temp + M(67, 50) * M(50, 51)
      M(67, 51) = M(67, 51) - temp
C     Lower part.
      temp = M(68, 44) * M(44, 51)
      temp = temp + M(68, 45) * M(45, 51)
      temp = temp + M(68, 46) * M(46, 51)
      temp = temp + M(68, 49) * M(49, 51)
      temp = temp + M(68, 50) * M(50, 51)
      M(68, 51) = M(68, 51) - temp
C     Lower part.
      temp = M(69, 33) * M(33, 51)
      temp = temp + M(69, 44) * M(44, 51)
      temp = temp + M(69, 45) * M(45, 51)
      temp = temp + M(69, 46) * M(46, 51)
      temp = temp + M(69, 49) * M(49, 51)
      M(69, 51) = M(69, 51) - temp
C     Lower part.
      temp = M(70, 44) * M(44, 51)
      temp = temp + M(70, 49) * M(49, 51)
      temp = temp + M(70, 50) * M(50, 51)
      M(70, 51) = M(70, 51) - temp
C     Lower part.
      temp = M(71, 33) * M(33, 51)
      temp = temp + M(71, 44) * M(44, 51)
      temp = temp + M(71, 49) * M(49, 51)
      M(71, 51) = M(71, 51) - temp
C     Lower part.
      temp = M(73, 45) * M(45, 51)
      temp = temp + M(73, 49) * M(49, 51)
      temp = temp + M(73, 50) * M(50, 51)
      M(73, 51) = M(73, 51) - temp
C     Lower part.
      temp = M(74, 33) * M(33, 51)
      temp = temp + M(74, 44) * M(44, 51)
      temp = temp + M(74, 45) * M(45, 51)
      temp = temp + M(74, 46) * M(46, 51)
      temp = temp + M(74, 49) * M(49, 51)
      temp = temp + M(74, 50) * M(50, 51)
      M(74, 51) = M(74, 51) - temp
C     Lower part.
      temp = M(75, 33) * M(33, 51)
      temp = temp + M(75, 44) * M(44, 51)
      temp = temp + M(75, 45) * M(45, 51)
      temp = temp + M(75, 49) * M(49, 51)
      temp = temp + M(75, 50) * M(50, 51)
      M(75, 51) = M(75, 51) - temp
C     Lower part.
      temp = M(76, 33) * M(33, 51)
      temp = temp + M(76, 44) * M(44, 51)
      temp = temp + M(76, 45) * M(45, 51)
      temp = temp + M(76, 49) * M(49, 51)
      M(76, 51) = M(76, 51) - temp
C     Lower part.
      temp = M(79, 33) * M(33, 51)
      temp = temp + M(79, 44) * M(44, 51)
      temp = temp + M(79, 45) * M(45, 51)
      temp = temp + M(79, 46) * M(46, 51)
      temp = temp + M(79, 49) * M(49, 51)
      M(79, 51) = M(79, 51) - temp
C     Lower part.
      temp = M(80, 44) * M(44, 51)
      temp = temp + M(80, 46) * M(46, 51)
      temp = temp + M(80, 49) * M(49, 51)
      temp = temp + M(80, 50) * M(50, 51)
      M(80, 51) = M(80, 51) - temp
C     Lower part.
      temp = M(81, 44) * M(44, 51)
      temp = temp + M(81, 46) * M(46, 51)
      temp = temp + M(81, 49) * M(49, 51)
      temp = temp + M(81, 50) * M(50, 51)
      M(81, 51) = M(81, 51) - temp
C     Lower part.
      temp = M(82, 44) * M(44, 51)
      temp = temp + M(82, 46) * M(46, 51)
      temp = temp + M(82, 49) * M(49, 51)
      M(82, 51) = M(82, 51) - temp
C     Upper part.
      temp = M(51, 49) * M(49, 57)
      temp = temp + M(51, 50) * M(50, 57)
      M(51, 57) = ( M(51, 57) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 44) * M(44, 58)
      temp = temp + M(51, 49) * M(49, 58)
      temp = temp + M(51, 50) * M(50, 58)
      M(51, 58) = ( M(51, 58) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 44) * M(44, 73)
      temp = temp + M(51, 49) * M(49, 73)
      temp = temp + M(51, 50) * M(50, 73)
      M(51, 73) = ( M(51, 73) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 44) * M(44, 75)
      temp = temp + M(51, 49) * M(49, 75)
      temp = temp + M(51, 50) * M(50, 75)
      M(51, 75) = ( M(51, 75) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 44) * M(44, 79)
      temp = temp + M(51, 49) * M(49, 79)
      temp = temp + M(51, 50) * M(50, 79)
      M(51, 79) = ( M(51, 79) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 44) * M(44, 80)
      temp = temp + M(51, 49) * M(49, 80)
      temp = temp + M(51, 50) * M(50, 80)
      M(51, 80) = ( M(51, 80) - temp ) / M(51, 51)

C     Upper part.
      temp = M(52, 49) * M(49, 57)
      temp = temp + M(52, 51) * M(51, 57)
      M(52, 57) = ( M(52, 57) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 44) * M(44, 58)
      temp = temp + M(52, 49) * M(49, 58)
      temp = temp + M(52, 51) * M(51, 58)
      M(52, 58) = ( M(52, 58) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 47) * M(47, 69)
      temp = temp + M(52, 48) * M(48, 69)
      M(52, 69) = ( M(52, 69) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 44) * M(44, 73)
      temp = temp + M(52, 49) * M(49, 73)
      temp = temp + M(52, 51) * M(51, 73)
      M(52, 73) = ( M(52, 73) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 44) * M(44, 75)
      temp = temp + M(52, 47) * M(47, 75)
      temp = temp + M(52, 48) * M(48, 75)
      temp = temp + M(52, 49) * M(49, 75)
      temp = temp + M(52, 51) * M(51, 75)
      M(52, 75) = ( M(52, 75) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 44) * M(44, 79)
      temp = temp + M(52, 47) * M(47, 79)
      temp = temp + M(52, 48) * M(48, 79)
      temp = temp + M(52, 49) * M(49, 79)
      temp = temp + M(52, 51) * M(51, 79)
      M(52, 79) = ( M(52, 79) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 44) * M(44, 80)
      temp = temp + M(52, 47) * M(47, 80)
      temp = temp + M(52, 48) * M(48, 80)
      temp = temp + M(52, 49) * M(49, 80)
      temp = temp + M(52, 51) * M(51, 80)
      M(52, 80) = ( M(52, 80) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 47) * M(47, 82)
      temp = temp + M(52, 48) * M(48, 82)
      M(52, 82) = ( M(52, 82) - temp ) / M(52, 52)

C     Upper part.
      M(53, 69) = M(53, 69) / M(53, 53)
C     Upper part.
      temp = M(53, 16) * M(16, 73)
      M(53, 73) = ( M(53, 73) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 16) * M(16, 75)
      M(53, 75) = ( M(53, 75) - temp ) / M(53, 53)
C     Upper part.
      M(53, 79) = M(53, 79) / M(53, 53)
C     Upper part.
      M(53, 81) = M(53, 81) / M(53, 53)
C     Upper part.
      M(53, 82) = M(53, 82) / M(53, 53)

C     Upper part.
      M(54, 59) = M(54, 59) / M(54, 54)
C     Upper part.
      M(54, 69) = M(54, 69) / M(54, 54)
C     Upper part.
      M(54, 75) = M(54, 75) / M(54, 54)
C     Upper part.
      M(54, 79) = M(54, 79) / M(54, 54)
C     Upper part.
      M(54, 80) = M(54, 80) / M(54, 54)
C     Upper part.
      M(54, 82) = M(54, 82) / M(54, 54)

C     Upper part.
      temp = M(55, 24) * M(24, 58)
      M(55, 58) = ( M(55, 58) - temp ) / M(55, 55)
C     Upper part.
      M(55, 69) = M(55, 69) / M(55, 55)
C     Upper part.
      temp = M(55, 24) * M(24, 73)
      M(55, 73) = ( M(55, 73) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 24) * M(24, 75)
      M(55, 75) = ( M(55, 75) - temp ) / M(55, 55)
C     Upper part.
      M(55, 79) = M(55, 79) / M(55, 55)
C     Upper part.
      M(55, 80) = M(55, 80) / M(55, 55)
C     Upper part.
      M(55, 82) = M(55, 82) / M(55, 55)

C     Upper part.
      temp = M(56, 25) * M(25, 58)
      M(56, 58) = ( M(56, 58) - temp ) / M(56, 56)
C     Upper part.
      M(56, 69) = M(56, 69) / M(56, 56)
C     Upper part.
      temp = M(56, 25) * M(25, 73)
      M(56, 73) = ( M(56, 73) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 25) * M(25, 75)
      M(56, 75) = ( M(56, 75) - temp ) / M(56, 56)
C     Upper part.
      M(56, 79) = M(56, 79) / M(56, 56)
C     Upper part.
      M(56, 80) = M(56, 80) / M(56, 56)
C     Upper part.
      M(56, 82) = M(56, 82) / M(56, 56)

C     Lower part.
      temp = M(57, 49) * M(49, 57)
      temp = temp + M(57, 51) * M(51, 57)
      M(57, 57) = M(57, 57) - temp
C     Lower part.
      temp = M(58, 32) * M(32, 57)
      temp = temp + M(58, 49) * M(49, 57)
      temp = temp + M(58, 50) * M(50, 57)
      temp = temp + M(58, 51) * M(51, 57)
      M(58, 57) = M(58, 57) - temp
C     Lower part.
      temp = M(59, 49) * M(49, 57)
      temp = temp + M(59, 51) * M(51, 57)
      M(59, 57) = M(59, 57) - temp
C     Lower part.
      temp = M(60, 49) * M(49, 57)
      temp = temp + M(60, 51) * M(51, 57)
      M(60, 57) = M(60, 57) - temp
C     Lower part.
      temp = M(61, 49) * M(49, 57)
      temp = temp + M(61, 51) * M(51, 57)
      M(61, 57) = M(61, 57) - temp
C     Lower part.
      temp = M(65, 49) * M(49, 57)
      temp = temp + M(65, 51) * M(51, 57)
      M(65, 57) = M(65, 57) - temp
C     Lower part.
      temp = M(67, 49) * M(49, 57)
      temp = temp + M(67, 50) * M(50, 57)
      temp = temp + M(67, 51) * M(51, 57)
      M(67, 57) = M(67, 57) - temp
C     Lower part.
      temp = M(68, 49) * M(49, 57)
      temp = temp + M(68, 50) * M(50, 57)
      temp = temp + M(68, 51) * M(51, 57)
      M(68, 57) = M(68, 57) - temp
C     Lower part.
      temp = M(69, 49) * M(49, 57)
      temp = temp + M(69, 51) * M(51, 57)
      M(69, 57) = M(69, 57) - temp
C     Lower part.
      temp = M(70, 49) * M(49, 57)
      temp = temp + M(70, 50) * M(50, 57)
      temp = temp + M(70, 51) * M(51, 57)
      M(70, 57) = M(70, 57) - temp
C     Lower part.
      temp = M(71, 49) * M(49, 57)
      temp = temp + M(71, 51) * M(51, 57)
      M(71, 57) = M(71, 57) - temp
C     Lower part.
      temp = M(72, 52) * M(52, 57)
      M(72, 57) = M(72, 57) - temp
C     Lower part.
      temp = M(73, 49) * M(49, 57)
      temp = temp + M(73, 50) * M(50, 57)
      temp = temp + M(73, 51) * M(51, 57)
      temp = temp + M(73, 52) * M(52, 57)
      M(73, 57) = M(73, 57) - temp
C     Lower part.
      temp = M(74, 49) * M(49, 57)
      temp = temp + M(74, 50) * M(50, 57)
      temp = temp + M(74, 51) * M(51, 57)
      M(74, 57) = M(74, 57) - temp
C     Lower part.
      temp = M(75, 49) * M(49, 57)
      temp = temp + M(75, 50) * M(50, 57)
      temp = temp + M(75, 51) * M(51, 57)
      temp = temp + M(75, 52) * M(52, 57)
      M(75, 57) = M(75, 57) - temp
C     Lower part.
      temp = M(76, 49) * M(49, 57)
      temp = temp + M(76, 51) * M(51, 57)
      M(76, 57) = M(76, 57) - temp
C     Lower part.
      temp = M(77, 52) * M(52, 57)
      M(77, 57) = M(77, 57) - temp
C     Lower part.
      temp = M(79, 49) * M(49, 57)
      temp = temp + M(79, 51) * M(51, 57)
      temp = temp + M(79, 52) * M(52, 57)
      M(79, 57) = M(79, 57) - temp
C     Lower part.
      temp = M(80, 32) * M(32, 57)
      temp = temp + M(80, 49) * M(49, 57)
      temp = temp + M(80, 50) * M(50, 57)
      temp = temp + M(80, 51) * M(51, 57)
      M(80, 57) = M(80, 57) - temp
C     Lower part.
      temp = M(81, 32) * M(32, 57)
      temp = temp + M(81, 49) * M(49, 57)
      temp = temp + M(81, 50) * M(50, 57)
      temp = temp + M(81, 51) * M(51, 57)
      M(81, 57) = M(81, 57) - temp
C     Lower part.
      temp = M(82, 49) * M(49, 57)
      temp = temp + M(82, 51) * M(51, 57)
      M(82, 57) = M(82, 57) - temp
C     Upper part.
      temp = M(57, 22) * M(22, 58)
      temp = temp + M(57, 23) * M(23, 58)
      temp = temp + M(57, 25) * M(25, 58)
      temp = temp + M(57, 44) * M(44, 58)
      temp = temp + M(57, 49) * M(49, 58)
      temp = temp + M(57, 51) * M(51, 58)
      temp = temp + M(57, 56) * M(56, 58)
      M(57, 58) = ( M(57, 58) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 56) * M(56, 69)
      M(57, 69) = ( M(57, 69) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 22) * M(22, 73)
      temp = temp + M(57, 23) * M(23, 73)
      temp = temp + M(57, 25) * M(25, 73)
      temp = temp + M(57, 44) * M(44, 73)
      temp = temp + M(57, 49) * M(49, 73)
      temp = temp + M(57, 51) * M(51, 73)
      temp = temp + M(57, 56) * M(56, 73)
      M(57, 73) = ( M(57, 73) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 22) * M(22, 75)
      temp = temp + M(57, 23) * M(23, 75)
      temp = temp + M(57, 25) * M(25, 75)
      temp = temp + M(57, 44) * M(44, 75)
      temp = temp + M(57, 49) * M(49, 75)
      temp = temp + M(57, 51) * M(51, 75)
      temp = temp + M(57, 56) * M(56, 75)
      M(57, 75) = ( M(57, 75) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 44) * M(44, 79)
      temp = temp + M(57, 49) * M(49, 79)
      temp = temp + M(57, 51) * M(51, 79)
      temp = temp + M(57, 56) * M(56, 79)
      M(57, 79) = ( M(57, 79) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 23) * M(23, 80)
      temp = temp + M(57, 44) * M(44, 80)
      temp = temp + M(57, 49) * M(49, 80)
      temp = temp + M(57, 51) * M(51, 80)
      temp = temp + M(57, 56) * M(56, 80)
      M(57, 80) = ( M(57, 80) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 56) * M(56, 82)
      M(57, 82) = ( M(57, 82) - temp ) / M(57, 57)

C     Lower part.
      temp = M(58, 19) * M(19, 58)
      temp = temp + M(58, 20) * M(20, 58)
      temp = temp + M(58, 21) * M(21, 58)
      temp = temp + M(58, 22) * M(22, 58)
      temp = temp + M(58, 24) * M(24, 58)
      temp = temp + M(58, 25) * M(25, 58)
      temp = temp + M(58, 32) * M(32, 58)
      temp = temp + M(58, 45) * M(45, 58)
      temp = temp + M(58, 49) * M(49, 58)
      temp = temp + M(58, 50) * M(50, 58)
      temp = temp + M(58, 51) * M(51, 58)
      temp = temp + M(58, 57) * M(57, 58)
      M(58, 58) = M(58, 58) - temp
C     Lower part.
      temp = M(59, 44) * M(44, 58)
      temp = temp + M(59, 49) * M(49, 58)
      temp = temp + M(59, 51) * M(51, 58)
      temp = temp + M(59, 56) * M(56, 58)
      temp = temp + M(59, 57) * M(57, 58)
      M(59, 58) = M(59, 58) - temp
C     Lower part.
      temp = M(60, 19) * M(19, 58)
      temp = temp + M(60, 20) * M(20, 58)
      temp = temp + M(60, 21) * M(21, 58)
      temp = temp + M(60, 24) * M(24, 58)
      temp = temp + M(60, 25) * M(25, 58)
      temp = temp + M(60, 45) * M(45, 58)
      temp = temp + M(60, 49) * M(49, 58)
      temp = temp + M(60, 51) * M(51, 58)
      temp = temp + M(60, 57) * M(57, 58)
      M(60, 58) = M(60, 58) - temp
C     Lower part.
      temp = M(61, 44) * M(44, 58)
      temp = temp + M(61, 49) * M(49, 58)
      temp = temp + M(61, 51) * M(51, 58)
      temp = temp + M(61, 55) * M(55, 58)
      temp = temp + M(61, 56) * M(56, 58)
      temp = temp + M(61, 57) * M(57, 58)
      M(61, 58) = M(61, 58) - temp
C     Lower part.
      temp = M(62, 20) * M(20, 58)
      temp = temp + M(62, 21) * M(21, 58)
      temp = temp + M(62, 24) * M(24, 58)
      temp = temp + M(62, 55) * M(55, 58)
      M(62, 58) = M(62, 58) - temp
C     Lower part.
      temp = M(63, 24) * M(24, 58)
      temp = temp + M(63, 25) * M(25, 58)
      M(63, 58) = M(63, 58) - temp
C     Lower part.
      temp = M(64, 24) * M(24, 58)
      temp = temp + M(64, 25) * M(25, 58)
      M(64, 58) = M(64, 58) - temp
C     Lower part.
      temp = M(65, 41) * M(41, 58)
      temp = temp + M(65, 42) * M(42, 58)
      temp = temp + M(65, 43) * M(43, 58)
      temp = temp + M(65, 44) * M(44, 58)
      temp = temp + M(65, 46) * M(46, 58)
      temp = temp + M(65, 49) * M(49, 58)
      temp = temp + M(65, 51) * M(51, 58)
      temp = temp + M(65, 55) * M(55, 58)
      temp = temp + M(65, 56) * M(56, 58)
      temp = temp + M(65, 57) * M(57, 58)
      M(65, 58) = M(65, 58) - temp
C     Lower part.
      temp = M(67, 20) * M(20, 58)
      temp = temp + M(67, 21) * M(21, 58)
      temp = temp + M(67, 24) * M(24, 58)
      temp = temp + M(67, 41) * M(41, 58)
      temp = temp + M(67, 42) * M(42, 58)
      temp = temp + M(67, 43) * M(43, 58)
      temp = temp + M(67, 45) * M(45, 58)
      temp = temp + M(67, 46) * M(46, 58)
      temp = temp + M(67, 49) * M(49, 58)
      temp = temp + M(67, 50) * M(50, 58)
      temp = temp + M(67, 51) * M(51, 58)
      temp = temp + M(67, 55) * M(55, 58)
      temp = temp + M(67, 57) * M(57, 58)
      M(67, 58) = M(67, 58) - temp
C     Lower part.
      temp = M(68, 20) * M(20, 58)
      temp = temp + M(68, 21) * M(21, 58)
      temp = temp + M(68, 22) * M(22, 58)
      temp = temp + M(68, 25) * M(25, 58)
      temp = temp + M(68, 41) * M(41, 58)
      temp = temp + M(68, 42) * M(42, 58)
      temp = temp + M(68, 43) * M(43, 58)
      temp = temp + M(68, 44) * M(44, 58)
      temp = temp + M(68, 45) * M(45, 58)
      temp = temp + M(68, 46) * M(46, 58)
      temp = temp + M(68, 49) * M(49, 58)
      temp = temp + M(68, 50) * M(50, 58)
      temp = temp + M(68, 51) * M(51, 58)
      temp = temp + M(68, 57) * M(57, 58)
      M(68, 58) = M(68, 58) - temp
C     Lower part.
      temp = M(69, 20) * M(20, 58)
      temp = temp + M(69, 21) * M(21, 58)
      temp = temp + M(69, 22) * M(22, 58)
      temp = temp + M(69, 31) * M(31, 58)
      temp = temp + M(69, 41) * M(41, 58)
      temp = temp + M(69, 42) * M(42, 58)
      temp = temp + M(69, 43) * M(43, 58)
      temp = temp + M(69, 44) * M(44, 58)
      temp = temp + M(69, 45) * M(45, 58)
      temp = temp + M(69, 46) * M(46, 58)
      temp = temp + M(69, 49) * M(49, 58)
      temp = temp + M(69, 51) * M(51, 58)
      temp = temp + M(69, 55) * M(55, 58)
      temp = temp + M(69, 56) * M(56, 58)
      temp = temp + M(69, 57) * M(57, 58)
      M(69, 58) = M(69, 58) - temp
C     Lower part.
      temp = M(70, 44) * M(44, 58)
      temp = temp + M(70, 49) * M(49, 58)
      temp = temp + M(70, 50) * M(50, 58)
      temp = temp + M(70, 51) * M(51, 58)
      temp = temp + M(70, 57) * M(57, 58)
      M(70, 58) = M(70, 58) - temp
C     Lower part.
      temp = M(71, 22) * M(22, 58)
      temp = temp + M(71, 41) * M(41, 58)
      temp = temp + M(71, 44) * M(44, 58)
      temp = temp + M(71, 49) * M(49, 58)
      temp = temp + M(71, 51) * M(51, 58)
      temp = temp + M(71, 57) * M(57, 58)
      M(71, 58) = M(71, 58) - temp
C     Lower part.
      temp = M(72, 52) * M(52, 58)
      temp = temp + M(72, 57) * M(57, 58)
      M(72, 58) = M(72, 58) - temp
C     Lower part.
      temp = M(73, 19) * M(19, 58)
      temp = temp + M(73, 20) * M(20, 58)
      temp = temp + M(73, 21) * M(21, 58)
      temp = temp + M(73, 22) * M(22, 58)
      temp = temp + M(73, 24) * M(24, 58)
      temp = temp + M(73, 25) * M(25, 58)
      temp = temp + M(73, 45) * M(45, 58)
      temp = temp + M(73, 49) * M(49, 58)
      temp = temp + M(73, 50) * M(50, 58)
      temp = temp + M(73, 51) * M(51, 58)
      temp = temp + M(73, 52) * M(52, 58)
      temp = temp + M(73, 55) * M(55, 58)
      temp = temp + M(73, 56) * M(56, 58)
      temp = temp + M(73, 57) * M(57, 58)
      M(73, 58) = M(73, 58) - temp
C     Lower part.
      temp = M(74, 19) * M(19, 58)
      temp = temp + M(74, 20) * M(20, 58)
      temp = temp + M(74, 21) * M(21, 58)
      temp = temp + M(74, 22) * M(22, 58)
      temp = temp + M(74, 23) * M(23, 58)
      temp = temp + M(74, 25) * M(25, 58)
      temp = temp + M(74, 41) * M(41, 58)
      temp = temp + M(74, 42) * M(42, 58)
      temp = temp + M(74, 43) * M(43, 58)
      temp = temp + M(74, 44) * M(44, 58)
      temp = temp + M(74, 45) * M(45, 58)
      temp = temp + M(74, 46) * M(46, 58)
      temp = temp + M(74, 49) * M(49, 58)
      temp = temp + M(74, 50) * M(50, 58)
      temp = temp + M(74, 51) * M(51, 58)
      temp = temp + M(74, 55) * M(55, 58)
      temp = temp + M(74, 56) * M(56, 58)
      temp = temp + M(74, 57) * M(57, 58)
      M(74, 58) = M(74, 58) - temp
C     Lower part.
      temp = M(75, 3) * M(3, 58)
      temp = temp + M(75, 19) * M(19, 58)
      temp = temp + M(75, 20) * M(20, 58)
      temp = temp + M(75, 21) * M(21, 58)
      temp = temp + M(75, 22) * M(22, 58)
      temp = temp + M(75, 24) * M(24, 58)
      temp = temp + M(75, 25) * M(25, 58)
      temp = temp + M(75, 29) * M(29, 58)
      temp = temp + M(75, 31) * M(31, 58)
      temp = temp + M(75, 41) * M(41, 58)
      temp = temp + M(75, 44) * M(44, 58)
      temp = temp + M(75, 45) * M(45, 58)
      temp = temp + M(75, 49) * M(49, 58)
      temp = temp + M(75, 50) * M(50, 58)
      temp = temp + M(75, 51) * M(51, 58)
      temp = temp + M(75, 52) * M(52, 58)
      temp = temp + M(75, 57) * M(57, 58)
      M(75, 58) = M(75, 58) - temp
C     Lower part.
      temp = M(76, 19) * M(19, 58)
      temp = temp + M(76, 20) * M(20, 58)
      temp = temp + M(76, 21) * M(21, 58)
      temp = temp + M(76, 22) * M(22, 58)
      temp = temp + M(76, 24) * M(24, 58)
      temp = temp + M(76, 25) * M(25, 58)
      temp = temp + M(76, 41) * M(41, 58)
      temp = temp + M(76, 44) * M(44, 58)
      temp = temp + M(76, 45) * M(45, 58)
      temp = temp + M(76, 49) * M(49, 58)
      temp = temp + M(76, 51) * M(51, 58)
      temp = temp + M(76, 57) * M(57, 58)
      M(76, 58) = M(76, 58) - temp
C     Lower part.
      temp = M(77, 52) * M(52, 58)
      temp = temp + M(77, 57) * M(57, 58)
      M(77, 58) = M(77, 58) - temp
C     Lower part.
      temp = M(79, 19) * M(19, 58)
      temp = temp + M(79, 20) * M(20, 58)
      temp = temp + M(79, 21) * M(21, 58)
      temp = temp + M(79, 22) * M(22, 58)
      temp = temp + M(79, 24) * M(24, 58)
      temp = temp + M(79, 25) * M(25, 58)
      temp = temp + M(79, 29) * M(29, 58)
      temp = temp + M(79, 41) * M(41, 58)
      temp = temp + M(79, 42) * M(42, 58)
      temp = temp + M(79, 43) * M(43, 58)
      temp = temp + M(79, 44) * M(44, 58)
      temp = temp + M(79, 45) * M(45, 58)
      temp = temp + M(79, 46) * M(46, 58)
      temp = temp + M(79, 49) * M(49, 58)
      temp = temp + M(79, 51) * M(51, 58)
      temp = temp + M(79, 52) * M(52, 58)
      temp = temp + M(79, 55) * M(55, 58)
      temp = temp + M(79, 56) * M(56, 58)
      temp = temp + M(79, 57) * M(57, 58)
      M(79, 58) = M(79, 58) - temp
C     Lower part.
      temp = M(80, 23) * M(23, 58)
      temp = temp + M(80, 32) * M(32, 58)
      temp = temp + M(80, 41) * M(41, 58)
      temp = temp + M(80, 42) * M(42, 58)
      temp = temp + M(80, 43) * M(43, 58)
      temp = temp + M(80, 44) * M(44, 58)
      temp = temp + M(80, 46) * M(46, 58)
      temp = temp + M(80, 49) * M(49, 58)
      temp = temp + M(80, 50) * M(50, 58)
      temp = temp + M(80, 51) * M(51, 58)
      temp = temp + M(80, 55) * M(55, 58)
      temp = temp + M(80, 56) * M(56, 58)
      temp = temp + M(80, 57) * M(57, 58)
      M(80, 58) = M(80, 58) - temp
C     Lower part.
      temp = M(81, 23) * M(23, 58)
      temp = temp + M(81, 32) * M(32, 58)
      temp = temp + M(81, 41) * M(41, 58)
      temp = temp + M(81, 42) * M(42, 58)
      temp = temp + M(81, 43) * M(43, 58)
      temp = temp + M(81, 44) * M(44, 58)
      temp = temp + M(81, 46) * M(46, 58)
      temp = temp + M(81, 49) * M(49, 58)
      temp = temp + M(81, 50) * M(50, 58)
      temp = temp + M(81, 51) * M(51, 58)
      temp = temp + M(81, 55) * M(55, 58)
      temp = temp + M(81, 56) * M(56, 58)
      temp = temp + M(81, 57) * M(57, 58)
      M(81, 58) = M(81, 58) - temp
C     Lower part.
      temp = M(82, 41) * M(41, 58)
      temp = temp + M(82, 42) * M(42, 58)
      temp = temp + M(82, 43) * M(43, 58)
      temp = temp + M(82, 44) * M(44, 58)
      temp = temp + M(82, 46) * M(46, 58)
      temp = temp + M(82, 49) * M(49, 58)
      temp = temp + M(82, 51) * M(51, 58)
      temp = temp + M(82, 55) * M(55, 58)
      temp = temp + M(82, 56) * M(56, 58)
      temp = temp + M(82, 57) * M(57, 58)
      M(82, 58) = M(82, 58) - temp
C     Upper part.
      M(58, 59) = M(58, 59) / M(58, 58)
C     Upper part.
      temp = M(58, 57) * M(57, 69)
      M(58, 69) = ( M(58, 69) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 19) * M(19, 73)
      temp = temp + M(58, 20) * M(20, 73)
      temp = temp + M(58, 21) * M(21, 73)
      temp = temp + M(58, 22) * M(22, 73)
      temp = temp + M(58, 24) * M(24, 73)
      temp = temp + M(58, 25) * M(25, 73)
      temp = temp + M(58, 32) * M(32, 73)
      temp = temp + M(58, 45) * M(45, 73)
      temp = temp + M(58, 49) * M(49, 73)
      temp = temp + M(58, 50) * M(50, 73)
      temp = temp + M(58, 51) * M(51, 73)
      temp = temp + M(58, 57) * M(57, 73)
      M(58, 73) = ( M(58, 73) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 19) * M(19, 75)
      temp = temp + M(58, 20) * M(20, 75)
      temp = temp + M(58, 21) * M(21, 75)
      temp = temp + M(58, 22) * M(22, 75)
      temp = temp + M(58, 24) * M(24, 75)
      temp = temp + M(58, 25) * M(25, 75)
      temp = temp + M(58, 32) * M(32, 75)
      temp = temp + M(58, 45) * M(45, 75)
      temp = temp + M(58, 49) * M(49, 75)
      temp = temp + M(58, 50) * M(50, 75)
      temp = temp + M(58, 51) * M(51, 75)
      temp = temp + M(58, 57) * M(57, 75)
      M(58, 75) = ( M(58, 75) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 45) * M(45, 79)
      temp = temp + M(58, 49) * M(49, 79)
      temp = temp + M(58, 50) * M(50, 79)
      temp = temp + M(58, 51) * M(51, 79)
      temp = temp + M(58, 57) * M(57, 79)
      M(58, 79) = ( M(58, 79) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 45) * M(45, 80)
      temp = temp + M(58, 49) * M(49, 80)
      temp = temp + M(58, 50) * M(50, 80)
      temp = temp + M(58, 51) * M(51, 80)
      temp = temp + M(58, 57) * M(57, 80)
      M(58, 80) = ( M(58, 80) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 32) * M(32, 81)
      M(58, 81) = ( M(58, 81) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 57) * M(57, 82)
      M(58, 82) = ( M(58, 82) - temp ) / M(58, 58)

C     Lower part.
      temp = M(59, 58) * M(58, 59)
      M(59, 59) = M(59, 59) - temp
C     Lower part.
      temp = M(60, 58) * M(58, 59)
      M(60, 59) = M(60, 59) - temp
C     Lower part.
      temp = M(61, 58) * M(58, 59)
      M(61, 59) = M(61, 59) - temp
C     Lower part.
      temp = M(62, 54) * M(54, 59)
      temp = temp + M(62, 58) * M(58, 59)
      M(62, 59) = M(62, 59) - temp
C     Lower part.
      temp = M(63, 58) * M(58, 59)
      M(63, 59) = M(63, 59) - temp
C     Lower part.
      temp = M(64, 58) * M(58, 59)
      M(64, 59) = M(64, 59) - temp
C     Lower part.
      temp = M(65, 54) * M(54, 59)
      temp = temp + M(65, 58) * M(58, 59)
      M(65, 59) = M(65, 59) - temp
C     Lower part.
      temp = M(67, 54) * M(54, 59)
      temp = temp + M(67, 58) * M(58, 59)
      M(67, 59) = M(67, 59) - temp
C     Lower part.
      temp = M(68, 54) * M(54, 59)
      temp = temp + M(68, 58) * M(58, 59)
      M(68, 59) = M(68, 59) - temp
C     Lower part.
      temp = M(69, 31) * M(31, 59)
      temp = temp + M(69, 54) * M(54, 59)
      temp = temp + M(69, 58) * M(58, 59)
      M(69, 59) = M(69, 59) - temp
C     Lower part.
      temp = M(70, 58) * M(58, 59)
      M(70, 59) = M(70, 59) - temp
C     Lower part.
      temp = M(71, 58) * M(58, 59)
      M(71, 59) = M(71, 59) - temp
C     Lower part.
      temp = M(72, 58) * M(58, 59)
      M(72, 59) = M(72, 59) - temp
C     Lower part.
      temp = M(73, 58) * M(58, 59)
      M(73, 59) = M(73, 59) - temp
C     Lower part.
      temp = M(74, 54) * M(54, 59)
      temp = temp + M(74, 58) * M(58, 59)
      M(74, 59) = M(74, 59) - temp
C     Lower part.
      temp = M(75, 31) * M(31, 59)
      temp = temp + M(75, 58) * M(58, 59)
      M(75, 59) = M(75, 59) - temp
C     Lower part.
      temp = M(76, 58) * M(58, 59)
      M(76, 59) = M(76, 59) - temp
C     Lower part.
      temp = M(77, 58) * M(58, 59)
      M(77, 59) = M(77, 59) - temp
C     Lower part.
      temp = M(79, 54) * M(54, 59)
      temp = temp + M(79, 58) * M(58, 59)
      M(79, 59) = M(79, 59) - temp
C     Lower part.
      temp = M(80, 54) * M(54, 59)
      temp = temp + M(80, 58) * M(58, 59)
      M(80, 59) = M(80, 59) - temp
C     Lower part.
      temp = M(81, 54) * M(54, 59)
      temp = temp + M(81, 58) * M(58, 59)
      M(81, 59) = M(81, 59) - temp
C     Lower part.
      temp = M(82, 54) * M(54, 59)
      temp = temp + M(82, 58) * M(58, 59)
      M(82, 59) = M(82, 59) - temp
C     Upper part.
      temp = M(59, 56) * M(56, 69)
      temp = temp + M(59, 57) * M(57, 69)
      temp = temp + M(59, 58) * M(58, 69)
      M(59, 69) = ( M(59, 69) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 44) * M(44, 73)
      temp = temp + M(59, 49) * M(49, 73)
      temp = temp + M(59, 51) * M(51, 73)
      temp = temp + M(59, 56) * M(56, 73)
      temp = temp + M(59, 57) * M(57, 73)
      temp = temp + M(59, 58) * M(58, 73)
      M(59, 73) = ( M(59, 73) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 44) * M(44, 75)
      temp = temp + M(59, 49) * M(49, 75)
      temp = temp + M(59, 51) * M(51, 75)
      temp = temp + M(59, 56) * M(56, 75)
      temp = temp + M(59, 57) * M(57, 75)
      temp = temp + M(59, 58) * M(58, 75)
      M(59, 75) = ( M(59, 75) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 44) * M(44, 79)
      temp = temp + M(59, 49) * M(49, 79)
      temp = temp + M(59, 51) * M(51, 79)
      temp = temp + M(59, 56) * M(56, 79)
      temp = temp + M(59, 57) * M(57, 79)
      temp = temp + M(59, 58) * M(58, 79)
      M(59, 79) = ( M(59, 79) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 44) * M(44, 80)
      temp = temp + M(59, 49) * M(49, 80)
      temp = temp + M(59, 51) * M(51, 80)
      temp = temp + M(59, 56) * M(56, 80)
      temp = temp + M(59, 57) * M(57, 80)
      temp = temp + M(59, 58) * M(58, 80)
      M(59, 80) = ( M(59, 80) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 58) * M(58, 81)
      M(59, 81) = ( M(59, 81) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 56) * M(56, 82)
      temp = temp + M(59, 57) * M(57, 82)
      temp = temp + M(59, 58) * M(58, 82)
      M(59, 82) = ( M(59, 82) - temp ) / M(59, 59)

C     Upper part.
      temp = M(60, 57) * M(57, 69)
      temp = temp + M(60, 58) * M(58, 69)
      temp = temp + M(60, 59) * M(59, 69)
      M(60, 69) = ( M(60, 69) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 19) * M(19, 73)
      temp = temp + M(60, 20) * M(20, 73)
      temp = temp + M(60, 21) * M(21, 73)
      temp = temp + M(60, 24) * M(24, 73)
      temp = temp + M(60, 25) * M(25, 73)
      temp = temp + M(60, 45) * M(45, 73)
      temp = temp + M(60, 49) * M(49, 73)
      temp = temp + M(60, 51) * M(51, 73)
      temp = temp + M(60, 57) * M(57, 73)
      temp = temp + M(60, 58) * M(58, 73)
      temp = temp + M(60, 59) * M(59, 73)
      M(60, 73) = ( M(60, 73) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 19) * M(19, 75)
      temp = temp + M(60, 20) * M(20, 75)
      temp = temp + M(60, 21) * M(21, 75)
      temp = temp + M(60, 24) * M(24, 75)
      temp = temp + M(60, 25) * M(25, 75)
      temp = temp + M(60, 45) * M(45, 75)
      temp = temp + M(60, 49) * M(49, 75)
      temp = temp + M(60, 51) * M(51, 75)
      temp = temp + M(60, 57) * M(57, 75)
      temp = temp + M(60, 58) * M(58, 75)
      temp = temp + M(60, 59) * M(59, 75)
      M(60, 75) = ( M(60, 75) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 45) * M(45, 79)
      temp = temp + M(60, 49) * M(49, 79)
      temp = temp + M(60, 51) * M(51, 79)
      temp = temp + M(60, 57) * M(57, 79)
      temp = temp + M(60, 58) * M(58, 79)
      temp = temp + M(60, 59) * M(59, 79)
      M(60, 79) = ( M(60, 79) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 45) * M(45, 80)
      temp = temp + M(60, 49) * M(49, 80)
      temp = temp + M(60, 51) * M(51, 80)
      temp = temp + M(60, 57) * M(57, 80)
      temp = temp + M(60, 58) * M(58, 80)
      temp = temp + M(60, 59) * M(59, 80)
      M(60, 80) = ( M(60, 80) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 58) * M(58, 81)
      temp = temp + M(60, 59) * M(59, 81)
      M(60, 81) = ( M(60, 81) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 57) * M(57, 82)
      temp = temp + M(60, 58) * M(58, 82)
      temp = temp + M(60, 59) * M(59, 82)
      M(60, 82) = ( M(60, 82) - temp ) / M(60, 60)

C     Upper part.
      M(61, 66) = M(61, 66) / M(61, 61)
C     Upper part.
      temp = M(61, 35) * M(35, 69)
      temp = temp + M(61, 36) * M(36, 69)
      temp = temp + M(61, 37) * M(37, 69)
      temp = temp + M(61, 38) * M(38, 69)
      temp = temp + M(61, 39) * M(39, 69)
      temp = temp + M(61, 53) * M(53, 69)
      temp = temp + M(61, 55) * M(55, 69)
      temp = temp + M(61, 56) * M(56, 69)
      temp = temp + M(61, 57) * M(57, 69)
      temp = temp + M(61, 58) * M(58, 69)
      temp = temp + M(61, 59) * M(59, 69)
      temp = temp + M(61, 60) * M(60, 69)
      M(61, 69) = ( M(61, 69) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 44) * M(44, 73)
      temp = temp + M(61, 49) * M(49, 73)
      temp = temp + M(61, 51) * M(51, 73)
      temp = temp + M(61, 53) * M(53, 73)
      temp = temp + M(61, 55) * M(55, 73)
      temp = temp + M(61, 56) * M(56, 73)
      temp = temp + M(61, 57) * M(57, 73)
      temp = temp + M(61, 58) * M(58, 73)
      temp = temp + M(61, 59) * M(59, 73)
      temp = temp + M(61, 60) * M(60, 73)
      M(61, 73) = ( M(61, 73) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 35) * M(35, 75)
      temp = temp + M(61, 36) * M(36, 75)
      temp = temp + M(61, 37) * M(37, 75)
      temp = temp + M(61, 38) * M(38, 75)
      temp = temp + M(61, 39) * M(39, 75)
      temp = temp + M(61, 44) * M(44, 75)
      temp = temp + M(61, 49) * M(49, 75)
      temp = temp + M(61, 51) * M(51, 75)
      temp = temp + M(61, 53) * M(53, 75)
      temp = temp + M(61, 55) * M(55, 75)
      temp = temp + M(61, 56) * M(56, 75)
      temp = temp + M(61, 57) * M(57, 75)
      temp = temp + M(61, 58) * M(58, 75)
      temp = temp + M(61, 59) * M(59, 75)
      temp = temp + M(61, 60) * M(60, 75)
      M(61, 75) = ( M(61, 75) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 35) * M(35, 79)
      temp = temp + M(61, 36) * M(36, 79)
      temp = temp + M(61, 37) * M(37, 79)
      temp = temp + M(61, 38) * M(38, 79)
      temp = temp + M(61, 39) * M(39, 79)
      temp = temp + M(61, 44) * M(44, 79)
      temp = temp + M(61, 49) * M(49, 79)
      temp = temp + M(61, 51) * M(51, 79)
      temp = temp + M(61, 53) * M(53, 79)
      temp = temp + M(61, 55) * M(55, 79)
      temp = temp + M(61, 56) * M(56, 79)
      temp = temp + M(61, 57) * M(57, 79)
      temp = temp + M(61, 58) * M(58, 79)
      temp = temp + M(61, 59) * M(59, 79)
      temp = temp + M(61, 60) * M(60, 79)
      M(61, 79) = ( M(61, 79) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 35) * M(35, 80)
      temp = temp + M(61, 36) * M(36, 80)
      temp = temp + M(61, 37) * M(37, 80)
      temp = temp + M(61, 38) * M(38, 80)
      temp = temp + M(61, 39) * M(39, 80)
      temp = temp + M(61, 44) * M(44, 80)
      temp = temp + M(61, 49) * M(49, 80)
      temp = temp + M(61, 51) * M(51, 80)
      temp = temp + M(61, 55) * M(55, 80)
      temp = temp + M(61, 56) * M(56, 80)
      temp = temp + M(61, 57) * M(57, 80)
      temp = temp + M(61, 58) * M(58, 80)
      temp = temp + M(61, 59) * M(59, 80)
      temp = temp + M(61, 60) * M(60, 80)
      M(61, 80) = ( M(61, 80) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 53) * M(53, 81)
      temp = temp + M(61, 58) * M(58, 81)
      temp = temp + M(61, 59) * M(59, 81)
      temp = temp + M(61, 60) * M(60, 81)
      M(61, 81) = ( M(61, 81) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 35) * M(35, 82)
      temp = temp + M(61, 36) * M(36, 82)
      temp = temp + M(61, 37) * M(37, 82)
      temp = temp + M(61, 38) * M(38, 82)
      temp = temp + M(61, 39) * M(39, 82)
      temp = temp + M(61, 53) * M(53, 82)
      temp = temp + M(61, 55) * M(55, 82)
      temp = temp + M(61, 56) * M(56, 82)
      temp = temp + M(61, 57) * M(57, 82)
      temp = temp + M(61, 58) * M(58, 82)
      temp = temp + M(61, 59) * M(59, 82)
      temp = temp + M(61, 60) * M(60, 82)
      M(61, 82) = ( M(61, 82) - temp ) / M(61, 61)

C     Upper part.
      temp = M(62, 61) * M(61, 66)
      M(62, 66) = ( M(62, 66) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 35) * M(35, 69)
      temp = temp + M(62, 36) * M(36, 69)
      temp = temp + M(62, 37) * M(37, 69)
      temp = temp + M(62, 38) * M(38, 69)
      temp = temp + M(62, 39) * M(39, 69)
      temp = temp + M(62, 54) * M(54, 69)
      temp = temp + M(62, 55) * M(55, 69)
      temp = temp + M(62, 58) * M(58, 69)
      temp = temp + M(62, 59) * M(59, 69)
      temp = temp + M(62, 61) * M(61, 69)
      M(62, 69) = ( M(62, 69) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 20) * M(20, 73)
      temp = temp + M(62, 21) * M(21, 73)
      temp = temp + M(62, 24) * M(24, 73)
      temp = temp + M(62, 55) * M(55, 73)
      temp = temp + M(62, 58) * M(58, 73)
      temp = temp + M(62, 59) * M(59, 73)
      temp = temp + M(62, 61) * M(61, 73)
      M(62, 73) = ( M(62, 73) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 20) * M(20, 75)
      temp = temp + M(62, 21) * M(21, 75)
      temp = temp + M(62, 24) * M(24, 75)
      temp = temp + M(62, 35) * M(35, 75)
      temp = temp + M(62, 36) * M(36, 75)
      temp = temp + M(62, 37) * M(37, 75)
      temp = temp + M(62, 38) * M(38, 75)
      temp = temp + M(62, 39) * M(39, 75)
      temp = temp + M(62, 54) * M(54, 75)
      temp = temp + M(62, 55) * M(55, 75)
      temp = temp + M(62, 58) * M(58, 75)
      temp = temp + M(62, 59) * M(59, 75)
      temp = temp + M(62, 61) * M(61, 75)
      M(62, 75) = ( M(62, 75) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 35) * M(35, 79)
      temp = temp + M(62, 36) * M(36, 79)
      temp = temp + M(62, 37) * M(37, 79)
      temp = temp + M(62, 38) * M(38, 79)
      temp = temp + M(62, 39) * M(39, 79)
      temp = temp + M(62, 54) * M(54, 79)
      temp = temp + M(62, 55) * M(55, 79)
      temp = temp + M(62, 58) * M(58, 79)
      temp = temp + M(62, 59) * M(59, 79)
      temp = temp + M(62, 61) * M(61, 79)
      M(62, 79) = ( M(62, 79) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 35) * M(35, 80)
      temp = temp + M(62, 36) * M(36, 80)
      temp = temp + M(62, 37) * M(37, 80)
      temp = temp + M(62, 38) * M(38, 80)
      temp = temp + M(62, 39) * M(39, 80)
      temp = temp + M(62, 54) * M(54, 80)
      temp = temp + M(62, 55) * M(55, 80)
      temp = temp + M(62, 58) * M(58, 80)
      temp = temp + M(62, 59) * M(59, 80)
      temp = temp + M(62, 61) * M(61, 80)
      M(62, 80) = ( M(62, 80) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 58) * M(58, 81)
      temp = temp + M(62, 59) * M(59, 81)
      temp = temp + M(62, 61) * M(61, 81)
      M(62, 81) = ( M(62, 81) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 35) * M(35, 82)
      temp = temp + M(62, 36) * M(36, 82)
      temp = temp + M(62, 37) * M(37, 82)
      temp = temp + M(62, 38) * M(38, 82)
      temp = temp + M(62, 39) * M(39, 82)
      temp = temp + M(62, 54) * M(54, 82)
      temp = temp + M(62, 55) * M(55, 82)
      temp = temp + M(62, 58) * M(58, 82)
      temp = temp + M(62, 59) * M(59, 82)
      temp = temp + M(62, 61) * M(61, 82)
      M(62, 82) = ( M(62, 82) - temp ) / M(62, 62)

C     Upper part.
      temp = M(63, 62) * M(62, 66)
      M(63, 66) = ( M(63, 66) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 58) * M(58, 69)
      temp = temp + M(63, 59) * M(59, 69)
      temp = temp + M(63, 62) * M(62, 69)
      M(63, 69) = ( M(63, 69) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 24) * M(24, 73)
      temp = temp + M(63, 25) * M(25, 73)
      temp = temp + M(63, 58) * M(58, 73)
      temp = temp + M(63, 59) * M(59, 73)
      temp = temp + M(63, 62) * M(62, 73)
      M(63, 73) = ( M(63, 73) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 4) * M(4, 75)
      temp = temp + M(63, 24) * M(24, 75)
      temp = temp + M(63, 25) * M(25, 75)
      temp = temp + M(63, 58) * M(58, 75)
      temp = temp + M(63, 59) * M(59, 75)
      temp = temp + M(63, 62) * M(62, 75)
      M(63, 75) = ( M(63, 75) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 58) * M(58, 79)
      temp = temp + M(63, 59) * M(59, 79)
      temp = temp + M(63, 62) * M(62, 79)
      M(63, 79) = ( M(63, 79) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 58) * M(58, 80)
      temp = temp + M(63, 59) * M(59, 80)
      temp = temp + M(63, 62) * M(62, 80)
      M(63, 80) = ( M(63, 80) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 58) * M(58, 81)
      temp = temp + M(63, 59) * M(59, 81)
      temp = temp + M(63, 62) * M(62, 81)
      M(63, 81) = ( M(63, 81) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 58) * M(58, 82)
      temp = temp + M(63, 59) * M(59, 82)
      temp = temp + M(63, 62) * M(62, 82)
      M(63, 82) = ( M(63, 82) - temp ) / M(63, 63)

C     Upper part.
      temp = M(64, 62) * M(62, 66)
      M(64, 66) = ( M(64, 66) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 58) * M(58, 69)
      temp = temp + M(64, 59) * M(59, 69)
      temp = temp + M(64, 62) * M(62, 69)
      M(64, 69) = ( M(64, 69) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 24) * M(24, 73)
      temp = temp + M(64, 25) * M(25, 73)
      temp = temp + M(64, 58) * M(58, 73)
      temp = temp + M(64, 59) * M(59, 73)
      temp = temp + M(64, 62) * M(62, 73)
      M(64, 73) = ( M(64, 73) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 24) * M(24, 75)
      temp = temp + M(64, 25) * M(25, 75)
      temp = temp + M(64, 58) * M(58, 75)
      temp = temp + M(64, 59) * M(59, 75)
      temp = temp + M(64, 62) * M(62, 75)
      M(64, 75) = ( M(64, 75) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 58) * M(58, 79)
      temp = temp + M(64, 59) * M(59, 79)
      temp = temp + M(64, 62) * M(62, 79)
      M(64, 79) = ( M(64, 79) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 58) * M(58, 80)
      temp = temp + M(64, 59) * M(59, 80)
      temp = temp + M(64, 62) * M(62, 80)
      M(64, 80) = ( M(64, 80) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 58) * M(58, 81)
      temp = temp + M(64, 59) * M(59, 81)
      temp = temp + M(64, 62) * M(62, 81)
      M(64, 81) = ( M(64, 81) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 58) * M(58, 82)
      temp = temp + M(64, 59) * M(59, 82)
      temp = temp + M(64, 62) * M(62, 82)
      M(64, 82) = ( M(64, 82) - temp ) / M(64, 64)

C     Upper part.
      temp = M(65, 63) * M(63, 66)
      temp = temp + M(65, 64) * M(64, 66)
      M(65, 66) = ( M(65, 66) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 35) * M(35, 69)
      temp = temp + M(65, 36) * M(36, 69)
      temp = temp + M(65, 37) * M(37, 69)
      temp = temp + M(65, 38) * M(38, 69)
      temp = temp + M(65, 39) * M(39, 69)
      temp = temp + M(65, 40) * M(40, 69)
      temp = temp + M(65, 41) * M(41, 69)
      temp = temp + M(65, 42) * M(42, 69)
      temp = temp + M(65, 43) * M(43, 69)
      temp = temp + M(65, 46) * M(46, 69)
      temp = temp + M(65, 47) * M(47, 69)
      temp = temp + M(65, 48) * M(48, 69)
      temp = temp + M(65, 53) * M(53, 69)
      temp = temp + M(65, 54) * M(54, 69)
      temp = temp + M(65, 55) * M(55, 69)
      temp = temp + M(65, 56) * M(56, 69)
      temp = temp + M(65, 57) * M(57, 69)
      temp = temp + M(65, 58) * M(58, 69)
      temp = temp + M(65, 59) * M(59, 69)
      temp = temp + M(65, 63) * M(63, 69)
      temp = temp + M(65, 64) * M(64, 69)
      M(65, 69) = ( M(65, 69) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 41) * M(41, 73)
      temp = temp + M(65, 42) * M(42, 73)
      temp = temp + M(65, 43) * M(43, 73)
      temp = temp + M(65, 44) * M(44, 73)
      temp = temp + M(65, 46) * M(46, 73)
      temp = temp + M(65, 49) * M(49, 73)
      temp = temp + M(65, 51) * M(51, 73)
      temp = temp + M(65, 53) * M(53, 73)
      temp = temp + M(65, 55) * M(55, 73)
      temp = temp + M(65, 56) * M(56, 73)
      temp = temp + M(65, 57) * M(57, 73)
      temp = temp + M(65, 58) * M(58, 73)
      temp = temp + M(65, 59) * M(59, 73)
      temp = temp + M(65, 63) * M(63, 73)
      temp = temp + M(65, 64) * M(64, 73)
      M(65, 73) = ( M(65, 73) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 35) * M(35, 75)
      temp = temp + M(65, 36) * M(36, 75)
      temp = temp + M(65, 37) * M(37, 75)
      temp = temp + M(65, 38) * M(38, 75)
      temp = temp + M(65, 39) * M(39, 75)
      temp = temp + M(65, 40) * M(40, 75)
      temp = temp + M(65, 41) * M(41, 75)
      temp = temp + M(65, 42) * M(42, 75)
      temp = temp + M(65, 43) * M(43, 75)
      temp = temp + M(65, 44) * M(44, 75)
      temp = temp + M(65, 46) * M(46, 75)
      temp = temp + M(65, 47) * M(47, 75)
      temp = temp + M(65, 48) * M(48, 75)
      temp = temp + M(65, 49) * M(49, 75)
      temp = temp + M(65, 51) * M(51, 75)
      temp = temp + M(65, 53) * M(53, 75)
      temp = temp + M(65, 54) * M(54, 75)
      temp = temp + M(65, 55) * M(55, 75)
      temp = temp + M(65, 56) * M(56, 75)
      temp = temp + M(65, 57) * M(57, 75)
      temp = temp + M(65, 58) * M(58, 75)
      temp = temp + M(65, 59) * M(59, 75)
      temp = temp + M(65, 63) * M(63, 75)
      temp = temp + M(65, 64) * M(64, 75)
      M(65, 75) = ( M(65, 75) - temp ) / M(65, 65)
C     Upper part.
      M(65, 77) = M(65, 77) / M(65, 65)
C     Upper part.
      M(65, 78) = M(65, 78) / M(65, 65)
C     Upper part.
      temp = M(65, 35) * M(35, 79)
      temp = temp + M(65, 36) * M(36, 79)
      temp = temp + M(65, 37) * M(37, 79)
      temp = temp + M(65, 38) * M(38, 79)
      temp = temp + M(65, 39) * M(39, 79)
      temp = temp + M(65, 40) * M(40, 79)
      temp = temp + M(65, 41) * M(41, 79)
      temp = temp + M(65, 42) * M(42, 79)
      temp = temp + M(65, 43) * M(43, 79)
      temp = temp + M(65, 44) * M(44, 79)
      temp = temp + M(65, 46) * M(46, 79)
      temp = temp + M(65, 47) * M(47, 79)
      temp = temp + M(65, 48) * M(48, 79)
      temp = temp + M(65, 49) * M(49, 79)
      temp = temp + M(65, 51) * M(51, 79)
      temp = temp + M(65, 53) * M(53, 79)
      temp = temp + M(65, 54) * M(54, 79)
      temp = temp + M(65, 55) * M(55, 79)
      temp = temp + M(65, 56) * M(56, 79)
      temp = temp + M(65, 57) * M(57, 79)
      temp = temp + M(65, 58) * M(58, 79)
      temp = temp + M(65, 59) * M(59, 79)
      temp = temp + M(65, 63) * M(63, 79)
      temp = temp + M(65, 64) * M(64, 79)
      M(65, 79) = ( M(65, 79) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 35) * M(35, 80)
      temp = temp + M(65, 36) * M(36, 80)
      temp = temp + M(65, 37) * M(37, 80)
      temp = temp + M(65, 38) * M(38, 80)
      temp = temp + M(65, 39) * M(39, 80)
      temp = temp + M(65, 40) * M(40, 80)
      temp = temp + M(65, 41) * M(41, 80)
      temp = temp + M(65, 42) * M(42, 80)
      temp = temp + M(65, 43) * M(43, 80)
      temp = temp + M(65, 44) * M(44, 80)
      temp = temp + M(65, 46) * M(46, 80)
      temp = temp + M(65, 47) * M(47, 80)
      temp = temp + M(65, 48) * M(48, 80)
      temp = temp + M(65, 49) * M(49, 80)
      temp = temp + M(65, 51) * M(51, 80)
      temp = temp + M(65, 54) * M(54, 80)
      temp = temp + M(65, 55) * M(55, 80)
      temp = temp + M(65, 56) * M(56, 80)
      temp = temp + M(65, 57) * M(57, 80)
      temp = temp + M(65, 58) * M(58, 80)
      temp = temp + M(65, 59) * M(59, 80)
      temp = temp + M(65, 63) * M(63, 80)
      temp = temp + M(65, 64) * M(64, 80)
      M(65, 80) = ( M(65, 80) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 53) * M(53, 81)
      temp = temp + M(65, 58) * M(58, 81)
      temp = temp + M(65, 59) * M(59, 81)
      temp = temp + M(65, 63) * M(63, 81)
      temp = temp + M(65, 64) * M(64, 81)
      M(65, 81) = ( M(65, 81) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 35) * M(35, 82)
      temp = temp + M(65, 36) * M(36, 82)
      temp = temp + M(65, 37) * M(37, 82)
      temp = temp + M(65, 38) * M(38, 82)
      temp = temp + M(65, 39) * M(39, 82)
      temp = temp + M(65, 40) * M(40, 82)
      temp = temp + M(65, 41) * M(41, 82)
      temp = temp + M(65, 42) * M(42, 82)
      temp = temp + M(65, 43) * M(43, 82)
      temp = temp + M(65, 46) * M(46, 82)
      temp = temp + M(65, 47) * M(47, 82)
      temp = temp + M(65, 48) * M(48, 82)
      temp = temp + M(65, 53) * M(53, 82)
      temp = temp + M(65, 54) * M(54, 82)
      temp = temp + M(65, 55) * M(55, 82)
      temp = temp + M(65, 56) * M(56, 82)
      temp = temp + M(65, 57) * M(57, 82)
      temp = temp + M(65, 58) * M(58, 82)
      temp = temp + M(65, 59) * M(59, 82)
      temp = temp + M(65, 63) * M(63, 82)
      temp = temp + M(65, 64) * M(64, 82)
      M(65, 82) = ( M(65, 82) - temp ) / M(65, 65)

C     Lower part.
      temp = M(66, 61) * M(61, 66)
      temp = temp + M(66, 65) * M(65, 66)
      M(66, 66) = M(66, 66) - temp
C     Lower part.
      temp = M(67, 61) * M(61, 66)
      temp = temp + M(67, 63) * M(63, 66)
      temp = temp + M(67, 65) * M(65, 66)
      M(67, 66) = M(67, 66) - temp
C     Lower part.
      temp = M(68, 63) * M(63, 66)
      temp = temp + M(68, 64) * M(64, 66)
      M(68, 66) = M(68, 66) - temp
C     Lower part.
      temp = M(69, 63) * M(63, 66)
      temp = temp + M(69, 64) * M(64, 66)
      M(69, 66) = M(69, 66) - temp
C     Lower part.
      temp = M(70, 64) * M(64, 66)
      M(70, 66) = M(70, 66) - temp
C     Lower part.
      temp = M(74, 63) * M(63, 66)
      temp = temp + M(74, 64) * M(64, 66)
      M(74, 66) = M(74, 66) - temp
C     Lower part.
      temp = M(75, 61) * M(61, 66)
      temp = temp + M(75, 62) * M(62, 66)
      temp = temp + M(75, 65) * M(65, 66)
      M(75, 66) = M(75, 66) - temp
C     Lower part.
      temp = M(79, 61) * M(61, 66)
      temp = temp + M(79, 63) * M(63, 66)
      temp = temp + M(79, 64) * M(64, 66)
      temp = temp + M(79, 65) * M(65, 66)
      M(79, 66) = M(79, 66) - temp
C     Lower part.
      temp = M(80, 63) * M(63, 66)
      temp = temp + M(80, 64) * M(64, 66)
      M(80, 66) = M(80, 66) - temp
C     Lower part.
      temp = M(81, 61) * M(61, 66)
      temp = temp + M(81, 63) * M(63, 66)
      temp = temp + M(81, 64) * M(64, 66)
      M(81, 66) = M(81, 66) - temp
C     Lower part.
      temp = M(82, 62) * M(62, 66)
      temp = temp + M(82, 63) * M(63, 66)
      temp = temp + M(82, 64) * M(64, 66)
      M(82, 66) = M(82, 66) - temp
C     Upper part.
      temp = M(66, 61) * M(61, 69)
      temp = temp + M(66, 65) * M(65, 69)
      M(66, 69) = ( M(66, 69) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 61) * M(61, 73)
      temp = temp + M(66, 65) * M(65, 73)
      M(66, 73) = ( M(66, 73) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 5) * M(5, 75)
      temp = temp + M(66, 61) * M(61, 75)
      temp = temp + M(66, 65) * M(65, 75)
      M(66, 75) = ( M(66, 75) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 65) * M(65, 77)
      M(66, 77) = ( M(66, 77) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 65) * M(65, 78)
      M(66, 78) = ( M(66, 78) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 61) * M(61, 79)
      temp = temp + M(66, 65) * M(65, 79)
      M(66, 79) = ( M(66, 79) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 61) * M(61, 80)
      temp = temp + M(66, 65) * M(65, 80)
      M(66, 80) = ( M(66, 80) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 61) * M(61, 81)
      temp = temp + M(66, 65) * M(65, 81)
      M(66, 81) = ( M(66, 81) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 61) * M(61, 82)
      temp = temp + M(66, 65) * M(65, 82)
      M(66, 82) = ( M(66, 82) - temp ) / M(66, 66)

C     Upper part.
      temp = M(67, 35) * M(35, 69)
      temp = temp + M(67, 36) * M(36, 69)
      temp = temp + M(67, 37) * M(37, 69)
      temp = temp + M(67, 38) * M(38, 69)
      temp = temp + M(67, 39) * M(39, 69)
      temp = temp + M(67, 41) * M(41, 69)
      temp = temp + M(67, 42) * M(42, 69)
      temp = temp + M(67, 43) * M(43, 69)
      temp = temp + M(67, 46) * M(46, 69)
      temp = temp + M(67, 54) * M(54, 69)
      temp = temp + M(67, 55) * M(55, 69)
      temp = temp + M(67, 57) * M(57, 69)
      temp = temp + M(67, 58) * M(58, 69)
      temp = temp + M(67, 59) * M(59, 69)
      temp = temp + M(67, 60) * M(60, 69)
      temp = temp + M(67, 61) * M(61, 69)
      temp = temp + M(67, 63) * M(63, 69)
      temp = temp + M(67, 65) * M(65, 69)
      temp = temp + M(67, 66) * M(66, 69)
      M(67, 69) = ( M(67, 69) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 20) * M(20, 73)
      temp = temp + M(67, 21) * M(21, 73)
      temp = temp + M(67, 24) * M(24, 73)
      temp = temp + M(67, 41) * M(41, 73)
      temp = temp + M(67, 42) * M(42, 73)
      temp = temp + M(67, 43) * M(43, 73)
      temp = temp + M(67, 45) * M(45, 73)
      temp = temp + M(67, 46) * M(46, 73)
      temp = temp + M(67, 49) * M(49, 73)
      temp = temp + M(67, 50) * M(50, 73)
      temp = temp + M(67, 51) * M(51, 73)
      temp = temp + M(67, 55) * M(55, 73)
      temp = temp + M(67, 57) * M(57, 73)
      temp = temp + M(67, 58) * M(58, 73)
      temp = temp + M(67, 59) * M(59, 73)
      temp = temp + M(67, 60) * M(60, 73)
      temp = temp + M(67, 61) * M(61, 73)
      temp = temp + M(67, 63) * M(63, 73)
      temp = temp + M(67, 65) * M(65, 73)
      temp = temp + M(67, 66) * M(66, 73)
      M(67, 73) = ( M(67, 73) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 20) * M(20, 75)
      temp = temp + M(67, 21) * M(21, 75)
      temp = temp + M(67, 24) * M(24, 75)
      temp = temp + M(67, 35) * M(35, 75)
      temp = temp + M(67, 36) * M(36, 75)
      temp = temp + M(67, 37) * M(37, 75)
      temp = temp + M(67, 38) * M(38, 75)
      temp = temp + M(67, 39) * M(39, 75)
      temp = temp + M(67, 41) * M(41, 75)
      temp = temp + M(67, 42) * M(42, 75)
      temp = temp + M(67, 43) * M(43, 75)
      temp = temp + M(67, 45) * M(45, 75)
      temp = temp + M(67, 46) * M(46, 75)
      temp = temp + M(67, 49) * M(49, 75)
      temp = temp + M(67, 50) * M(50, 75)
      temp = temp + M(67, 51) * M(51, 75)
      temp = temp + M(67, 54) * M(54, 75)
      temp = temp + M(67, 55) * M(55, 75)
      temp = temp + M(67, 57) * M(57, 75)
      temp = temp + M(67, 58) * M(58, 75)
      temp = temp + M(67, 59) * M(59, 75)
      temp = temp + M(67, 60) * M(60, 75)
      temp = temp + M(67, 61) * M(61, 75)
      temp = temp + M(67, 63) * M(63, 75)
      temp = temp + M(67, 65) * M(65, 75)
      temp = temp + M(67, 66) * M(66, 75)
      M(67, 75) = ( M(67, 75) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 65) * M(65, 77)
      temp = temp + M(67, 66) * M(66, 77)
      M(67, 77) = ( M(67, 77) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 65) * M(65, 78)
      temp = temp + M(67, 66) * M(66, 78)
      M(67, 78) = ( M(67, 78) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 35) * M(35, 79)
      temp = temp + M(67, 36) * M(36, 79)
      temp = temp + M(67, 37) * M(37, 79)
      temp = temp + M(67, 38) * M(38, 79)
      temp = temp + M(67, 39) * M(39, 79)
      temp = temp + M(67, 41) * M(41, 79)
      temp = temp + M(67, 42) * M(42, 79)
      temp = temp + M(67, 43) * M(43, 79)
      temp = temp + M(67, 45) * M(45, 79)
      temp = temp + M(67, 46) * M(46, 79)
      temp = temp + M(67, 49) * M(49, 79)
      temp = temp + M(67, 50) * M(50, 79)
      temp = temp + M(67, 51) * M(51, 79)
      temp = temp + M(67, 54) * M(54, 79)
      temp = temp + M(67, 55) * M(55, 79)
      temp = temp + M(67, 57) * M(57, 79)
      temp = temp + M(67, 58) * M(58, 79)
      temp = temp + M(67, 59) * M(59, 79)
      temp = temp + M(67, 60) * M(60, 79)
      temp = temp + M(67, 61) * M(61, 79)
      temp = temp + M(67, 63) * M(63, 79)
      temp = temp + M(67, 65) * M(65, 79)
      temp = temp + M(67, 66) * M(66, 79)
      M(67, 79) = ( M(67, 79) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 35) * M(35, 80)
      temp = temp + M(67, 36) * M(36, 80)
      temp = temp + M(67, 37) * M(37, 80)
      temp = temp + M(67, 38) * M(38, 80)
      temp = temp + M(67, 39) * M(39, 80)
      temp = temp + M(67, 41) * M(41, 80)
      temp = temp + M(67, 42) * M(42, 80)
      temp = temp + M(67, 43) * M(43, 80)
      temp = temp + M(67, 45) * M(45, 80)
      temp = temp + M(67, 46) * M(46, 80)
      temp = temp + M(67, 49) * M(49, 80)
      temp = temp + M(67, 50) * M(50, 80)
      temp = temp + M(67, 51) * M(51, 80)
      temp = temp + M(67, 54) * M(54, 80)
      temp = temp + M(67, 55) * M(55, 80)
      temp = temp + M(67, 57) * M(57, 80)
      temp = temp + M(67, 58) * M(58, 80)
      temp = temp + M(67, 59) * M(59, 80)
      temp = temp + M(67, 60) * M(60, 80)
      temp = temp + M(67, 61) * M(61, 80)
      temp = temp + M(67, 63) * M(63, 80)
      temp = temp + M(67, 65) * M(65, 80)
      temp = temp + M(67, 66) * M(66, 80)
      M(67, 80) = ( M(67, 80) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 58) * M(58, 81)
      temp = temp + M(67, 59) * M(59, 81)
      temp = temp + M(67, 60) * M(60, 81)
      temp = temp + M(67, 61) * M(61, 81)
      temp = temp + M(67, 63) * M(63, 81)
      temp = temp + M(67, 65) * M(65, 81)
      temp = temp + M(67, 66) * M(66, 81)
      M(67, 81) = ( M(67, 81) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 35) * M(35, 82)
      temp = temp + M(67, 36) * M(36, 82)
      temp = temp + M(67, 37) * M(37, 82)
      temp = temp + M(67, 38) * M(38, 82)
      temp = temp + M(67, 39) * M(39, 82)
      temp = temp + M(67, 41) * M(41, 82)
      temp = temp + M(67, 42) * M(42, 82)
      temp = temp + M(67, 43) * M(43, 82)
      temp = temp + M(67, 46) * M(46, 82)
      temp = temp + M(67, 54) * M(54, 82)
      temp = temp + M(67, 55) * M(55, 82)
      temp = temp + M(67, 57) * M(57, 82)
      temp = temp + M(67, 58) * M(58, 82)
      temp = temp + M(67, 59) * M(59, 82)
      temp = temp + M(67, 60) * M(60, 82)
      temp = temp + M(67, 61) * M(61, 82)
      temp = temp + M(67, 63) * M(63, 82)
      temp = temp + M(67, 65) * M(65, 82)
      temp = temp + M(67, 66) * M(66, 82)
      M(67, 82) = ( M(67, 82) - temp ) / M(67, 67)

C     Upper part.
      temp = M(68, 35) * M(35, 69)
      temp = temp + M(68, 36) * M(36, 69)
      temp = temp + M(68, 37) * M(37, 69)
      temp = temp + M(68, 38) * M(38, 69)
      temp = temp + M(68, 39) * M(39, 69)
      temp = temp + M(68, 40) * M(40, 69)
      temp = temp + M(68, 41) * M(41, 69)
      temp = temp + M(68, 42) * M(42, 69)
      temp = temp + M(68, 43) * M(43, 69)
      temp = temp + M(68, 46) * M(46, 69)
      temp = temp + M(68, 54) * M(54, 69)
      temp = temp + M(68, 57) * M(57, 69)
      temp = temp + M(68, 58) * M(58, 69)
      temp = temp + M(68, 59) * M(59, 69)
      temp = temp + M(68, 60) * M(60, 69)
      temp = temp + M(68, 63) * M(63, 69)
      temp = temp + M(68, 64) * M(64, 69)
      temp = temp + M(68, 66) * M(66, 69)
      M(68, 69) = ( M(68, 69) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 20) * M(20, 73)
      temp = temp + M(68, 21) * M(21, 73)
      temp = temp + M(68, 22) * M(22, 73)
      temp = temp + M(68, 25) * M(25, 73)
      temp = temp + M(68, 41) * M(41, 73)
      temp = temp + M(68, 42) * M(42, 73)
      temp = temp + M(68, 43) * M(43, 73)
      temp = temp + M(68, 44) * M(44, 73)
      temp = temp + M(68, 45) * M(45, 73)
      temp = temp + M(68, 46) * M(46, 73)
      temp = temp + M(68, 49) * M(49, 73)
      temp = temp + M(68, 50) * M(50, 73)
      temp = temp + M(68, 51) * M(51, 73)
      temp = temp + M(68, 57) * M(57, 73)
      temp = temp + M(68, 58) * M(58, 73)
      temp = temp + M(68, 59) * M(59, 73)
      temp = temp + M(68, 60) * M(60, 73)
      temp = temp + M(68, 63) * M(63, 73)
      temp = temp + M(68, 64) * M(64, 73)
      temp = temp + M(68, 66) * M(66, 73)
      M(68, 73) = ( M(68, 73) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 20) * M(20, 75)
      temp = temp + M(68, 21) * M(21, 75)
      temp = temp + M(68, 22) * M(22, 75)
      temp = temp + M(68, 25) * M(25, 75)
      temp = temp + M(68, 30) * M(30, 75)
      temp = temp + M(68, 35) * M(35, 75)
      temp = temp + M(68, 36) * M(36, 75)
      temp = temp + M(68, 37) * M(37, 75)
      temp = temp + M(68, 38) * M(38, 75)
      temp = temp + M(68, 39) * M(39, 75)
      temp = temp + M(68, 40) * M(40, 75)
      temp = temp + M(68, 41) * M(41, 75)
      temp = temp + M(68, 42) * M(42, 75)
      temp = temp + M(68, 43) * M(43, 75)
      temp = temp + M(68, 44) * M(44, 75)
      temp = temp + M(68, 45) * M(45, 75)
      temp = temp + M(68, 46) * M(46, 75)
      temp = temp + M(68, 49) * M(49, 75)
      temp = temp + M(68, 50) * M(50, 75)
      temp = temp + M(68, 51) * M(51, 75)
      temp = temp + M(68, 54) * M(54, 75)
      temp = temp + M(68, 57) * M(57, 75)
      temp = temp + M(68, 58) * M(58, 75)
      temp = temp + M(68, 59) * M(59, 75)
      temp = temp + M(68, 60) * M(60, 75)
      temp = temp + M(68, 63) * M(63, 75)
      temp = temp + M(68, 64) * M(64, 75)
      temp = temp + M(68, 66) * M(66, 75)
      M(68, 75) = ( M(68, 75) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 66) * M(66, 77)
      M(68, 77) = ( M(68, 77) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 66) * M(66, 78)
      M(68, 78) = ( M(68, 78) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 35) * M(35, 79)
      temp = temp + M(68, 36) * M(36, 79)
      temp = temp + M(68, 37) * M(37, 79)
      temp = temp + M(68, 38) * M(38, 79)
      temp = temp + M(68, 39) * M(39, 79)
      temp = temp + M(68, 40) * M(40, 79)
      temp = temp + M(68, 41) * M(41, 79)
      temp = temp + M(68, 42) * M(42, 79)
      temp = temp + M(68, 43) * M(43, 79)
      temp = temp + M(68, 44) * M(44, 79)
      temp = temp + M(68, 45) * M(45, 79)
      temp = temp + M(68, 46) * M(46, 79)
      temp = temp + M(68, 49) * M(49, 79)
      temp = temp + M(68, 50) * M(50, 79)
      temp = temp + M(68, 51) * M(51, 79)
      temp = temp + M(68, 54) * M(54, 79)
      temp = temp + M(68, 57) * M(57, 79)
      temp = temp + M(68, 58) * M(58, 79)
      temp = temp + M(68, 59) * M(59, 79)
      temp = temp + M(68, 60) * M(60, 79)
      temp = temp + M(68, 63) * M(63, 79)
      temp = temp + M(68, 64) * M(64, 79)
      temp = temp + M(68, 66) * M(66, 79)
      M(68, 79) = ( M(68, 79) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 30) * M(30, 80)
      temp = temp + M(68, 35) * M(35, 80)
      temp = temp + M(68, 36) * M(36, 80)
      temp = temp + M(68, 37) * M(37, 80)
      temp = temp + M(68, 38) * M(38, 80)
      temp = temp + M(68, 39) * M(39, 80)
      temp = temp + M(68, 40) * M(40, 80)
      temp = temp + M(68, 41) * M(41, 80)
      temp = temp + M(68, 42) * M(42, 80)
      temp = temp + M(68, 43) * M(43, 80)
      temp = temp + M(68, 44) * M(44, 80)
      temp = temp + M(68, 45) * M(45, 80)
      temp = temp + M(68, 46) * M(46, 80)
      temp = temp + M(68, 49) * M(49, 80)
      temp = temp + M(68, 50) * M(50, 80)
      temp = temp + M(68, 51) * M(51, 80)
      temp = temp + M(68, 54) * M(54, 80)
      temp = temp + M(68, 57) * M(57, 80)
      temp = temp + M(68, 58) * M(58, 80)
      temp = temp + M(68, 59) * M(59, 80)
      temp = temp + M(68, 60) * M(60, 80)
      temp = temp + M(68, 63) * M(63, 80)
      temp = temp + M(68, 64) * M(64, 80)
      temp = temp + M(68, 66) * M(66, 80)
      M(68, 80) = ( M(68, 80) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 58) * M(58, 81)
      temp = temp + M(68, 59) * M(59, 81)
      temp = temp + M(68, 60) * M(60, 81)
      temp = temp + M(68, 63) * M(63, 81)
      temp = temp + M(68, 64) * M(64, 81)
      temp = temp + M(68, 66) * M(66, 81)
      M(68, 81) = ( M(68, 81) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 35) * M(35, 82)
      temp = temp + M(68, 36) * M(36, 82)
      temp = temp + M(68, 37) * M(37, 82)
      temp = temp + M(68, 38) * M(38, 82)
      temp = temp + M(68, 39) * M(39, 82)
      temp = temp + M(68, 40) * M(40, 82)
      temp = temp + M(68, 41) * M(41, 82)
      temp = temp + M(68, 42) * M(42, 82)
      temp = temp + M(68, 43) * M(43, 82)
      temp = temp + M(68, 46) * M(46, 82)
      temp = temp + M(68, 54) * M(54, 82)
      temp = temp + M(68, 57) * M(57, 82)
      temp = temp + M(68, 58) * M(58, 82)
      temp = temp + M(68, 59) * M(59, 82)
      temp = temp + M(68, 60) * M(60, 82)
      temp = temp + M(68, 63) * M(63, 82)
      temp = temp + M(68, 64) * M(64, 82)
      temp = temp + M(68, 66) * M(66, 82)
      M(68, 82) = ( M(68, 82) - temp ) / M(68, 68)

C     Lower part.
      temp = M(69, 27) * M(27, 69)
      temp = temp + M(69, 35) * M(35, 69)
      temp = temp + M(69, 36) * M(36, 69)
      temp = temp + M(69, 37) * M(37, 69)
      temp = temp + M(69, 38) * M(38, 69)
      temp = temp + M(69, 39) * M(39, 69)
      temp = temp + M(69, 40) * M(40, 69)
      temp = temp + M(69, 41) * M(41, 69)
      temp = temp + M(69, 42) * M(42, 69)
      temp = temp + M(69, 43) * M(43, 69)
      temp = temp + M(69, 46) * M(46, 69)
      temp = temp + M(69, 47) * M(47, 69)
      temp = temp + M(69, 48) * M(48, 69)
      temp = temp + M(69, 53) * M(53, 69)
      temp = temp + M(69, 54) * M(54, 69)
      temp = temp + M(69, 55) * M(55, 69)
      temp = temp + M(69, 56) * M(56, 69)
      temp = temp + M(69, 57) * M(57, 69)
      temp = temp + M(69, 58) * M(58, 69)
      temp = temp + M(69, 59) * M(59, 69)
      temp = temp + M(69, 60) * M(60, 69)
      temp = temp + M(69, 63) * M(63, 69)
      temp = temp + M(69, 64) * M(64, 69)
      temp = temp + M(69, 66) * M(66, 69)
      temp = temp + M(69, 67) * M(67, 69)
      M(69, 69) = M(69, 69) - temp
C     Lower part.
      temp = M(70, 47) * M(47, 69)
      temp = temp + M(70, 48) * M(48, 69)
      temp = temp + M(70, 57) * M(57, 69)
      temp = temp + M(70, 58) * M(58, 69)
      temp = temp + M(70, 59) * M(59, 69)
      temp = temp + M(70, 64) * M(64, 69)
      temp = temp + M(70, 66) * M(66, 69)
      M(70, 69) = M(70, 69) - temp
C     Lower part.
      temp = M(71, 40) * M(40, 69)
      temp = temp + M(71, 41) * M(41, 69)
      temp = temp + M(71, 47) * M(47, 69)
      temp = temp + M(71, 57) * M(57, 69)
      temp = temp + M(71, 58) * M(58, 69)
      temp = temp + M(71, 59) * M(59, 69)
      M(71, 69) = M(71, 69) - temp
C     Lower part.
      temp = M(72, 52) * M(52, 69)
      temp = temp + M(72, 57) * M(57, 69)
      temp = temp + M(72, 58) * M(58, 69)
      temp = temp + M(72, 59) * M(59, 69)
      temp = temp + M(72, 67) * M(67, 69)
      M(72, 69) = M(72, 69) - temp
C     Lower part.
      temp = M(73, 52) * M(52, 69)
      temp = temp + M(73, 55) * M(55, 69)
      temp = temp + M(73, 56) * M(56, 69)
      temp = temp + M(73, 57) * M(57, 69)
      temp = temp + M(73, 58) * M(58, 69)
      temp = temp + M(73, 59) * M(59, 69)
      temp = temp + M(73, 67) * M(67, 69)
      M(73, 69) = M(73, 69) - temp
C     Lower part.
      temp = M(74, 27) * M(27, 69)
      temp = temp + M(74, 35) * M(35, 69)
      temp = temp + M(74, 36) * M(36, 69)
      temp = temp + M(74, 37) * M(37, 69)
      temp = temp + M(74, 38) * M(38, 69)
      temp = temp + M(74, 39) * M(39, 69)
      temp = temp + M(74, 40) * M(40, 69)
      temp = temp + M(74, 41) * M(41, 69)
      temp = temp + M(74, 42) * M(42, 69)
      temp = temp + M(74, 43) * M(43, 69)
      temp = temp + M(74, 46) * M(46, 69)
      temp = temp + M(74, 47) * M(47, 69)
      temp = temp + M(74, 48) * M(48, 69)
      temp = temp + M(74, 53) * M(53, 69)
      temp = temp + M(74, 54) * M(54, 69)
      temp = temp + M(74, 55) * M(55, 69)
      temp = temp + M(74, 56) * M(56, 69)
      temp = temp + M(74, 57) * M(57, 69)
      temp = temp + M(74, 58) * M(58, 69)
      temp = temp + M(74, 59) * M(59, 69)
      temp = temp + M(74, 60) * M(60, 69)
      temp = temp + M(74, 63) * M(63, 69)
      temp = temp + M(74, 64) * M(64, 69)
      temp = temp + M(74, 66) * M(66, 69)
      M(74, 69) = M(74, 69) - temp
C     Lower part.
      temp = M(75, 27) * M(27, 69)
      temp = temp + M(75, 41) * M(41, 69)
      temp = temp + M(75, 52) * M(52, 69)
      temp = temp + M(75, 57) * M(57, 69)
      temp = temp + M(75, 58) * M(58, 69)
      temp = temp + M(75, 59) * M(59, 69)
      temp = temp + M(75, 61) * M(61, 69)
      temp = temp + M(75, 62) * M(62, 69)
      temp = temp + M(75, 65) * M(65, 69)
      temp = temp + M(75, 66) * M(66, 69)
      temp = temp + M(75, 67) * M(67, 69)
      M(75, 69) = M(75, 69) - temp
C     Lower part.
      temp = M(76, 41) * M(41, 69)
      temp = temp + M(76, 57) * M(57, 69)
      temp = temp + M(76, 58) * M(58, 69)
      temp = temp + M(76, 59) * M(59, 69)
      temp = temp + M(76, 67) * M(67, 69)
      M(76, 69) = M(76, 69) - temp
C     Lower part.
      temp = M(77, 52) * M(52, 69)
      temp = temp + M(77, 57) * M(57, 69)
      temp = temp + M(77, 58) * M(58, 69)
      temp = temp + M(77, 59) * M(59, 69)
      M(77, 69) = M(77, 69) - temp
C     Lower part.
      temp = M(79, 27) * M(27, 69)
      temp = temp + M(79, 35) * M(35, 69)
      temp = temp + M(79, 36) * M(36, 69)
      temp = temp + M(79, 37) * M(37, 69)
      temp = temp + M(79, 38) * M(38, 69)
      temp = temp + M(79, 39) * M(39, 69)
      temp = temp + M(79, 40) * M(40, 69)
      temp = temp + M(79, 41) * M(41, 69)
      temp = temp + M(79, 42) * M(42, 69)
      temp = temp + M(79, 43) * M(43, 69)
      temp = temp + M(79, 46) * M(46, 69)
      temp = temp + M(79, 47) * M(47, 69)
      temp = temp + M(79, 48) * M(48, 69)
      temp = temp + M(79, 52) * M(52, 69)
      temp = temp + M(79, 53) * M(53, 69)
      temp = temp + M(79, 54) * M(54, 69)
      temp = temp + M(79, 55) * M(55, 69)
      temp = temp + M(79, 56) * M(56, 69)
      temp = temp + M(79, 57) * M(57, 69)
      temp = temp + M(79, 58) * M(58, 69)
      temp = temp + M(79, 59) * M(59, 69)
      temp = temp + M(79, 60) * M(60, 69)
      temp = temp + M(79, 61) * M(61, 69)
      temp = temp + M(79, 63) * M(63, 69)
      temp = temp + M(79, 64) * M(64, 69)
      temp = temp + M(79, 65) * M(65, 69)
      temp = temp + M(79, 66) * M(66, 69)
      temp = temp + M(79, 67) * M(67, 69)
      M(79, 69) = M(79, 69) - temp
C     Lower part.
      temp = M(80, 35) * M(35, 69)
      temp = temp + M(80, 36) * M(36, 69)
      temp = temp + M(80, 37) * M(37, 69)
      temp = temp + M(80, 38) * M(38, 69)
      temp = temp + M(80, 39) * M(39, 69)
      temp = temp + M(80, 40) * M(40, 69)
      temp = temp + M(80, 41) * M(41, 69)
      temp = temp + M(80, 42) * M(42, 69)
      temp = temp + M(80, 43) * M(43, 69)
      temp = temp + M(80, 46) * M(46, 69)
      temp = temp + M(80, 47) * M(47, 69)
      temp = temp + M(80, 48) * M(48, 69)
      temp = temp + M(80, 54) * M(54, 69)
      temp = temp + M(80, 55) * M(55, 69)
      temp = temp + M(80, 56) * M(56, 69)
      temp = temp + M(80, 57) * M(57, 69)
      temp = temp + M(80, 58) * M(58, 69)
      temp = temp + M(80, 59) * M(59, 69)
      temp = temp + M(80, 60) * M(60, 69)
      temp = temp + M(80, 63) * M(63, 69)
      temp = temp + M(80, 64) * M(64, 69)
      temp = temp + M(80, 66) * M(66, 69)
      M(80, 69) = M(80, 69) - temp
C     Lower part.
      temp = M(81, 35) * M(35, 69)
      temp = temp + M(81, 36) * M(36, 69)
      temp = temp + M(81, 37) * M(37, 69)
      temp = temp + M(81, 38) * M(38, 69)
      temp = temp + M(81, 39) * M(39, 69)
      temp = temp + M(81, 40) * M(40, 69)
      temp = temp + M(81, 41) * M(41, 69)
      temp = temp + M(81, 42) * M(42, 69)
      temp = temp + M(81, 43) * M(43, 69)
      temp = temp + M(81, 46) * M(46, 69)
      temp = temp + M(81, 47) * M(47, 69)
      temp = temp + M(81, 48) * M(48, 69)
      temp = temp + M(81, 53) * M(53, 69)
      temp = temp + M(81, 54) * M(54, 69)
      temp = temp + M(81, 55) * M(55, 69)
      temp = temp + M(81, 56) * M(56, 69)
      temp = temp + M(81, 57) * M(57, 69)
      temp = temp + M(81, 58) * M(58, 69)
      temp = temp + M(81, 59) * M(59, 69)
      temp = temp + M(81, 60) * M(60, 69)
      temp = temp + M(81, 61) * M(61, 69)
      temp = temp + M(81, 63) * M(63, 69)
      temp = temp + M(81, 64) * M(64, 69)
      temp = temp + M(81, 66) * M(66, 69)
      M(81, 69) = M(81, 69) - temp
C     Lower part.
      temp = M(82, 35) * M(35, 69)
      temp = temp + M(82, 36) * M(36, 69)
      temp = temp + M(82, 37) * M(37, 69)
      temp = temp + M(82, 38) * M(38, 69)
      temp = temp + M(82, 39) * M(39, 69)
      temp = temp + M(82, 40) * M(40, 69)
      temp = temp + M(82, 41) * M(41, 69)
      temp = temp + M(82, 42) * M(42, 69)
      temp = temp + M(82, 43) * M(43, 69)
      temp = temp + M(82, 46) * M(46, 69)
      temp = temp + M(82, 47) * M(47, 69)
      temp = temp + M(82, 48) * M(48, 69)
      temp = temp + M(82, 53) * M(53, 69)
      temp = temp + M(82, 54) * M(54, 69)
      temp = temp + M(82, 55) * M(55, 69)
      temp = temp + M(82, 56) * M(56, 69)
      temp = temp + M(82, 57) * M(57, 69)
      temp = temp + M(82, 58) * M(58, 69)
      temp = temp + M(82, 59) * M(59, 69)
      temp = temp + M(82, 60) * M(60, 69)
      temp = temp + M(82, 62) * M(62, 69)
      temp = temp + M(82, 63) * M(63, 69)
      temp = temp + M(82, 64) * M(64, 69)
      temp = temp + M(82, 66) * M(66, 69)
      temp = temp + M(82, 67) * M(67, 69)
      M(82, 69) = M(82, 69) - temp
C     Upper part.
      temp = M(69, 20) * M(20, 73)
      temp = temp + M(69, 21) * M(21, 73)
      temp = temp + M(69, 22) * M(22, 73)
      temp = temp + M(69, 41) * M(41, 73)
      temp = temp + M(69, 42) * M(42, 73)
      temp = temp + M(69, 43) * M(43, 73)
      temp = temp + M(69, 44) * M(44, 73)
      temp = temp + M(69, 45) * M(45, 73)
      temp = temp + M(69, 46) * M(46, 73)
      temp = temp + M(69, 49) * M(49, 73)
      temp = temp + M(69, 51) * M(51, 73)
      temp = temp + M(69, 53) * M(53, 73)
      temp = temp + M(69, 55) * M(55, 73)
      temp = temp + M(69, 56) * M(56, 73)
      temp = temp + M(69, 57) * M(57, 73)
      temp = temp + M(69, 58) * M(58, 73)
      temp = temp + M(69, 59) * M(59, 73)
      temp = temp + M(69, 60) * M(60, 73)
      temp = temp + M(69, 63) * M(63, 73)
      temp = temp + M(69, 64) * M(64, 73)
      temp = temp + M(69, 66) * M(66, 73)
      temp = temp + M(69, 67) * M(67, 73)
      M(69, 73) = ( M(69, 73) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 20) * M(20, 75)
      temp = temp + M(69, 21) * M(21, 75)
      temp = temp + M(69, 22) * M(22, 75)
      temp = temp + M(69, 27) * M(27, 75)
      temp = temp + M(69, 28) * M(28, 75)
      temp = temp + M(69, 30) * M(30, 75)
      temp = temp + M(69, 31) * M(31, 75)
      temp = temp + M(69, 33) * M(33, 75)
      temp = temp + M(69, 35) * M(35, 75)
      temp = temp + M(69, 36) * M(36, 75)
      temp = temp + M(69, 37) * M(37, 75)
      temp = temp + M(69, 38) * M(38, 75)
      temp = temp + M(69, 39) * M(39, 75)
      temp = temp + M(69, 40) * M(40, 75)
      temp = temp + M(69, 41) * M(41, 75)
      temp = temp + M(69, 42) * M(42, 75)
      temp = temp + M(69, 43) * M(43, 75)
      temp = temp + M(69, 44) * M(44, 75)
      temp = temp + M(69, 45) * M(45, 75)
      temp = temp + M(69, 46) * M(46, 75)
      temp = temp + M(69, 47) * M(47, 75)
      temp = temp + M(69, 48) * M(48, 75)
      temp = temp + M(69, 49) * M(49, 75)
      temp = temp + M(69, 51) * M(51, 75)
      temp = temp + M(69, 53) * M(53, 75)
      temp = temp + M(69, 54) * M(54, 75)
      temp = temp + M(69, 55) * M(55, 75)
      temp = temp + M(69, 56) * M(56, 75)
      temp = temp + M(69, 57) * M(57, 75)
      temp = temp + M(69, 58) * M(58, 75)
      temp = temp + M(69, 59) * M(59, 75)
      temp = temp + M(69, 60) * M(60, 75)
      temp = temp + M(69, 63) * M(63, 75)
      temp = temp + M(69, 64) * M(64, 75)
      temp = temp + M(69, 66) * M(66, 75)
      temp = temp + M(69, 67) * M(67, 75)
      M(69, 75) = ( M(69, 75) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 66) * M(66, 77)
      temp = temp + M(69, 67) * M(67, 77)
      M(69, 77) = ( M(69, 77) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 66) * M(66, 78)
      temp = temp + M(69, 67) * M(67, 78)
      M(69, 78) = ( M(69, 78) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 27) * M(27, 79)
      temp = temp + M(69, 28) * M(28, 79)
      temp = temp + M(69, 35) * M(35, 79)
      temp = temp + M(69, 36) * M(36, 79)
      temp = temp + M(69, 37) * M(37, 79)
      temp = temp + M(69, 38) * M(38, 79)
      temp = temp + M(69, 39) * M(39, 79)
      temp = temp + M(69, 40) * M(40, 79)
      temp = temp + M(69, 41) * M(41, 79)
      temp = temp + M(69, 42) * M(42, 79)
      temp = temp + M(69, 43) * M(43, 79)
      temp = temp + M(69, 44) * M(44, 79)
      temp = temp + M(69, 45) * M(45, 79)
      temp = temp + M(69, 46) * M(46, 79)
      temp = temp + M(69, 47) * M(47, 79)
      temp = temp + M(69, 48) * M(48, 79)
      temp = temp + M(69, 49) * M(49, 79)
      temp = temp + M(69, 51) * M(51, 79)
      temp = temp + M(69, 53) * M(53, 79)
      temp = temp + M(69, 54) * M(54, 79)
      temp = temp + M(69, 55) * M(55, 79)
      temp = temp + M(69, 56) * M(56, 79)
      temp = temp + M(69, 57) * M(57, 79)
      temp = temp + M(69, 58) * M(58, 79)
      temp = temp + M(69, 59) * M(59, 79)
      temp = temp + M(69, 60) * M(60, 79)
      temp = temp + M(69, 63) * M(63, 79)
      temp = temp + M(69, 64) * M(64, 79)
      temp = temp + M(69, 66) * M(66, 79)
      temp = temp + M(69, 67) * M(67, 79)
      M(69, 79) = ( M(69, 79) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 30) * M(30, 80)
      temp = temp + M(69, 33) * M(33, 80)
      temp = temp + M(69, 35) * M(35, 80)
      temp = temp + M(69, 36) * M(36, 80)
      temp = temp + M(69, 37) * M(37, 80)
      temp = temp + M(69, 38) * M(38, 80)
      temp = temp + M(69, 39) * M(39, 80)
      temp = temp + M(69, 40) * M(40, 80)
      temp = temp + M(69, 41) * M(41, 80)
      temp = temp + M(69, 42) * M(42, 80)
      temp = temp + M(69, 43) * M(43, 80)
      temp = temp + M(69, 44) * M(44, 80)
      temp = temp + M(69, 45) * M(45, 80)
      temp = temp + M(69, 46) * M(46, 80)
      temp = temp + M(69, 47) * M(47, 80)
      temp = temp + M(69, 48) * M(48, 80)
      temp = temp + M(69, 49) * M(49, 80)
      temp = temp + M(69, 51) * M(51, 80)
      temp = temp + M(69, 54) * M(54, 80)
      temp = temp + M(69, 55) * M(55, 80)
      temp = temp + M(69, 56) * M(56, 80)
      temp = temp + M(69, 57) * M(57, 80)
      temp = temp + M(69, 58) * M(58, 80)
      temp = temp + M(69, 59) * M(59, 80)
      temp = temp + M(69, 60) * M(60, 80)
      temp = temp + M(69, 63) * M(63, 80)
      temp = temp + M(69, 64) * M(64, 80)
      temp = temp + M(69, 66) * M(66, 80)
      temp = temp + M(69, 67) * M(67, 80)
      M(69, 80) = ( M(69, 80) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 53) * M(53, 81)
      temp = temp + M(69, 58) * M(58, 81)
      temp = temp + M(69, 59) * M(59, 81)
      temp = temp + M(69, 60) * M(60, 81)
      temp = temp + M(69, 63) * M(63, 81)
      temp = temp + M(69, 64) * M(64, 81)
      temp = temp + M(69, 66) * M(66, 81)
      temp = temp + M(69, 67) * M(67, 81)
      M(69, 81) = ( M(69, 81) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 28) * M(28, 82)
      temp = temp + M(69, 35) * M(35, 82)
      temp = temp + M(69, 36) * M(36, 82)
      temp = temp + M(69, 37) * M(37, 82)
      temp = temp + M(69, 38) * M(38, 82)
      temp = temp + M(69, 39) * M(39, 82)
      temp = temp + M(69, 40) * M(40, 82)
      temp = temp + M(69, 41) * M(41, 82)
      temp = temp + M(69, 42) * M(42, 82)
      temp = temp + M(69, 43) * M(43, 82)
      temp = temp + M(69, 46) * M(46, 82)
      temp = temp + M(69, 47) * M(47, 82)
      temp = temp + M(69, 48) * M(48, 82)
      temp = temp + M(69, 53) * M(53, 82)
      temp = temp + M(69, 54) * M(54, 82)
      temp = temp + M(69, 55) * M(55, 82)
      temp = temp + M(69, 56) * M(56, 82)
      temp = temp + M(69, 57) * M(57, 82)
      temp = temp + M(69, 58) * M(58, 82)
      temp = temp + M(69, 59) * M(59, 82)
      temp = temp + M(69, 60) * M(60, 82)
      temp = temp + M(69, 63) * M(63, 82)
      temp = temp + M(69, 64) * M(64, 82)
      temp = temp + M(69, 66) * M(66, 82)
      temp = temp + M(69, 67) * M(67, 82)
      M(69, 82) = ( M(69, 82) - temp ) / M(69, 69)

C     Upper part.
      temp = M(70, 44) * M(44, 73)
      temp = temp + M(70, 49) * M(49, 73)
      temp = temp + M(70, 50) * M(50, 73)
      temp = temp + M(70, 51) * M(51, 73)
      temp = temp + M(70, 57) * M(57, 73)
      temp = temp + M(70, 58) * M(58, 73)
      temp = temp + M(70, 59) * M(59, 73)
      temp = temp + M(70, 64) * M(64, 73)
      temp = temp + M(70, 66) * M(66, 73)
      temp = temp + M(70, 69) * M(69, 73)
      M(70, 73) = ( M(70, 73) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 44) * M(44, 75)
      temp = temp + M(70, 47) * M(47, 75)
      temp = temp + M(70, 48) * M(48, 75)
      temp = temp + M(70, 49) * M(49, 75)
      temp = temp + M(70, 50) * M(50, 75)
      temp = temp + M(70, 51) * M(51, 75)
      temp = temp + M(70, 57) * M(57, 75)
      temp = temp + M(70, 58) * M(58, 75)
      temp = temp + M(70, 59) * M(59, 75)
      temp = temp + M(70, 64) * M(64, 75)
      temp = temp + M(70, 66) * M(66, 75)
      temp = temp + M(70, 69) * M(69, 75)
      M(70, 75) = ( M(70, 75) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 66) * M(66, 77)
      temp = temp + M(70, 69) * M(69, 77)
      M(70, 77) = ( M(70, 77) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 66) * M(66, 78)
      temp = temp + M(70, 69) * M(69, 78)
      M(70, 78) = ( M(70, 78) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 44) * M(44, 79)
      temp = temp + M(70, 47) * M(47, 79)
      temp = temp + M(70, 48) * M(48, 79)
      temp = temp + M(70, 49) * M(49, 79)
      temp = temp + M(70, 50) * M(50, 79)
      temp = temp + M(70, 51) * M(51, 79)
      temp = temp + M(70, 57) * M(57, 79)
      temp = temp + M(70, 58) * M(58, 79)
      temp = temp + M(70, 59) * M(59, 79)
      temp = temp + M(70, 64) * M(64, 79)
      temp = temp + M(70, 66) * M(66, 79)
      temp = temp + M(70, 69) * M(69, 79)
      M(70, 79) = ( M(70, 79) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 44) * M(44, 80)
      temp = temp + M(70, 47) * M(47, 80)
      temp = temp + M(70, 48) * M(48, 80)
      temp = temp + M(70, 49) * M(49, 80)
      temp = temp + M(70, 50) * M(50, 80)
      temp = temp + M(70, 51) * M(51, 80)
      temp = temp + M(70, 57) * M(57, 80)
      temp = temp + M(70, 58) * M(58, 80)
      temp = temp + M(70, 59) * M(59, 80)
      temp = temp + M(70, 64) * M(64, 80)
      temp = temp + M(70, 66) * M(66, 80)
      temp = temp + M(70, 69) * M(69, 80)
      M(70, 80) = ( M(70, 80) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 58) * M(58, 81)
      temp = temp + M(70, 59) * M(59, 81)
      temp = temp + M(70, 64) * M(64, 81)
      temp = temp + M(70, 66) * M(66, 81)
      temp = temp + M(70, 69) * M(69, 81)
      M(70, 81) = ( M(70, 81) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 47) * M(47, 82)
      temp = temp + M(70, 48) * M(48, 82)
      temp = temp + M(70, 57) * M(57, 82)
      temp = temp + M(70, 58) * M(58, 82)
      temp = temp + M(70, 59) * M(59, 82)
      temp = temp + M(70, 64) * M(64, 82)
      temp = temp + M(70, 66) * M(66, 82)
      temp = temp + M(70, 69) * M(69, 82)
      M(70, 82) = ( M(70, 82) - temp ) / M(70, 70)

C     Upper part.
      temp = M(71, 22) * M(22, 73)
      temp = temp + M(71, 41) * M(41, 73)
      temp = temp + M(71, 44) * M(44, 73)
      temp = temp + M(71, 49) * M(49, 73)
      temp = temp + M(71, 51) * M(51, 73)
      temp = temp + M(71, 57) * M(57, 73)
      temp = temp + M(71, 58) * M(58, 73)
      temp = temp + M(71, 59) * M(59, 73)
      temp = temp + M(71, 69) * M(69, 73)
      M(71, 73) = ( M(71, 73) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 22) * M(22, 75)
      temp = temp + M(71, 33) * M(33, 75)
      temp = temp + M(71, 40) * M(40, 75)
      temp = temp + M(71, 41) * M(41, 75)
      temp = temp + M(71, 44) * M(44, 75)
      temp = temp + M(71, 47) * M(47, 75)
      temp = temp + M(71, 49) * M(49, 75)
      temp = temp + M(71, 51) * M(51, 75)
      temp = temp + M(71, 57) * M(57, 75)
      temp = temp + M(71, 58) * M(58, 75)
      temp = temp + M(71, 59) * M(59, 75)
      temp = temp + M(71, 69) * M(69, 75)
      M(71, 75) = ( M(71, 75) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 69) * M(69, 77)
      M(71, 77) = ( M(71, 77) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 69) * M(69, 78)
      M(71, 78) = ( M(71, 78) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 40) * M(40, 79)
      temp = temp + M(71, 41) * M(41, 79)
      temp = temp + M(71, 44) * M(44, 79)
      temp = temp + M(71, 47) * M(47, 79)
      temp = temp + M(71, 49) * M(49, 79)
      temp = temp + M(71, 51) * M(51, 79)
      temp = temp + M(71, 57) * M(57, 79)
      temp = temp + M(71, 58) * M(58, 79)
      temp = temp + M(71, 59) * M(59, 79)
      temp = temp + M(71, 69) * M(69, 79)
      M(71, 79) = ( M(71, 79) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 33) * M(33, 80)
      temp = temp + M(71, 40) * M(40, 80)
      temp = temp + M(71, 41) * M(41, 80)
      temp = temp + M(71, 44) * M(44, 80)
      temp = temp + M(71, 47) * M(47, 80)
      temp = temp + M(71, 49) * M(49, 80)
      temp = temp + M(71, 51) * M(51, 80)
      temp = temp + M(71, 57) * M(57, 80)
      temp = temp + M(71, 58) * M(58, 80)
      temp = temp + M(71, 59) * M(59, 80)
      temp = temp + M(71, 69) * M(69, 80)
      M(71, 80) = ( M(71, 80) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 58) * M(58, 81)
      temp = temp + M(71, 59) * M(59, 81)
      temp = temp + M(71, 69) * M(69, 81)
      M(71, 81) = ( M(71, 81) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 40) * M(40, 82)
      temp = temp + M(71, 41) * M(41, 82)
      temp = temp + M(71, 47) * M(47, 82)
      temp = temp + M(71, 57) * M(57, 82)
      temp = temp + M(71, 58) * M(58, 82)
      temp = temp + M(71, 59) * M(59, 82)
      temp = temp + M(71, 69) * M(69, 82)
      M(71, 82) = ( M(71, 82) - temp ) / M(71, 71)

C     Upper part.
      temp = M(72, 16) * M(16, 73)
      temp = temp + M(72, 52) * M(52, 73)
      temp = temp + M(72, 57) * M(57, 73)
      temp = temp + M(72, 58) * M(58, 73)
      temp = temp + M(72, 59) * M(59, 73)
      temp = temp + M(72, 67) * M(67, 73)
      temp = temp + M(72, 69) * M(69, 73)
      temp = temp + M(72, 70) * M(70, 73)
      temp = temp + M(72, 71) * M(71, 73)
      M(72, 73) = ( M(72, 73) - temp ) / M(72, 72)
C     Upper part.
      M(72, 74) = M(72, 74) / M(72, 72)
C     Upper part.
      temp = M(72, 16) * M(16, 75)
      temp = temp + M(72, 52) * M(52, 75)
      temp = temp + M(72, 57) * M(57, 75)
      temp = temp + M(72, 58) * M(58, 75)
      temp = temp + M(72, 59) * M(59, 75)
      temp = temp + M(72, 67) * M(67, 75)
      temp = temp + M(72, 69) * M(69, 75)
      temp = temp + M(72, 70) * M(70, 75)
      temp = temp + M(72, 71) * M(71, 75)
      M(72, 75) = ( M(72, 75) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 67) * M(67, 77)
      temp = temp + M(72, 69) * M(69, 77)
      temp = temp + M(72, 70) * M(70, 77)
      temp = temp + M(72, 71) * M(71, 77)
      M(72, 77) = ( M(72, 77) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 67) * M(67, 78)
      temp = temp + M(72, 69) * M(69, 78)
      temp = temp + M(72, 70) * M(70, 78)
      temp = temp + M(72, 71) * M(71, 78)
      M(72, 78) = ( M(72, 78) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 52) * M(52, 79)
      temp = temp + M(72, 57) * M(57, 79)
      temp = temp + M(72, 58) * M(58, 79)
      temp = temp + M(72, 59) * M(59, 79)
      temp = temp + M(72, 67) * M(67, 79)
      temp = temp + M(72, 69) * M(69, 79)
      temp = temp + M(72, 70) * M(70, 79)
      temp = temp + M(72, 71) * M(71, 79)
      M(72, 79) = ( M(72, 79) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 52) * M(52, 80)
      temp = temp + M(72, 57) * M(57, 80)
      temp = temp + M(72, 58) * M(58, 80)
      temp = temp + M(72, 59) * M(59, 80)
      temp = temp + M(72, 67) * M(67, 80)
      temp = temp + M(72, 69) * M(69, 80)
      temp = temp + M(72, 70) * M(70, 80)
      temp = temp + M(72, 71) * M(71, 80)
      M(72, 80) = ( M(72, 80) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 58) * M(58, 81)
      temp = temp + M(72, 59) * M(59, 81)
      temp = temp + M(72, 67) * M(67, 81)
      temp = temp + M(72, 69) * M(69, 81)
      temp = temp + M(72, 70) * M(70, 81)
      temp = temp + M(72, 71) * M(71, 81)
      M(72, 81) = ( M(72, 81) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 52) * M(52, 82)
      temp = temp + M(72, 57) * M(57, 82)
      temp = temp + M(72, 58) * M(58, 82)
      temp = temp + M(72, 59) * M(59, 82)
      temp = temp + M(72, 67) * M(67, 82)
      temp = temp + M(72, 69) * M(69, 82)
      temp = temp + M(72, 70) * M(70, 82)
      temp = temp + M(72, 71) * M(71, 82)
      M(72, 82) = ( M(72, 82) - temp ) / M(72, 72)

C     Lower part.
      temp = M(73, 15) * M(15, 73)
      temp = temp + M(73, 16) * M(16, 73)
      temp = temp + M(73, 19) * M(19, 73)
      temp = temp + M(73, 20) * M(20, 73)
      temp = temp + M(73, 21) * M(21, 73)
      temp = temp + M(73, 22) * M(22, 73)
      temp = temp + M(73, 24) * M(24, 73)
      temp = temp + M(73, 25) * M(25, 73)
      temp = temp + M(73, 45) * M(45, 73)
      temp = temp + M(73, 49) * M(49, 73)
      temp = temp + M(73, 50) * M(50, 73)
      temp = temp + M(73, 51) * M(51, 73)
      temp = temp + M(73, 52) * M(52, 73)
      temp = temp + M(73, 55) * M(55, 73)
      temp = temp + M(73, 56) * M(56, 73)
      temp = temp + M(73, 57) * M(57, 73)
      temp = temp + M(73, 58) * M(58, 73)
      temp = temp + M(73, 59) * M(59, 73)
      temp = temp + M(73, 67) * M(67, 73)
      temp = temp + M(73, 69) * M(69, 73)
      temp = temp + M(73, 70) * M(70, 73)
      temp = temp + M(73, 71) * M(71, 73)
      temp = temp + M(73, 72) * M(72, 73)
      M(73, 73) = M(73, 73) - temp
C     Lower part.
      temp = M(74, 19) * M(19, 73)
      temp = temp + M(74, 20) * M(20, 73)
      temp = temp + M(74, 21) * M(21, 73)
      temp = temp + M(74, 22) * M(22, 73)
      temp = temp + M(74, 23) * M(23, 73)
      temp = temp + M(74, 25) * M(25, 73)
      temp = temp + M(74, 41) * M(41, 73)
      temp = temp + M(74, 42) * M(42, 73)
      temp = temp + M(74, 43) * M(43, 73)
      temp = temp + M(74, 44) * M(44, 73)
      temp = temp + M(74, 45) * M(45, 73)
      temp = temp + M(74, 46) * M(46, 73)
      temp = temp + M(74, 49) * M(49, 73)
      temp = temp + M(74, 50) * M(50, 73)
      temp = temp + M(74, 51) * M(51, 73)
      temp = temp + M(74, 53) * M(53, 73)
      temp = temp + M(74, 55) * M(55, 73)
      temp = temp + M(74, 56) * M(56, 73)
      temp = temp + M(74, 57) * M(57, 73)
      temp = temp + M(74, 58) * M(58, 73)
      temp = temp + M(74, 59) * M(59, 73)
      temp = temp + M(74, 60) * M(60, 73)
      temp = temp + M(74, 63) * M(63, 73)
      temp = temp + M(74, 64) * M(64, 73)
      temp = temp + M(74, 66) * M(66, 73)
      temp = temp + M(74, 69) * M(69, 73)
      temp = temp + M(74, 71) * M(71, 73)
      M(74, 73) = M(74, 73) - temp
C     Lower part.
      temp = M(75, 16) * M(16, 73)
      temp = temp + M(75, 19) * M(19, 73)
      temp = temp + M(75, 20) * M(20, 73)
      temp = temp + M(75, 21) * M(21, 73)
      temp = temp + M(75, 22) * M(22, 73)
      temp = temp + M(75, 24) * M(24, 73)
      temp = temp + M(75, 25) * M(25, 73)
      temp = temp + M(75, 29) * M(29, 73)
      temp = temp + M(75, 41) * M(41, 73)
      temp = temp + M(75, 44) * M(44, 73)
      temp = temp + M(75, 45) * M(45, 73)
      temp = temp + M(75, 49) * M(49, 73)
      temp = temp + M(75, 50) * M(50, 73)
      temp = temp + M(75, 51) * M(51, 73)
      temp = temp + M(75, 52) * M(52, 73)
      temp = temp + M(75, 57) * M(57, 73)
      temp = temp + M(75, 58) * M(58, 73)
      temp = temp + M(75, 59) * M(59, 73)
      temp = temp + M(75, 61) * M(61, 73)
      temp = temp + M(75, 62) * M(62, 73)
      temp = temp + M(75, 65) * M(65, 73)
      temp = temp + M(75, 66) * M(66, 73)
      temp = temp + M(75, 67) * M(67, 73)
      temp = temp + M(75, 69) * M(69, 73)
      temp = temp + M(75, 70) * M(70, 73)
      temp = temp + M(75, 71) * M(71, 73)
      temp = temp + M(75, 72) * M(72, 73)
      M(75, 73) = M(75, 73) - temp
C     Lower part.
      temp = M(76, 19) * M(19, 73)
      temp = temp + M(76, 20) * M(20, 73)
      temp = temp + M(76, 21) * M(21, 73)
      temp = temp + M(76, 22) * M(22, 73)
      temp = temp + M(76, 24) * M(24, 73)
      temp = temp + M(76, 25) * M(25, 73)
      temp = temp + M(76, 41) * M(41, 73)
      temp = temp + M(76, 44) * M(44, 73)
      temp = temp + M(76, 45) * M(45, 73)
      temp = temp + M(76, 49) * M(49, 73)
      temp = temp + M(76, 51) * M(51, 73)
      temp = temp + M(76, 57) * M(57, 73)
      temp = temp + M(76, 58) * M(58, 73)
      temp = temp + M(76, 59) * M(59, 73)
      temp = temp + M(76, 67) * M(67, 73)
      temp = temp + M(76, 69) * M(69, 73)
      temp = temp + M(76, 70) * M(70, 73)
      temp = temp + M(76, 71) * M(71, 73)
      M(76, 73) = M(76, 73) - temp
C     Lower part.
      temp = M(77, 16) * M(16, 73)
      temp = temp + M(77, 52) * M(52, 73)
      temp = temp + M(77, 57) * M(57, 73)
      temp = temp + M(77, 58) * M(58, 73)
      temp = temp + M(77, 59) * M(59, 73)
      temp = temp + M(77, 69) * M(69, 73)
      M(77, 73) = M(77, 73) - temp
C     Lower part.
      temp = M(78, 16) * M(16, 73)
      temp = temp + M(78, 69) * M(69, 73)
      M(78, 73) = M(78, 73) - temp
C     Lower part.
      temp = M(79, 16) * M(16, 73)
      temp = temp + M(79, 19) * M(19, 73)
      temp = temp + M(79, 20) * M(20, 73)
      temp = temp + M(79, 21) * M(21, 73)
      temp = temp + M(79, 22) * M(22, 73)
      temp = temp + M(79, 24) * M(24, 73)
      temp = temp + M(79, 25) * M(25, 73)
      temp = temp + M(79, 29) * M(29, 73)
      temp = temp + M(79, 41) * M(41, 73)
      temp = temp + M(79, 42) * M(42, 73)
      temp = temp + M(79, 43) * M(43, 73)
      temp = temp + M(79, 44) * M(44, 73)
      temp = temp + M(79, 45) * M(45, 73)
      temp = temp + M(79, 46) * M(46, 73)
      temp = temp + M(79, 49) * M(49, 73)
      temp = temp + M(79, 51) * M(51, 73)
      temp = temp + M(79, 52) * M(52, 73)
      temp = temp + M(79, 53) * M(53, 73)
      temp = temp + M(79, 55) * M(55, 73)
      temp = temp + M(79, 56) * M(56, 73)
      temp = temp + M(79, 57) * M(57, 73)
      temp = temp + M(79, 58) * M(58, 73)
      temp = temp + M(79, 59) * M(59, 73)
      temp = temp + M(79, 60) * M(60, 73)
      temp = temp + M(79, 61) * M(61, 73)
      temp = temp + M(79, 63) * M(63, 73)
      temp = temp + M(79, 64) * M(64, 73)
      temp = temp + M(79, 65) * M(65, 73)
      temp = temp + M(79, 66) * M(66, 73)
      temp = temp + M(79, 67) * M(67, 73)
      temp = temp + M(79, 69) * M(69, 73)
      temp = temp + M(79, 70) * M(70, 73)
      temp = temp + M(79, 71) * M(71, 73)
      M(79, 73) = M(79, 73) - temp
C     Lower part.
      temp = M(80, 23) * M(23, 73)
      temp = temp + M(80, 32) * M(32, 73)
      temp = temp + M(80, 41) * M(41, 73)
      temp = temp + M(80, 42) * M(42, 73)
      temp = temp + M(80, 43) * M(43, 73)
      temp = temp + M(80, 44) * M(44, 73)
      temp = temp + M(80, 46) * M(46, 73)
      temp = temp + M(80, 49) * M(49, 73)
      temp = temp + M(80, 50) * M(50, 73)
      temp = temp + M(80, 51) * M(51, 73)
      temp = temp + M(80, 55) * M(55, 73)
      temp = temp + M(80, 56) * M(56, 73)
      temp = temp + M(80, 57) * M(57, 73)
      temp = temp + M(80, 58) * M(58, 73)
      temp = temp + M(80, 59) * M(59, 73)
      temp = temp + M(80, 60) * M(60, 73)
      temp = temp + M(80, 63) * M(63, 73)
      temp = temp + M(80, 64) * M(64, 73)
      temp = temp + M(80, 66) * M(66, 73)
      temp = temp + M(80, 69) * M(69, 73)
      M(80, 73) = M(80, 73) - temp
C     Lower part.
      temp = M(81, 15) * M(15, 73)
      temp = temp + M(81, 23) * M(23, 73)
      temp = temp + M(81, 32) * M(32, 73)
      temp = temp + M(81, 41) * M(41, 73)
      temp = temp + M(81, 42) * M(42, 73)
      temp = temp + M(81, 43) * M(43, 73)
      temp = temp + M(81, 44) * M(44, 73)
      temp = temp + M(81, 46) * M(46, 73)
      temp = temp + M(81, 49) * M(49, 73)
      temp = temp + M(81, 50) * M(50, 73)
      temp = temp + M(81, 51) * M(51, 73)
      temp = temp + M(81, 53) * M(53, 73)
      temp = temp + M(81, 55) * M(55, 73)
      temp = temp + M(81, 56) * M(56, 73)
      temp = temp + M(81, 57) * M(57, 73)
      temp = temp + M(81, 58) * M(58, 73)
      temp = temp + M(81, 59) * M(59, 73)
      temp = temp + M(81, 60) * M(60, 73)
      temp = temp + M(81, 61) * M(61, 73)
      temp = temp + M(81, 63) * M(63, 73)
      temp = temp + M(81, 64) * M(64, 73)
      temp = temp + M(81, 66) * M(66, 73)
      temp = temp + M(81, 69) * M(69, 73)
      temp = temp + M(81, 72) * M(72, 73)
      M(81, 73) = M(81, 73) - temp
C     Lower part.
      temp = M(82, 41) * M(41, 73)
      temp = temp + M(82, 42) * M(42, 73)
      temp = temp + M(82, 43) * M(43, 73)
      temp = temp + M(82, 44) * M(44, 73)
      temp = temp + M(82, 46) * M(46, 73)
      temp = temp + M(82, 49) * M(49, 73)
      temp = temp + M(82, 51) * M(51, 73)
      temp = temp + M(82, 53) * M(53, 73)
      temp = temp + M(82, 55) * M(55, 73)
      temp = temp + M(82, 56) * M(56, 73)
      temp = temp + M(82, 57) * M(57, 73)
      temp = temp + M(82, 58) * M(58, 73)
      temp = temp + M(82, 59) * M(59, 73)
      temp = temp + M(82, 60) * M(60, 73)
      temp = temp + M(82, 62) * M(62, 73)
      temp = temp + M(82, 63) * M(63, 73)
      temp = temp + M(82, 64) * M(64, 73)
      temp = temp + M(82, 66) * M(66, 73)
      temp = temp + M(82, 67) * M(67, 73)
      temp = temp + M(82, 69) * M(69, 73)
      temp = temp + M(82, 70) * M(70, 73)
      M(82, 73) = M(82, 73) - temp
C     Upper part.
      temp = M(73, 72) * M(72, 74)
      M(73, 74) = ( M(73, 74) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 16) * M(16, 75)
      temp = temp + M(73, 18) * M(18, 75)
      temp = temp + M(73, 19) * M(19, 75)
      temp = temp + M(73, 20) * M(20, 75)
      temp = temp + M(73, 21) * M(21, 75)
      temp = temp + M(73, 22) * M(22, 75)
      temp = temp + M(73, 24) * M(24, 75)
      temp = temp + M(73, 25) * M(25, 75)
      temp = temp + M(73, 26) * M(26, 75)
      temp = temp + M(73, 45) * M(45, 75)
      temp = temp + M(73, 49) * M(49, 75)
      temp = temp + M(73, 50) * M(50, 75)
      temp = temp + M(73, 51) * M(51, 75)
      temp = temp + M(73, 52) * M(52, 75)
      temp = temp + M(73, 55) * M(55, 75)
      temp = temp + M(73, 56) * M(56, 75)
      temp = temp + M(73, 57) * M(57, 75)
      temp = temp + M(73, 58) * M(58, 75)
      temp = temp + M(73, 59) * M(59, 75)
      temp = temp + M(73, 67) * M(67, 75)
      temp = temp + M(73, 69) * M(69, 75)
      temp = temp + M(73, 70) * M(70, 75)
      temp = temp + M(73, 71) * M(71, 75)
      temp = temp + M(73, 72) * M(72, 75)
      M(73, 75) = ( M(73, 75) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 67) * M(67, 77)
      temp = temp + M(73, 69) * M(69, 77)
      temp = temp + M(73, 70) * M(70, 77)
      temp = temp + M(73, 71) * M(71, 77)
      temp = temp + M(73, 72) * M(72, 77)
      M(73, 77) = ( M(73, 77) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 67) * M(67, 78)
      temp = temp + M(73, 69) * M(69, 78)
      temp = temp + M(73, 70) * M(70, 78)
      temp = temp + M(73, 71) * M(71, 78)
      temp = temp + M(73, 72) * M(72, 78)
      M(73, 78) = ( M(73, 78) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 18) * M(18, 79)
      temp = temp + M(73, 45) * M(45, 79)
      temp = temp + M(73, 49) * M(49, 79)
      temp = temp + M(73, 50) * M(50, 79)
      temp = temp + M(73, 51) * M(51, 79)
      temp = temp + M(73, 52) * M(52, 79)
      temp = temp + M(73, 55) * M(55, 79)
      temp = temp + M(73, 56) * M(56, 79)
      temp = temp + M(73, 57) * M(57, 79)
      temp = temp + M(73, 58) * M(58, 79)
      temp = temp + M(73, 59) * M(59, 79)
      temp = temp + M(73, 67) * M(67, 79)
      temp = temp + M(73, 69) * M(69, 79)
      temp = temp + M(73, 70) * M(70, 79)
      temp = temp + M(73, 71) * M(71, 79)
      temp = temp + M(73, 72) * M(72, 79)
      M(73, 79) = ( M(73, 79) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 45) * M(45, 80)
      temp = temp + M(73, 49) * M(49, 80)
      temp = temp + M(73, 50) * M(50, 80)
      temp = temp + M(73, 51) * M(51, 80)
      temp = temp + M(73, 52) * M(52, 80)
      temp = temp + M(73, 55) * M(55, 80)
      temp = temp + M(73, 56) * M(56, 80)
      temp = temp + M(73, 57) * M(57, 80)
      temp = temp + M(73, 58) * M(58, 80)
      temp = temp + M(73, 59) * M(59, 80)
      temp = temp + M(73, 67) * M(67, 80)
      temp = temp + M(73, 69) * M(69, 80)
      temp = temp + M(73, 70) * M(70, 80)
      temp = temp + M(73, 71) * M(71, 80)
      temp = temp + M(73, 72) * M(72, 80)
      M(73, 80) = ( M(73, 80) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 15) * M(15, 81)
      temp = temp + M(73, 18) * M(18, 81)
      temp = temp + M(73, 26) * M(26, 81)
      temp = temp + M(73, 58) * M(58, 81)
      temp = temp + M(73, 59) * M(59, 81)
      temp = temp + M(73, 67) * M(67, 81)
      temp = temp + M(73, 69) * M(69, 81)
      temp = temp + M(73, 70) * M(70, 81)
      temp = temp + M(73, 71) * M(71, 81)
      temp = temp + M(73, 72) * M(72, 81)
      M(73, 81) = ( M(73, 81) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 26) * M(26, 82)
      temp = temp + M(73, 52) * M(52, 82)
      temp = temp + M(73, 55) * M(55, 82)
      temp = temp + M(73, 56) * M(56, 82)
      temp = temp + M(73, 57) * M(57, 82)
      temp = temp + M(73, 58) * M(58, 82)
      temp = temp + M(73, 59) * M(59, 82)
      temp = temp + M(73, 67) * M(67, 82)
      temp = temp + M(73, 69) * M(69, 82)
      temp = temp + M(73, 70) * M(70, 82)
      temp = temp + M(73, 71) * M(71, 82)
      temp = temp + M(73, 72) * M(72, 82)
      M(73, 82) = ( M(73, 82) - temp ) / M(73, 73)

C     Lower part.
      temp = M(74, 73) * M(73, 74)
      M(74, 74) = M(74, 74) - temp
C     Lower part.
      temp = M(75, 72) * M(72, 74)
      temp = temp + M(75, 73) * M(73, 74)
      M(75, 74) = M(75, 74) - temp
C     Lower part.
      temp = M(76, 73) * M(73, 74)
      M(76, 74) = M(76, 74) - temp
C     Lower part.
      temp = M(77, 73) * M(73, 74)
      M(77, 74) = M(77, 74) - temp
C     Lower part.
      temp = M(78, 73) * M(73, 74)
      M(78, 74) = M(78, 74) - temp
C     Lower part.
      temp = M(79, 73) * M(73, 74)
      M(79, 74) = M(79, 74) - temp
C     Lower part.
      temp = M(80, 73) * M(73, 74)
      M(80, 74) = M(80, 74) - temp
C     Lower part.
      temp = M(81, 72) * M(72, 74)
      temp = temp + M(81, 73) * M(73, 74)
      M(81, 74) = M(81, 74) - temp
C     Lower part.
      temp = M(82, 73) * M(73, 74)
      M(82, 74) = M(82, 74) - temp
C     Upper part.
      temp = M(74, 19) * M(19, 75)
      temp = temp + M(74, 20) * M(20, 75)
      temp = temp + M(74, 21) * M(21, 75)
      temp = temp + M(74, 22) * M(22, 75)
      temp = temp + M(74, 23) * M(23, 75)
      temp = temp + M(74, 25) * M(25, 75)
      temp = temp + M(74, 26) * M(26, 75)
      temp = temp + M(74, 27) * M(27, 75)
      temp = temp + M(74, 30) * M(30, 75)
      temp = temp + M(74, 33) * M(33, 75)
      temp = temp + M(74, 35) * M(35, 75)
      temp = temp + M(74, 36) * M(36, 75)
      temp = temp + M(74, 37) * M(37, 75)
      temp = temp + M(74, 38) * M(38, 75)
      temp = temp + M(74, 39) * M(39, 75)
      temp = temp + M(74, 40) * M(40, 75)
      temp = temp + M(74, 41) * M(41, 75)
      temp = temp + M(74, 42) * M(42, 75)
      temp = temp + M(74, 43) * M(43, 75)
      temp = temp + M(74, 44) * M(44, 75)
      temp = temp + M(74, 45) * M(45, 75)
      temp = temp + M(74, 46) * M(46, 75)
      temp = temp + M(74, 47) * M(47, 75)
      temp = temp + M(74, 48) * M(48, 75)
      temp = temp + M(74, 49) * M(49, 75)
      temp = temp + M(74, 50) * M(50, 75)
      temp = temp + M(74, 51) * M(51, 75)
      temp = temp + M(74, 53) * M(53, 75)
      temp = temp + M(74, 54) * M(54, 75)
      temp = temp + M(74, 55) * M(55, 75)
      temp = temp + M(74, 56) * M(56, 75)
      temp = temp + M(74, 57) * M(57, 75)
      temp = temp + M(74, 58) * M(58, 75)
      temp = temp + M(74, 59) * M(59, 75)
      temp = temp + M(74, 60) * M(60, 75)
      temp = temp + M(74, 63) * M(63, 75)
      temp = temp + M(74, 64) * M(64, 75)
      temp = temp + M(74, 66) * M(66, 75)
      temp = temp + M(74, 69) * M(69, 75)
      temp = temp + M(74, 71) * M(71, 75)
      temp = temp + M(74, 73) * M(73, 75)
      M(74, 75) = ( M(74, 75) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 66) * M(66, 77)
      temp = temp + M(74, 69) * M(69, 77)
      temp = temp + M(74, 71) * M(71, 77)
      temp = temp + M(74, 73) * M(73, 77)
      M(74, 77) = ( M(74, 77) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 66) * M(66, 78)
      temp = temp + M(74, 69) * M(69, 78)
      temp = temp + M(74, 71) * M(71, 78)
      temp = temp + M(74, 73) * M(73, 78)
      M(74, 78) = ( M(74, 78) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 27) * M(27, 79)
      temp = temp + M(74, 35) * M(35, 79)
      temp = temp + M(74, 36) * M(36, 79)
      temp = temp + M(74, 37) * M(37, 79)
      temp = temp + M(74, 38) * M(38, 79)
      temp = temp + M(74, 39) * M(39, 79)
      temp = temp + M(74, 40) * M(40, 79)
      temp = temp + M(74, 41) * M(41, 79)
      temp = temp + M(74, 42) * M(42, 79)
      temp = temp + M(74, 43) * M(43, 79)
      temp = temp + M(74, 44) * M(44, 79)
      temp = temp + M(74, 45) * M(45, 79)
      temp = temp + M(74, 46) * M(46, 79)
      temp = temp + M(74, 47) * M(47, 79)
      temp = temp + M(74, 48) * M(48, 79)
      temp = temp + M(74, 49) * M(49, 79)
      temp = temp + M(74, 50) * M(50, 79)
      temp = temp + M(74, 51) * M(51, 79)
      temp = temp + M(74, 53) * M(53, 79)
      temp = temp + M(74, 54) * M(54, 79)
      temp = temp + M(74, 55) * M(55, 79)
      temp = temp + M(74, 56) * M(56, 79)
      temp = temp + M(74, 57) * M(57, 79)
      temp = temp + M(74, 58) * M(58, 79)
      temp = temp + M(74, 59) * M(59, 79)
      temp = temp + M(74, 60) * M(60, 79)
      temp = temp + M(74, 63) * M(63, 79)
      temp = temp + M(74, 64) * M(64, 79)
      temp = temp + M(74, 66) * M(66, 79)
      temp = temp + M(74, 69) * M(69, 79)
      temp = temp + M(74, 71) * M(71, 79)
      temp = temp + M(74, 73) * M(73, 79)
      M(74, 79) = ( M(74, 79) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 23) * M(23, 80)
      temp = temp + M(74, 30) * M(30, 80)
      temp = temp + M(74, 33) * M(33, 80)
      temp = temp + M(74, 35) * M(35, 80)
      temp = temp + M(74, 36) * M(36, 80)
      temp = temp + M(74, 37) * M(37, 80)
      temp = temp + M(74, 38) * M(38, 80)
      temp = temp + M(74, 39) * M(39, 80)
      temp = temp + M(74, 40) * M(40, 80)
      temp = temp + M(74, 41) * M(41, 80)
      temp = temp + M(74, 42) * M(42, 80)
      temp = temp + M(74, 43) * M(43, 80)
      temp = temp + M(74, 44) * M(44, 80)
      temp = temp + M(74, 45) * M(45, 80)
      temp = temp + M(74, 46) * M(46, 80)
      temp = temp + M(74, 47) * M(47, 80)
      temp = temp + M(74, 48) * M(48, 80)
      temp = temp + M(74, 49) * M(49, 80)
      temp = temp + M(74, 50) * M(50, 80)
      temp = temp + M(74, 51) * M(51, 80)
      temp = temp + M(74, 54) * M(54, 80)
      temp = temp + M(74, 55) * M(55, 80)
      temp = temp + M(74, 56) * M(56, 80)
      temp = temp + M(74, 57) * M(57, 80)
      temp = temp + M(74, 58) * M(58, 80)
      temp = temp + M(74, 59) * M(59, 80)
      temp = temp + M(74, 60) * M(60, 80)
      temp = temp + M(74, 63) * M(63, 80)
      temp = temp + M(74, 64) * M(64, 80)
      temp = temp + M(74, 66) * M(66, 80)
      temp = temp + M(74, 69) * M(69, 80)
      temp = temp + M(74, 71) * M(71, 80)
      temp = temp + M(74, 73) * M(73, 80)
      M(74, 80) = ( M(74, 80) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 26) * M(26, 81)
      temp = temp + M(74, 53) * M(53, 81)
      temp = temp + M(74, 58) * M(58, 81)
      temp = temp + M(74, 59) * M(59, 81)
      temp = temp + M(74, 60) * M(60, 81)
      temp = temp + M(74, 63) * M(63, 81)
      temp = temp + M(74, 64) * M(64, 81)
      temp = temp + M(74, 66) * M(66, 81)
      temp = temp + M(74, 69) * M(69, 81)
      temp = temp + M(74, 71) * M(71, 81)
      temp = temp + M(74, 73) * M(73, 81)
      M(74, 81) = ( M(74, 81) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 26) * M(26, 82)
      temp = temp + M(74, 35) * M(35, 82)
      temp = temp + M(74, 36) * M(36, 82)
      temp = temp + M(74, 37) * M(37, 82)
      temp = temp + M(74, 38) * M(38, 82)
      temp = temp + M(74, 39) * M(39, 82)
      temp = temp + M(74, 40) * M(40, 82)
      temp = temp + M(74, 41) * M(41, 82)
      temp = temp + M(74, 42) * M(42, 82)
      temp = temp + M(74, 43) * M(43, 82)
      temp = temp + M(74, 46) * M(46, 82)
      temp = temp + M(74, 47) * M(47, 82)
      temp = temp + M(74, 48) * M(48, 82)
      temp = temp + M(74, 53) * M(53, 82)
      temp = temp + M(74, 54) * M(54, 82)
      temp = temp + M(74, 55) * M(55, 82)
      temp = temp + M(74, 56) * M(56, 82)
      temp = temp + M(74, 57) * M(57, 82)
      temp = temp + M(74, 58) * M(58, 82)
      temp = temp + M(74, 59) * M(59, 82)
      temp = temp + M(74, 60) * M(60, 82)
      temp = temp + M(74, 63) * M(63, 82)
      temp = temp + M(74, 64) * M(64, 82)
      temp = temp + M(74, 66) * M(66, 82)
      temp = temp + M(74, 69) * M(69, 82)
      temp = temp + M(74, 71) * M(71, 82)
      temp = temp + M(74, 73) * M(73, 82)
      M(74, 82) = ( M(74, 82) - temp ) / M(74, 74)

C     Lower part.
      temp = M(75, 1) * M(1, 75)
      temp = temp + M(75, 4) * M(4, 75)
      temp = temp + M(75, 5) * M(5, 75)
      temp = temp + M(75, 6) * M(6, 75)
      temp = temp + M(75, 7) * M(7, 75)
      temp = temp + M(75, 8) * M(8, 75)
      temp = temp + M(75, 9) * M(9, 75)
      temp = temp + M(75, 10) * M(10, 75)
      temp = temp + M(75, 11) * M(11, 75)
      temp = temp + M(75, 12) * M(12, 75)
      temp = temp + M(75, 13) * M(13, 75)
      temp = temp + M(75, 14) * M(14, 75)
      temp = temp + M(75, 16) * M(16, 75)
      temp = temp + M(75, 18) * M(18, 75)
      temp = temp + M(75, 19) * M(19, 75)
      temp = temp + M(75, 20) * M(20, 75)
      temp = temp + M(75, 21) * M(21, 75)
      temp = temp + M(75, 22) * M(22, 75)
      temp = temp + M(75, 24) * M(24, 75)
      temp = temp + M(75, 25) * M(25, 75)
      temp = temp + M(75, 26) * M(26, 75)
      temp = temp + M(75, 27) * M(27, 75)
      temp = temp + M(75, 28) * M(28, 75)
      temp = temp + M(75, 29) * M(29, 75)
      temp = temp + M(75, 30) * M(30, 75)
      temp = temp + M(75, 31) * M(31, 75)
      temp = temp + M(75, 33) * M(33, 75)
      temp = temp + M(75, 41) * M(41, 75)
      temp = temp + M(75, 44) * M(44, 75)
      temp = temp + M(75, 45) * M(45, 75)
      temp = temp + M(75, 49) * M(49, 75)
      temp = temp + M(75, 50) * M(50, 75)
      temp = temp + M(75, 51) * M(51, 75)
      temp = temp + M(75, 52) * M(52, 75)
      temp = temp + M(75, 57) * M(57, 75)
      temp = temp + M(75, 58) * M(58, 75)
      temp = temp + M(75, 59) * M(59, 75)
      temp = temp + M(75, 61) * M(61, 75)
      temp = temp + M(75, 62) * M(62, 75)
      temp = temp + M(75, 65) * M(65, 75)
      temp = temp + M(75, 66) * M(66, 75)
      temp = temp + M(75, 67) * M(67, 75)
      temp = temp + M(75, 69) * M(69, 75)
      temp = temp + M(75, 70) * M(70, 75)
      temp = temp + M(75, 71) * M(71, 75)
      temp = temp + M(75, 72) * M(72, 75)
      temp = temp + M(75, 73) * M(73, 75)
      temp = temp + M(75, 74) * M(74, 75)
      M(75, 75) = M(75, 75) - temp
C     Lower part.
      temp = M(76, 19) * M(19, 75)
      temp = temp + M(76, 20) * M(20, 75)
      temp = temp + M(76, 21) * M(21, 75)
      temp = temp + M(76, 22) * M(22, 75)
      temp = temp + M(76, 24) * M(24, 75)
      temp = temp + M(76, 25) * M(25, 75)
      temp = temp + M(76, 33) * M(33, 75)
      temp = temp + M(76, 41) * M(41, 75)
      temp = temp + M(76, 44) * M(44, 75)
      temp = temp + M(76, 45) * M(45, 75)
      temp = temp + M(76, 49) * M(49, 75)
      temp = temp + M(76, 51) * M(51, 75)
      temp = temp + M(76, 57) * M(57, 75)
      temp = temp + M(76, 58) * M(58, 75)
      temp = temp + M(76, 59) * M(59, 75)
      temp = temp + M(76, 67) * M(67, 75)
      temp = temp + M(76, 69) * M(69, 75)
      temp = temp + M(76, 70) * M(70, 75)
      temp = temp + M(76, 71) * M(71, 75)
      temp = temp + M(76, 73) * M(73, 75)
      temp = temp + M(76, 74) * M(74, 75)
      M(76, 75) = M(76, 75) - temp
C     Lower part.
      temp = M(77, 16) * M(16, 75)
      temp = temp + M(77, 52) * M(52, 75)
      temp = temp + M(77, 57) * M(57, 75)
      temp = temp + M(77, 58) * M(58, 75)
      temp = temp + M(77, 59) * M(59, 75)
      temp = temp + M(77, 69) * M(69, 75)
      temp = temp + M(77, 73) * M(73, 75)
      temp = temp + M(77, 74) * M(74, 75)
      M(77, 75) = M(77, 75) - temp
C     Lower part.
      temp = M(78, 6) * M(6, 75)
      temp = temp + M(78, 7) * M(7, 75)
      temp = temp + M(78, 8) * M(8, 75)
      temp = temp + M(78, 9) * M(9, 75)
      temp = temp + M(78, 10) * M(10, 75)
      temp = temp + M(78, 16) * M(16, 75)
      temp = temp + M(78, 26) * M(26, 75)
      temp = temp + M(78, 69) * M(69, 75)
      temp = temp + M(78, 73) * M(73, 75)
      temp = temp + M(78, 74) * M(74, 75)
      M(78, 75) = M(78, 75) - temp
C     Lower part.
      temp = M(79, 1) * M(1, 75)
      temp = temp + M(79, 11) * M(11, 75)
      temp = temp + M(79, 12) * M(12, 75)
      temp = temp + M(79, 13) * M(13, 75)
      temp = temp + M(79, 16) * M(16, 75)
      temp = temp + M(79, 18) * M(18, 75)
      temp = temp + M(79, 19) * M(19, 75)
      temp = temp + M(79, 20) * M(20, 75)
      temp = temp + M(79, 21) * M(21, 75)
      temp = temp + M(79, 22) * M(22, 75)
      temp = temp + M(79, 24) * M(24, 75)
      temp = temp + M(79, 25) * M(25, 75)
      temp = temp + M(79, 27) * M(27, 75)
      temp = temp + M(79, 29) * M(29, 75)
      temp = temp + M(79, 30) * M(30, 75)
      temp = temp + M(79, 33) * M(33, 75)
      temp = temp + M(79, 35) * M(35, 75)
      temp = temp + M(79, 36) * M(36, 75)
      temp = temp + M(79, 37) * M(37, 75)
      temp = temp + M(79, 38) * M(38, 75)
      temp = temp + M(79, 39) * M(39, 75)
      temp = temp + M(79, 40) * M(40, 75)
      temp = temp + M(79, 41) * M(41, 75)
      temp = temp + M(79, 42) * M(42, 75)
      temp = temp + M(79, 43) * M(43, 75)
      temp = temp + M(79, 44) * M(44, 75)
      temp = temp + M(79, 45) * M(45, 75)
      temp = temp + M(79, 46) * M(46, 75)
      temp = temp + M(79, 47) * M(47, 75)
      temp = temp + M(79, 48) * M(48, 75)
      temp = temp + M(79, 49) * M(49, 75)
      temp = temp + M(79, 51) * M(51, 75)
      temp = temp + M(79, 52) * M(52, 75)
      temp = temp + M(79, 53) * M(53, 75)
      temp = temp + M(79, 54) * M(54, 75)
      temp = temp + M(79, 55) * M(55, 75)
      temp = temp + M(79, 56) * M(56, 75)
      temp = temp + M(79, 57) * M(57, 75)
      temp = temp + M(79, 58) * M(58, 75)
      temp = temp + M(79, 59) * M(59, 75)
      temp = temp + M(79, 60) * M(60, 75)
      temp = temp + M(79, 61) * M(61, 75)
      temp = temp + M(79, 63) * M(63, 75)
      temp = temp + M(79, 64) * M(64, 75)
      temp = temp + M(79, 65) * M(65, 75)
      temp = temp + M(79, 66) * M(66, 75)
      temp = temp + M(79, 67) * M(67, 75)
      temp = temp + M(79, 69) * M(69, 75)
      temp = temp + M(79, 70) * M(70, 75)
      temp = temp + M(79, 71) * M(71, 75)
      temp = temp + M(79, 73) * M(73, 75)
      temp = temp + M(79, 74) * M(74, 75)
      M(79, 75) = M(79, 75) - temp
C     Lower part.
      temp = M(80, 14) * M(14, 75)
      temp = temp + M(80, 23) * M(23, 75)
      temp = temp + M(80, 32) * M(32, 75)
      temp = temp + M(80, 35) * M(35, 75)
      temp = temp + M(80, 36) * M(36, 75)
      temp = temp + M(80, 37) * M(37, 75)
      temp = temp + M(80, 38) * M(38, 75)
      temp = temp + M(80, 39) * M(39, 75)
      temp = temp + M(80, 40) * M(40, 75)
      temp = temp + M(80, 41) * M(41, 75)
      temp = temp + M(80, 42) * M(42, 75)
      temp = temp + M(80, 43) * M(43, 75)
      temp = temp + M(80, 44) * M(44, 75)
      temp = temp + M(80, 46) * M(46, 75)
      temp = temp + M(80, 47) * M(47, 75)
      temp = temp + M(80, 48) * M(48, 75)
      temp = temp + M(80, 49) * M(49, 75)
      temp = temp + M(80, 50) * M(50, 75)
      temp = temp + M(80, 51) * M(51, 75)
      temp = temp + M(80, 54) * M(54, 75)
      temp = temp + M(80, 55) * M(55, 75)
      temp = temp + M(80, 56) * M(56, 75)
      temp = temp + M(80, 57) * M(57, 75)
      temp = temp + M(80, 58) * M(58, 75)
      temp = temp + M(80, 59) * M(59, 75)
      temp = temp + M(80, 60) * M(60, 75)
      temp = temp + M(80, 63) * M(63, 75)
      temp = temp + M(80, 64) * M(64, 75)
      temp = temp + M(80, 66) * M(66, 75)
      temp = temp + M(80, 69) * M(69, 75)
      temp = temp + M(80, 73) * M(73, 75)
      temp = temp + M(80, 74) * M(74, 75)
      M(80, 75) = M(80, 75) - temp
C     Lower part.
      temp = M(81, 18) * M(18, 75)
      temp = temp + M(81, 23) * M(23, 75)
      temp = temp + M(81, 26) * M(26, 75)
      temp = temp + M(81, 32) * M(32, 75)
      temp = temp + M(81, 35) * M(35, 75)
      temp = temp + M(81, 36) * M(36, 75)
      temp = temp + M(81, 37) * M(37, 75)
      temp = temp + M(81, 38) * M(38, 75)
      temp = temp + M(81, 39) * M(39, 75)
      temp = temp + M(81, 40) * M(40, 75)
      temp = temp + M(81, 41) * M(41, 75)
      temp = temp + M(81, 42) * M(42, 75)
      temp = temp + M(81, 43) * M(43, 75)
      temp = temp + M(81, 44) * M(44, 75)
      temp = temp + M(81, 46) * M(46, 75)
      temp = temp + M(81, 47) * M(47, 75)
      temp = temp + M(81, 48) * M(48, 75)
      temp = temp + M(81, 49) * M(49, 75)
      temp = temp + M(81, 50) * M(50, 75)
      temp = temp + M(81, 51) * M(51, 75)
      temp = temp + M(81, 53) * M(53, 75)
      temp = temp + M(81, 54) * M(54, 75)
      temp = temp + M(81, 55) * M(55, 75)
      temp = temp + M(81, 56) * M(56, 75)
      temp = temp + M(81, 57) * M(57, 75)
      temp = temp + M(81, 58) * M(58, 75)
      temp = temp + M(81, 59) * M(59, 75)
      temp = temp + M(81, 60) * M(60, 75)
      temp = temp + M(81, 61) * M(61, 75)
      temp = temp + M(81, 63) * M(63, 75)
      temp = temp + M(81, 64) * M(64, 75)
      temp = temp + M(81, 66) * M(66, 75)
      temp = temp + M(81, 69) * M(69, 75)
      temp = temp + M(81, 72) * M(72, 75)
      temp = temp + M(81, 73) * M(73, 75)
      temp = temp + M(81, 74) * M(74, 75)
      M(81, 75) = M(81, 75) - temp
C     Lower part.
      temp = M(82, 26) * M(26, 75)
      temp = temp + M(82, 28) * M(28, 75)
      temp = temp + M(82, 30) * M(30, 75)
      temp = temp + M(82, 35) * M(35, 75)
      temp = temp + M(82, 36) * M(36, 75)
      temp = temp + M(82, 37) * M(37, 75)
      temp = temp + M(82, 38) * M(38, 75)
      temp = temp + M(82, 39) * M(39, 75)
      temp = temp + M(82, 40) * M(40, 75)
      temp = temp + M(82, 41) * M(41, 75)
      temp = temp + M(82, 42) * M(42, 75)
      temp = temp + M(82, 43) * M(43, 75)
      temp = temp + M(82, 44) * M(44, 75)
      temp = temp + M(82, 46) * M(46, 75)
      temp = temp + M(82, 47) * M(47, 75)
      temp = temp + M(82, 48) * M(48, 75)
      temp = temp + M(82, 49) * M(49, 75)
      temp = temp + M(82, 51) * M(51, 75)
      temp = temp + M(82, 53) * M(53, 75)
      temp = temp + M(82, 54) * M(54, 75)
      temp = temp + M(82, 55) * M(55, 75)
      temp = temp + M(82, 56) * M(56, 75)
      temp = temp + M(82, 57) * M(57, 75)
      temp = temp + M(82, 58) * M(58, 75)
      temp = temp + M(82, 59) * M(59, 75)
      temp = temp + M(82, 60) * M(60, 75)
      temp = temp + M(82, 62) * M(62, 75)
      temp = temp + M(82, 63) * M(63, 75)
      temp = temp + M(82, 64) * M(64, 75)
      temp = temp + M(82, 66) * M(66, 75)
      temp = temp + M(82, 67) * M(67, 75)
      temp = temp + M(82, 69) * M(69, 75)
      temp = temp + M(82, 70) * M(70, 75)
      temp = temp + M(82, 73) * M(73, 75)
      temp = temp + M(82, 74) * M(74, 75)
      M(82, 75) = M(82, 75) - temp
C     Upper part.
      M(75, 76) = M(75, 76) / M(75, 75)
C     Upper part.
      temp = M(75, 65) * M(65, 77)
      temp = temp + M(75, 66) * M(66, 77)
      temp = temp + M(75, 67) * M(67, 77)
      temp = temp + M(75, 69) * M(69, 77)
      temp = temp + M(75, 70) * M(70, 77)
      temp = temp + M(75, 71) * M(71, 77)
      temp = temp + M(75, 72) * M(72, 77)
      temp = temp + M(75, 73) * M(73, 77)
      temp = temp + M(75, 74) * M(74, 77)
      M(75, 77) = ( M(75, 77) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 65) * M(65, 78)
      temp = temp + M(75, 66) * M(66, 78)
      temp = temp + M(75, 67) * M(67, 78)
      temp = temp + M(75, 69) * M(69, 78)
      temp = temp + M(75, 70) * M(70, 78)
      temp = temp + M(75, 71) * M(71, 78)
      temp = temp + M(75, 72) * M(72, 78)
      temp = temp + M(75, 73) * M(73, 78)
      temp = temp + M(75, 74) * M(74, 78)
      M(75, 78) = ( M(75, 78) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 18) * M(18, 79)
      temp = temp + M(75, 27) * M(27, 79)
      temp = temp + M(75, 28) * M(28, 79)
      temp = temp + M(75, 29) * M(29, 79)
      temp = temp + M(75, 41) * M(41, 79)
      temp = temp + M(75, 44) * M(44, 79)
      temp = temp + M(75, 45) * M(45, 79)
      temp = temp + M(75, 49) * M(49, 79)
      temp = temp + M(75, 50) * M(50, 79)
      temp = temp + M(75, 51) * M(51, 79)
      temp = temp + M(75, 52) * M(52, 79)
      temp = temp + M(75, 57) * M(57, 79)
      temp = temp + M(75, 58) * M(58, 79)
      temp = temp + M(75, 59) * M(59, 79)
      temp = temp + M(75, 61) * M(61, 79)
      temp = temp + M(75, 62) * M(62, 79)
      temp = temp + M(75, 65) * M(65, 79)
      temp = temp + M(75, 66) * M(66, 79)
      temp = temp + M(75, 67) * M(67, 79)
      temp = temp + M(75, 69) * M(69, 79)
      temp = temp + M(75, 70) * M(70, 79)
      temp = temp + M(75, 71) * M(71, 79)
      temp = temp + M(75, 72) * M(72, 79)
      temp = temp + M(75, 73) * M(73, 79)
      temp = temp + M(75, 74) * M(74, 79)
      M(75, 79) = ( M(75, 79) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 14) * M(14, 80)
      temp = temp + M(75, 30) * M(30, 80)
      temp = temp + M(75, 33) * M(33, 80)
      temp = temp + M(75, 41) * M(41, 80)
      temp = temp + M(75, 44) * M(44, 80)
      temp = temp + M(75, 45) * M(45, 80)
      temp = temp + M(75, 49) * M(49, 80)
      temp = temp + M(75, 50) * M(50, 80)
      temp = temp + M(75, 51) * M(51, 80)
      temp = temp + M(75, 52) * M(52, 80)
      temp = temp + M(75, 57) * M(57, 80)
      temp = temp + M(75, 58) * M(58, 80)
      temp = temp + M(75, 59) * M(59, 80)
      temp = temp + M(75, 61) * M(61, 80)
      temp = temp + M(75, 62) * M(62, 80)
      temp = temp + M(75, 65) * M(65, 80)
      temp = temp + M(75, 66) * M(66, 80)
      temp = temp + M(75, 67) * M(67, 80)
      temp = temp + M(75, 69) * M(69, 80)
      temp = temp + M(75, 70) * M(70, 80)
      temp = temp + M(75, 71) * M(71, 80)
      temp = temp + M(75, 72) * M(72, 80)
      temp = temp + M(75, 73) * M(73, 80)
      temp = temp + M(75, 74) * M(74, 80)
      M(75, 80) = ( M(75, 80) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 18) * M(18, 81)
      temp = temp + M(75, 26) * M(26, 81)
      temp = temp + M(75, 58) * M(58, 81)
      temp = temp + M(75, 59) * M(59, 81)
      temp = temp + M(75, 61) * M(61, 81)
      temp = temp + M(75, 62) * M(62, 81)
      temp = temp + M(75, 65) * M(65, 81)
      temp = temp + M(75, 66) * M(66, 81)
      temp = temp + M(75, 67) * M(67, 81)
      temp = temp + M(75, 69) * M(69, 81)
      temp = temp + M(75, 70) * M(70, 81)
      temp = temp + M(75, 71) * M(71, 81)
      temp = temp + M(75, 72) * M(72, 81)
      temp = temp + M(75, 73) * M(73, 81)
      temp = temp + M(75, 74) * M(74, 81)
      M(75, 81) = ( M(75, 81) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 26) * M(26, 82)
      temp = temp + M(75, 28) * M(28, 82)
      temp = temp + M(75, 41) * M(41, 82)
      temp = temp + M(75, 52) * M(52, 82)
      temp = temp + M(75, 57) * M(57, 82)
      temp = temp + M(75, 58) * M(58, 82)
      temp = temp + M(75, 59) * M(59, 82)
      temp = temp + M(75, 61) * M(61, 82)
      temp = temp + M(75, 62) * M(62, 82)
      temp = temp + M(75, 65) * M(65, 82)
      temp = temp + M(75, 66) * M(66, 82)
      temp = temp + M(75, 67) * M(67, 82)
      temp = temp + M(75, 69) * M(69, 82)
      temp = temp + M(75, 70) * M(70, 82)
      temp = temp + M(75, 71) * M(71, 82)
      temp = temp + M(75, 72) * M(72, 82)
      temp = temp + M(75, 73) * M(73, 82)
      temp = temp + M(75, 74) * M(74, 82)
      M(75, 82) = ( M(75, 82) - temp ) / M(75, 75)

C     Lower part.
      temp = M(76, 75) * M(75, 76)
      M(76, 76) = M(76, 76) - temp
C     Lower part.
      temp = M(77, 75) * M(75, 76)
      M(77, 76) = M(77, 76) - temp
C     Lower part.
      temp = M(78, 75) * M(75, 76)
      M(78, 76) = M(78, 76) - temp
C     Lower part.
      temp = M(79, 75) * M(75, 76)
      M(79, 76) = M(79, 76) - temp
C     Lower part.
      temp = M(80, 75) * M(75, 76)
      M(80, 76) = M(80, 76) - temp
C     Lower part.
      temp = M(81, 75) * M(75, 76)
      M(81, 76) = M(81, 76) - temp
C     Lower part.
      temp = M(82, 75) * M(75, 76)
      M(82, 76) = M(82, 76) - temp
C     Upper part.
      temp = M(76, 67) * M(67, 77)
      temp = temp + M(76, 69) * M(69, 77)
      temp = temp + M(76, 70) * M(70, 77)
      temp = temp + M(76, 71) * M(71, 77)
      temp = temp + M(76, 73) * M(73, 77)
      temp = temp + M(76, 74) * M(74, 77)
      temp = temp + M(76, 75) * M(75, 77)
      M(76, 77) = ( M(76, 77) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 67) * M(67, 78)
      temp = temp + M(76, 69) * M(69, 78)
      temp = temp + M(76, 70) * M(70, 78)
      temp = temp + M(76, 71) * M(71, 78)
      temp = temp + M(76, 73) * M(73, 78)
      temp = temp + M(76, 74) * M(74, 78)
      temp = temp + M(76, 75) * M(75, 78)
      M(76, 78) = ( M(76, 78) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 41) * M(41, 79)
      temp = temp + M(76, 44) * M(44, 79)
      temp = temp + M(76, 45) * M(45, 79)
      temp = temp + M(76, 49) * M(49, 79)
      temp = temp + M(76, 51) * M(51, 79)
      temp = temp + M(76, 57) * M(57, 79)
      temp = temp + M(76, 58) * M(58, 79)
      temp = temp + M(76, 59) * M(59, 79)
      temp = temp + M(76, 67) * M(67, 79)
      temp = temp + M(76, 69) * M(69, 79)
      temp = temp + M(76, 70) * M(70, 79)
      temp = temp + M(76, 71) * M(71, 79)
      temp = temp + M(76, 73) * M(73, 79)
      temp = temp + M(76, 74) * M(74, 79)
      temp = temp + M(76, 75) * M(75, 79)
      M(76, 79) = ( M(76, 79) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 33) * M(33, 80)
      temp = temp + M(76, 41) * M(41, 80)
      temp = temp + M(76, 44) * M(44, 80)
      temp = temp + M(76, 45) * M(45, 80)
      temp = temp + M(76, 49) * M(49, 80)
      temp = temp + M(76, 51) * M(51, 80)
      temp = temp + M(76, 57) * M(57, 80)
      temp = temp + M(76, 58) * M(58, 80)
      temp = temp + M(76, 59) * M(59, 80)
      temp = temp + M(76, 67) * M(67, 80)
      temp = temp + M(76, 69) * M(69, 80)
      temp = temp + M(76, 70) * M(70, 80)
      temp = temp + M(76, 71) * M(71, 80)
      temp = temp + M(76, 73) * M(73, 80)
      temp = temp + M(76, 74) * M(74, 80)
      temp = temp + M(76, 75) * M(75, 80)
      M(76, 80) = ( M(76, 80) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 58) * M(58, 81)
      temp = temp + M(76, 59) * M(59, 81)
      temp = temp + M(76, 67) * M(67, 81)
      temp = temp + M(76, 69) * M(69, 81)
      temp = temp + M(76, 70) * M(70, 81)
      temp = temp + M(76, 71) * M(71, 81)
      temp = temp + M(76, 73) * M(73, 81)
      temp = temp + M(76, 74) * M(74, 81)
      temp = temp + M(76, 75) * M(75, 81)
      M(76, 81) = ( M(76, 81) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 41) * M(41, 82)
      temp = temp + M(76, 57) * M(57, 82)
      temp = temp + M(76, 58) * M(58, 82)
      temp = temp + M(76, 59) * M(59, 82)
      temp = temp + M(76, 67) * M(67, 82)
      temp = temp + M(76, 69) * M(69, 82)
      temp = temp + M(76, 70) * M(70, 82)
      temp = temp + M(76, 71) * M(71, 82)
      temp = temp + M(76, 73) * M(73, 82)
      temp = temp + M(76, 74) * M(74, 82)
      temp = temp + M(76, 75) * M(75, 82)
      M(76, 82) = ( M(76, 82) - temp ) / M(76, 76)

C     Lower part.
      temp = M(77, 17) * M(17, 77)
      temp = temp + M(77, 69) * M(69, 77)
      temp = temp + M(77, 73) * M(73, 77)
      temp = temp + M(77, 74) * M(74, 77)
      temp = temp + M(77, 75) * M(75, 77)
      temp = temp + M(77, 76) * M(76, 77)
      M(77, 77) = M(77, 77) - temp
C     Lower part.
      temp = M(78, 69) * M(69, 77)
      temp = temp + M(78, 73) * M(73, 77)
      temp = temp + M(78, 74) * M(74, 77)
      temp = temp + M(78, 75) * M(75, 77)
      temp = temp + M(78, 76) * M(76, 77)
      M(78, 77) = M(78, 77) - temp
C     Lower part.
      temp = M(79, 65) * M(65, 77)
      temp = temp + M(79, 66) * M(66, 77)
      temp = temp + M(79, 67) * M(67, 77)
      temp = temp + M(79, 69) * M(69, 77)
      temp = temp + M(79, 70) * M(70, 77)
      temp = temp + M(79, 71) * M(71, 77)
      temp = temp + M(79, 73) * M(73, 77)
      temp = temp + M(79, 74) * M(74, 77)
      temp = temp + M(79, 75) * M(75, 77)
      temp = temp + M(79, 76) * M(76, 77)
      M(79, 77) = M(79, 77) - temp
C     Lower part.
      temp = M(80, 66) * M(66, 77)
      temp = temp + M(80, 69) * M(69, 77)
      temp = temp + M(80, 73) * M(73, 77)
      temp = temp + M(80, 74) * M(74, 77)
      temp = temp + M(80, 75) * M(75, 77)
      temp = temp + M(80, 76) * M(76, 77)
      M(80, 77) = M(80, 77) - temp
C     Lower part.
      temp = M(81, 17) * M(17, 77)
      temp = temp + M(81, 66) * M(66, 77)
      temp = temp + M(81, 69) * M(69, 77)
      temp = temp + M(81, 72) * M(72, 77)
      temp = temp + M(81, 73) * M(73, 77)
      temp = temp + M(81, 74) * M(74, 77)
      temp = temp + M(81, 75) * M(75, 77)
      temp = temp + M(81, 76) * M(76, 77)
      M(81, 77) = M(81, 77) - temp
C     Lower part.
      temp = M(82, 66) * M(66, 77)
      temp = temp + M(82, 67) * M(67, 77)
      temp = temp + M(82, 69) * M(69, 77)
      temp = temp + M(82, 70) * M(70, 77)
      temp = temp + M(82, 73) * M(73, 77)
      temp = temp + M(82, 74) * M(74, 77)
      temp = temp + M(82, 75) * M(75, 77)
      temp = temp + M(82, 76) * M(76, 77)
      M(82, 77) = M(82, 77) - temp
C     Upper part.
      temp = M(77, 69) * M(69, 78)
      temp = temp + M(77, 73) * M(73, 78)
      temp = temp + M(77, 74) * M(74, 78)
      temp = temp + M(77, 75) * M(75, 78)
      temp = temp + M(77, 76) * M(76, 78)
      M(77, 78) = ( M(77, 78) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 52) * M(52, 79)
      temp = temp + M(77, 57) * M(57, 79)
      temp = temp + M(77, 58) * M(58, 79)
      temp = temp + M(77, 59) * M(59, 79)
      temp = temp + M(77, 69) * M(69, 79)
      temp = temp + M(77, 73) * M(73, 79)
      temp = temp + M(77, 74) * M(74, 79)
      temp = temp + M(77, 75) * M(75, 79)
      temp = temp + M(77, 76) * M(76, 79)
      M(77, 79) = ( M(77, 79) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 52) * M(52, 80)
      temp = temp + M(77, 57) * M(57, 80)
      temp = temp + M(77, 58) * M(58, 80)
      temp = temp + M(77, 59) * M(59, 80)
      temp = temp + M(77, 69) * M(69, 80)
      temp = temp + M(77, 73) * M(73, 80)
      temp = temp + M(77, 74) * M(74, 80)
      temp = temp + M(77, 75) * M(75, 80)
      temp = temp + M(77, 76) * M(76, 80)
      M(77, 80) = ( M(77, 80) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 17) * M(17, 81)
      temp = temp + M(77, 58) * M(58, 81)
      temp = temp + M(77, 59) * M(59, 81)
      temp = temp + M(77, 69) * M(69, 81)
      temp = temp + M(77, 73) * M(73, 81)
      temp = temp + M(77, 74) * M(74, 81)
      temp = temp + M(77, 75) * M(75, 81)
      temp = temp + M(77, 76) * M(76, 81)
      M(77, 81) = ( M(77, 81) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 52) * M(52, 82)
      temp = temp + M(77, 57) * M(57, 82)
      temp = temp + M(77, 58) * M(58, 82)
      temp = temp + M(77, 59) * M(59, 82)
      temp = temp + M(77, 69) * M(69, 82)
      temp = temp + M(77, 73) * M(73, 82)
      temp = temp + M(77, 74) * M(74, 82)
      temp = temp + M(77, 75) * M(75, 82)
      temp = temp + M(77, 76) * M(76, 82)
      M(77, 82) = ( M(77, 82) - temp ) / M(77, 77)

C     Lower part.
      temp = M(78, 69) * M(69, 78)
      temp = temp + M(78, 73) * M(73, 78)
      temp = temp + M(78, 74) * M(74, 78)
      temp = temp + M(78, 75) * M(75, 78)
      temp = temp + M(78, 76) * M(76, 78)
      temp = temp + M(78, 77) * M(77, 78)
      M(78, 78) = M(78, 78) - temp
C     Lower part.
      temp = M(79, 65) * M(65, 78)
      temp = temp + M(79, 66) * M(66, 78)
      temp = temp + M(79, 67) * M(67, 78)
      temp = temp + M(79, 69) * M(69, 78)
      temp = temp + M(79, 70) * M(70, 78)
      temp = temp + M(79, 71) * M(71, 78)
      temp = temp + M(79, 73) * M(73, 78)
      temp = temp + M(79, 74) * M(74, 78)
      temp = temp + M(79, 75) * M(75, 78)
      temp = temp + M(79, 76) * M(76, 78)
      temp = temp + M(79, 77) * M(77, 78)
      M(79, 78) = M(79, 78) - temp
C     Lower part.
      temp = M(80, 66) * M(66, 78)
      temp = temp + M(80, 69) * M(69, 78)
      temp = temp + M(80, 73) * M(73, 78)
      temp = temp + M(80, 74) * M(74, 78)
      temp = temp + M(80, 75) * M(75, 78)
      temp = temp + M(80, 76) * M(76, 78)
      temp = temp + M(80, 77) * M(77, 78)
      M(80, 78) = M(80, 78) - temp
C     Lower part.
      temp = M(81, 66) * M(66, 78)
      temp = temp + M(81, 69) * M(69, 78)
      temp = temp + M(81, 72) * M(72, 78)
      temp = temp + M(81, 73) * M(73, 78)
      temp = temp + M(81, 74) * M(74, 78)
      temp = temp + M(81, 75) * M(75, 78)
      temp = temp + M(81, 76) * M(76, 78)
      temp = temp + M(81, 77) * M(77, 78)
      M(81, 78) = M(81, 78) - temp
C     Lower part.
      temp = M(82, 66) * M(66, 78)
      temp = temp + M(82, 67) * M(67, 78)
      temp = temp + M(82, 69) * M(69, 78)
      temp = temp + M(82, 70) * M(70, 78)
      temp = temp + M(82, 73) * M(73, 78)
      temp = temp + M(82, 74) * M(74, 78)
      temp = temp + M(82, 75) * M(75, 78)
      temp = temp + M(82, 76) * M(76, 78)
      temp = temp + M(82, 77) * M(77, 78)
      M(82, 78) = M(82, 78) - temp
C     Upper part.
      temp = M(78, 69) * M(69, 79)
      temp = temp + M(78, 73) * M(73, 79)
      temp = temp + M(78, 74) * M(74, 79)
      temp = temp + M(78, 75) * M(75, 79)
      temp = temp + M(78, 76) * M(76, 79)
      temp = temp + M(78, 77) * M(77, 79)
      M(78, 79) = ( M(78, 79) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 69) * M(69, 80)
      temp = temp + M(78, 73) * M(73, 80)
      temp = temp + M(78, 74) * M(74, 80)
      temp = temp + M(78, 75) * M(75, 80)
      temp = temp + M(78, 76) * M(76, 80)
      temp = temp + M(78, 77) * M(77, 80)
      M(78, 80) = ( M(78, 80) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 26) * M(26, 81)
      temp = temp + M(78, 69) * M(69, 81)
      temp = temp + M(78, 73) * M(73, 81)
      temp = temp + M(78, 74) * M(74, 81)
      temp = temp + M(78, 75) * M(75, 81)
      temp = temp + M(78, 76) * M(76, 81)
      temp = temp + M(78, 77) * M(77, 81)
      M(78, 81) = ( M(78, 81) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 26) * M(26, 82)
      temp = temp + M(78, 69) * M(69, 82)
      temp = temp + M(78, 73) * M(73, 82)
      temp = temp + M(78, 74) * M(74, 82)
      temp = temp + M(78, 75) * M(75, 82)
      temp = temp + M(78, 76) * M(76, 82)
      temp = temp + M(78, 77) * M(77, 82)
      M(78, 82) = ( M(78, 82) - temp ) / M(78, 78)

C     Lower part.
      temp = M(79, 18) * M(18, 79)
      temp = temp + M(79, 27) * M(27, 79)
      temp = temp + M(79, 29) * M(29, 79)
      temp = temp + M(79, 35) * M(35, 79)
      temp = temp + M(79, 36) * M(36, 79)
      temp = temp + M(79, 37) * M(37, 79)
      temp = temp + M(79, 38) * M(38, 79)
      temp = temp + M(79, 39) * M(39, 79)
      temp = temp + M(79, 40) * M(40, 79)
      temp = temp + M(79, 41) * M(41, 79)
      temp = temp + M(79, 42) * M(42, 79)
      temp = temp + M(79, 43) * M(43, 79)
      temp = temp + M(79, 44) * M(44, 79)
      temp = temp + M(79, 45) * M(45, 79)
      temp = temp + M(79, 46) * M(46, 79)
      temp = temp + M(79, 47) * M(47, 79)
      temp = temp + M(79, 48) * M(48, 79)
      temp = temp + M(79, 49) * M(49, 79)
      temp = temp + M(79, 51) * M(51, 79)
      temp = temp + M(79, 52) * M(52, 79)
      temp = temp + M(79, 53) * M(53, 79)
      temp = temp + M(79, 54) * M(54, 79)
      temp = temp + M(79, 55) * M(55, 79)
      temp = temp + M(79, 56) * M(56, 79)
      temp = temp + M(79, 57) * M(57, 79)
      temp = temp + M(79, 58) * M(58, 79)
      temp = temp + M(79, 59) * M(59, 79)
      temp = temp + M(79, 60) * M(60, 79)
      temp = temp + M(79, 61) * M(61, 79)
      temp = temp + M(79, 63) * M(63, 79)
      temp = temp + M(79, 64) * M(64, 79)
      temp = temp + M(79, 65) * M(65, 79)
      temp = temp + M(79, 66) * M(66, 79)
      temp = temp + M(79, 67) * M(67, 79)
      temp = temp + M(79, 69) * M(69, 79)
      temp = temp + M(79, 70) * M(70, 79)
      temp = temp + M(79, 71) * M(71, 79)
      temp = temp + M(79, 73) * M(73, 79)
      temp = temp + M(79, 74) * M(74, 79)
      temp = temp + M(79, 75) * M(75, 79)
      temp = temp + M(79, 76) * M(76, 79)
      temp = temp + M(79, 77) * M(77, 79)
      temp = temp + M(79, 78) * M(78, 79)
      M(79, 79) = M(79, 79) - temp
C     Lower part.
      temp = M(80, 35) * M(35, 79)
      temp = temp + M(80, 36) * M(36, 79)
      temp = temp + M(80, 37) * M(37, 79)
      temp = temp + M(80, 38) * M(38, 79)
      temp = temp + M(80, 39) * M(39, 79)
      temp = temp + M(80, 40) * M(40, 79)
      temp = temp + M(80, 41) * M(41, 79)
      temp = temp + M(80, 42) * M(42, 79)
      temp = temp + M(80, 43) * M(43, 79)
      temp = temp + M(80, 44) * M(44, 79)
      temp = temp + M(80, 46) * M(46, 79)
      temp = temp + M(80, 47) * M(47, 79)
      temp = temp + M(80, 48) * M(48, 79)
      temp = temp + M(80, 49) * M(49, 79)
      temp = temp + M(80, 50) * M(50, 79)
      temp = temp + M(80, 51) * M(51, 79)
      temp = temp + M(80, 54) * M(54, 79)
      temp = temp + M(80, 55) * M(55, 79)
      temp = temp + M(80, 56) * M(56, 79)
      temp = temp + M(80, 57) * M(57, 79)
      temp = temp + M(80, 58) * M(58, 79)
      temp = temp + M(80, 59) * M(59, 79)
      temp = temp + M(80, 60) * M(60, 79)
      temp = temp + M(80, 63) * M(63, 79)
      temp = temp + M(80, 64) * M(64, 79)
      temp = temp + M(80, 66) * M(66, 79)
      temp = temp + M(80, 69) * M(69, 79)
      temp = temp + M(80, 73) * M(73, 79)
      temp = temp + M(80, 74) * M(74, 79)
      temp = temp + M(80, 75) * M(75, 79)
      temp = temp + M(80, 76) * M(76, 79)
      temp = temp + M(80, 77) * M(77, 79)
      temp = temp + M(80, 78) * M(78, 79)
      M(80, 79) = M(80, 79) - temp
C     Lower part.
      temp = M(81, 18) * M(18, 79)
      temp = temp + M(81, 35) * M(35, 79)
      temp = temp + M(81, 36) * M(36, 79)
      temp = temp + M(81, 37) * M(37, 79)
      temp = temp + M(81, 38) * M(38, 79)
      temp = temp + M(81, 39) * M(39, 79)
      temp = temp + M(81, 40) * M(40, 79)
      temp = temp + M(81, 41) * M(41, 79)
      temp = temp + M(81, 42) * M(42, 79)
      temp = temp + M(81, 43) * M(43, 79)
      temp = temp + M(81, 44) * M(44, 79)
      temp = temp + M(81, 46) * M(46, 79)
      temp = temp + M(81, 47) * M(47, 79)
      temp = temp + M(81, 48) * M(48, 79)
      temp = temp + M(81, 49) * M(49, 79)
      temp = temp + M(81, 50) * M(50, 79)
      temp = temp + M(81, 51) * M(51, 79)
      temp = temp + M(81, 53) * M(53, 79)
      temp = temp + M(81, 54) * M(54, 79)
      temp = temp + M(81, 55) * M(55, 79)
      temp = temp + M(81, 56) * M(56, 79)
      temp = temp + M(81, 57) * M(57, 79)
      temp = temp + M(81, 58) * M(58, 79)
      temp = temp + M(81, 59) * M(59, 79)
      temp = temp + M(81, 60) * M(60, 79)
      temp = temp + M(81, 61) * M(61, 79)
      temp = temp + M(81, 63) * M(63, 79)
      temp = temp + M(81, 64) * M(64, 79)
      temp = temp + M(81, 66) * M(66, 79)
      temp = temp + M(81, 69) * M(69, 79)
      temp = temp + M(81, 72) * M(72, 79)
      temp = temp + M(81, 73) * M(73, 79)
      temp = temp + M(81, 74) * M(74, 79)
      temp = temp + M(81, 75) * M(75, 79)
      temp = temp + M(81, 76) * M(76, 79)
      temp = temp + M(81, 77) * M(77, 79)
      temp = temp + M(81, 78) * M(78, 79)
      M(81, 79) = M(81, 79) - temp
C     Lower part.
      temp = M(82, 28) * M(28, 79)
      temp = temp + M(82, 35) * M(35, 79)
      temp = temp + M(82, 36) * M(36, 79)
      temp = temp + M(82, 37) * M(37, 79)
      temp = temp + M(82, 38) * M(38, 79)
      temp = temp + M(82, 39) * M(39, 79)
      temp = temp + M(82, 40) * M(40, 79)
      temp = temp + M(82, 41) * M(41, 79)
      temp = temp + M(82, 42) * M(42, 79)
      temp = temp + M(82, 43) * M(43, 79)
      temp = temp + M(82, 44) * M(44, 79)
      temp = temp + M(82, 46) * M(46, 79)
      temp = temp + M(82, 47) * M(47, 79)
      temp = temp + M(82, 48) * M(48, 79)
      temp = temp + M(82, 49) * M(49, 79)
      temp = temp + M(82, 51) * M(51, 79)
      temp = temp + M(82, 53) * M(53, 79)
      temp = temp + M(82, 54) * M(54, 79)
      temp = temp + M(82, 55) * M(55, 79)
      temp = temp + M(82, 56) * M(56, 79)
      temp = temp + M(82, 57) * M(57, 79)
      temp = temp + M(82, 58) * M(58, 79)
      temp = temp + M(82, 59) * M(59, 79)
      temp = temp + M(82, 60) * M(60, 79)
      temp = temp + M(82, 62) * M(62, 79)
      temp = temp + M(82, 63) * M(63, 79)
      temp = temp + M(82, 64) * M(64, 79)
      temp = temp + M(82, 66) * M(66, 79)
      temp = temp + M(82, 67) * M(67, 79)
      temp = temp + M(82, 69) * M(69, 79)
      temp = temp + M(82, 70) * M(70, 79)
      temp = temp + M(82, 73) * M(73, 79)
      temp = temp + M(82, 74) * M(74, 79)
      temp = temp + M(82, 75) * M(75, 79)
      temp = temp + M(82, 76) * M(76, 79)
      temp = temp + M(82, 77) * M(77, 79)
      temp = temp + M(82, 78) * M(78, 79)
      M(82, 79) = M(82, 79) - temp
C     Upper part.
      temp = M(79, 30) * M(30, 80)
      temp = temp + M(79, 33) * M(33, 80)
      temp = temp + M(79, 35) * M(35, 80)
      temp = temp + M(79, 36) * M(36, 80)
      temp = temp + M(79, 37) * M(37, 80)
      temp = temp + M(79, 38) * M(38, 80)
      temp = temp + M(79, 39) * M(39, 80)
      temp = temp + M(79, 40) * M(40, 80)
      temp = temp + M(79, 41) * M(41, 80)
      temp = temp + M(79, 42) * M(42, 80)
      temp = temp + M(79, 43) * M(43, 80)
      temp = temp + M(79, 44) * M(44, 80)
      temp = temp + M(79, 45) * M(45, 80)
      temp = temp + M(79, 46) * M(46, 80)
      temp = temp + M(79, 47) * M(47, 80)
      temp = temp + M(79, 48) * M(48, 80)
      temp = temp + M(79, 49) * M(49, 80)
      temp = temp + M(79, 51) * M(51, 80)
      temp = temp + M(79, 52) * M(52, 80)
      temp = temp + M(79, 54) * M(54, 80)
      temp = temp + M(79, 55) * M(55, 80)
      temp = temp + M(79, 56) * M(56, 80)
      temp = temp + M(79, 57) * M(57, 80)
      temp = temp + M(79, 58) * M(58, 80)
      temp = temp + M(79, 59) * M(59, 80)
      temp = temp + M(79, 60) * M(60, 80)
      temp = temp + M(79, 61) * M(61, 80)
      temp = temp + M(79, 63) * M(63, 80)
      temp = temp + M(79, 64) * M(64, 80)
      temp = temp + M(79, 65) * M(65, 80)
      temp = temp + M(79, 66) * M(66, 80)
      temp = temp + M(79, 67) * M(67, 80)
      temp = temp + M(79, 69) * M(69, 80)
      temp = temp + M(79, 70) * M(70, 80)
      temp = temp + M(79, 71) * M(71, 80)
      temp = temp + M(79, 73) * M(73, 80)
      temp = temp + M(79, 74) * M(74, 80)
      temp = temp + M(79, 75) * M(75, 80)
      temp = temp + M(79, 76) * M(76, 80)
      temp = temp + M(79, 77) * M(77, 80)
      temp = temp + M(79, 78) * M(78, 80)
      M(79, 80) = ( M(79, 80) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 18) * M(18, 81)
      temp = temp + M(79, 53) * M(53, 81)
      temp = temp + M(79, 58) * M(58, 81)
      temp = temp + M(79, 59) * M(59, 81)
      temp = temp + M(79, 60) * M(60, 81)
      temp = temp + M(79, 61) * M(61, 81)
      temp = temp + M(79, 63) * M(63, 81)
      temp = temp + M(79, 64) * M(64, 81)
      temp = temp + M(79, 65) * M(65, 81)
      temp = temp + M(79, 66) * M(66, 81)
      temp = temp + M(79, 67) * M(67, 81)
      temp = temp + M(79, 69) * M(69, 81)
      temp = temp + M(79, 70) * M(70, 81)
      temp = temp + M(79, 71) * M(71, 81)
      temp = temp + M(79, 73) * M(73, 81)
      temp = temp + M(79, 74) * M(74, 81)
      temp = temp + M(79, 75) * M(75, 81)
      temp = temp + M(79, 76) * M(76, 81)
      temp = temp + M(79, 77) * M(77, 81)
      temp = temp + M(79, 78) * M(78, 81)
      M(79, 81) = ( M(79, 81) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 35) * M(35, 82)
      temp = temp + M(79, 36) * M(36, 82)
      temp = temp + M(79, 37) * M(37, 82)
      temp = temp + M(79, 38) * M(38, 82)
      temp = temp + M(79, 39) * M(39, 82)
      temp = temp + M(79, 40) * M(40, 82)
      temp = temp + M(79, 41) * M(41, 82)
      temp = temp + M(79, 42) * M(42, 82)
      temp = temp + M(79, 43) * M(43, 82)
      temp = temp + M(79, 46) * M(46, 82)
      temp = temp + M(79, 47) * M(47, 82)
      temp = temp + M(79, 48) * M(48, 82)
      temp = temp + M(79, 52) * M(52, 82)
      temp = temp + M(79, 53) * M(53, 82)
      temp = temp + M(79, 54) * M(54, 82)
      temp = temp + M(79, 55) * M(55, 82)
      temp = temp + M(79, 56) * M(56, 82)
      temp = temp + M(79, 57) * M(57, 82)
      temp = temp + M(79, 58) * M(58, 82)
      temp = temp + M(79, 59) * M(59, 82)
      temp = temp + M(79, 60) * M(60, 82)
      temp = temp + M(79, 61) * M(61, 82)
      temp = temp + M(79, 63) * M(63, 82)
      temp = temp + M(79, 64) * M(64, 82)
      temp = temp + M(79, 65) * M(65, 82)
      temp = temp + M(79, 66) * M(66, 82)
      temp = temp + M(79, 67) * M(67, 82)
      temp = temp + M(79, 69) * M(69, 82)
      temp = temp + M(79, 70) * M(70, 82)
      temp = temp + M(79, 71) * M(71, 82)
      temp = temp + M(79, 73) * M(73, 82)
      temp = temp + M(79, 74) * M(74, 82)
      temp = temp + M(79, 75) * M(75, 82)
      temp = temp + M(79, 76) * M(76, 82)
      temp = temp + M(79, 77) * M(77, 82)
      temp = temp + M(79, 78) * M(78, 82)
      M(79, 82) = ( M(79, 82) - temp ) / M(79, 79)

C     Lower part.
      temp = M(80, 14) * M(14, 80)
      temp = temp + M(80, 23) * M(23, 80)
      temp = temp + M(80, 35) * M(35, 80)
      temp = temp + M(80, 36) * M(36, 80)
      temp = temp + M(80, 37) * M(37, 80)
      temp = temp + M(80, 38) * M(38, 80)
      temp = temp + M(80, 39) * M(39, 80)
      temp = temp + M(80, 40) * M(40, 80)
      temp = temp + M(80, 41) * M(41, 80)
      temp = temp + M(80, 42) * M(42, 80)
      temp = temp + M(80, 43) * M(43, 80)
      temp = temp + M(80, 44) * M(44, 80)
      temp = temp + M(80, 46) * M(46, 80)
      temp = temp + M(80, 47) * M(47, 80)
      temp = temp + M(80, 48) * M(48, 80)
      temp = temp + M(80, 49) * M(49, 80)
      temp = temp + M(80, 50) * M(50, 80)
      temp = temp + M(80, 51) * M(51, 80)
      temp = temp + M(80, 54) * M(54, 80)
      temp = temp + M(80, 55) * M(55, 80)
      temp = temp + M(80, 56) * M(56, 80)
      temp = temp + M(80, 57) * M(57, 80)
      temp = temp + M(80, 58) * M(58, 80)
      temp = temp + M(80, 59) * M(59, 80)
      temp = temp + M(80, 60) * M(60, 80)
      temp = temp + M(80, 63) * M(63, 80)
      temp = temp + M(80, 64) * M(64, 80)
      temp = temp + M(80, 66) * M(66, 80)
      temp = temp + M(80, 69) * M(69, 80)
      temp = temp + M(80, 73) * M(73, 80)
      temp = temp + M(80, 74) * M(74, 80)
      temp = temp + M(80, 75) * M(75, 80)
      temp = temp + M(80, 76) * M(76, 80)
      temp = temp + M(80, 77) * M(77, 80)
      temp = temp + M(80, 78) * M(78, 80)
      temp = temp + M(80, 79) * M(79, 80)
      M(80, 80) = M(80, 80) - temp
C     Lower part.
      temp = M(81, 23) * M(23, 80)
      temp = temp + M(81, 35) * M(35, 80)
      temp = temp + M(81, 36) * M(36, 80)
      temp = temp + M(81, 37) * M(37, 80)
      temp = temp + M(81, 38) * M(38, 80)
      temp = temp + M(81, 39) * M(39, 80)
      temp = temp + M(81, 40) * M(40, 80)
      temp = temp + M(81, 41) * M(41, 80)
      temp = temp + M(81, 42) * M(42, 80)
      temp = temp + M(81, 43) * M(43, 80)
      temp = temp + M(81, 44) * M(44, 80)
      temp = temp + M(81, 46) * M(46, 80)
      temp = temp + M(81, 47) * M(47, 80)
      temp = temp + M(81, 48) * M(48, 80)
      temp = temp + M(81, 49) * M(49, 80)
      temp = temp + M(81, 50) * M(50, 80)
      temp = temp + M(81, 51) * M(51, 80)
      temp = temp + M(81, 54) * M(54, 80)
      temp = temp + M(81, 55) * M(55, 80)
      temp = temp + M(81, 56) * M(56, 80)
      temp = temp + M(81, 57) * M(57, 80)
      temp = temp + M(81, 58) * M(58, 80)
      temp = temp + M(81, 59) * M(59, 80)
      temp = temp + M(81, 60) * M(60, 80)
      temp = temp + M(81, 61) * M(61, 80)
      temp = temp + M(81, 63) * M(63, 80)
      temp = temp + M(81, 64) * M(64, 80)
      temp = temp + M(81, 66) * M(66, 80)
      temp = temp + M(81, 69) * M(69, 80)
      temp = temp + M(81, 72) * M(72, 80)
      temp = temp + M(81, 73) * M(73, 80)
      temp = temp + M(81, 74) * M(74, 80)
      temp = temp + M(81, 75) * M(75, 80)
      temp = temp + M(81, 76) * M(76, 80)
      temp = temp + M(81, 77) * M(77, 80)
      temp = temp + M(81, 78) * M(78, 80)
      temp = temp + M(81, 79) * M(79, 80)
      M(81, 80) = M(81, 80) - temp
C     Lower part.
      temp = M(82, 30) * M(30, 80)
      temp = temp + M(82, 35) * M(35, 80)
      temp = temp + M(82, 36) * M(36, 80)
      temp = temp + M(82, 37) * M(37, 80)
      temp = temp + M(82, 38) * M(38, 80)
      temp = temp + M(82, 39) * M(39, 80)
      temp = temp + M(82, 40) * M(40, 80)
      temp = temp + M(82, 41) * M(41, 80)
      temp = temp + M(82, 42) * M(42, 80)
      temp = temp + M(82, 43) * M(43, 80)
      temp = temp + M(82, 44) * M(44, 80)
      temp = temp + M(82, 46) * M(46, 80)
      temp = temp + M(82, 47) * M(47, 80)
      temp = temp + M(82, 48) * M(48, 80)
      temp = temp + M(82, 49) * M(49, 80)
      temp = temp + M(82, 51) * M(51, 80)
      temp = temp + M(82, 54) * M(54, 80)
      temp = temp + M(82, 55) * M(55, 80)
      temp = temp + M(82, 56) * M(56, 80)
      temp = temp + M(82, 57) * M(57, 80)
      temp = temp + M(82, 58) * M(58, 80)
      temp = temp + M(82, 59) * M(59, 80)
      temp = temp + M(82, 60) * M(60, 80)
      temp = temp + M(82, 62) * M(62, 80)
      temp = temp + M(82, 63) * M(63, 80)
      temp = temp + M(82, 64) * M(64, 80)
      temp = temp + M(82, 66) * M(66, 80)
      temp = temp + M(82, 67) * M(67, 80)
      temp = temp + M(82, 69) * M(69, 80)
      temp = temp + M(82, 70) * M(70, 80)
      temp = temp + M(82, 73) * M(73, 80)
      temp = temp + M(82, 74) * M(74, 80)
      temp = temp + M(82, 75) * M(75, 80)
      temp = temp + M(82, 76) * M(76, 80)
      temp = temp + M(82, 77) * M(77, 80)
      temp = temp + M(82, 78) * M(78, 80)
      temp = temp + M(82, 79) * M(79, 80)
      M(82, 80) = M(82, 80) - temp
C     Upper part.
      temp = M(80, 32) * M(32, 81)
      temp = temp + M(80, 58) * M(58, 81)
      temp = temp + M(80, 59) * M(59, 81)
      temp = temp + M(80, 60) * M(60, 81)
      temp = temp + M(80, 63) * M(63, 81)
      temp = temp + M(80, 64) * M(64, 81)
      temp = temp + M(80, 66) * M(66, 81)
      temp = temp + M(80, 69) * M(69, 81)
      temp = temp + M(80, 73) * M(73, 81)
      temp = temp + M(80, 74) * M(74, 81)
      temp = temp + M(80, 75) * M(75, 81)
      temp = temp + M(80, 76) * M(76, 81)
      temp = temp + M(80, 77) * M(77, 81)
      temp = temp + M(80, 78) * M(78, 81)
      temp = temp + M(80, 79) * M(79, 81)
      M(80, 81) = ( M(80, 81) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 35) * M(35, 82)
      temp = temp + M(80, 36) * M(36, 82)
      temp = temp + M(80, 37) * M(37, 82)
      temp = temp + M(80, 38) * M(38, 82)
      temp = temp + M(80, 39) * M(39, 82)
      temp = temp + M(80, 40) * M(40, 82)
      temp = temp + M(80, 41) * M(41, 82)
      temp = temp + M(80, 42) * M(42, 82)
      temp = temp + M(80, 43) * M(43, 82)
      temp = temp + M(80, 46) * M(46, 82)
      temp = temp + M(80, 47) * M(47, 82)
      temp = temp + M(80, 48) * M(48, 82)
      temp = temp + M(80, 54) * M(54, 82)
      temp = temp + M(80, 55) * M(55, 82)
      temp = temp + M(80, 56) * M(56, 82)
      temp = temp + M(80, 57) * M(57, 82)
      temp = temp + M(80, 58) * M(58, 82)
      temp = temp + M(80, 59) * M(59, 82)
      temp = temp + M(80, 60) * M(60, 82)
      temp = temp + M(80, 63) * M(63, 82)
      temp = temp + M(80, 64) * M(64, 82)
      temp = temp + M(80, 66) * M(66, 82)
      temp = temp + M(80, 69) * M(69, 82)
      temp = temp + M(80, 73) * M(73, 82)
      temp = temp + M(80, 74) * M(74, 82)
      temp = temp + M(80, 75) * M(75, 82)
      temp = temp + M(80, 76) * M(76, 82)
      temp = temp + M(80, 77) * M(77, 82)
      temp = temp + M(80, 78) * M(78, 82)
      temp = temp + M(80, 79) * M(79, 82)
      M(80, 82) = ( M(80, 82) - temp ) / M(80, 80)

C     Lower part.
      temp = M(81, 15) * M(15, 81)
      temp = temp + M(81, 17) * M(17, 81)
      temp = temp + M(81, 18) * M(18, 81)
      temp = temp + M(81, 26) * M(26, 81)
      temp = temp + M(81, 32) * M(32, 81)
      temp = temp + M(81, 53) * M(53, 81)
      temp = temp + M(81, 58) * M(58, 81)
      temp = temp + M(81, 59) * M(59, 81)
      temp = temp + M(81, 60) * M(60, 81)
      temp = temp + M(81, 61) * M(61, 81)
      temp = temp + M(81, 63) * M(63, 81)
      temp = temp + M(81, 64) * M(64, 81)
      temp = temp + M(81, 66) * M(66, 81)
      temp = temp + M(81, 69) * M(69, 81)
      temp = temp + M(81, 72) * M(72, 81)
      temp = temp + M(81, 73) * M(73, 81)
      temp = temp + M(81, 74) * M(74, 81)
      temp = temp + M(81, 75) * M(75, 81)
      temp = temp + M(81, 76) * M(76, 81)
      temp = temp + M(81, 77) * M(77, 81)
      temp = temp + M(81, 78) * M(78, 81)
      temp = temp + M(81, 79) * M(79, 81)
      temp = temp + M(81, 80) * M(80, 81)
      M(81, 81) = M(81, 81) - temp
C     Lower part.
      temp = M(82, 26) * M(26, 81)
      temp = temp + M(82, 53) * M(53, 81)
      temp = temp + M(82, 58) * M(58, 81)
      temp = temp + M(82, 59) * M(59, 81)
      temp = temp + M(82, 60) * M(60, 81)
      temp = temp + M(82, 62) * M(62, 81)
      temp = temp + M(82, 63) * M(63, 81)
      temp = temp + M(82, 64) * M(64, 81)
      temp = temp + M(82, 66) * M(66, 81)
      temp = temp + M(82, 67) * M(67, 81)
      temp = temp + M(82, 69) * M(69, 81)
      temp = temp + M(82, 70) * M(70, 81)
      temp = temp + M(82, 73) * M(73, 81)
      temp = temp + M(82, 74) * M(74, 81)
      temp = temp + M(82, 75) * M(75, 81)
      temp = temp + M(82, 76) * M(76, 81)
      temp = temp + M(82, 77) * M(77, 81)
      temp = temp + M(82, 78) * M(78, 81)
      temp = temp + M(82, 79) * M(79, 81)
      temp = temp + M(82, 80) * M(80, 81)
      M(82, 81) = M(82, 81) - temp
C     Upper part.
      temp = M(81, 26) * M(26, 82)
      temp = temp + M(81, 35) * M(35, 82)
      temp = temp + M(81, 36) * M(36, 82)
      temp = temp + M(81, 37) * M(37, 82)
      temp = temp + M(81, 38) * M(38, 82)
      temp = temp + M(81, 39) * M(39, 82)
      temp = temp + M(81, 40) * M(40, 82)
      temp = temp + M(81, 41) * M(41, 82)
      temp = temp + M(81, 42) * M(42, 82)
      temp = temp + M(81, 43) * M(43, 82)
      temp = temp + M(81, 46) * M(46, 82)
      temp = temp + M(81, 47) * M(47, 82)
      temp = temp + M(81, 48) * M(48, 82)
      temp = temp + M(81, 53) * M(53, 82)
      temp = temp + M(81, 54) * M(54, 82)
      temp = temp + M(81, 55) * M(55, 82)
      temp = temp + M(81, 56) * M(56, 82)
      temp = temp + M(81, 57) * M(57, 82)
      temp = temp + M(81, 58) * M(58, 82)
      temp = temp + M(81, 59) * M(59, 82)
      temp = temp + M(81, 60) * M(60, 82)
      temp = temp + M(81, 61) * M(61, 82)
      temp = temp + M(81, 63) * M(63, 82)
      temp = temp + M(81, 64) * M(64, 82)
      temp = temp + M(81, 66) * M(66, 82)
      temp = temp + M(81, 69) * M(69, 82)
      temp = temp + M(81, 72) * M(72, 82)
      temp = temp + M(81, 73) * M(73, 82)
      temp = temp + M(81, 74) * M(74, 82)
      temp = temp + M(81, 75) * M(75, 82)
      temp = temp + M(81, 76) * M(76, 82)
      temp = temp + M(81, 77) * M(77, 82)
      temp = temp + M(81, 78) * M(78, 82)
      temp = temp + M(81, 79) * M(79, 82)
      temp = temp + M(81, 80) * M(80, 82)
      M(81, 82) = ( M(81, 82) - temp ) / M(81, 81)

C     Lower part.
      temp = M(82, 26) * M(26, 82)
      temp = temp + M(82, 28) * M(28, 82)
      temp = temp + M(82, 35) * M(35, 82)
      temp = temp + M(82, 36) * M(36, 82)
      temp = temp + M(82, 37) * M(37, 82)
      temp = temp + M(82, 38) * M(38, 82)
      temp = temp + M(82, 39) * M(39, 82)
      temp = temp + M(82, 40) * M(40, 82)
      temp = temp + M(82, 41) * M(41, 82)
      temp = temp + M(82, 42) * M(42, 82)
      temp = temp + M(82, 43) * M(43, 82)
      temp = temp + M(82, 46) * M(46, 82)
      temp = temp + M(82, 47) * M(47, 82)
      temp = temp + M(82, 48) * M(48, 82)
      temp = temp + M(82, 53) * M(53, 82)
      temp = temp + M(82, 54) * M(54, 82)
      temp = temp + M(82, 55) * M(55, 82)
      temp = temp + M(82, 56) * M(56, 82)
      temp = temp + M(82, 57) * M(57, 82)
      temp = temp + M(82, 58) * M(58, 82)
      temp = temp + M(82, 59) * M(59, 82)
      temp = temp + M(82, 60) * M(60, 82)
      temp = temp + M(82, 62) * M(62, 82)
      temp = temp + M(82, 63) * M(63, 82)
      temp = temp + M(82, 64) * M(64, 82)
      temp = temp + M(82, 66) * M(66, 82)
      temp = temp + M(82, 67) * M(67, 82)
      temp = temp + M(82, 69) * M(69, 82)
      temp = temp + M(82, 70) * M(70, 82)
      temp = temp + M(82, 73) * M(73, 82)
      temp = temp + M(82, 74) * M(74, 82)
      temp = temp + M(82, 75) * M(75, 82)
      temp = temp + M(82, 76) * M(76, 82)
      temp = temp + M(82, 77) * M(77, 82)
      temp = temp + M(82, 78) * M(78, 82)
      temp = temp + M(82, 79) * M(79, 82)
      temp = temp + M(82, 80) * M(80, 82)
      temp = temp + M(82, 81) * M(81, 82)
      M(82, 82) = M(82, 82) - temp


      END
