C------------------------------------------------------------------------
C     
C     Copyright (C) 2001-2003 CEREA (ENPC)
C     
C     This file is part of Polair.
C     Polair is a 3D eulerian chemistry-transport-model.
C     
C     Polair is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published by
C     the Free Software Foundation; either version 2 of the License, or
C     (at your option) any later version.
C     
C     Polair is distributed in the hope that it will be useful,
C     but WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C     GNU General Public License (file "LICENSE") for more details.
C     
C------------------------------------------------------------------------

      SUBROUTINE LU_decompose (M)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes an LU factorization of M.
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     M: on entry, an invertible matrix. On exit, an LU factorization
C     of M.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of 'chemical' arrays.

      INCLUDE 'PARACHEM.INC'

      DOUBLE PRECISION M(Nesp,Nesp)
      DOUBLE PRECISION temp


C     Upper part.
      M(1, 62) = M(1, 62) / M(1, 1)

C     Upper part.
      M(2, 62) = M(2, 62) / M(2, 2)

C     Upper part.
      M(3, 62) = M(3, 62) / M(3, 3)

C     Upper part.
      M(4, 62) = M(4, 62) / M(4, 4)

C     Upper part.
      M(5, 62) = M(5, 62) / M(5, 5)

C     Upper part.
      M(6, 62) = M(6, 62) / M(6, 6)

C     Upper part.
      M(7, 50) = M(7, 50) / M(7, 7)

C     Upper part.
      temp = M(8, 1) * M(1, 62)
      M(8, 62) = ( M(8, 62) - temp ) / M(8, 8)

C     Upper part.
      M(9, 68) = M(9, 68) / M(9, 9)
C     Upper part.
      M(9, 72) = M(9, 72) / M(9, 9)

C     Upper part.
      M(10, 48) = M(10, 48) / M(10, 10)
C     Upper part.
      M(10, 62) = M(10, 62) / M(10, 10)

C     Upper part.
      M(11, 50) = M(11, 50) / M(11, 11)
C     Upper part.
      M(11, 62) = M(11, 62) / M(11, 11)
C     Upper part.
      M(11, 68) = M(11, 68) / M(11, 11)

C     Upper part.
      M(12, 50) = M(12, 50) / M(12, 12)
C     Upper part.
      M(12, 62) = M(12, 62) / M(12, 12)
C     Upper part.
      M(12, 68) = M(12, 68) / M(12, 12)

C     Upper part.
      M(13, 50) = M(13, 50) / M(13, 13)
C     Upper part.
      M(13, 62) = M(13, 62) / M(13, 13)
C     Upper part.
      M(13, 68) = M(13, 68) / M(13, 13)

C     Upper part.
      M(14, 50) = M(14, 50) / M(14, 14)
C     Upper part.
      M(14, 62) = M(14, 62) / M(14, 14)
C     Upper part.
      M(14, 68) = M(14, 68) / M(14, 14)

C     Upper part.
      M(15, 62) = M(15, 62) / M(15, 15)
C     Upper part.
      M(15, 71) = M(15, 71) / M(15, 15)
C     Upper part.
      M(15, 72) = M(15, 72) / M(15, 15)

C     Upper part.
      M(16, 62) = M(16, 62) / M(16, 16)
C     Upper part.
      M(16, 63) = M(16, 63) / M(16, 16)
C     Upper part.
      M(16, 71) = M(16, 71) / M(16, 16)

C     Upper part.
      M(17, 50) = M(17, 50) / M(17, 17)
C     Upper part.
      temp = M(17, 5) * M(5, 62)
      M(17, 62) = ( M(17, 62) - temp ) / M(17, 17)
C     Upper part.
      M(17, 72) = M(17, 72) / M(17, 17)

C     Upper part.
      M(18, 50) = M(18, 50) / M(18, 18)
C     Upper part.
      temp = M(18, 6) * M(6, 62)
      M(18, 62) = ( M(18, 62) - temp ) / M(18, 18)
C     Upper part.
      M(18, 72) = M(18, 72) / M(18, 18)

C     Upper part.
      M(19, 35) = M(19, 35) / M(19, 19)
C     Upper part.
      M(19, 50) = M(19, 50) / M(19, 19)
C     Upper part.
      M(19, 62) = M(19, 62) / M(19, 19)
C     Upper part.
      M(19, 68) = M(19, 68) / M(19, 19)

C     Upper part.
      M(20, 40) = M(20, 40) / M(20, 20)
C     Upper part.
      M(20, 44) = M(20, 44) / M(20, 20)
C     Upper part.
      M(20, 50) = M(20, 50) / M(20, 20)
C     Upper part.
      M(20, 62) = M(20, 62) / M(20, 20)

C     Upper part.
      M(21, 40) = M(21, 40) / M(21, 21)
C     Upper part.
      M(21, 44) = M(21, 44) / M(21, 21)
C     Upper part.
      M(21, 50) = M(21, 50) / M(21, 21)
C     Upper part.
      M(21, 62) = M(21, 62) / M(21, 21)

C     Upper part.
      M(22, 30) = M(22, 30) / M(22, 22)
C     Upper part.
      M(22, 50) = M(22, 50) / M(22, 22)
C     Upper part.
      M(22, 62) = M(22, 62) / M(22, 22)
C     Upper part.
      M(22, 72) = M(22, 72) / M(22, 22)

C     Upper part.
      temp = M(23, 22) * M(22, 30)
      M(23, 30) = ( M(23, 30) - temp ) / M(23, 23)
C     Upper part.
      temp = M(23, 17) * M(17, 50)
      temp = temp + M(23, 18) * M(18, 50)
      temp = temp + M(23, 22) * M(22, 50)
      M(23, 50) = ( M(23, 50) - temp ) / M(23, 23)
C     Upper part.
      temp = M(23, 17) * M(17, 62)
      temp = temp + M(23, 18) * M(18, 62)
      temp = temp + M(23, 22) * M(22, 62)
      M(23, 62) = ( M(23, 62) - temp ) / M(23, 23)
C     Upper part.
      M(23, 67) = M(23, 67) / M(23, 23)
C     Upper part.
      temp = M(23, 17) * M(17, 72)
      temp = temp + M(23, 18) * M(18, 72)
      temp = temp + M(23, 22) * M(22, 72)
      M(23, 72) = ( M(23, 72) - temp ) / M(23, 23)

C     Upper part.
      M(24, 25) = M(24, 25) / M(24, 24)
C     Upper part.
      M(24, 49) = M(24, 49) / M(24, 24)
C     Upper part.
      M(24, 58) = M(24, 58) / M(24, 24)
C     Upper part.
      temp = M(24, 4) * M(4, 62)
      M(24, 62) = ( M(24, 62) - temp ) / M(24, 24)
C     Upper part.
      M(24, 63) = M(24, 63) / M(24, 24)

C     Lower part.
      temp = M(54, 24) * M(24, 25)
      M(54, 25) = M(54, 25) - temp
C     Lower part.
      temp = M(62, 24) * M(24, 25)
      M(62, 25) = M(62, 25) - temp
C     Lower part.
      temp = M(66, 24) * M(24, 25)
      M(66, 25) = M(66, 25) - temp
C     Lower part.
      temp = M(69, 24) * M(24, 25)
      M(69, 25) = M(69, 25) - temp
C     Lower part.
      temp = M(71, 24) * M(24, 25)
      M(71, 25) = M(71, 25) - temp
C     Upper part.
      M(25, 50) = M(25, 50) / M(25, 25)
C     Upper part.
      M(25, 56) = M(25, 56) / M(25, 25)
C     Upper part.
      M(25, 62) = M(25, 62) / M(25, 25)
C     Upper part.
      M(25, 68) = M(25, 68) / M(25, 25)
C     Upper part.
      M(25, 72) = M(25, 72) / M(25, 25)

C     Upper part.
      temp = M(26, 25) * M(25, 50)
      M(26, 50) = ( M(26, 50) - temp ) / M(26, 26)
C     Upper part.
      temp = M(26, 25) * M(25, 56)
      M(26, 56) = ( M(26, 56) - temp ) / M(26, 26)
C     Upper part.
      temp = M(26, 25) * M(25, 62)
      M(26, 62) = ( M(26, 62) - temp ) / M(26, 26)
C     Upper part.
      temp = M(26, 25) * M(25, 68)
      M(26, 68) = ( M(26, 68) - temp ) / M(26, 26)
C     Upper part.
      M(26, 69) = M(26, 69) / M(26, 26)
C     Upper part.
      temp = M(26, 25) * M(25, 72)
      M(26, 72) = ( M(26, 72) - temp ) / M(26, 26)

C     Upper part.
      temp = M(27, 19) * M(19, 35)
      M(27, 35) = ( M(27, 35) - temp ) / M(27, 27)
C     Upper part.
      M(27, 40) = M(27, 40) / M(27, 27)
C     Upper part.
      M(27, 44) = M(27, 44) / M(27, 27)
C     Upper part.
      temp = M(27, 12) * M(12, 50)
      temp = temp + M(27, 13) * M(13, 50)
      temp = temp + M(27, 14) * M(14, 50)
      temp = temp + M(27, 19) * M(19, 50)
      M(27, 50) = ( M(27, 50) - temp ) / M(27, 27)
C     Upper part.
      temp = M(27, 12) * M(12, 62)
      temp = temp + M(27, 13) * M(13, 62)
      temp = temp + M(27, 14) * M(14, 62)
      temp = temp + M(27, 19) * M(19, 62)
      M(27, 62) = ( M(27, 62) - temp ) / M(27, 27)
C     Upper part.
      temp = M(27, 12) * M(12, 68)
      temp = temp + M(27, 13) * M(13, 68)
      temp = temp + M(27, 14) * M(14, 68)
      temp = temp + M(27, 19) * M(19, 68)
      M(27, 68) = ( M(27, 68) - temp ) / M(27, 27)
C     Upper part.
      M(27, 71) = M(27, 71) / M(27, 27)

C     Upper part.
      M(28, 48) = M(28, 48) / M(28, 28)
C     Upper part.
      M(28, 50) = M(28, 50) / M(28, 28)
C     Upper part.
      M(28, 62) = M(28, 62) / M(28, 28)
C     Upper part.
      M(28, 69) = M(28, 69) / M(28, 28)
C     Upper part.
      M(28, 71) = M(28, 71) / M(28, 28)

C     Upper part.
      M(29, 30) = M(29, 30) / M(29, 29)
C     Upper part.
      M(29, 62) = M(29, 62) / M(29, 29)
C     Upper part.
      M(29, 68) = M(29, 68) / M(29, 29)
C     Upper part.
      M(29, 71) = M(29, 71) / M(29, 29)
C     Upper part.
      M(29, 72) = M(29, 72) / M(29, 29)

C     Lower part.
      temp = M(30, 22) * M(22, 30)
      temp = temp + M(30, 29) * M(29, 30)
      M(30, 30) = M(30, 30) - temp
C     Lower part.
      temp = M(33, 22) * M(22, 30)
      M(33, 30) = M(33, 30) - temp
C     Lower part.
      temp = M(50, 22) * M(22, 30)
      M(50, 30) = M(50, 30) - temp
C     Lower part.
      temp = M(62, 22) * M(22, 30)
      temp = temp + M(62, 23) * M(23, 30)
      M(62, 30) = M(62, 30) - temp
C     Lower part.
      temp = M(67, 23) * M(23, 30)
      M(67, 30) = M(67, 30) - temp
C     Lower part.
      temp = M(70, 29) * M(29, 30)
      M(70, 30) = M(70, 30) - temp
C     Lower part.
      temp = M(71, 22) * M(22, 30)
      temp = temp + M(71, 29) * M(29, 30)
      M(71, 30) = M(71, 30) - temp
C     Lower part.
      temp = M(72, 22) * M(22, 30)
      temp = temp + M(72, 23) * M(23, 30)
      temp = temp + M(72, 29) * M(29, 30)
      M(72, 30) = M(72, 30) - temp
C     Upper part.
      temp = M(30, 17) * M(17, 50)
      temp = temp + M(30, 18) * M(18, 50)
      temp = temp + M(30, 22) * M(22, 50)
      M(30, 50) = ( M(30, 50) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 17) * M(17, 62)
      temp = temp + M(30, 18) * M(18, 62)
      temp = temp + M(30, 22) * M(22, 62)
      temp = temp + M(30, 29) * M(29, 62)
      M(30, 62) = ( M(30, 62) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 29) * M(29, 68)
      M(30, 68) = ( M(30, 68) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 29) * M(29, 71)
      M(30, 71) = ( M(30, 71) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 17) * M(17, 72)
      temp = temp + M(30, 18) * M(18, 72)
      temp = temp + M(30, 22) * M(22, 72)
      temp = temp + M(30, 29) * M(29, 72)
      M(30, 72) = ( M(30, 72) - temp ) / M(30, 30)

C     Upper part.
      temp = M(31, 17) * M(17, 50)
      M(31, 50) = ( M(31, 50) - temp ) / M(31, 31)
C     Upper part.
      temp = M(31, 17) * M(17, 62)
      M(31, 62) = ( M(31, 62) - temp ) / M(31, 31)
C     Upper part.
      M(31, 63) = M(31, 63) / M(31, 31)
C     Upper part.
      M(31, 67) = M(31, 67) / M(31, 31)
C     Upper part.
      M(31, 68) = M(31, 68) / M(31, 31)
C     Upper part.
      M(31, 69) = M(31, 69) / M(31, 31)
C     Upper part.
      M(31, 71) = M(31, 71) / M(31, 31)
C     Upper part.
      temp = M(31, 17) * M(17, 72)
      M(31, 72) = ( M(31, 72) - temp ) / M(31, 31)

C     Upper part.
      temp = M(32, 18) * M(18, 50)
      M(32, 50) = ( M(32, 50) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 18) * M(18, 62)
      M(32, 62) = ( M(32, 62) - temp ) / M(32, 32)
C     Upper part.
      M(32, 63) = M(32, 63) / M(32, 32)
C     Upper part.
      M(32, 67) = M(32, 67) / M(32, 32)
C     Upper part.
      M(32, 68) = M(32, 68) / M(32, 32)
C     Upper part.
      M(32, 69) = M(32, 69) / M(32, 32)
C     Upper part.
      M(32, 71) = M(32, 71) / M(32, 32)
C     Upper part.
      temp = M(32, 18) * M(18, 72)
      M(32, 72) = ( M(32, 72) - temp ) / M(32, 32)

C     Upper part.
      temp = M(33, 22) * M(22, 50)
      temp = temp + M(33, 30) * M(30, 50)
      M(33, 50) = ( M(33, 50) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 22) * M(22, 62)
      temp = temp + M(33, 30) * M(30, 62)
      M(33, 62) = ( M(33, 62) - temp ) / M(33, 33)
C     Upper part.
      M(33, 63) = M(33, 63) / M(33, 33)
C     Upper part.
      M(33, 67) = M(33, 67) / M(33, 33)
C     Upper part.
      temp = M(33, 30) * M(30, 68)
      M(33, 68) = ( M(33, 68) - temp ) / M(33, 33)
C     Upper part.
      M(33, 69) = M(33, 69) / M(33, 33)
C     Upper part.
      temp = M(33, 30) * M(30, 71)
      M(33, 71) = ( M(33, 71) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 22) * M(22, 72)
      temp = temp + M(33, 30) * M(30, 72)
      M(33, 72) = ( M(33, 72) - temp ) / M(33, 33)

C     Upper part.
      temp = M(34, 19) * M(19, 35)
      M(34, 35) = ( M(34, 35) - temp ) / M(34, 34)
C     Upper part.
      M(34, 40) = M(34, 40) / M(34, 34)
C     Upper part.
      M(34, 48) = M(34, 48) / M(34, 34)
C     Upper part.
      M(34, 49) = M(34, 49) / M(34, 34)
C     Upper part.
      temp = M(34, 11) * M(11, 50)
      temp = temp + M(34, 12) * M(12, 50)
      temp = temp + M(34, 14) * M(14, 50)
      temp = temp + M(34, 19) * M(19, 50)
      temp = temp + M(34, 25) * M(25, 50)
      M(34, 50) = ( M(34, 50) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 25) * M(25, 56)
      M(34, 56) = ( M(34, 56) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 2) * M(2, 62)
      temp = temp + M(34, 11) * M(11, 62)
      temp = temp + M(34, 12) * M(12, 62)
      temp = temp + M(34, 14) * M(14, 62)
      temp = temp + M(34, 19) * M(19, 62)
      temp = temp + M(34, 25) * M(25, 62)
      M(34, 62) = ( M(34, 62) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 11) * M(11, 68)
      temp = temp + M(34, 12) * M(12, 68)
      temp = temp + M(34, 14) * M(14, 68)
      temp = temp + M(34, 19) * M(19, 68)
      temp = temp + M(34, 25) * M(25, 68)
      M(34, 68) = ( M(34, 68) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 25) * M(25, 72)
      M(34, 72) = ( M(34, 72) - temp ) / M(34, 34)

C     Lower part.
      temp = M(35, 19) * M(19, 35)
      M(35, 35) = M(35, 35) - temp
C     Lower part.
      temp = M(39, 19) * M(19, 35)
      M(39, 35) = M(39, 35) - temp
C     Lower part.
      temp = M(40, 19) * M(19, 35)
      M(40, 35) = M(40, 35) - temp
C     Lower part.
      temp = M(46, 19) * M(19, 35)
      M(46, 35) = M(46, 35) - temp
C     Lower part.
      temp = M(47, 19) * M(19, 35)
      M(47, 35) = M(47, 35) - temp
C     Lower part.
      temp = M(48, 19) * M(19, 35)
      M(48, 35) = M(48, 35) - temp
C     Lower part.
      temp = M(49, 19) * M(19, 35)
      M(49, 35) = M(49, 35) - temp
C     Lower part.
      temp = M(50, 19) * M(19, 35)
      M(50, 35) = M(50, 35) - temp
C     Lower part.
      temp = M(52, 19) * M(19, 35)
      M(52, 35) = M(52, 35) - temp
C     Lower part.
      temp = M(58, 19) * M(19, 35)
      M(58, 35) = M(58, 35) - temp
C     Lower part.
      temp = M(62, 19) * M(19, 35)
      temp = temp + M(62, 27) * M(27, 35)
      M(62, 35) = M(62, 35) - temp
C     Lower part.
      temp = M(63, 19) * M(19, 35)
      M(63, 35) = M(63, 35) - temp
C     Lower part.
      temp = M(65, 19) * M(19, 35)
      M(65, 35) = M(65, 35) - temp
C     Lower part.
      temp = M(66, 19) * M(19, 35)
      M(66, 35) = M(66, 35) - temp
C     Lower part.
      temp = M(68, 19) * M(19, 35)
      M(68, 35) = M(68, 35) - temp
C     Lower part.
      temp = M(69, 19) * M(19, 35)
      M(69, 35) = M(69, 35) - temp
C     Lower part.
      temp = M(71, 19) * M(19, 35)
      temp = temp + M(71, 27) * M(27, 35)
      M(71, 35) = M(71, 35) - temp
C     Upper part.
      M(35, 49) = M(35, 49) / M(35, 35)
C     Upper part.
      temp = M(35, 7) * M(7, 50)
      temp = temp + M(35, 12) * M(12, 50)
      temp = temp + M(35, 19) * M(19, 50)
      M(35, 50) = ( M(35, 50) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 12) * M(12, 62)
      temp = temp + M(35, 19) * M(19, 62)
      M(35, 62) = ( M(35, 62) - temp ) / M(35, 35)
C     Upper part.
      M(35, 67) = M(35, 67) / M(35, 35)
C     Upper part.
      temp = M(35, 12) * M(12, 68)
      temp = temp + M(35, 19) * M(19, 68)
      M(35, 68) = ( M(35, 68) - temp ) / M(35, 35)
C     Upper part.
      M(35, 72) = M(35, 72) / M(35, 35)

C     Upper part.
      temp = M(36, 3) * M(3, 62)
      M(36, 62) = ( M(36, 62) - temp ) / M(36, 36)
C     Upper part.
      M(36, 63) = M(36, 63) / M(36, 36)
C     Upper part.
      M(36, 67) = M(36, 67) / M(36, 36)
C     Upper part.
      M(36, 68) = M(36, 68) / M(36, 36)
C     Upper part.
      M(36, 69) = M(36, 69) / M(36, 36)
C     Upper part.
      M(36, 71) = M(36, 71) / M(36, 36)

C     Upper part.
      temp = M(37, 4) * M(4, 62)
      M(37, 62) = ( M(37, 62) - temp ) / M(37, 37)
C     Upper part.
      M(37, 63) = M(37, 63) / M(37, 37)
C     Upper part.
      M(37, 67) = M(37, 67) / M(37, 37)
C     Upper part.
      M(37, 68) = M(37, 68) / M(37, 37)
C     Upper part.
      M(37, 69) = M(37, 69) / M(37, 37)
C     Upper part.
      M(37, 71) = M(37, 71) / M(37, 37)

C     Upper part.
      temp = M(38, 11) * M(11, 50)
      M(38, 50) = ( M(38, 50) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 11) * M(11, 62)
      M(38, 62) = ( M(38, 62) - temp ) / M(38, 38)
C     Upper part.
      M(38, 63) = M(38, 63) / M(38, 38)
C     Upper part.
      M(38, 67) = M(38, 67) / M(38, 38)
C     Upper part.
      temp = M(38, 11) * M(11, 68)
      M(38, 68) = ( M(38, 68) - temp ) / M(38, 38)
C     Upper part.
      M(38, 69) = M(38, 69) / M(38, 38)
C     Upper part.
      M(38, 71) = M(38, 71) / M(38, 38)

C     Upper part.
      temp = M(39, 35) * M(35, 49)
      M(39, 49) = ( M(39, 49) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 12) * M(12, 50)
      temp = temp + M(39, 19) * M(19, 50)
      temp = temp + M(39, 35) * M(35, 50)
      M(39, 50) = ( M(39, 50) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 12) * M(12, 62)
      temp = temp + M(39, 19) * M(19, 62)
      temp = temp + M(39, 35) * M(35, 62)
      M(39, 62) = ( M(39, 62) - temp ) / M(39, 39)
C     Upper part.
      M(39, 63) = M(39, 63) / M(39, 39)
C     Upper part.
      temp = M(39, 35) * M(35, 67)
      M(39, 67) = ( M(39, 67) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 12) * M(12, 68)
      temp = temp + M(39, 19) * M(19, 68)
      temp = temp + M(39, 35) * M(35, 68)
      M(39, 68) = ( M(39, 68) - temp ) / M(39, 39)
C     Upper part.
      M(39, 69) = M(39, 69) / M(39, 39)
C     Upper part.
      M(39, 71) = M(39, 71) / M(39, 39)
C     Upper part.
      temp = M(39, 35) * M(35, 72)
      M(39, 72) = ( M(39, 72) - temp ) / M(39, 39)

C     Lower part.
      temp = M(60, 21) * M(21, 40)
      M(60, 40) = M(60, 40) - temp
C     Lower part.
      temp = M(62, 20) * M(20, 40)
      temp = temp + M(62, 21) * M(21, 40)
      temp = temp + M(62, 27) * M(27, 40)
      M(62, 40) = M(62, 40) - temp
C     Lower part.
      temp = M(63, 20) * M(20, 40)
      M(63, 40) = M(63, 40) - temp
C     Lower part.
      temp = M(71, 27) * M(27, 40)
      M(71, 40) = M(71, 40) - temp
C     Upper part.
      temp = M(40, 35) * M(35, 49)
      temp = temp + M(40, 39) * M(39, 49)
      M(40, 49) = ( M(40, 49) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 12) * M(12, 50)
      temp = temp + M(40, 14) * M(14, 50)
      temp = temp + M(40, 19) * M(19, 50)
      temp = temp + M(40, 35) * M(35, 50)
      temp = temp + M(40, 39) * M(39, 50)
      M(40, 50) = ( M(40, 50) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 12) * M(12, 62)
      temp = temp + M(40, 14) * M(14, 62)
      temp = temp + M(40, 19) * M(19, 62)
      temp = temp + M(40, 35) * M(35, 62)
      temp = temp + M(40, 39) * M(39, 62)
      M(40, 62) = ( M(40, 62) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 39) * M(39, 63)
      M(40, 63) = ( M(40, 63) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 35) * M(35, 67)
      temp = temp + M(40, 39) * M(39, 67)
      M(40, 67) = ( M(40, 67) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 12) * M(12, 68)
      temp = temp + M(40, 14) * M(14, 68)
      temp = temp + M(40, 19) * M(19, 68)
      temp = temp + M(40, 35) * M(35, 68)
      temp = temp + M(40, 39) * M(39, 68)
      M(40, 68) = ( M(40, 68) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 39) * M(39, 69)
      M(40, 69) = ( M(40, 69) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 39) * M(39, 71)
      M(40, 71) = ( M(40, 71) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 35) * M(35, 72)
      temp = temp + M(40, 39) * M(39, 72)
      M(40, 72) = ( M(40, 72) - temp ) / M(40, 40)

C     Upper part.
      temp = M(41, 40) * M(40, 49)
      M(41, 49) = ( M(41, 49) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 50)
      M(41, 50) = ( M(41, 50) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 62)
      M(41, 62) = ( M(41, 62) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 63)
      M(41, 63) = ( M(41, 63) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 67)
      M(41, 67) = ( M(41, 67) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 68)
      M(41, 68) = ( M(41, 68) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 69)
      M(41, 69) = ( M(41, 69) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 71)
      M(41, 71) = ( M(41, 71) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 72)
      M(41, 72) = ( M(41, 72) - temp ) / M(41, 41)

C     Upper part.
      temp = M(42, 13) * M(13, 50)
      M(42, 50) = ( M(42, 50) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 13) * M(13, 62)
      M(42, 62) = ( M(42, 62) - temp ) / M(42, 42)
C     Upper part.
      M(42, 63) = M(42, 63) / M(42, 42)
C     Upper part.
      M(42, 67) = M(42, 67) / M(42, 42)
C     Upper part.
      temp = M(42, 13) * M(13, 68)
      M(42, 68) = ( M(42, 68) - temp ) / M(42, 42)
C     Upper part.
      M(42, 69) = M(42, 69) / M(42, 42)
C     Upper part.
      M(42, 71) = M(42, 71) / M(42, 42)

C     Upper part.
      temp = M(43, 14) * M(14, 50)
      M(43, 50) = ( M(43, 50) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 14) * M(14, 62)
      M(43, 62) = ( M(43, 62) - temp ) / M(43, 43)
C     Upper part.
      M(43, 63) = M(43, 63) / M(43, 43)
C     Upper part.
      M(43, 67) = M(43, 67) / M(43, 43)
C     Upper part.
      temp = M(43, 14) * M(14, 68)
      M(43, 68) = ( M(43, 68) - temp ) / M(43, 43)
C     Upper part.
      M(43, 69) = M(43, 69) / M(43, 43)
C     Upper part.
      M(43, 71) = M(43, 71) / M(43, 43)

C     Lower part.
      temp = M(60, 21) * M(21, 44)
      M(60, 44) = M(60, 44) - temp
C     Lower part.
      temp = M(62, 20) * M(20, 44)
      temp = temp + M(62, 21) * M(21, 44)
      temp = temp + M(62, 27) * M(27, 44)
      M(62, 44) = M(62, 44) - temp
C     Lower part.
      temp = M(63, 20) * M(20, 44)
      M(63, 44) = M(63, 44) - temp
C     Lower part.
      temp = M(71, 27) * M(27, 44)
      M(71, 44) = M(71, 44) - temp
C     Upper part.
      temp = M(44, 39) * M(39, 49)
      M(44, 49) = ( M(44, 49) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 39) * M(39, 50)
      temp = temp + M(44, 43) * M(43, 50)
      M(44, 50) = ( M(44, 50) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 39) * M(39, 62)
      temp = temp + M(44, 43) * M(43, 62)
      M(44, 62) = ( M(44, 62) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 39) * M(39, 63)
      temp = temp + M(44, 43) * M(43, 63)
      M(44, 63) = ( M(44, 63) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 39) * M(39, 67)
      temp = temp + M(44, 43) * M(43, 67)
      M(44, 67) = ( M(44, 67) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 39) * M(39, 68)
      temp = temp + M(44, 43) * M(43, 68)
      M(44, 68) = ( M(44, 68) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 39) * M(39, 69)
      temp = temp + M(44, 43) * M(43, 69)
      M(44, 69) = ( M(44, 69) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 39) * M(39, 71)
      temp = temp + M(44, 43) * M(43, 71)
      M(44, 71) = ( M(44, 71) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 39) * M(39, 72)
      M(44, 72) = ( M(44, 72) - temp ) / M(44, 44)

C     Upper part.
      temp = M(45, 44) * M(44, 49)
      M(45, 49) = ( M(45, 49) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 50)
      M(45, 50) = ( M(45, 50) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 62)
      M(45, 62) = ( M(45, 62) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 63)
      M(45, 63) = ( M(45, 63) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 67)
      M(45, 67) = ( M(45, 67) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 68)
      M(45, 68) = ( M(45, 68) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 69)
      M(45, 69) = ( M(45, 69) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 71)
      M(45, 71) = ( M(45, 71) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 72)
      M(45, 72) = ( M(45, 72) - temp ) / M(45, 45)

C     Upper part.
      M(46, 47) = M(46, 47) / M(46, 46)
C     Upper part.
      temp = M(46, 35) * M(35, 49)
      temp = temp + M(46, 40) * M(40, 49)
      temp = temp + M(46, 44) * M(44, 49)
      M(46, 49) = ( M(46, 49) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 11) * M(11, 50)
      temp = temp + M(46, 12) * M(12, 50)
      temp = temp + M(46, 13) * M(13, 50)
      temp = temp + M(46, 14) * M(14, 50)
      temp = temp + M(46, 19) * M(19, 50)
      temp = temp + M(46, 35) * M(35, 50)
      temp = temp + M(46, 40) * M(40, 50)
      temp = temp + M(46, 44) * M(44, 50)
      M(46, 50) = ( M(46, 50) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 11) * M(11, 62)
      temp = temp + M(46, 12) * M(12, 62)
      temp = temp + M(46, 13) * M(13, 62)
      temp = temp + M(46, 14) * M(14, 62)
      temp = temp + M(46, 19) * M(19, 62)
      temp = temp + M(46, 35) * M(35, 62)
      temp = temp + M(46, 40) * M(40, 62)
      temp = temp + M(46, 44) * M(44, 62)
      M(46, 62) = ( M(46, 62) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 40) * M(40, 63)
      temp = temp + M(46, 44) * M(44, 63)
      M(46, 63) = ( M(46, 63) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 35) * M(35, 67)
      temp = temp + M(46, 40) * M(40, 67)
      temp = temp + M(46, 44) * M(44, 67)
      M(46, 67) = ( M(46, 67) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 11) * M(11, 68)
      temp = temp + M(46, 12) * M(12, 68)
      temp = temp + M(46, 13) * M(13, 68)
      temp = temp + M(46, 14) * M(14, 68)
      temp = temp + M(46, 19) * M(19, 68)
      temp = temp + M(46, 35) * M(35, 68)
      temp = temp + M(46, 40) * M(40, 68)
      temp = temp + M(46, 44) * M(44, 68)
      M(46, 68) = ( M(46, 68) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 40) * M(40, 69)
      temp = temp + M(46, 44) * M(44, 69)
      M(46, 69) = ( M(46, 69) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 40) * M(40, 71)
      temp = temp + M(46, 44) * M(44, 71)
      M(46, 71) = ( M(46, 71) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 35) * M(35, 72)
      temp = temp + M(46, 40) * M(40, 72)
      temp = temp + M(46, 44) * M(44, 72)
      M(46, 72) = ( M(46, 72) - temp ) / M(46, 46)

C     Lower part.
      temp = M(47, 46) * M(46, 47)
      M(47, 47) = M(47, 47) - temp
C     Lower part.
      temp = M(57, 46) * M(46, 47)
      M(57, 47) = M(57, 47) - temp
C     Lower part.
      temp = M(59, 46) * M(46, 47)
      M(59, 47) = M(59, 47) - temp
C     Lower part.
      temp = M(61, 46) * M(46, 47)
      M(61, 47) = M(61, 47) - temp
C     Lower part.
      temp = M(63, 46) * M(46, 47)
      M(63, 47) = M(63, 47) - temp
C     Lower part.
      temp = M(66, 46) * M(46, 47)
      M(66, 47) = M(66, 47) - temp
C     Lower part.
      temp = M(67, 46) * M(46, 47)
      M(67, 47) = M(67, 47) - temp
C     Lower part.
      temp = M(68, 46) * M(46, 47)
      M(68, 47) = M(68, 47) - temp
C     Lower part.
      temp = M(69, 46) * M(46, 47)
      M(69, 47) = M(69, 47) - temp
C     Lower part.
      temp = M(70, 46) * M(46, 47)
      M(70, 47) = M(70, 47) - temp
C     Lower part.
      temp = M(71, 46) * M(46, 47)
      M(71, 47) = M(71, 47) - temp
C     Lower part.
      temp = M(72, 46) * M(46, 47)
      M(72, 47) = M(72, 47) - temp
C     Upper part.
      temp = M(47, 35) * M(35, 49)
      temp = temp + M(47, 40) * M(40, 49)
      temp = temp + M(47, 44) * M(44, 49)
      temp = temp + M(47, 46) * M(46, 49)
      M(47, 49) = ( M(47, 49) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 11) * M(11, 50)
      temp = temp + M(47, 12) * M(12, 50)
      temp = temp + M(47, 13) * M(13, 50)
      temp = temp + M(47, 14) * M(14, 50)
      temp = temp + M(47, 19) * M(19, 50)
      temp = temp + M(47, 35) * M(35, 50)
      temp = temp + M(47, 40) * M(40, 50)
      temp = temp + M(47, 44) * M(44, 50)
      temp = temp + M(47, 46) * M(46, 50)
      M(47, 50) = ( M(47, 50) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 11) * M(11, 62)
      temp = temp + M(47, 12) * M(12, 62)
      temp = temp + M(47, 13) * M(13, 62)
      temp = temp + M(47, 14) * M(14, 62)
      temp = temp + M(47, 19) * M(19, 62)
      temp = temp + M(47, 35) * M(35, 62)
      temp = temp + M(47, 40) * M(40, 62)
      temp = temp + M(47, 44) * M(44, 62)
      temp = temp + M(47, 46) * M(46, 62)
      M(47, 62) = ( M(47, 62) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 40) * M(40, 63)
      temp = temp + M(47, 44) * M(44, 63)
      temp = temp + M(47, 46) * M(46, 63)
      M(47, 63) = ( M(47, 63) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 35) * M(35, 67)
      temp = temp + M(47, 40) * M(40, 67)
      temp = temp + M(47, 44) * M(44, 67)
      temp = temp + M(47, 46) * M(46, 67)
      M(47, 67) = ( M(47, 67) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 11) * M(11, 68)
      temp = temp + M(47, 12) * M(12, 68)
      temp = temp + M(47, 13) * M(13, 68)
      temp = temp + M(47, 14) * M(14, 68)
      temp = temp + M(47, 19) * M(19, 68)
      temp = temp + M(47, 35) * M(35, 68)
      temp = temp + M(47, 40) * M(40, 68)
      temp = temp + M(47, 44) * M(44, 68)
      temp = temp + M(47, 46) * M(46, 68)
      M(47, 68) = ( M(47, 68) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 40) * M(40, 69)
      temp = temp + M(47, 44) * M(44, 69)
      temp = temp + M(47, 46) * M(46, 69)
      M(47, 69) = ( M(47, 69) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 40) * M(40, 71)
      temp = temp + M(47, 44) * M(44, 71)
      temp = temp + M(47, 46) * M(46, 71)
      M(47, 71) = ( M(47, 71) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 35) * M(35, 72)
      temp = temp + M(47, 40) * M(40, 72)
      temp = temp + M(47, 44) * M(44, 72)
      temp = temp + M(47, 46) * M(46, 72)
      M(47, 72) = ( M(47, 72) - temp ) / M(47, 47)

C     Lower part.
      temp = M(59, 10) * M(10, 48)
      M(59, 48) = M(59, 48) - temp
C     Lower part.
      temp = M(61, 10) * M(10, 48)
      M(61, 48) = M(61, 48) - temp
C     Lower part.
      temp = M(62, 10) * M(10, 48)
      temp = temp + M(62, 28) * M(28, 48)
      M(62, 48) = M(62, 48) - temp
C     Lower part.
      temp = M(63, 28) * M(28, 48)
      M(63, 48) = M(63, 48) - temp
C     Lower part.
      temp = M(65, 28) * M(28, 48)
      M(65, 48) = M(65, 48) - temp
C     Lower part.
      temp = M(66, 28) * M(28, 48)
      M(66, 48) = M(66, 48) - temp
C     Lower part.
      temp = M(69, 28) * M(28, 48)
      M(69, 48) = M(69, 48) - temp
C     Lower part.
      temp = M(71, 10) * M(10, 48)
      temp = temp + M(71, 28) * M(28, 48)
      M(71, 48) = M(71, 48) - temp
C     Upper part.
      temp = M(48, 35) * M(35, 49)
      M(48, 49) = ( M(48, 49) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 19) * M(19, 50)
      temp = temp + M(48, 31) * M(31, 50)
      temp = temp + M(48, 32) * M(32, 50)
      temp = temp + M(48, 35) * M(35, 50)
      M(48, 50) = ( M(48, 50) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 19) * M(19, 62)
      temp = temp + M(48, 31) * M(31, 62)
      temp = temp + M(48, 32) * M(32, 62)
      temp = temp + M(48, 35) * M(35, 62)
      M(48, 62) = ( M(48, 62) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 31) * M(31, 63)
      temp = temp + M(48, 32) * M(32, 63)
      M(48, 63) = ( M(48, 63) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 31) * M(31, 67)
      temp = temp + M(48, 32) * M(32, 67)
      temp = temp + M(48, 35) * M(35, 67)
      M(48, 67) = ( M(48, 67) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 19) * M(19, 68)
      temp = temp + M(48, 31) * M(31, 68)
      temp = temp + M(48, 32) * M(32, 68)
      temp = temp + M(48, 35) * M(35, 68)
      M(48, 68) = ( M(48, 68) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 31) * M(31, 69)
      temp = temp + M(48, 32) * M(32, 69)
      M(48, 69) = ( M(48, 69) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 31) * M(31, 71)
      temp = temp + M(48, 32) * M(32, 71)
      M(48, 71) = ( M(48, 71) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 31) * M(31, 72)
      temp = temp + M(48, 32) * M(32, 72)
      temp = temp + M(48, 35) * M(35, 72)
      M(48, 72) = ( M(48, 72) - temp ) / M(48, 48)

C     Lower part.
      temp = M(49, 35) * M(35, 49)
      temp = temp + M(49, 39) * M(39, 49)
      M(49, 49) = M(49, 49) - temp
C     Lower part.
      temp = M(50, 35) * M(35, 49)
      temp = temp + M(50, 40) * M(40, 49)
      temp = temp + M(50, 44) * M(44, 49)
      temp = temp + M(50, 48) * M(48, 49)
      M(50, 49) = M(50, 49) - temp
C     Lower part.
      temp = M(51, 48) * M(48, 49)
      M(51, 49) = M(51, 49) - temp
C     Lower part.
      temp = M(52, 35) * M(35, 49)
      temp = temp + M(52, 40) * M(40, 49)
      temp = temp + M(52, 44) * M(44, 49)
      temp = temp + M(52, 48) * M(48, 49)
      M(52, 49) = M(52, 49) - temp
C     Lower part.
      temp = M(53, 39) * M(39, 49)
      temp = temp + M(53, 41) * M(41, 49)
      temp = temp + M(53, 45) * M(45, 49)
      M(53, 49) = M(53, 49) - temp
C     Lower part.
      temp = M(54, 24) * M(24, 49)
      temp = temp + M(54, 48) * M(48, 49)
      M(54, 49) = M(54, 49) - temp
C     Lower part.
      temp = M(55, 48) * M(48, 49)
      M(55, 49) = M(55, 49) - temp
C     Lower part.
      temp = M(56, 48) * M(48, 49)
      M(56, 49) = M(56, 49) - temp
C     Lower part.
      temp = M(57, 39) * M(39, 49)
      temp = temp + M(57, 40) * M(40, 49)
      temp = temp + M(57, 41) * M(41, 49)
      temp = temp + M(57, 44) * M(44, 49)
      temp = temp + M(57, 45) * M(45, 49)
      temp = temp + M(57, 46) * M(46, 49)
      temp = temp + M(57, 47) * M(47, 49)
      temp = temp + M(57, 48) * M(48, 49)
      M(57, 49) = M(57, 49) - temp
C     Lower part.
      temp = M(58, 35) * M(35, 49)
      temp = temp + M(58, 40) * M(40, 49)
      temp = temp + M(58, 44) * M(44, 49)
      M(58, 49) = M(58, 49) - temp
C     Lower part.
      temp = M(59, 40) * M(40, 49)
      temp = temp + M(59, 41) * M(41, 49)
      temp = temp + M(59, 44) * M(44, 49)
      temp = temp + M(59, 45) * M(45, 49)
      temp = temp + M(59, 46) * M(46, 49)
      temp = temp + M(59, 47) * M(47, 49)
      temp = temp + M(59, 48) * M(48, 49)
      M(59, 49) = M(59, 49) - temp
C     Lower part.
      temp = M(60, 40) * M(40, 49)
      temp = temp + M(60, 44) * M(44, 49)
      M(60, 49) = M(60, 49) - temp
C     Lower part.
      temp = M(61, 35) * M(35, 49)
      temp = temp + M(61, 40) * M(40, 49)
      temp = temp + M(61, 41) * M(41, 49)
      temp = temp + M(61, 44) * M(44, 49)
      temp = temp + M(61, 45) * M(45, 49)
      temp = temp + M(61, 46) * M(46, 49)
      temp = temp + M(61, 47) * M(47, 49)
      temp = temp + M(61, 48) * M(48, 49)
      M(61, 49) = M(61, 49) - temp
C     Lower part.
      temp = M(62, 24) * M(24, 49)
      temp = temp + M(62, 35) * M(35, 49)
      temp = temp + M(62, 40) * M(40, 49)
      temp = temp + M(62, 44) * M(44, 49)
      temp = temp + M(62, 48) * M(48, 49)
      M(62, 49) = M(62, 49) - temp
C     Lower part.
      temp = M(63, 35) * M(35, 49)
      temp = temp + M(63, 39) * M(39, 49)
      temp = temp + M(63, 40) * M(40, 49)
      temp = temp + M(63, 41) * M(41, 49)
      temp = temp + M(63, 44) * M(44, 49)
      temp = temp + M(63, 45) * M(45, 49)
      temp = temp + M(63, 46) * M(46, 49)
      temp = temp + M(63, 47) * M(47, 49)
      temp = temp + M(63, 48) * M(48, 49)
      M(63, 49) = M(63, 49) - temp
C     Lower part.
      temp = M(65, 35) * M(35, 49)
      temp = temp + M(65, 48) * M(48, 49)
      M(65, 49) = M(65, 49) - temp
C     Lower part.
      temp = M(66, 24) * M(24, 49)
      temp = temp + M(66, 35) * M(35, 49)
      temp = temp + M(66, 39) * M(39, 49)
      temp = temp + M(66, 40) * M(40, 49)
      temp = temp + M(66, 41) * M(41, 49)
      temp = temp + M(66, 44) * M(44, 49)
      temp = temp + M(66, 45) * M(45, 49)
      temp = temp + M(66, 46) * M(46, 49)
      temp = temp + M(66, 47) * M(47, 49)
      temp = temp + M(66, 48) * M(48, 49)
      M(66, 49) = M(66, 49) - temp
C     Lower part.
      temp = M(67, 35) * M(35, 49)
      temp = temp + M(67, 39) * M(39, 49)
      temp = temp + M(67, 41) * M(41, 49)
      temp = temp + M(67, 45) * M(45, 49)
      temp = temp + M(67, 46) * M(46, 49)
      temp = temp + M(67, 47) * M(47, 49)
      M(67, 49) = M(67, 49) - temp
C     Lower part.
      temp = M(68, 35) * M(35, 49)
      temp = temp + M(68, 39) * M(39, 49)
      temp = temp + M(68, 40) * M(40, 49)
      temp = temp + M(68, 41) * M(41, 49)
      temp = temp + M(68, 44) * M(44, 49)
      temp = temp + M(68, 45) * M(45, 49)
      temp = temp + M(68, 46) * M(46, 49)
      temp = temp + M(68, 47) * M(47, 49)
      temp = temp + M(68, 48) * M(48, 49)
      M(68, 49) = M(68, 49) - temp
C     Lower part.
      temp = M(69, 24) * M(24, 49)
      temp = temp + M(69, 35) * M(35, 49)
      temp = temp + M(69, 39) * M(39, 49)
      temp = temp + M(69, 41) * M(41, 49)
      temp = temp + M(69, 45) * M(45, 49)
      temp = temp + M(69, 46) * M(46, 49)
      temp = temp + M(69, 47) * M(47, 49)
      temp = temp + M(69, 48) * M(48, 49)
      M(69, 49) = M(69, 49) - temp
C     Lower part.
      temp = M(70, 39) * M(39, 49)
      temp = temp + M(70, 46) * M(46, 49)
      temp = temp + M(70, 47) * M(47, 49)
      M(70, 49) = M(70, 49) - temp
C     Lower part.
      temp = M(71, 24) * M(24, 49)
      temp = temp + M(71, 35) * M(35, 49)
      temp = temp + M(71, 39) * M(39, 49)
      temp = temp + M(71, 40) * M(40, 49)
      temp = temp + M(71, 41) * M(41, 49)
      temp = temp + M(71, 44) * M(44, 49)
      temp = temp + M(71, 45) * M(45, 49)
      temp = temp + M(71, 46) * M(46, 49)
      temp = temp + M(71, 47) * M(47, 49)
      temp = temp + M(71, 48) * M(48, 49)
      M(71, 49) = M(71, 49) - temp
C     Lower part.
      temp = M(72, 35) * M(35, 49)
      temp = temp + M(72, 39) * M(39, 49)
      temp = temp + M(72, 41) * M(41, 49)
      temp = temp + M(72, 45) * M(45, 49)
      temp = temp + M(72, 46) * M(46, 49)
      temp = temp + M(72, 47) * M(47, 49)
      temp = temp + M(72, 48) * M(48, 49)
      M(72, 49) = M(72, 49) - temp
C     Upper part.
      temp = M(49, 12) * M(12, 50)
      temp = temp + M(49, 14) * M(14, 50)
      temp = temp + M(49, 19) * M(19, 50)
      temp = temp + M(49, 35) * M(35, 50)
      temp = temp + M(49, 39) * M(39, 50)
      temp = temp + M(49, 43) * M(43, 50)
      M(49, 50) = ( M(49, 50) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 12) * M(12, 62)
      temp = temp + M(49, 14) * M(14, 62)
      temp = temp + M(49, 19) * M(19, 62)
      temp = temp + M(49, 35) * M(35, 62)
      temp = temp + M(49, 39) * M(39, 62)
      temp = temp + M(49, 43) * M(43, 62)
      M(49, 62) = ( M(49, 62) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 39) * M(39, 63)
      temp = temp + M(49, 43) * M(43, 63)
      M(49, 63) = ( M(49, 63) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 35) * M(35, 67)
      temp = temp + M(49, 39) * M(39, 67)
      temp = temp + M(49, 43) * M(43, 67)
      M(49, 67) = ( M(49, 67) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 12) * M(12, 68)
      temp = temp + M(49, 14) * M(14, 68)
      temp = temp + M(49, 19) * M(19, 68)
      temp = temp + M(49, 35) * M(35, 68)
      temp = temp + M(49, 39) * M(39, 68)
      temp = temp + M(49, 43) * M(43, 68)
      M(49, 68) = ( M(49, 68) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 39) * M(39, 69)
      temp = temp + M(49, 43) * M(43, 69)
      M(49, 69) = ( M(49, 69) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 39) * M(39, 71)
      temp = temp + M(49, 43) * M(43, 71)
      M(49, 71) = ( M(49, 71) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 35) * M(35, 72)
      temp = temp + M(49, 39) * M(39, 72)
      M(49, 72) = ( M(49, 72) - temp ) / M(49, 49)

C     Lower part.
      temp = M(50, 11) * M(11, 50)
      temp = temp + M(50, 12) * M(12, 50)
      temp = temp + M(50, 13) * M(13, 50)
      temp = temp + M(50, 14) * M(14, 50)
      temp = temp + M(50, 17) * M(17, 50)
      temp = temp + M(50, 18) * M(18, 50)
      temp = temp + M(50, 19) * M(19, 50)
      temp = temp + M(50, 22) * M(22, 50)
      temp = temp + M(50, 25) * M(25, 50)
      temp = temp + M(50, 30) * M(30, 50)
      temp = temp + M(50, 35) * M(35, 50)
      temp = temp + M(50, 40) * M(40, 50)
      temp = temp + M(50, 44) * M(44, 50)
      temp = temp + M(50, 48) * M(48, 50)
      temp = temp + M(50, 49) * M(49, 50)
      M(50, 50) = M(50, 50) - temp
C     Lower part.
      temp = M(51, 31) * M(31, 50)
      temp = temp + M(51, 32) * M(32, 50)
      temp = temp + M(51, 33) * M(33, 50)
      temp = temp + M(51, 48) * M(48, 50)
      temp = temp + M(51, 49) * M(49, 50)
      M(51, 50) = M(51, 50) - temp
C     Lower part.
      temp = M(52, 11) * M(11, 50)
      temp = temp + M(52, 12) * M(12, 50)
      temp = temp + M(52, 13) * M(13, 50)
      temp = temp + M(52, 14) * M(14, 50)
      temp = temp + M(52, 19) * M(19, 50)
      temp = temp + M(52, 25) * M(25, 50)
      temp = temp + M(52, 35) * M(35, 50)
      temp = temp + M(52, 40) * M(40, 50)
      temp = temp + M(52, 44) * M(44, 50)
      temp = temp + M(52, 48) * M(48, 50)
      temp = temp + M(52, 49) * M(49, 50)
      M(52, 50) = M(52, 50) - temp
C     Lower part.
      temp = M(53, 31) * M(31, 50)
      temp = temp + M(53, 32) * M(32, 50)
      temp = temp + M(53, 33) * M(33, 50)
      temp = temp + M(53, 38) * M(38, 50)
      temp = temp + M(53, 39) * M(39, 50)
      temp = temp + M(53, 41) * M(41, 50)
      temp = temp + M(53, 42) * M(42, 50)
      temp = temp + M(53, 43) * M(43, 50)
      temp = temp + M(53, 45) * M(45, 50)
      temp = temp + M(53, 49) * M(49, 50)
      M(53, 50) = M(53, 50) - temp
C     Lower part.
      temp = M(54, 25) * M(25, 50)
      temp = temp + M(54, 31) * M(31, 50)
      temp = temp + M(54, 32) * M(32, 50)
      temp = temp + M(54, 33) * M(33, 50)
      temp = temp + M(54, 48) * M(48, 50)
      temp = temp + M(54, 49) * M(49, 50)
      M(54, 50) = M(54, 50) - temp
C     Lower part.
      temp = M(55, 30) * M(30, 50)
      temp = temp + M(55, 48) * M(48, 50)
      temp = temp + M(55, 49) * M(49, 50)
      M(55, 50) = M(55, 50) - temp
C     Lower part.
      temp = M(56, 25) * M(25, 50)
      temp = temp + M(56, 48) * M(48, 50)
      temp = temp + M(56, 49) * M(49, 50)
      M(56, 50) = M(56, 50) - temp
C     Lower part.
      temp = M(57, 14) * M(14, 50)
      temp = temp + M(57, 38) * M(38, 50)
      temp = temp + M(57, 39) * M(39, 50)
      temp = temp + M(57, 40) * M(40, 50)
      temp = temp + M(57, 41) * M(41, 50)
      temp = temp + M(57, 44) * M(44, 50)
      temp = temp + M(57, 45) * M(45, 50)
      temp = temp + M(57, 46) * M(46, 50)
      temp = temp + M(57, 47) * M(47, 50)
      temp = temp + M(57, 48) * M(48, 50)
      temp = temp + M(57, 49) * M(49, 50)
      M(57, 50) = M(57, 50) - temp
C     Lower part.
      temp = M(58, 12) * M(12, 50)
      temp = temp + M(58, 13) * M(13, 50)
      temp = temp + M(58, 14) * M(14, 50)
      temp = temp + M(58, 19) * M(19, 50)
      temp = temp + M(58, 35) * M(35, 50)
      temp = temp + M(58, 40) * M(40, 50)
      temp = temp + M(58, 44) * M(44, 50)
      temp = temp + M(58, 49) * M(49, 50)
      M(58, 50) = M(58, 50) - temp
C     Lower part.
      temp = M(59, 13) * M(13, 50)
      temp = temp + M(59, 40) * M(40, 50)
      temp = temp + M(59, 41) * M(41, 50)
      temp = temp + M(59, 42) * M(42, 50)
      temp = temp + M(59, 44) * M(44, 50)
      temp = temp + M(59, 45) * M(45, 50)
      temp = temp + M(59, 46) * M(46, 50)
      temp = temp + M(59, 47) * M(47, 50)
      temp = temp + M(59, 48) * M(48, 50)
      temp = temp + M(59, 49) * M(49, 50)
      M(59, 50) = M(59, 50) - temp
C     Lower part.
      temp = M(60, 13) * M(13, 50)
      temp = temp + M(60, 14) * M(14, 50)
      temp = temp + M(60, 21) * M(21, 50)
      temp = temp + M(60, 40) * M(40, 50)
      temp = temp + M(60, 44) * M(44, 50)
      temp = temp + M(60, 49) * M(49, 50)
      M(60, 50) = M(60, 50) - temp
C     Lower part.
      temp = M(61, 13) * M(13, 50)
      temp = temp + M(61, 35) * M(35, 50)
      temp = temp + M(61, 38) * M(38, 50)
      temp = temp + M(61, 40) * M(40, 50)
      temp = temp + M(61, 41) * M(41, 50)
      temp = temp + M(61, 42) * M(42, 50)
      temp = temp + M(61, 44) * M(44, 50)
      temp = temp + M(61, 45) * M(45, 50)
      temp = temp + M(61, 46) * M(46, 50)
      temp = temp + M(61, 47) * M(47, 50)
      temp = temp + M(61, 48) * M(48, 50)
      temp = temp + M(61, 49) * M(49, 50)
      M(61, 50) = M(61, 50) - temp
C     Lower part.
      temp = M(62, 7) * M(7, 50)
      temp = temp + M(62, 11) * M(11, 50)
      temp = temp + M(62, 12) * M(12, 50)
      temp = temp + M(62, 13) * M(13, 50)
      temp = temp + M(62, 14) * M(14, 50)
      temp = temp + M(62, 17) * M(17, 50)
      temp = temp + M(62, 18) * M(18, 50)
      temp = temp + M(62, 19) * M(19, 50)
      temp = temp + M(62, 20) * M(20, 50)
      temp = temp + M(62, 21) * M(21, 50)
      temp = temp + M(62, 22) * M(22, 50)
      temp = temp + M(62, 23) * M(23, 50)
      temp = temp + M(62, 25) * M(25, 50)
      temp = temp + M(62, 26) * M(26, 50)
      temp = temp + M(62, 27) * M(27, 50)
      temp = temp + M(62, 28) * M(28, 50)
      temp = temp + M(62, 30) * M(30, 50)
      temp = temp + M(62, 35) * M(35, 50)
      temp = temp + M(62, 40) * M(40, 50)
      temp = temp + M(62, 44) * M(44, 50)
      temp = temp + M(62, 48) * M(48, 50)
      temp = temp + M(62, 49) * M(49, 50)
      M(62, 50) = M(62, 50) - temp
C     Lower part.
      temp = M(63, 12) * M(12, 50)
      temp = temp + M(63, 19) * M(19, 50)
      temp = temp + M(63, 20) * M(20, 50)
      temp = temp + M(63, 28) * M(28, 50)
      temp = temp + M(63, 31) * M(31, 50)
      temp = temp + M(63, 32) * M(32, 50)
      temp = temp + M(63, 33) * M(33, 50)
      temp = temp + M(63, 35) * M(35, 50)
      temp = temp + M(63, 38) * M(38, 50)
      temp = temp + M(63, 39) * M(39, 50)
      temp = temp + M(63, 40) * M(40, 50)
      temp = temp + M(63, 41) * M(41, 50)
      temp = temp + M(63, 42) * M(42, 50)
      temp = temp + M(63, 43) * M(43, 50)
      temp = temp + M(63, 44) * M(44, 50)
      temp = temp + M(63, 45) * M(45, 50)
      temp = temp + M(63, 46) * M(46, 50)
      temp = temp + M(63, 47) * M(47, 50)
      temp = temp + M(63, 48) * M(48, 50)
      temp = temp + M(63, 49) * M(49, 50)
      M(63, 50) = M(63, 50) - temp
C     Lower part.
      temp = M(65, 12) * M(12, 50)
      temp = temp + M(65, 19) * M(19, 50)
      temp = temp + M(65, 25) * M(25, 50)
      temp = temp + M(65, 26) * M(26, 50)
      temp = temp + M(65, 28) * M(28, 50)
      temp = temp + M(65, 30) * M(30, 50)
      temp = temp + M(65, 35) * M(35, 50)
      temp = temp + M(65, 48) * M(48, 50)
      temp = temp + M(65, 49) * M(49, 50)
      M(65, 50) = M(65, 50) - temp
C     Lower part.
      temp = M(66, 11) * M(11, 50)
      temp = temp + M(66, 12) * M(12, 50)
      temp = temp + M(66, 14) * M(14, 50)
      temp = temp + M(66, 19) * M(19, 50)
      temp = temp + M(66, 25) * M(25, 50)
      temp = temp + M(66, 26) * M(26, 50)
      temp = temp + M(66, 28) * M(28, 50)
      temp = temp + M(66, 31) * M(31, 50)
      temp = temp + M(66, 32) * M(32, 50)
      temp = temp + M(66, 33) * M(33, 50)
      temp = temp + M(66, 35) * M(35, 50)
      temp = temp + M(66, 38) * M(38, 50)
      temp = temp + M(66, 39) * M(39, 50)
      temp = temp + M(66, 40) * M(40, 50)
      temp = temp + M(66, 41) * M(41, 50)
      temp = temp + M(66, 42) * M(42, 50)
      temp = temp + M(66, 43) * M(43, 50)
      temp = temp + M(66, 44) * M(44, 50)
      temp = temp + M(66, 45) * M(45, 50)
      temp = temp + M(66, 46) * M(46, 50)
      temp = temp + M(66, 47) * M(47, 50)
      temp = temp + M(66, 48) * M(48, 50)
      temp = temp + M(66, 49) * M(49, 50)
      M(66, 50) = M(66, 50) - temp
C     Lower part.
      temp = M(67, 23) * M(23, 50)
      temp = temp + M(67, 30) * M(30, 50)
      temp = temp + M(67, 31) * M(31, 50)
      temp = temp + M(67, 32) * M(32, 50)
      temp = temp + M(67, 33) * M(33, 50)
      temp = temp + M(67, 35) * M(35, 50)
      temp = temp + M(67, 38) * M(38, 50)
      temp = temp + M(67, 39) * M(39, 50)
      temp = temp + M(67, 41) * M(41, 50)
      temp = temp + M(67, 42) * M(42, 50)
      temp = temp + M(67, 43) * M(43, 50)
      temp = temp + M(67, 45) * M(45, 50)
      temp = temp + M(67, 46) * M(46, 50)
      temp = temp + M(67, 47) * M(47, 50)
      temp = temp + M(67, 49) * M(49, 50)
      M(67, 50) = M(67, 50) - temp
C     Lower part.
      temp = M(68, 11) * M(11, 50)
      temp = temp + M(68, 12) * M(12, 50)
      temp = temp + M(68, 13) * M(13, 50)
      temp = temp + M(68, 14) * M(14, 50)
      temp = temp + M(68, 19) * M(19, 50)
      temp = temp + M(68, 25) * M(25, 50)
      temp = temp + M(68, 26) * M(26, 50)
      temp = temp + M(68, 30) * M(30, 50)
      temp = temp + M(68, 31) * M(31, 50)
      temp = temp + M(68, 32) * M(32, 50)
      temp = temp + M(68, 33) * M(33, 50)
      temp = temp + M(68, 35) * M(35, 50)
      temp = temp + M(68, 38) * M(38, 50)
      temp = temp + M(68, 39) * M(39, 50)
      temp = temp + M(68, 40) * M(40, 50)
      temp = temp + M(68, 41) * M(41, 50)
      temp = temp + M(68, 42) * M(42, 50)
      temp = temp + M(68, 43) * M(43, 50)
      temp = temp + M(68, 44) * M(44, 50)
      temp = temp + M(68, 45) * M(45, 50)
      temp = temp + M(68, 46) * M(46, 50)
      temp = temp + M(68, 47) * M(47, 50)
      temp = temp + M(68, 48) * M(48, 50)
      temp = temp + M(68, 49) * M(49, 50)
      M(68, 50) = M(68, 50) - temp
C     Lower part.
      temp = M(69, 12) * M(12, 50)
      temp = temp + M(69, 19) * M(19, 50)
      temp = temp + M(69, 25) * M(25, 50)
      temp = temp + M(69, 26) * M(26, 50)
      temp = temp + M(69, 28) * M(28, 50)
      temp = temp + M(69, 31) * M(31, 50)
      temp = temp + M(69, 32) * M(32, 50)
      temp = temp + M(69, 33) * M(33, 50)
      temp = temp + M(69, 35) * M(35, 50)
      temp = temp + M(69, 38) * M(38, 50)
      temp = temp + M(69, 39) * M(39, 50)
      temp = temp + M(69, 41) * M(41, 50)
      temp = temp + M(69, 42) * M(42, 50)
      temp = temp + M(69, 43) * M(43, 50)
      temp = temp + M(69, 45) * M(45, 50)
      temp = temp + M(69, 46) * M(46, 50)
      temp = temp + M(69, 47) * M(47, 50)
      temp = temp + M(69, 48) * M(48, 50)
      temp = temp + M(69, 49) * M(49, 50)
      M(69, 50) = M(69, 50) - temp
C     Lower part.
      temp = M(70, 25) * M(25, 50)
      temp = temp + M(70, 30) * M(30, 50)
      temp = temp + M(70, 31) * M(31, 50)
      temp = temp + M(70, 32) * M(32, 50)
      temp = temp + M(70, 39) * M(39, 50)
      temp = temp + M(70, 42) * M(42, 50)
      temp = temp + M(70, 43) * M(43, 50)
      temp = temp + M(70, 46) * M(46, 50)
      temp = temp + M(70, 47) * M(47, 50)
      temp = temp + M(70, 49) * M(49, 50)
      M(70, 50) = M(70, 50) - temp
C     Lower part.
      temp = M(71, 11) * M(11, 50)
      temp = temp + M(71, 12) * M(12, 50)
      temp = temp + M(71, 13) * M(13, 50)
      temp = temp + M(71, 14) * M(14, 50)
      temp = temp + M(71, 17) * M(17, 50)
      temp = temp + M(71, 18) * M(18, 50)
      temp = temp + M(71, 19) * M(19, 50)
      temp = temp + M(71, 22) * M(22, 50)
      temp = temp + M(71, 25) * M(25, 50)
      temp = temp + M(71, 27) * M(27, 50)
      temp = temp + M(71, 28) * M(28, 50)
      temp = temp + M(71, 30) * M(30, 50)
      temp = temp + M(71, 31) * M(31, 50)
      temp = temp + M(71, 32) * M(32, 50)
      temp = temp + M(71, 33) * M(33, 50)
      temp = temp + M(71, 35) * M(35, 50)
      temp = temp + M(71, 38) * M(38, 50)
      temp = temp + M(71, 39) * M(39, 50)
      temp = temp + M(71, 40) * M(40, 50)
      temp = temp + M(71, 41) * M(41, 50)
      temp = temp + M(71, 42) * M(42, 50)
      temp = temp + M(71, 43) * M(43, 50)
      temp = temp + M(71, 44) * M(44, 50)
      temp = temp + M(71, 45) * M(45, 50)
      temp = temp + M(71, 46) * M(46, 50)
      temp = temp + M(71, 47) * M(47, 50)
      temp = temp + M(71, 48) * M(48, 50)
      temp = temp + M(71, 49) * M(49, 50)
      M(71, 50) = M(71, 50) - temp
C     Lower part.
      temp = M(72, 17) * M(17, 50)
      temp = temp + M(72, 18) * M(18, 50)
      temp = temp + M(72, 22) * M(22, 50)
      temp = temp + M(72, 23) * M(23, 50)
      temp = temp + M(72, 25) * M(25, 50)
      temp = temp + M(72, 26) * M(26, 50)
      temp = temp + M(72, 30) * M(30, 50)
      temp = temp + M(72, 31) * M(31, 50)
      temp = temp + M(72, 32) * M(32, 50)
      temp = temp + M(72, 33) * M(33, 50)
      temp = temp + M(72, 35) * M(35, 50)
      temp = temp + M(72, 38) * M(38, 50)
      temp = temp + M(72, 39) * M(39, 50)
      temp = temp + M(72, 41) * M(41, 50)
      temp = temp + M(72, 42) * M(42, 50)
      temp = temp + M(72, 43) * M(43, 50)
      temp = temp + M(72, 45) * M(45, 50)
      temp = temp + M(72, 46) * M(46, 50)
      temp = temp + M(72, 47) * M(47, 50)
      temp = temp + M(72, 48) * M(48, 50)
      temp = temp + M(72, 49) * M(49, 50)
      M(72, 50) = M(72, 50) - temp
C     Upper part.
      temp = M(50, 25) * M(25, 56)
      M(50, 56) = ( M(50, 56) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 11) * M(11, 62)
      temp = temp + M(50, 12) * M(12, 62)
      temp = temp + M(50, 13) * M(13, 62)
      temp = temp + M(50, 14) * M(14, 62)
      temp = temp + M(50, 17) * M(17, 62)
      temp = temp + M(50, 18) * M(18, 62)
      temp = temp + M(50, 19) * M(19, 62)
      temp = temp + M(50, 22) * M(22, 62)
      temp = temp + M(50, 25) * M(25, 62)
      temp = temp + M(50, 30) * M(30, 62)
      temp = temp + M(50, 35) * M(35, 62)
      temp = temp + M(50, 40) * M(40, 62)
      temp = temp + M(50, 44) * M(44, 62)
      temp = temp + M(50, 48) * M(48, 62)
      temp = temp + M(50, 49) * M(49, 62)
      M(50, 62) = ( M(50, 62) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 40) * M(40, 63)
      temp = temp + M(50, 44) * M(44, 63)
      temp = temp + M(50, 48) * M(48, 63)
      temp = temp + M(50, 49) * M(49, 63)
      M(50, 63) = ( M(50, 63) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 35) * M(35, 67)
      temp = temp + M(50, 40) * M(40, 67)
      temp = temp + M(50, 44) * M(44, 67)
      temp = temp + M(50, 48) * M(48, 67)
      temp = temp + M(50, 49) * M(49, 67)
      M(50, 67) = ( M(50, 67) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 11) * M(11, 68)
      temp = temp + M(50, 12) * M(12, 68)
      temp = temp + M(50, 13) * M(13, 68)
      temp = temp + M(50, 14) * M(14, 68)
      temp = temp + M(50, 19) * M(19, 68)
      temp = temp + M(50, 25) * M(25, 68)
      temp = temp + M(50, 30) * M(30, 68)
      temp = temp + M(50, 35) * M(35, 68)
      temp = temp + M(50, 40) * M(40, 68)
      temp = temp + M(50, 44) * M(44, 68)
      temp = temp + M(50, 48) * M(48, 68)
      temp = temp + M(50, 49) * M(49, 68)
      M(50, 68) = ( M(50, 68) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 40) * M(40, 69)
      temp = temp + M(50, 44) * M(44, 69)
      temp = temp + M(50, 48) * M(48, 69)
      temp = temp + M(50, 49) * M(49, 69)
      M(50, 69) = ( M(50, 69) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 30) * M(30, 71)
      temp = temp + M(50, 40) * M(40, 71)
      temp = temp + M(50, 44) * M(44, 71)
      temp = temp + M(50, 48) * M(48, 71)
      temp = temp + M(50, 49) * M(49, 71)
      M(50, 71) = ( M(50, 71) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 17) * M(17, 72)
      temp = temp + M(50, 18) * M(18, 72)
      temp = temp + M(50, 22) * M(22, 72)
      temp = temp + M(50, 25) * M(25, 72)
      temp = temp + M(50, 30) * M(30, 72)
      temp = temp + M(50, 35) * M(35, 72)
      temp = temp + M(50, 40) * M(40, 72)
      temp = temp + M(50, 44) * M(44, 72)
      temp = temp + M(50, 48) * M(48, 72)
      temp = temp + M(50, 49) * M(49, 72)
      M(50, 72) = ( M(50, 72) - temp ) / M(50, 50)

C     Upper part.
      temp = M(51, 50) * M(50, 56)
      M(51, 56) = ( M(51, 56) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 2) * M(2, 62)
      temp = temp + M(51, 31) * M(31, 62)
      temp = temp + M(51, 32) * M(32, 62)
      temp = temp + M(51, 33) * M(33, 62)
      temp = temp + M(51, 48) * M(48, 62)
      temp = temp + M(51, 49) * M(49, 62)
      temp = temp + M(51, 50) * M(50, 62)
      M(51, 62) = ( M(51, 62) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 31) * M(31, 63)
      temp = temp + M(51, 32) * M(32, 63)
      temp = temp + M(51, 33) * M(33, 63)
      temp = temp + M(51, 48) * M(48, 63)
      temp = temp + M(51, 49) * M(49, 63)
      temp = temp + M(51, 50) * M(50, 63)
      M(51, 63) = ( M(51, 63) - temp ) / M(51, 51)
C     Upper part.
      M(51, 64) = M(51, 64) / M(51, 51)
C     Upper part.
      temp = M(51, 31) * M(31, 67)
      temp = temp + M(51, 32) * M(32, 67)
      temp = temp + M(51, 33) * M(33, 67)
      temp = temp + M(51, 48) * M(48, 67)
      temp = temp + M(51, 49) * M(49, 67)
      temp = temp + M(51, 50) * M(50, 67)
      M(51, 67) = ( M(51, 67) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 31) * M(31, 68)
      temp = temp + M(51, 32) * M(32, 68)
      temp = temp + M(51, 33) * M(33, 68)
      temp = temp + M(51, 48) * M(48, 68)
      temp = temp + M(51, 49) * M(49, 68)
      temp = temp + M(51, 50) * M(50, 68)
      M(51, 68) = ( M(51, 68) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 31) * M(31, 69)
      temp = temp + M(51, 32) * M(32, 69)
      temp = temp + M(51, 33) * M(33, 69)
      temp = temp + M(51, 48) * M(48, 69)
      temp = temp + M(51, 49) * M(49, 69)
      temp = temp + M(51, 50) * M(50, 69)
      M(51, 69) = ( M(51, 69) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 31) * M(31, 71)
      temp = temp + M(51, 32) * M(32, 71)
      temp = temp + M(51, 33) * M(33, 71)
      temp = temp + M(51, 48) * M(48, 71)
      temp = temp + M(51, 49) * M(49, 71)
      temp = temp + M(51, 50) * M(50, 71)
      M(51, 71) = ( M(51, 71) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 31) * M(31, 72)
      temp = temp + M(51, 32) * M(32, 72)
      temp = temp + M(51, 33) * M(33, 72)
      temp = temp + M(51, 48) * M(48, 72)
      temp = temp + M(51, 49) * M(49, 72)
      temp = temp + M(51, 50) * M(50, 72)
      M(51, 72) = ( M(51, 72) - temp ) / M(51, 51)

C     Upper part.
      M(52, 54) = M(52, 54) / M(52, 52)
C     Upper part.
      temp = M(52, 25) * M(25, 56)
      temp = temp + M(52, 50) * M(50, 56)
      temp = temp + M(52, 51) * M(51, 56)
      M(52, 56) = ( M(52, 56) - temp ) / M(52, 52)
C     Upper part.
      M(52, 61) = M(52, 61) / M(52, 52)
C     Upper part.
      temp = M(52, 2) * M(2, 62)
      temp = temp + M(52, 11) * M(11, 62)
      temp = temp + M(52, 12) * M(12, 62)
      temp = temp + M(52, 13) * M(13, 62)
      temp = temp + M(52, 14) * M(14, 62)
      temp = temp + M(52, 19) * M(19, 62)
      temp = temp + M(52, 25) * M(25, 62)
      temp = temp + M(52, 35) * M(35, 62)
      temp = temp + M(52, 40) * M(40, 62)
      temp = temp + M(52, 44) * M(44, 62)
      temp = temp + M(52, 48) * M(48, 62)
      temp = temp + M(52, 49) * M(49, 62)
      temp = temp + M(52, 50) * M(50, 62)
      temp = temp + M(52, 51) * M(51, 62)
      M(52, 62) = ( M(52, 62) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 40) * M(40, 63)
      temp = temp + M(52, 44) * M(44, 63)
      temp = temp + M(52, 48) * M(48, 63)
      temp = temp + M(52, 49) * M(49, 63)
      temp = temp + M(52, 50) * M(50, 63)
      temp = temp + M(52, 51) * M(51, 63)
      M(52, 63) = ( M(52, 63) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 51) * M(51, 64)
      M(52, 64) = ( M(52, 64) - temp ) / M(52, 52)
C     Upper part.
      M(52, 66) = M(52, 66) / M(52, 52)
C     Upper part.
      temp = M(52, 35) * M(35, 67)
      temp = temp + M(52, 40) * M(40, 67)
      temp = temp + M(52, 44) * M(44, 67)
      temp = temp + M(52, 48) * M(48, 67)
      temp = temp + M(52, 49) * M(49, 67)
      temp = temp + M(52, 50) * M(50, 67)
      temp = temp + M(52, 51) * M(51, 67)
      M(52, 67) = ( M(52, 67) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 11) * M(11, 68)
      temp = temp + M(52, 12) * M(12, 68)
      temp = temp + M(52, 13) * M(13, 68)
      temp = temp + M(52, 14) * M(14, 68)
      temp = temp + M(52, 19) * M(19, 68)
      temp = temp + M(52, 25) * M(25, 68)
      temp = temp + M(52, 35) * M(35, 68)
      temp = temp + M(52, 40) * M(40, 68)
      temp = temp + M(52, 44) * M(44, 68)
      temp = temp + M(52, 48) * M(48, 68)
      temp = temp + M(52, 49) * M(49, 68)
      temp = temp + M(52, 50) * M(50, 68)
      temp = temp + M(52, 51) * M(51, 68)
      M(52, 68) = ( M(52, 68) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 40) * M(40, 69)
      temp = temp + M(52, 44) * M(44, 69)
      temp = temp + M(52, 48) * M(48, 69)
      temp = temp + M(52, 49) * M(49, 69)
      temp = temp + M(52, 50) * M(50, 69)
      temp = temp + M(52, 51) * M(51, 69)
      M(52, 69) = ( M(52, 69) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 40) * M(40, 71)
      temp = temp + M(52, 44) * M(44, 71)
      temp = temp + M(52, 48) * M(48, 71)
      temp = temp + M(52, 49) * M(49, 71)
      temp = temp + M(52, 50) * M(50, 71)
      temp = temp + M(52, 51) * M(51, 71)
      M(52, 71) = ( M(52, 71) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 25) * M(25, 72)
      temp = temp + M(52, 35) * M(35, 72)
      temp = temp + M(52, 40) * M(40, 72)
      temp = temp + M(52, 44) * M(44, 72)
      temp = temp + M(52, 48) * M(48, 72)
      temp = temp + M(52, 49) * M(49, 72)
      temp = temp + M(52, 50) * M(50, 72)
      temp = temp + M(52, 51) * M(51, 72)
      M(52, 72) = ( M(52, 72) - temp ) / M(52, 52)

C     Upper part.
      temp = M(53, 50) * M(50, 56)
      M(53, 56) = ( M(53, 56) - temp ) / M(53, 53)
C     Upper part.
      M(53, 58) = M(53, 58) / M(53, 53)
C     Upper part.
      M(53, 60) = M(53, 60) / M(53, 53)
C     Upper part.
      temp = M(53, 31) * M(31, 62)
      temp = temp + M(53, 32) * M(32, 62)
      temp = temp + M(53, 33) * M(33, 62)
      temp = temp + M(53, 36) * M(36, 62)
      temp = temp + M(53, 37) * M(37, 62)
      temp = temp + M(53, 38) * M(38, 62)
      temp = temp + M(53, 39) * M(39, 62)
      temp = temp + M(53, 41) * M(41, 62)
      temp = temp + M(53, 42) * M(42, 62)
      temp = temp + M(53, 43) * M(43, 62)
      temp = temp + M(53, 45) * M(45, 62)
      temp = temp + M(53, 49) * M(49, 62)
      temp = temp + M(53, 50) * M(50, 62)
      M(53, 62) = ( M(53, 62) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 31) * M(31, 63)
      temp = temp + M(53, 32) * M(32, 63)
      temp = temp + M(53, 33) * M(33, 63)
      temp = temp + M(53, 36) * M(36, 63)
      temp = temp + M(53, 37) * M(37, 63)
      temp = temp + M(53, 38) * M(38, 63)
      temp = temp + M(53, 39) * M(39, 63)
      temp = temp + M(53, 41) * M(41, 63)
      temp = temp + M(53, 42) * M(42, 63)
      temp = temp + M(53, 43) * M(43, 63)
      temp = temp + M(53, 45) * M(45, 63)
      temp = temp + M(53, 49) * M(49, 63)
      temp = temp + M(53, 50) * M(50, 63)
      M(53, 63) = ( M(53, 63) - temp ) / M(53, 53)
C     Upper part.
      M(53, 64) = M(53, 64) / M(53, 53)
C     Upper part.
      M(53, 65) = M(53, 65) / M(53, 53)
C     Upper part.
      temp = M(53, 31) * M(31, 67)
      temp = temp + M(53, 32) * M(32, 67)
      temp = temp + M(53, 33) * M(33, 67)
      temp = temp + M(53, 36) * M(36, 67)
      temp = temp + M(53, 37) * M(37, 67)
      temp = temp + M(53, 38) * M(38, 67)
      temp = temp + M(53, 39) * M(39, 67)
      temp = temp + M(53, 41) * M(41, 67)
      temp = temp + M(53, 42) * M(42, 67)
      temp = temp + M(53, 43) * M(43, 67)
      temp = temp + M(53, 45) * M(45, 67)
      temp = temp + M(53, 49) * M(49, 67)
      temp = temp + M(53, 50) * M(50, 67)
      M(53, 67) = ( M(53, 67) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 31) * M(31, 68)
      temp = temp + M(53, 32) * M(32, 68)
      temp = temp + M(53, 33) * M(33, 68)
      temp = temp + M(53, 36) * M(36, 68)
      temp = temp + M(53, 37) * M(37, 68)
      temp = temp + M(53, 38) * M(38, 68)
      temp = temp + M(53, 39) * M(39, 68)
      temp = temp + M(53, 41) * M(41, 68)
      temp = temp + M(53, 42) * M(42, 68)
      temp = temp + M(53, 43) * M(43, 68)
      temp = temp + M(53, 45) * M(45, 68)
      temp = temp + M(53, 49) * M(49, 68)
      temp = temp + M(53, 50) * M(50, 68)
      M(53, 68) = ( M(53, 68) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 31) * M(31, 69)
      temp = temp + M(53, 32) * M(32, 69)
      temp = temp + M(53, 33) * M(33, 69)
      temp = temp + M(53, 36) * M(36, 69)
      temp = temp + M(53, 37) * M(37, 69)
      temp = temp + M(53, 38) * M(38, 69)
      temp = temp + M(53, 39) * M(39, 69)
      temp = temp + M(53, 41) * M(41, 69)
      temp = temp + M(53, 42) * M(42, 69)
      temp = temp + M(53, 43) * M(43, 69)
      temp = temp + M(53, 45) * M(45, 69)
      temp = temp + M(53, 49) * M(49, 69)
      temp = temp + M(53, 50) * M(50, 69)
      M(53, 69) = ( M(53, 69) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 31) * M(31, 71)
      temp = temp + M(53, 32) * M(32, 71)
      temp = temp + M(53, 33) * M(33, 71)
      temp = temp + M(53, 36) * M(36, 71)
      temp = temp + M(53, 37) * M(37, 71)
      temp = temp + M(53, 38) * M(38, 71)
      temp = temp + M(53, 39) * M(39, 71)
      temp = temp + M(53, 41) * M(41, 71)
      temp = temp + M(53, 42) * M(42, 71)
      temp = temp + M(53, 43) * M(43, 71)
      temp = temp + M(53, 45) * M(45, 71)
      temp = temp + M(53, 49) * M(49, 71)
      temp = temp + M(53, 50) * M(50, 71)
      M(53, 71) = ( M(53, 71) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 31) * M(31, 72)
      temp = temp + M(53, 32) * M(32, 72)
      temp = temp + M(53, 33) * M(33, 72)
      temp = temp + M(53, 39) * M(39, 72)
      temp = temp + M(53, 41) * M(41, 72)
      temp = temp + M(53, 45) * M(45, 72)
      temp = temp + M(53, 49) * M(49, 72)
      temp = temp + M(53, 50) * M(50, 72)
      M(53, 72) = ( M(53, 72) - temp ) / M(53, 53)

C     Lower part.
      temp = M(62, 52) * M(52, 54)
      M(62, 54) = M(62, 54) - temp
C     Lower part.
      temp = M(71, 52) * M(52, 54)
      M(71, 54) = M(71, 54) - temp
C     Upper part.
      temp = M(54, 25) * M(25, 56)
      temp = temp + M(54, 50) * M(50, 56)
      M(54, 56) = ( M(54, 56) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 24) * M(24, 58)
      M(54, 58) = ( M(54, 58) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 24) * M(24, 62)
      temp = temp + M(54, 25) * M(25, 62)
      temp = temp + M(54, 31) * M(31, 62)
      temp = temp + M(54, 32) * M(32, 62)
      temp = temp + M(54, 33) * M(33, 62)
      temp = temp + M(54, 48) * M(48, 62)
      temp = temp + M(54, 49) * M(49, 62)
      temp = temp + M(54, 50) * M(50, 62)
      M(54, 62) = ( M(54, 62) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 24) * M(24, 63)
      temp = temp + M(54, 31) * M(31, 63)
      temp = temp + M(54, 32) * M(32, 63)
      temp = temp + M(54, 33) * M(33, 63)
      temp = temp + M(54, 48) * M(48, 63)
      temp = temp + M(54, 49) * M(49, 63)
      temp = temp + M(54, 50) * M(50, 63)
      M(54, 63) = ( M(54, 63) - temp ) / M(54, 54)
C     Upper part.
      M(54, 64) = M(54, 64) / M(54, 54)
C     Upper part.
      temp = M(54, 31) * M(31, 67)
      temp = temp + M(54, 32) * M(32, 67)
      temp = temp + M(54, 33) * M(33, 67)
      temp = temp + M(54, 48) * M(48, 67)
      temp = temp + M(54, 49) * M(49, 67)
      temp = temp + M(54, 50) * M(50, 67)
      M(54, 67) = ( M(54, 67) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 25) * M(25, 68)
      temp = temp + M(54, 31) * M(31, 68)
      temp = temp + M(54, 32) * M(32, 68)
      temp = temp + M(54, 33) * M(33, 68)
      temp = temp + M(54, 48) * M(48, 68)
      temp = temp + M(54, 49) * M(49, 68)
      temp = temp + M(54, 50) * M(50, 68)
      M(54, 68) = ( M(54, 68) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 31) * M(31, 69)
      temp = temp + M(54, 32) * M(32, 69)
      temp = temp + M(54, 33) * M(33, 69)
      temp = temp + M(54, 48) * M(48, 69)
      temp = temp + M(54, 49) * M(49, 69)
      temp = temp + M(54, 50) * M(50, 69)
      M(54, 69) = ( M(54, 69) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 31) * M(31, 71)
      temp = temp + M(54, 32) * M(32, 71)
      temp = temp + M(54, 33) * M(33, 71)
      temp = temp + M(54, 48) * M(48, 71)
      temp = temp + M(54, 49) * M(49, 71)
      temp = temp + M(54, 50) * M(50, 71)
      M(54, 71) = ( M(54, 71) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 25) * M(25, 72)
      temp = temp + M(54, 31) * M(31, 72)
      temp = temp + M(54, 32) * M(32, 72)
      temp = temp + M(54, 33) * M(33, 72)
      temp = temp + M(54, 48) * M(48, 72)
      temp = temp + M(54, 49) * M(49, 72)
      temp = temp + M(54, 50) * M(50, 72)
      M(54, 72) = ( M(54, 72) - temp ) / M(54, 54)

C     Upper part.
      temp = M(55, 50) * M(50, 56)
      temp = temp + M(55, 51) * M(51, 56)
      temp = temp + M(55, 54) * M(54, 56)
      M(55, 56) = ( M(55, 56) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 54) * M(54, 58)
      M(55, 58) = ( M(55, 58) - temp ) / M(55, 55)
C     Upper part.
      M(55, 61) = M(55, 61) / M(55, 55)
C     Upper part.
      temp = M(55, 30) * M(30, 62)
      temp = temp + M(55, 48) * M(48, 62)
      temp = temp + M(55, 49) * M(49, 62)
      temp = temp + M(55, 50) * M(50, 62)
      temp = temp + M(55, 51) * M(51, 62)
      temp = temp + M(55, 54) * M(54, 62)
      M(55, 62) = ( M(55, 62) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 48) * M(48, 63)
      temp = temp + M(55, 49) * M(49, 63)
      temp = temp + M(55, 50) * M(50, 63)
      temp = temp + M(55, 51) * M(51, 63)
      temp = temp + M(55, 54) * M(54, 63)
      M(55, 63) = ( M(55, 63) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 51) * M(51, 64)
      temp = temp + M(55, 54) * M(54, 64)
      M(55, 64) = ( M(55, 64) - temp ) / M(55, 55)
C     Upper part.
      M(55, 66) = M(55, 66) / M(55, 55)
C     Upper part.
      temp = M(55, 48) * M(48, 67)
      temp = temp + M(55, 49) * M(49, 67)
      temp = temp + M(55, 50) * M(50, 67)
      temp = temp + M(55, 51) * M(51, 67)
      temp = temp + M(55, 54) * M(54, 67)
      M(55, 67) = ( M(55, 67) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 30) * M(30, 68)
      temp = temp + M(55, 48) * M(48, 68)
      temp = temp + M(55, 49) * M(49, 68)
      temp = temp + M(55, 50) * M(50, 68)
      temp = temp + M(55, 51) * M(51, 68)
      temp = temp + M(55, 54) * M(54, 68)
      M(55, 68) = ( M(55, 68) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 48) * M(48, 69)
      temp = temp + M(55, 49) * M(49, 69)
      temp = temp + M(55, 50) * M(50, 69)
      temp = temp + M(55, 51) * M(51, 69)
      temp = temp + M(55, 54) * M(54, 69)
      M(55, 69) = ( M(55, 69) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 30) * M(30, 71)
      temp = temp + M(55, 48) * M(48, 71)
      temp = temp + M(55, 49) * M(49, 71)
      temp = temp + M(55, 50) * M(50, 71)
      temp = temp + M(55, 51) * M(51, 71)
      temp = temp + M(55, 54) * M(54, 71)
      M(55, 71) = ( M(55, 71) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 30) * M(30, 72)
      temp = temp + M(55, 48) * M(48, 72)
      temp = temp + M(55, 49) * M(49, 72)
      temp = temp + M(55, 50) * M(50, 72)
      temp = temp + M(55, 51) * M(51, 72)
      temp = temp + M(55, 54) * M(54, 72)
      M(55, 72) = ( M(55, 72) - temp ) / M(55, 55)

C     Lower part.
      temp = M(56, 25) * M(25, 56)
      temp = temp + M(56, 50) * M(50, 56)
      M(56, 56) = M(56, 56) - temp
C     Lower part.
      temp = M(57, 50) * M(50, 56)
      M(57, 56) = M(57, 56) - temp
C     Lower part.
      temp = M(58, 50) * M(50, 56)
      M(58, 56) = M(58, 56) - temp
C     Lower part.
      temp = M(59, 50) * M(50, 56)
      temp = temp + M(59, 53) * M(53, 56)
      M(59, 56) = M(59, 56) - temp
C     Lower part.
      temp = M(60, 50) * M(50, 56)
      M(60, 56) = M(60, 56) - temp
C     Lower part.
      temp = M(61, 50) * M(50, 56)
      temp = temp + M(61, 53) * M(53, 56)
      M(61, 56) = M(61, 56) - temp
C     Lower part.
      temp = M(62, 25) * M(25, 56)
      temp = temp + M(62, 26) * M(26, 56)
      temp = temp + M(62, 50) * M(50, 56)
      temp = temp + M(62, 51) * M(51, 56)
      temp = temp + M(62, 52) * M(52, 56)
      temp = temp + M(62, 53) * M(53, 56)
      temp = temp + M(62, 54) * M(54, 56)
      temp = temp + M(62, 55) * M(55, 56)
      M(62, 56) = M(62, 56) - temp
C     Lower part.
      temp = M(63, 50) * M(50, 56)
      M(63, 56) = M(63, 56) - temp
C     Lower part.
      temp = M(64, 53) * M(53, 56)
      M(64, 56) = M(64, 56) - temp
C     Lower part.
      temp = M(65, 25) * M(25, 56)
      temp = temp + M(65, 26) * M(26, 56)
      temp = temp + M(65, 50) * M(50, 56)
      temp = temp + M(65, 53) * M(53, 56)
      M(65, 56) = M(65, 56) - temp
C     Lower part.
      temp = M(66, 25) * M(25, 56)
      temp = temp + M(66, 26) * M(26, 56)
      temp = temp + M(66, 50) * M(50, 56)
      temp = temp + M(66, 51) * M(51, 56)
      M(66, 56) = M(66, 56) - temp
C     Lower part.
      temp = M(67, 50) * M(50, 56)
      M(67, 56) = M(67, 56) - temp
C     Lower part.
      temp = M(68, 25) * M(25, 56)
      temp = temp + M(68, 26) * M(26, 56)
      temp = temp + M(68, 50) * M(50, 56)
      temp = temp + M(68, 51) * M(51, 56)
      temp = temp + M(68, 54) * M(54, 56)
      temp = temp + M(68, 55) * M(55, 56)
      M(68, 56) = M(68, 56) - temp
C     Lower part.
      temp = M(69, 25) * M(25, 56)
      temp = temp + M(69, 26) * M(26, 56)
      temp = temp + M(69, 50) * M(50, 56)
      temp = temp + M(69, 54) * M(54, 56)
      M(69, 56) = M(69, 56) - temp
C     Lower part.
      temp = M(70, 25) * M(25, 56)
      temp = temp + M(70, 50) * M(50, 56)
      M(70, 56) = M(70, 56) - temp
C     Lower part.
      temp = M(71, 25) * M(25, 56)
      temp = temp + M(71, 50) * M(50, 56)
      temp = temp + M(71, 51) * M(51, 56)
      temp = temp + M(71, 52) * M(52, 56)
      temp = temp + M(71, 53) * M(53, 56)
      temp = temp + M(71, 54) * M(54, 56)
      M(71, 56) = M(71, 56) - temp
C     Lower part.
      temp = M(72, 25) * M(25, 56)
      temp = temp + M(72, 26) * M(26, 56)
      temp = temp + M(72, 50) * M(50, 56)
      temp = temp + M(72, 55) * M(55, 56)
      M(72, 56) = M(72, 56) - temp
C     Upper part.
      temp = M(56, 25) * M(25, 62)
      temp = temp + M(56, 48) * M(48, 62)
      temp = temp + M(56, 49) * M(49, 62)
      temp = temp + M(56, 50) * M(50, 62)
      M(56, 62) = ( M(56, 62) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 48) * M(48, 63)
      temp = temp + M(56, 49) * M(49, 63)
      temp = temp + M(56, 50) * M(50, 63)
      M(56, 63) = ( M(56, 63) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 48) * M(48, 67)
      temp = temp + M(56, 49) * M(49, 67)
      temp = temp + M(56, 50) * M(50, 67)
      M(56, 67) = ( M(56, 67) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 25) * M(25, 68)
      temp = temp + M(56, 48) * M(48, 68)
      temp = temp + M(56, 49) * M(49, 68)
      temp = temp + M(56, 50) * M(50, 68)
      M(56, 68) = ( M(56, 68) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 48) * M(48, 69)
      temp = temp + M(56, 49) * M(49, 69)
      temp = temp + M(56, 50) * M(50, 69)
      M(56, 69) = ( M(56, 69) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 48) * M(48, 71)
      temp = temp + M(56, 49) * M(49, 71)
      temp = temp + M(56, 50) * M(50, 71)
      M(56, 71) = ( M(56, 71) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 25) * M(25, 72)
      temp = temp + M(56, 48) * M(48, 72)
      temp = temp + M(56, 49) * M(49, 72)
      temp = temp + M(56, 50) * M(50, 72)
      M(56, 72) = ( M(56, 72) - temp ) / M(56, 56)

C     Upper part.
      M(57, 58) = M(57, 58) / M(57, 57)
C     Upper part.
      M(57, 60) = M(57, 60) / M(57, 57)
C     Upper part.
      temp = M(57, 14) * M(14, 62)
      temp = temp + M(57, 36) * M(36, 62)
      temp = temp + M(57, 37) * M(37, 62)
      temp = temp + M(57, 38) * M(38, 62)
      temp = temp + M(57, 39) * M(39, 62)
      temp = temp + M(57, 40) * M(40, 62)
      temp = temp + M(57, 41) * M(41, 62)
      temp = temp + M(57, 44) * M(44, 62)
      temp = temp + M(57, 45) * M(45, 62)
      temp = temp + M(57, 46) * M(46, 62)
      temp = temp + M(57, 47) * M(47, 62)
      temp = temp + M(57, 48) * M(48, 62)
      temp = temp + M(57, 49) * M(49, 62)
      temp = temp + M(57, 50) * M(50, 62)
      temp = temp + M(57, 56) * M(56, 62)
      M(57, 62) = ( M(57, 62) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 36) * M(36, 63)
      temp = temp + M(57, 37) * M(37, 63)
      temp = temp + M(57, 38) * M(38, 63)
      temp = temp + M(57, 39) * M(39, 63)
      temp = temp + M(57, 40) * M(40, 63)
      temp = temp + M(57, 41) * M(41, 63)
      temp = temp + M(57, 44) * M(44, 63)
      temp = temp + M(57, 45) * M(45, 63)
      temp = temp + M(57, 46) * M(46, 63)
      temp = temp + M(57, 47) * M(47, 63)
      temp = temp + M(57, 48) * M(48, 63)
      temp = temp + M(57, 49) * M(49, 63)
      temp = temp + M(57, 50) * M(50, 63)
      temp = temp + M(57, 56) * M(56, 63)
      M(57, 63) = ( M(57, 63) - temp ) / M(57, 57)
C     Upper part.
      M(57, 64) = M(57, 64) / M(57, 57)
C     Upper part.
      temp = M(57, 36) * M(36, 67)
      temp = temp + M(57, 37) * M(37, 67)
      temp = temp + M(57, 38) * M(38, 67)
      temp = temp + M(57, 39) * M(39, 67)
      temp = temp + M(57, 40) * M(40, 67)
      temp = temp + M(57, 41) * M(41, 67)
      temp = temp + M(57, 44) * M(44, 67)
      temp = temp + M(57, 45) * M(45, 67)
      temp = temp + M(57, 46) * M(46, 67)
      temp = temp + M(57, 47) * M(47, 67)
      temp = temp + M(57, 48) * M(48, 67)
      temp = temp + M(57, 49) * M(49, 67)
      temp = temp + M(57, 50) * M(50, 67)
      temp = temp + M(57, 56) * M(56, 67)
      M(57, 67) = ( M(57, 67) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 14) * M(14, 68)
      temp = temp + M(57, 36) * M(36, 68)
      temp = temp + M(57, 37) * M(37, 68)
      temp = temp + M(57, 38) * M(38, 68)
      temp = temp + M(57, 39) * M(39, 68)
      temp = temp + M(57, 40) * M(40, 68)
      temp = temp + M(57, 41) * M(41, 68)
      temp = temp + M(57, 44) * M(44, 68)
      temp = temp + M(57, 45) * M(45, 68)
      temp = temp + M(57, 46) * M(46, 68)
      temp = temp + M(57, 47) * M(47, 68)
      temp = temp + M(57, 48) * M(48, 68)
      temp = temp + M(57, 49) * M(49, 68)
      temp = temp + M(57, 50) * M(50, 68)
      temp = temp + M(57, 56) * M(56, 68)
      M(57, 68) = ( M(57, 68) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 36) * M(36, 69)
      temp = temp + M(57, 37) * M(37, 69)
      temp = temp + M(57, 38) * M(38, 69)
      temp = temp + M(57, 39) * M(39, 69)
      temp = temp + M(57, 40) * M(40, 69)
      temp = temp + M(57, 41) * M(41, 69)
      temp = temp + M(57, 44) * M(44, 69)
      temp = temp + M(57, 45) * M(45, 69)
      temp = temp + M(57, 46) * M(46, 69)
      temp = temp + M(57, 47) * M(47, 69)
      temp = temp + M(57, 48) * M(48, 69)
      temp = temp + M(57, 49) * M(49, 69)
      temp = temp + M(57, 50) * M(50, 69)
      temp = temp + M(57, 56) * M(56, 69)
      M(57, 69) = ( M(57, 69) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 36) * M(36, 71)
      temp = temp + M(57, 37) * M(37, 71)
      temp = temp + M(57, 38) * M(38, 71)
      temp = temp + M(57, 39) * M(39, 71)
      temp = temp + M(57, 40) * M(40, 71)
      temp = temp + M(57, 41) * M(41, 71)
      temp = temp + M(57, 44) * M(44, 71)
      temp = temp + M(57, 45) * M(45, 71)
      temp = temp + M(57, 46) * M(46, 71)
      temp = temp + M(57, 47) * M(47, 71)
      temp = temp + M(57, 48) * M(48, 71)
      temp = temp + M(57, 49) * M(49, 71)
      temp = temp + M(57, 50) * M(50, 71)
      temp = temp + M(57, 56) * M(56, 71)
      M(57, 71) = ( M(57, 71) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 39) * M(39, 72)
      temp = temp + M(57, 40) * M(40, 72)
      temp = temp + M(57, 41) * M(41, 72)
      temp = temp + M(57, 44) * M(44, 72)
      temp = temp + M(57, 45) * M(45, 72)
      temp = temp + M(57, 46) * M(46, 72)
      temp = temp + M(57, 47) * M(47, 72)
      temp = temp + M(57, 48) * M(48, 72)
      temp = temp + M(57, 49) * M(49, 72)
      temp = temp + M(57, 50) * M(50, 72)
      temp = temp + M(57, 56) * M(56, 72)
      M(57, 72) = ( M(57, 72) - temp ) / M(57, 57)

C     Lower part.
      temp = M(59, 53) * M(53, 58)
      M(59, 58) = M(59, 58) - temp
C     Lower part.
      temp = M(61, 53) * M(53, 58)
      M(61, 58) = M(61, 58) - temp
C     Lower part.
      temp = M(62, 24) * M(24, 58)
      temp = temp + M(62, 53) * M(53, 58)
      temp = temp + M(62, 54) * M(54, 58)
      temp = temp + M(62, 55) * M(55, 58)
      M(62, 58) = M(62, 58) - temp
C     Lower part.
      temp = M(64, 53) * M(53, 58)
      M(64, 58) = M(64, 58) - temp
C     Lower part.
      temp = M(65, 53) * M(53, 58)
      M(65, 58) = M(65, 58) - temp
C     Lower part.
      temp = M(66, 24) * M(24, 58)
      M(66, 58) = M(66, 58) - temp
C     Lower part.
      temp = M(68, 54) * M(54, 58)
      temp = temp + M(68, 55) * M(55, 58)
      M(68, 58) = M(68, 58) - temp
C     Lower part.
      temp = M(69, 24) * M(24, 58)
      temp = temp + M(69, 54) * M(54, 58)
      M(69, 58) = M(69, 58) - temp
C     Lower part.
      temp = M(71, 24) * M(24, 58)
      temp = temp + M(71, 53) * M(53, 58)
      temp = temp + M(71, 54) * M(54, 58)
      M(71, 58) = M(71, 58) - temp
C     Lower part.
      temp = M(72, 55) * M(55, 58)
      M(72, 58) = M(72, 58) - temp
C     Upper part.
      M(58, 59) = M(58, 59) / M(58, 58)
C     Upper part.
      temp = M(58, 12) * M(12, 62)
      temp = temp + M(58, 13) * M(13, 62)
      temp = temp + M(58, 14) * M(14, 62)
      temp = temp + M(58, 19) * M(19, 62)
      temp = temp + M(58, 35) * M(35, 62)
      temp = temp + M(58, 40) * M(40, 62)
      temp = temp + M(58, 44) * M(44, 62)
      temp = temp + M(58, 49) * M(49, 62)
      temp = temp + M(58, 50) * M(50, 62)
      temp = temp + M(58, 56) * M(56, 62)
      M(58, 62) = ( M(58, 62) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 40) * M(40, 63)
      temp = temp + M(58, 44) * M(44, 63)
      temp = temp + M(58, 49) * M(49, 63)
      temp = temp + M(58, 50) * M(50, 63)
      temp = temp + M(58, 56) * M(56, 63)
      M(58, 63) = ( M(58, 63) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 35) * M(35, 67)
      temp = temp + M(58, 40) * M(40, 67)
      temp = temp + M(58, 44) * M(44, 67)
      temp = temp + M(58, 49) * M(49, 67)
      temp = temp + M(58, 50) * M(50, 67)
      temp = temp + M(58, 56) * M(56, 67)
      M(58, 67) = ( M(58, 67) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 12) * M(12, 68)
      temp = temp + M(58, 13) * M(13, 68)
      temp = temp + M(58, 14) * M(14, 68)
      temp = temp + M(58, 19) * M(19, 68)
      temp = temp + M(58, 35) * M(35, 68)
      temp = temp + M(58, 40) * M(40, 68)
      temp = temp + M(58, 44) * M(44, 68)
      temp = temp + M(58, 49) * M(49, 68)
      temp = temp + M(58, 50) * M(50, 68)
      temp = temp + M(58, 56) * M(56, 68)
      M(58, 68) = ( M(58, 68) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 40) * M(40, 69)
      temp = temp + M(58, 44) * M(44, 69)
      temp = temp + M(58, 49) * M(49, 69)
      temp = temp + M(58, 50) * M(50, 69)
      temp = temp + M(58, 56) * M(56, 69)
      M(58, 69) = ( M(58, 69) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 40) * M(40, 71)
      temp = temp + M(58, 44) * M(44, 71)
      temp = temp + M(58, 49) * M(49, 71)
      temp = temp + M(58, 50) * M(50, 71)
      temp = temp + M(58, 56) * M(56, 71)
      M(58, 71) = ( M(58, 71) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 35) * M(35, 72)
      temp = temp + M(58, 40) * M(40, 72)
      temp = temp + M(58, 44) * M(44, 72)
      temp = temp + M(58, 49) * M(49, 72)
      temp = temp + M(58, 50) * M(50, 72)
      temp = temp + M(58, 56) * M(56, 72)
      M(58, 72) = ( M(58, 72) - temp ) / M(58, 58)

C     Lower part.
      temp = M(59, 58) * M(58, 59)
      M(59, 59) = M(59, 59) - temp
C     Lower part.
      temp = M(61, 58) * M(58, 59)
      M(61, 59) = M(61, 59) - temp
C     Lower part.
      temp = M(62, 58) * M(58, 59)
      M(62, 59) = M(62, 59) - temp
C     Lower part.
      temp = M(63, 58) * M(58, 59)
      M(63, 59) = M(63, 59) - temp
C     Lower part.
      temp = M(64, 58) * M(58, 59)
      M(64, 59) = M(64, 59) - temp
C     Lower part.
      temp = M(65, 58) * M(58, 59)
      M(65, 59) = M(65, 59) - temp
C     Lower part.
      temp = M(66, 58) * M(58, 59)
      M(66, 59) = M(66, 59) - temp
C     Lower part.
      temp = M(67, 58) * M(58, 59)
      M(67, 59) = M(67, 59) - temp
C     Lower part.
      temp = M(68, 58) * M(58, 59)
      M(68, 59) = M(68, 59) - temp
C     Lower part.
      temp = M(69, 58) * M(58, 59)
      M(69, 59) = M(69, 59) - temp
C     Lower part.
      temp = M(71, 58) * M(58, 59)
      M(71, 59) = M(71, 59) - temp
C     Lower part.
      temp = M(72, 58) * M(58, 59)
      M(72, 59) = M(72, 59) - temp
C     Upper part.
      temp = M(59, 53) * M(53, 60)
      M(59, 60) = ( M(59, 60) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 3) * M(3, 62)
      temp = temp + M(59, 10) * M(10, 62)
      temp = temp + M(59, 13) * M(13, 62)
      temp = temp + M(59, 36) * M(36, 62)
      temp = temp + M(59, 37) * M(37, 62)
      temp = temp + M(59, 40) * M(40, 62)
      temp = temp + M(59, 41) * M(41, 62)
      temp = temp + M(59, 42) * M(42, 62)
      temp = temp + M(59, 44) * M(44, 62)
      temp = temp + M(59, 45) * M(45, 62)
      temp = temp + M(59, 46) * M(46, 62)
      temp = temp + M(59, 47) * M(47, 62)
      temp = temp + M(59, 48) * M(48, 62)
      temp = temp + M(59, 49) * M(49, 62)
      temp = temp + M(59, 50) * M(50, 62)
      temp = temp + M(59, 53) * M(53, 62)
      temp = temp + M(59, 56) * M(56, 62)
      temp = temp + M(59, 58) * M(58, 62)
      M(59, 62) = ( M(59, 62) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 36) * M(36, 63)
      temp = temp + M(59, 37) * M(37, 63)
      temp = temp + M(59, 40) * M(40, 63)
      temp = temp + M(59, 41) * M(41, 63)
      temp = temp + M(59, 42) * M(42, 63)
      temp = temp + M(59, 44) * M(44, 63)
      temp = temp + M(59, 45) * M(45, 63)
      temp = temp + M(59, 46) * M(46, 63)
      temp = temp + M(59, 47) * M(47, 63)
      temp = temp + M(59, 48) * M(48, 63)
      temp = temp + M(59, 49) * M(49, 63)
      temp = temp + M(59, 50) * M(50, 63)
      temp = temp + M(59, 53) * M(53, 63)
      temp = temp + M(59, 56) * M(56, 63)
      temp = temp + M(59, 58) * M(58, 63)
      M(59, 63) = ( M(59, 63) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 53) * M(53, 64)
      M(59, 64) = ( M(59, 64) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 53) * M(53, 65)
      M(59, 65) = ( M(59, 65) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 36) * M(36, 67)
      temp = temp + M(59, 37) * M(37, 67)
      temp = temp + M(59, 40) * M(40, 67)
      temp = temp + M(59, 41) * M(41, 67)
      temp = temp + M(59, 42) * M(42, 67)
      temp = temp + M(59, 44) * M(44, 67)
      temp = temp + M(59, 45) * M(45, 67)
      temp = temp + M(59, 46) * M(46, 67)
      temp = temp + M(59, 47) * M(47, 67)
      temp = temp + M(59, 48) * M(48, 67)
      temp = temp + M(59, 49) * M(49, 67)
      temp = temp + M(59, 50) * M(50, 67)
      temp = temp + M(59, 53) * M(53, 67)
      temp = temp + M(59, 56) * M(56, 67)
      temp = temp + M(59, 58) * M(58, 67)
      M(59, 67) = ( M(59, 67) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 13) * M(13, 68)
      temp = temp + M(59, 36) * M(36, 68)
      temp = temp + M(59, 37) * M(37, 68)
      temp = temp + M(59, 40) * M(40, 68)
      temp = temp + M(59, 41) * M(41, 68)
      temp = temp + M(59, 42) * M(42, 68)
      temp = temp + M(59, 44) * M(44, 68)
      temp = temp + M(59, 45) * M(45, 68)
      temp = temp + M(59, 46) * M(46, 68)
      temp = temp + M(59, 47) * M(47, 68)
      temp = temp + M(59, 48) * M(48, 68)
      temp = temp + M(59, 49) * M(49, 68)
      temp = temp + M(59, 50) * M(50, 68)
      temp = temp + M(59, 53) * M(53, 68)
      temp = temp + M(59, 56) * M(56, 68)
      temp = temp + M(59, 58) * M(58, 68)
      M(59, 68) = ( M(59, 68) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 36) * M(36, 69)
      temp = temp + M(59, 37) * M(37, 69)
      temp = temp + M(59, 40) * M(40, 69)
      temp = temp + M(59, 41) * M(41, 69)
      temp = temp + M(59, 42) * M(42, 69)
      temp = temp + M(59, 44) * M(44, 69)
      temp = temp + M(59, 45) * M(45, 69)
      temp = temp + M(59, 46) * M(46, 69)
      temp = temp + M(59, 47) * M(47, 69)
      temp = temp + M(59, 48) * M(48, 69)
      temp = temp + M(59, 49) * M(49, 69)
      temp = temp + M(59, 50) * M(50, 69)
      temp = temp + M(59, 53) * M(53, 69)
      temp = temp + M(59, 56) * M(56, 69)
      temp = temp + M(59, 58) * M(58, 69)
      M(59, 69) = ( M(59, 69) - temp ) / M(59, 59)
C     Upper part.
      M(59, 70) = M(59, 70) / M(59, 59)
C     Upper part.
      temp = M(59, 36) * M(36, 71)
      temp = temp + M(59, 37) * M(37, 71)
      temp = temp + M(59, 40) * M(40, 71)
      temp = temp + M(59, 41) * M(41, 71)
      temp = temp + M(59, 42) * M(42, 71)
      temp = temp + M(59, 44) * M(44, 71)
      temp = temp + M(59, 45) * M(45, 71)
      temp = temp + M(59, 46) * M(46, 71)
      temp = temp + M(59, 47) * M(47, 71)
      temp = temp + M(59, 48) * M(48, 71)
      temp = temp + M(59, 49) * M(49, 71)
      temp = temp + M(59, 50) * M(50, 71)
      temp = temp + M(59, 53) * M(53, 71)
      temp = temp + M(59, 56) * M(56, 71)
      temp = temp + M(59, 58) * M(58, 71)
      M(59, 71) = ( M(59, 71) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 40) * M(40, 72)
      temp = temp + M(59, 41) * M(41, 72)
      temp = temp + M(59, 44) * M(44, 72)
      temp = temp + M(59, 45) * M(45, 72)
      temp = temp + M(59, 46) * M(46, 72)
      temp = temp + M(59, 47) * M(47, 72)
      temp = temp + M(59, 48) * M(48, 72)
      temp = temp + M(59, 49) * M(49, 72)
      temp = temp + M(59, 50) * M(50, 72)
      temp = temp + M(59, 53) * M(53, 72)
      temp = temp + M(59, 56) * M(56, 72)
      temp = temp + M(59, 58) * M(58, 72)
      M(59, 72) = ( M(59, 72) - temp ) / M(59, 59)

C     Lower part.
      temp = M(60, 59) * M(59, 60)
      M(60, 60) = M(60, 60) - temp
C     Lower part.
      temp = M(61, 53) * M(53, 60)
      temp = temp + M(61, 59) * M(59, 60)
      M(61, 60) = M(61, 60) - temp
C     Lower part.
      temp = M(62, 53) * M(53, 60)
      temp = temp + M(62, 59) * M(59, 60)
      M(62, 60) = M(62, 60) - temp
C     Lower part.
      temp = M(63, 59) * M(59, 60)
      M(63, 60) = M(63, 60) - temp
C     Lower part.
      temp = M(64, 53) * M(53, 60)
      temp = temp + M(64, 59) * M(59, 60)
      M(64, 60) = M(64, 60) - temp
C     Lower part.
      temp = M(65, 53) * M(53, 60)
      temp = temp + M(65, 59) * M(59, 60)
      M(65, 60) = M(65, 60) - temp
C     Lower part.
      temp = M(66, 59) * M(59, 60)
      M(66, 60) = M(66, 60) - temp
C     Lower part.
      temp = M(67, 59) * M(59, 60)
      M(67, 60) = M(67, 60) - temp
C     Lower part.
      temp = M(68, 59) * M(59, 60)
      M(68, 60) = M(68, 60) - temp
C     Lower part.
      temp = M(69, 59) * M(59, 60)
      M(69, 60) = M(69, 60) - temp
C     Lower part.
      temp = M(71, 53) * M(53, 60)
      temp = temp + M(71, 59) * M(59, 60)
      M(71, 60) = M(71, 60) - temp
C     Lower part.
      temp = M(72, 59) * M(59, 60)
      M(72, 60) = M(72, 60) - temp
C     Upper part.
      temp = M(60, 13) * M(13, 62)
      temp = temp + M(60, 14) * M(14, 62)
      temp = temp + M(60, 21) * M(21, 62)
      temp = temp + M(60, 36) * M(36, 62)
      temp = temp + M(60, 37) * M(37, 62)
      temp = temp + M(60, 40) * M(40, 62)
      temp = temp + M(60, 44) * M(44, 62)
      temp = temp + M(60, 49) * M(49, 62)
      temp = temp + M(60, 50) * M(50, 62)
      temp = temp + M(60, 56) * M(56, 62)
      temp = temp + M(60, 59) * M(59, 62)
      M(60, 62) = ( M(60, 62) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 36) * M(36, 63)
      temp = temp + M(60, 37) * M(37, 63)
      temp = temp + M(60, 40) * M(40, 63)
      temp = temp + M(60, 44) * M(44, 63)
      temp = temp + M(60, 49) * M(49, 63)
      temp = temp + M(60, 50) * M(50, 63)
      temp = temp + M(60, 56) * M(56, 63)
      temp = temp + M(60, 59) * M(59, 63)
      M(60, 63) = ( M(60, 63) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 59) * M(59, 64)
      M(60, 64) = ( M(60, 64) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 59) * M(59, 65)
      M(60, 65) = ( M(60, 65) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 36) * M(36, 67)
      temp = temp + M(60, 37) * M(37, 67)
      temp = temp + M(60, 40) * M(40, 67)
      temp = temp + M(60, 44) * M(44, 67)
      temp = temp + M(60, 49) * M(49, 67)
      temp = temp + M(60, 50) * M(50, 67)
      temp = temp + M(60, 56) * M(56, 67)
      temp = temp + M(60, 59) * M(59, 67)
      M(60, 67) = ( M(60, 67) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 13) * M(13, 68)
      temp = temp + M(60, 14) * M(14, 68)
      temp = temp + M(60, 36) * M(36, 68)
      temp = temp + M(60, 37) * M(37, 68)
      temp = temp + M(60, 40) * M(40, 68)
      temp = temp + M(60, 44) * M(44, 68)
      temp = temp + M(60, 49) * M(49, 68)
      temp = temp + M(60, 50) * M(50, 68)
      temp = temp + M(60, 56) * M(56, 68)
      temp = temp + M(60, 59) * M(59, 68)
      M(60, 68) = ( M(60, 68) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 36) * M(36, 69)
      temp = temp + M(60, 37) * M(37, 69)
      temp = temp + M(60, 40) * M(40, 69)
      temp = temp + M(60, 44) * M(44, 69)
      temp = temp + M(60, 49) * M(49, 69)
      temp = temp + M(60, 50) * M(50, 69)
      temp = temp + M(60, 56) * M(56, 69)
      temp = temp + M(60, 59) * M(59, 69)
      M(60, 69) = ( M(60, 69) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 59) * M(59, 70)
      M(60, 70) = ( M(60, 70) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 36) * M(36, 71)
      temp = temp + M(60, 37) * M(37, 71)
      temp = temp + M(60, 40) * M(40, 71)
      temp = temp + M(60, 44) * M(44, 71)
      temp = temp + M(60, 49) * M(49, 71)
      temp = temp + M(60, 50) * M(50, 71)
      temp = temp + M(60, 56) * M(56, 71)
      temp = temp + M(60, 59) * M(59, 71)
      M(60, 71) = ( M(60, 71) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 40) * M(40, 72)
      temp = temp + M(60, 44) * M(44, 72)
      temp = temp + M(60, 49) * M(49, 72)
      temp = temp + M(60, 50) * M(50, 72)
      temp = temp + M(60, 56) * M(56, 72)
      temp = temp + M(60, 59) * M(59, 72)
      M(60, 72) = ( M(60, 72) - temp ) / M(60, 60)

C     Lower part.
      temp = M(62, 52) * M(52, 61)
      temp = temp + M(62, 55) * M(55, 61)
      M(62, 61) = M(62, 61) - temp
C     Lower part.
      temp = M(68, 55) * M(55, 61)
      M(68, 61) = M(68, 61) - temp
C     Lower part.
      temp = M(71, 52) * M(52, 61)
      M(71, 61) = M(71, 61) - temp
C     Lower part.
      temp = M(72, 55) * M(55, 61)
      M(72, 61) = M(72, 61) - temp
C     Upper part.
      temp = M(61, 2) * M(2, 62)
      temp = temp + M(61, 4) * M(4, 62)
      temp = temp + M(61, 10) * M(10, 62)
      temp = temp + M(61, 13) * M(13, 62)
      temp = temp + M(61, 35) * M(35, 62)
      temp = temp + M(61, 36) * M(36, 62)
      temp = temp + M(61, 37) * M(37, 62)
      temp = temp + M(61, 38) * M(38, 62)
      temp = temp + M(61, 40) * M(40, 62)
      temp = temp + M(61, 41) * M(41, 62)
      temp = temp + M(61, 42) * M(42, 62)
      temp = temp + M(61, 44) * M(44, 62)
      temp = temp + M(61, 45) * M(45, 62)
      temp = temp + M(61, 46) * M(46, 62)
      temp = temp + M(61, 47) * M(47, 62)
      temp = temp + M(61, 48) * M(48, 62)
      temp = temp + M(61, 49) * M(49, 62)
      temp = temp + M(61, 50) * M(50, 62)
      temp = temp + M(61, 53) * M(53, 62)
      temp = temp + M(61, 56) * M(56, 62)
      temp = temp + M(61, 58) * M(58, 62)
      temp = temp + M(61, 59) * M(59, 62)
      temp = temp + M(61, 60) * M(60, 62)
      M(61, 62) = ( M(61, 62) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 36) * M(36, 63)
      temp = temp + M(61, 37) * M(37, 63)
      temp = temp + M(61, 38) * M(38, 63)
      temp = temp + M(61, 40) * M(40, 63)
      temp = temp + M(61, 41) * M(41, 63)
      temp = temp + M(61, 42) * M(42, 63)
      temp = temp + M(61, 44) * M(44, 63)
      temp = temp + M(61, 45) * M(45, 63)
      temp = temp + M(61, 46) * M(46, 63)
      temp = temp + M(61, 47) * M(47, 63)
      temp = temp + M(61, 48) * M(48, 63)
      temp = temp + M(61, 49) * M(49, 63)
      temp = temp + M(61, 50) * M(50, 63)
      temp = temp + M(61, 53) * M(53, 63)
      temp = temp + M(61, 56) * M(56, 63)
      temp = temp + M(61, 58) * M(58, 63)
      temp = temp + M(61, 59) * M(59, 63)
      temp = temp + M(61, 60) * M(60, 63)
      M(61, 63) = ( M(61, 63) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 53) * M(53, 64)
      temp = temp + M(61, 59) * M(59, 64)
      temp = temp + M(61, 60) * M(60, 64)
      M(61, 64) = ( M(61, 64) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 53) * M(53, 65)
      temp = temp + M(61, 59) * M(59, 65)
      temp = temp + M(61, 60) * M(60, 65)
      M(61, 65) = ( M(61, 65) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 35) * M(35, 67)
      temp = temp + M(61, 36) * M(36, 67)
      temp = temp + M(61, 37) * M(37, 67)
      temp = temp + M(61, 38) * M(38, 67)
      temp = temp + M(61, 40) * M(40, 67)
      temp = temp + M(61, 41) * M(41, 67)
      temp = temp + M(61, 42) * M(42, 67)
      temp = temp + M(61, 44) * M(44, 67)
      temp = temp + M(61, 45) * M(45, 67)
      temp = temp + M(61, 46) * M(46, 67)
      temp = temp + M(61, 47) * M(47, 67)
      temp = temp + M(61, 48) * M(48, 67)
      temp = temp + M(61, 49) * M(49, 67)
      temp = temp + M(61, 50) * M(50, 67)
      temp = temp + M(61, 53) * M(53, 67)
      temp = temp + M(61, 56) * M(56, 67)
      temp = temp + M(61, 58) * M(58, 67)
      temp = temp + M(61, 59) * M(59, 67)
      temp = temp + M(61, 60) * M(60, 67)
      M(61, 67) = ( M(61, 67) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 13) * M(13, 68)
      temp = temp + M(61, 35) * M(35, 68)
      temp = temp + M(61, 36) * M(36, 68)
      temp = temp + M(61, 37) * M(37, 68)
      temp = temp + M(61, 38) * M(38, 68)
      temp = temp + M(61, 40) * M(40, 68)
      temp = temp + M(61, 41) * M(41, 68)
      temp = temp + M(61, 42) * M(42, 68)
      temp = temp + M(61, 44) * M(44, 68)
      temp = temp + M(61, 45) * M(45, 68)
      temp = temp + M(61, 46) * M(46, 68)
      temp = temp + M(61, 47) * M(47, 68)
      temp = temp + M(61, 48) * M(48, 68)
      temp = temp + M(61, 49) * M(49, 68)
      temp = temp + M(61, 50) * M(50, 68)
      temp = temp + M(61, 53) * M(53, 68)
      temp = temp + M(61, 56) * M(56, 68)
      temp = temp + M(61, 58) * M(58, 68)
      temp = temp + M(61, 59) * M(59, 68)
      temp = temp + M(61, 60) * M(60, 68)
      M(61, 68) = ( M(61, 68) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 36) * M(36, 69)
      temp = temp + M(61, 37) * M(37, 69)
      temp = temp + M(61, 38) * M(38, 69)
      temp = temp + M(61, 40) * M(40, 69)
      temp = temp + M(61, 41) * M(41, 69)
      temp = temp + M(61, 42) * M(42, 69)
      temp = temp + M(61, 44) * M(44, 69)
      temp = temp + M(61, 45) * M(45, 69)
      temp = temp + M(61, 46) * M(46, 69)
      temp = temp + M(61, 47) * M(47, 69)
      temp = temp + M(61, 48) * M(48, 69)
      temp = temp + M(61, 49) * M(49, 69)
      temp = temp + M(61, 50) * M(50, 69)
      temp = temp + M(61, 53) * M(53, 69)
      temp = temp + M(61, 56) * M(56, 69)
      temp = temp + M(61, 58) * M(58, 69)
      temp = temp + M(61, 59) * M(59, 69)
      temp = temp + M(61, 60) * M(60, 69)
      M(61, 69) = ( M(61, 69) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 59) * M(59, 70)
      temp = temp + M(61, 60) * M(60, 70)
      M(61, 70) = ( M(61, 70) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 36) * M(36, 71)
      temp = temp + M(61, 37) * M(37, 71)
      temp = temp + M(61, 38) * M(38, 71)
      temp = temp + M(61, 40) * M(40, 71)
      temp = temp + M(61, 41) * M(41, 71)
      temp = temp + M(61, 42) * M(42, 71)
      temp = temp + M(61, 44) * M(44, 71)
      temp = temp + M(61, 45) * M(45, 71)
      temp = temp + M(61, 46) * M(46, 71)
      temp = temp + M(61, 47) * M(47, 71)
      temp = temp + M(61, 48) * M(48, 71)
      temp = temp + M(61, 49) * M(49, 71)
      temp = temp + M(61, 50) * M(50, 71)
      temp = temp + M(61, 53) * M(53, 71)
      temp = temp + M(61, 56) * M(56, 71)
      temp = temp + M(61, 58) * M(58, 71)
      temp = temp + M(61, 59) * M(59, 71)
      temp = temp + M(61, 60) * M(60, 71)
      M(61, 71) = ( M(61, 71) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 35) * M(35, 72)
      temp = temp + M(61, 40) * M(40, 72)
      temp = temp + M(61, 41) * M(41, 72)
      temp = temp + M(61, 44) * M(44, 72)
      temp = temp + M(61, 45) * M(45, 72)
      temp = temp + M(61, 46) * M(46, 72)
      temp = temp + M(61, 47) * M(47, 72)
      temp = temp + M(61, 48) * M(48, 72)
      temp = temp + M(61, 49) * M(49, 72)
      temp = temp + M(61, 50) * M(50, 72)
      temp = temp + M(61, 53) * M(53, 72)
      temp = temp + M(61, 56) * M(56, 72)
      temp = temp + M(61, 58) * M(58, 72)
      temp = temp + M(61, 59) * M(59, 72)
      temp = temp + M(61, 60) * M(60, 72)
      M(61, 72) = ( M(61, 72) - temp ) / M(61, 61)

C     Lower part.
      temp = M(62, 1) * M(1, 62)
      temp = temp + M(62, 2) * M(2, 62)
      temp = temp + M(62, 3) * M(3, 62)
      temp = temp + M(62, 4) * M(4, 62)
      temp = temp + M(62, 5) * M(5, 62)
      temp = temp + M(62, 6) * M(6, 62)
      temp = temp + M(62, 10) * M(10, 62)
      temp = temp + M(62, 11) * M(11, 62)
      temp = temp + M(62, 12) * M(12, 62)
      temp = temp + M(62, 13) * M(13, 62)
      temp = temp + M(62, 14) * M(14, 62)
      temp = temp + M(62, 15) * M(15, 62)
      temp = temp + M(62, 16) * M(16, 62)
      temp = temp + M(62, 17) * M(17, 62)
      temp = temp + M(62, 18) * M(18, 62)
      temp = temp + M(62, 19) * M(19, 62)
      temp = temp + M(62, 20) * M(20, 62)
      temp = temp + M(62, 21) * M(21, 62)
      temp = temp + M(62, 22) * M(22, 62)
      temp = temp + M(62, 23) * M(23, 62)
      temp = temp + M(62, 24) * M(24, 62)
      temp = temp + M(62, 25) * M(25, 62)
      temp = temp + M(62, 26) * M(26, 62)
      temp = temp + M(62, 27) * M(27, 62)
      temp = temp + M(62, 28) * M(28, 62)
      temp = temp + M(62, 30) * M(30, 62)
      temp = temp + M(62, 35) * M(35, 62)
      temp = temp + M(62, 40) * M(40, 62)
      temp = temp + M(62, 44) * M(44, 62)
      temp = temp + M(62, 48) * M(48, 62)
      temp = temp + M(62, 49) * M(49, 62)
      temp = temp + M(62, 50) * M(50, 62)
      temp = temp + M(62, 51) * M(51, 62)
      temp = temp + M(62, 52) * M(52, 62)
      temp = temp + M(62, 53) * M(53, 62)
      temp = temp + M(62, 54) * M(54, 62)
      temp = temp + M(62, 55) * M(55, 62)
      temp = temp + M(62, 56) * M(56, 62)
      temp = temp + M(62, 58) * M(58, 62)
      temp = temp + M(62, 59) * M(59, 62)
      temp = temp + M(62, 60) * M(60, 62)
      temp = temp + M(62, 61) * M(61, 62)
      M(62, 62) = M(62, 62) - temp
C     Lower part.
      temp = M(63, 12) * M(12, 62)
      temp = temp + M(63, 16) * M(16, 62)
      temp = temp + M(63, 19) * M(19, 62)
      temp = temp + M(63, 20) * M(20, 62)
      temp = temp + M(63, 28) * M(28, 62)
      temp = temp + M(63, 31) * M(31, 62)
      temp = temp + M(63, 32) * M(32, 62)
      temp = temp + M(63, 33) * M(33, 62)
      temp = temp + M(63, 35) * M(35, 62)
      temp = temp + M(63, 36) * M(36, 62)
      temp = temp + M(63, 37) * M(37, 62)
      temp = temp + M(63, 38) * M(38, 62)
      temp = temp + M(63, 39) * M(39, 62)
      temp = temp + M(63, 40) * M(40, 62)
      temp = temp + M(63, 41) * M(41, 62)
      temp = temp + M(63, 42) * M(42, 62)
      temp = temp + M(63, 43) * M(43, 62)
      temp = temp + M(63, 44) * M(44, 62)
      temp = temp + M(63, 45) * M(45, 62)
      temp = temp + M(63, 46) * M(46, 62)
      temp = temp + M(63, 47) * M(47, 62)
      temp = temp + M(63, 48) * M(48, 62)
      temp = temp + M(63, 49) * M(49, 62)
      temp = temp + M(63, 50) * M(50, 62)
      temp = temp + M(63, 56) * M(56, 62)
      temp = temp + M(63, 58) * M(58, 62)
      temp = temp + M(63, 59) * M(59, 62)
      temp = temp + M(63, 60) * M(60, 62)
      temp = temp + M(63, 61) * M(61, 62)
      M(63, 62) = M(63, 62) - temp
C     Lower part.
      temp = M(64, 2) * M(2, 62)
      temp = temp + M(64, 53) * M(53, 62)
      temp = temp + M(64, 56) * M(56, 62)
      temp = temp + M(64, 58) * M(58, 62)
      temp = temp + M(64, 59) * M(59, 62)
      temp = temp + M(64, 60) * M(60, 62)
      M(64, 62) = M(64, 62) - temp
C     Lower part.
      temp = M(65, 5) * M(5, 62)
      temp = temp + M(65, 6) * M(6, 62)
      temp = temp + M(65, 12) * M(12, 62)
      temp = temp + M(65, 19) * M(19, 62)
      temp = temp + M(65, 25) * M(25, 62)
      temp = temp + M(65, 26) * M(26, 62)
      temp = temp + M(65, 28) * M(28, 62)
      temp = temp + M(65, 30) * M(30, 62)
      temp = temp + M(65, 35) * M(35, 62)
      temp = temp + M(65, 36) * M(36, 62)
      temp = temp + M(65, 37) * M(37, 62)
      temp = temp + M(65, 48) * M(48, 62)
      temp = temp + M(65, 49) * M(49, 62)
      temp = temp + M(65, 50) * M(50, 62)
      temp = temp + M(65, 53) * M(53, 62)
      temp = temp + M(65, 56) * M(56, 62)
      temp = temp + M(65, 58) * M(58, 62)
      temp = temp + M(65, 59) * M(59, 62)
      temp = temp + M(65, 60) * M(60, 62)
      M(65, 62) = M(65, 62) - temp
C     Lower part.
      temp = M(66, 2) * M(2, 62)
      temp = temp + M(66, 11) * M(11, 62)
      temp = temp + M(66, 12) * M(12, 62)
      temp = temp + M(66, 14) * M(14, 62)
      temp = temp + M(66, 16) * M(16, 62)
      temp = temp + M(66, 19) * M(19, 62)
      temp = temp + M(66, 24) * M(24, 62)
      temp = temp + M(66, 25) * M(25, 62)
      temp = temp + M(66, 26) * M(26, 62)
      temp = temp + M(66, 28) * M(28, 62)
      temp = temp + M(66, 31) * M(31, 62)
      temp = temp + M(66, 32) * M(32, 62)
      temp = temp + M(66, 33) * M(33, 62)
      temp = temp + M(66, 35) * M(35, 62)
      temp = temp + M(66, 36) * M(36, 62)
      temp = temp + M(66, 37) * M(37, 62)
      temp = temp + M(66, 38) * M(38, 62)
      temp = temp + M(66, 39) * M(39, 62)
      temp = temp + M(66, 40) * M(40, 62)
      temp = temp + M(66, 41) * M(41, 62)
      temp = temp + M(66, 42) * M(42, 62)
      temp = temp + M(66, 43) * M(43, 62)
      temp = temp + M(66, 44) * M(44, 62)
      temp = temp + M(66, 45) * M(45, 62)
      temp = temp + M(66, 46) * M(46, 62)
      temp = temp + M(66, 47) * M(47, 62)
      temp = temp + M(66, 48) * M(48, 62)
      temp = temp + M(66, 49) * M(49, 62)
      temp = temp + M(66, 50) * M(50, 62)
      temp = temp + M(66, 51) * M(51, 62)
      temp = temp + M(66, 56) * M(56, 62)
      temp = temp + M(66, 58) * M(58, 62)
      temp = temp + M(66, 59) * M(59, 62)
      temp = temp + M(66, 60) * M(60, 62)
      M(66, 62) = M(66, 62) - temp
C     Lower part.
      temp = M(67, 23) * M(23, 62)
      temp = temp + M(67, 30) * M(30, 62)
      temp = temp + M(67, 31) * M(31, 62)
      temp = temp + M(67, 32) * M(32, 62)
      temp = temp + M(67, 33) * M(33, 62)
      temp = temp + M(67, 35) * M(35, 62)
      temp = temp + M(67, 36) * M(36, 62)
      temp = temp + M(67, 37) * M(37, 62)
      temp = temp + M(67, 38) * M(38, 62)
      temp = temp + M(67, 39) * M(39, 62)
      temp = temp + M(67, 41) * M(41, 62)
      temp = temp + M(67, 42) * M(42, 62)
      temp = temp + M(67, 43) * M(43, 62)
      temp = temp + M(67, 45) * M(45, 62)
      temp = temp + M(67, 46) * M(46, 62)
      temp = temp + M(67, 47) * M(47, 62)
      temp = temp + M(67, 49) * M(49, 62)
      temp = temp + M(67, 50) * M(50, 62)
      temp = temp + M(67, 56) * M(56, 62)
      temp = temp + M(67, 58) * M(58, 62)
      temp = temp + M(67, 59) * M(59, 62)
      temp = temp + M(67, 60) * M(60, 62)
      M(67, 62) = M(67, 62) - temp
C     Lower part.
      temp = M(68, 11) * M(11, 62)
      temp = temp + M(68, 12) * M(12, 62)
      temp = temp + M(68, 13) * M(13, 62)
      temp = temp + M(68, 14) * M(14, 62)
      temp = temp + M(68, 15) * M(15, 62)
      temp = temp + M(68, 19) * M(19, 62)
      temp = temp + M(68, 25) * M(25, 62)
      temp = temp + M(68, 26) * M(26, 62)
      temp = temp + M(68, 30) * M(30, 62)
      temp = temp + M(68, 31) * M(31, 62)
      temp = temp + M(68, 32) * M(32, 62)
      temp = temp + M(68, 33) * M(33, 62)
      temp = temp + M(68, 35) * M(35, 62)
      temp = temp + M(68, 36) * M(36, 62)
      temp = temp + M(68, 37) * M(37, 62)
      temp = temp + M(68, 38) * M(38, 62)
      temp = temp + M(68, 39) * M(39, 62)
      temp = temp + M(68, 40) * M(40, 62)
      temp = temp + M(68, 41) * M(41, 62)
      temp = temp + M(68, 42) * M(42, 62)
      temp = temp + M(68, 43) * M(43, 62)
      temp = temp + M(68, 44) * M(44, 62)
      temp = temp + M(68, 45) * M(45, 62)
      temp = temp + M(68, 46) * M(46, 62)
      temp = temp + M(68, 47) * M(47, 62)
      temp = temp + M(68, 48) * M(48, 62)
      temp = temp + M(68, 49) * M(49, 62)
      temp = temp + M(68, 50) * M(50, 62)
      temp = temp + M(68, 51) * M(51, 62)
      temp = temp + M(68, 54) * M(54, 62)
      temp = temp + M(68, 55) * M(55, 62)
      temp = temp + M(68, 56) * M(56, 62)
      temp = temp + M(68, 58) * M(58, 62)
      temp = temp + M(68, 59) * M(59, 62)
      temp = temp + M(68, 60) * M(60, 62)
      temp = temp + M(68, 61) * M(61, 62)
      M(68, 62) = M(68, 62) - temp
C     Lower part.
      temp = M(69, 12) * M(12, 62)
      temp = temp + M(69, 19) * M(19, 62)
      temp = temp + M(69, 24) * M(24, 62)
      temp = temp + M(69, 25) * M(25, 62)
      temp = temp + M(69, 26) * M(26, 62)
      temp = temp + M(69, 28) * M(28, 62)
      temp = temp + M(69, 31) * M(31, 62)
      temp = temp + M(69, 32) * M(32, 62)
      temp = temp + M(69, 33) * M(33, 62)
      temp = temp + M(69, 35) * M(35, 62)
      temp = temp + M(69, 36) * M(36, 62)
      temp = temp + M(69, 37) * M(37, 62)
      temp = temp + M(69, 38) * M(38, 62)
      temp = temp + M(69, 39) * M(39, 62)
      temp = temp + M(69, 41) * M(41, 62)
      temp = temp + M(69, 42) * M(42, 62)
      temp = temp + M(69, 43) * M(43, 62)
      temp = temp + M(69, 45) * M(45, 62)
      temp = temp + M(69, 46) * M(46, 62)
      temp = temp + M(69, 47) * M(47, 62)
      temp = temp + M(69, 48) * M(48, 62)
      temp = temp + M(69, 49) * M(49, 62)
      temp = temp + M(69, 50) * M(50, 62)
      temp = temp + M(69, 54) * M(54, 62)
      temp = temp + M(69, 56) * M(56, 62)
      temp = temp + M(69, 58) * M(58, 62)
      temp = temp + M(69, 59) * M(59, 62)
      temp = temp + M(69, 60) * M(60, 62)
      temp = temp + M(69, 61) * M(61, 62)
      M(69, 62) = M(69, 62) - temp
C     Lower part.
      temp = M(70, 25) * M(25, 62)
      temp = temp + M(70, 29) * M(29, 62)
      temp = temp + M(70, 30) * M(30, 62)
      temp = temp + M(70, 31) * M(31, 62)
      temp = temp + M(70, 32) * M(32, 62)
      temp = temp + M(70, 36) * M(36, 62)
      temp = temp + M(70, 37) * M(37, 62)
      temp = temp + M(70, 39) * M(39, 62)
      temp = temp + M(70, 42) * M(42, 62)
      temp = temp + M(70, 43) * M(43, 62)
      temp = temp + M(70, 46) * M(46, 62)
      temp = temp + M(70, 47) * M(47, 62)
      temp = temp + M(70, 49) * M(49, 62)
      temp = temp + M(70, 50) * M(50, 62)
      temp = temp + M(70, 56) * M(56, 62)
      M(70, 62) = M(70, 62) - temp
C     Lower part.
      temp = M(71, 1) * M(1, 62)
      temp = temp + M(71, 2) * M(2, 62)
      temp = temp + M(71, 3) * M(3, 62)
      temp = temp + M(71, 4) * M(4, 62)
      temp = temp + M(71, 5) * M(5, 62)
      temp = temp + M(71, 6) * M(6, 62)
      temp = temp + M(71, 10) * M(10, 62)
      temp = temp + M(71, 11) * M(11, 62)
      temp = temp + M(71, 12) * M(12, 62)
      temp = temp + M(71, 13) * M(13, 62)
      temp = temp + M(71, 14) * M(14, 62)
      temp = temp + M(71, 15) * M(15, 62)
      temp = temp + M(71, 16) * M(16, 62)
      temp = temp + M(71, 17) * M(17, 62)
      temp = temp + M(71, 18) * M(18, 62)
      temp = temp + M(71, 19) * M(19, 62)
      temp = temp + M(71, 22) * M(22, 62)
      temp = temp + M(71, 24) * M(24, 62)
      temp = temp + M(71, 25) * M(25, 62)
      temp = temp + M(71, 27) * M(27, 62)
      temp = temp + M(71, 28) * M(28, 62)
      temp = temp + M(71, 29) * M(29, 62)
      temp = temp + M(71, 30) * M(30, 62)
      temp = temp + M(71, 31) * M(31, 62)
      temp = temp + M(71, 32) * M(32, 62)
      temp = temp + M(71, 33) * M(33, 62)
      temp = temp + M(71, 35) * M(35, 62)
      temp = temp + M(71, 36) * M(36, 62)
      temp = temp + M(71, 37) * M(37, 62)
      temp = temp + M(71, 38) * M(38, 62)
      temp = temp + M(71, 39) * M(39, 62)
      temp = temp + M(71, 40) * M(40, 62)
      temp = temp + M(71, 41) * M(41, 62)
      temp = temp + M(71, 42) * M(42, 62)
      temp = temp + M(71, 43) * M(43, 62)
      temp = temp + M(71, 44) * M(44, 62)
      temp = temp + M(71, 45) * M(45, 62)
      temp = temp + M(71, 46) * M(46, 62)
      temp = temp + M(71, 47) * M(47, 62)
      temp = temp + M(71, 48) * M(48, 62)
      temp = temp + M(71, 49) * M(49, 62)
      temp = temp + M(71, 50) * M(50, 62)
      temp = temp + M(71, 51) * M(51, 62)
      temp = temp + M(71, 52) * M(52, 62)
      temp = temp + M(71, 53) * M(53, 62)
      temp = temp + M(71, 54) * M(54, 62)
      temp = temp + M(71, 56) * M(56, 62)
      temp = temp + M(71, 58) * M(58, 62)
      temp = temp + M(71, 59) * M(59, 62)
      temp = temp + M(71, 60) * M(60, 62)
      temp = temp + M(71, 61) * M(61, 62)
      M(71, 62) = M(71, 62) - temp
C     Lower part.
      temp = M(72, 15) * M(15, 62)
      temp = temp + M(72, 17) * M(17, 62)
      temp = temp + M(72, 18) * M(18, 62)
      temp = temp + M(72, 22) * M(22, 62)
      temp = temp + M(72, 23) * M(23, 62)
      temp = temp + M(72, 25) * M(25, 62)
      temp = temp + M(72, 26) * M(26, 62)
      temp = temp + M(72, 29) * M(29, 62)
      temp = temp + M(72, 30) * M(30, 62)
      temp = temp + M(72, 31) * M(31, 62)
      temp = temp + M(72, 32) * M(32, 62)
      temp = temp + M(72, 33) * M(33, 62)
      temp = temp + M(72, 35) * M(35, 62)
      temp = temp + M(72, 36) * M(36, 62)
      temp = temp + M(72, 37) * M(37, 62)
      temp = temp + M(72, 38) * M(38, 62)
      temp = temp + M(72, 39) * M(39, 62)
      temp = temp + M(72, 41) * M(41, 62)
      temp = temp + M(72, 42) * M(42, 62)
      temp = temp + M(72, 43) * M(43, 62)
      temp = temp + M(72, 45) * M(45, 62)
      temp = temp + M(72, 46) * M(46, 62)
      temp = temp + M(72, 47) * M(47, 62)
      temp = temp + M(72, 48) * M(48, 62)
      temp = temp + M(72, 49) * M(49, 62)
      temp = temp + M(72, 50) * M(50, 62)
      temp = temp + M(72, 55) * M(55, 62)
      temp = temp + M(72, 56) * M(56, 62)
      temp = temp + M(72, 58) * M(58, 62)
      temp = temp + M(72, 59) * M(59, 62)
      temp = temp + M(72, 60) * M(60, 62)
      temp = temp + M(72, 61) * M(61, 62)
      M(72, 62) = M(72, 62) - temp
C     Upper part.
      temp = M(62, 16) * M(16, 63)
      temp = temp + M(62, 24) * M(24, 63)
      temp = temp + M(62, 40) * M(40, 63)
      temp = temp + M(62, 44) * M(44, 63)
      temp = temp + M(62, 48) * M(48, 63)
      temp = temp + M(62, 49) * M(49, 63)
      temp = temp + M(62, 50) * M(50, 63)
      temp = temp + M(62, 51) * M(51, 63)
      temp = temp + M(62, 52) * M(52, 63)
      temp = temp + M(62, 53) * M(53, 63)
      temp = temp + M(62, 54) * M(54, 63)
      temp = temp + M(62, 55) * M(55, 63)
      temp = temp + M(62, 56) * M(56, 63)
      temp = temp + M(62, 58) * M(58, 63)
      temp = temp + M(62, 59) * M(59, 63)
      temp = temp + M(62, 60) * M(60, 63)
      temp = temp + M(62, 61) * M(61, 63)
      M(62, 63) = ( M(62, 63) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 51) * M(51, 64)
      temp = temp + M(62, 52) * M(52, 64)
      temp = temp + M(62, 53) * M(53, 64)
      temp = temp + M(62, 54) * M(54, 64)
      temp = temp + M(62, 55) * M(55, 64)
      temp = temp + M(62, 59) * M(59, 64)
      temp = temp + M(62, 60) * M(60, 64)
      temp = temp + M(62, 61) * M(61, 64)
      M(62, 64) = ( M(62, 64) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 53) * M(53, 65)
      temp = temp + M(62, 59) * M(59, 65)
      temp = temp + M(62, 60) * M(60, 65)
      temp = temp + M(62, 61) * M(61, 65)
      M(62, 65) = ( M(62, 65) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 52) * M(52, 66)
      temp = temp + M(62, 55) * M(55, 66)
      M(62, 66) = ( M(62, 66) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 23) * M(23, 67)
      temp = temp + M(62, 35) * M(35, 67)
      temp = temp + M(62, 40) * M(40, 67)
      temp = temp + M(62, 44) * M(44, 67)
      temp = temp + M(62, 48) * M(48, 67)
      temp = temp + M(62, 49) * M(49, 67)
      temp = temp + M(62, 50) * M(50, 67)
      temp = temp + M(62, 51) * M(51, 67)
      temp = temp + M(62, 52) * M(52, 67)
      temp = temp + M(62, 53) * M(53, 67)
      temp = temp + M(62, 54) * M(54, 67)
      temp = temp + M(62, 55) * M(55, 67)
      temp = temp + M(62, 56) * M(56, 67)
      temp = temp + M(62, 58) * M(58, 67)
      temp = temp + M(62, 59) * M(59, 67)
      temp = temp + M(62, 60) * M(60, 67)
      temp = temp + M(62, 61) * M(61, 67)
      M(62, 67) = ( M(62, 67) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 11) * M(11, 68)
      temp = temp + M(62, 12) * M(12, 68)
      temp = temp + M(62, 13) * M(13, 68)
      temp = temp + M(62, 14) * M(14, 68)
      temp = temp + M(62, 19) * M(19, 68)
      temp = temp + M(62, 25) * M(25, 68)
      temp = temp + M(62, 26) * M(26, 68)
      temp = temp + M(62, 27) * M(27, 68)
      temp = temp + M(62, 30) * M(30, 68)
      temp = temp + M(62, 35) * M(35, 68)
      temp = temp + M(62, 40) * M(40, 68)
      temp = temp + M(62, 44) * M(44, 68)
      temp = temp + M(62, 48) * M(48, 68)
      temp = temp + M(62, 49) * M(49, 68)
      temp = temp + M(62, 50) * M(50, 68)
      temp = temp + M(62, 51) * M(51, 68)
      temp = temp + M(62, 52) * M(52, 68)
      temp = temp + M(62, 53) * M(53, 68)
      temp = temp + M(62, 54) * M(54, 68)
      temp = temp + M(62, 55) * M(55, 68)
      temp = temp + M(62, 56) * M(56, 68)
      temp = temp + M(62, 58) * M(58, 68)
      temp = temp + M(62, 59) * M(59, 68)
      temp = temp + M(62, 60) * M(60, 68)
      temp = temp + M(62, 61) * M(61, 68)
      M(62, 68) = ( M(62, 68) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 26) * M(26, 69)
      temp = temp + M(62, 28) * M(28, 69)
      temp = temp + M(62, 40) * M(40, 69)
      temp = temp + M(62, 44) * M(44, 69)
      temp = temp + M(62, 48) * M(48, 69)
      temp = temp + M(62, 49) * M(49, 69)
      temp = temp + M(62, 50) * M(50, 69)
      temp = temp + M(62, 51) * M(51, 69)
      temp = temp + M(62, 52) * M(52, 69)
      temp = temp + M(62, 53) * M(53, 69)
      temp = temp + M(62, 54) * M(54, 69)
      temp = temp + M(62, 55) * M(55, 69)
      temp = temp + M(62, 56) * M(56, 69)
      temp = temp + M(62, 58) * M(58, 69)
      temp = temp + M(62, 59) * M(59, 69)
      temp = temp + M(62, 60) * M(60, 69)
      temp = temp + M(62, 61) * M(61, 69)
      M(62, 69) = ( M(62, 69) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 59) * M(59, 70)
      temp = temp + M(62, 60) * M(60, 70)
      temp = temp + M(62, 61) * M(61, 70)
      M(62, 70) = ( M(62, 70) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 15) * M(15, 71)
      temp = temp + M(62, 16) * M(16, 71)
      temp = temp + M(62, 27) * M(27, 71)
      temp = temp + M(62, 28) * M(28, 71)
      temp = temp + M(62, 30) * M(30, 71)
      temp = temp + M(62, 40) * M(40, 71)
      temp = temp + M(62, 44) * M(44, 71)
      temp = temp + M(62, 48) * M(48, 71)
      temp = temp + M(62, 49) * M(49, 71)
      temp = temp + M(62, 50) * M(50, 71)
      temp = temp + M(62, 51) * M(51, 71)
      temp = temp + M(62, 52) * M(52, 71)
      temp = temp + M(62, 53) * M(53, 71)
      temp = temp + M(62, 54) * M(54, 71)
      temp = temp + M(62, 55) * M(55, 71)
      temp = temp + M(62, 56) * M(56, 71)
      temp = temp + M(62, 58) * M(58, 71)
      temp = temp + M(62, 59) * M(59, 71)
      temp = temp + M(62, 60) * M(60, 71)
      temp = temp + M(62, 61) * M(61, 71)
      M(62, 71) = ( M(62, 71) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 15) * M(15, 72)
      temp = temp + M(62, 17) * M(17, 72)
      temp = temp + M(62, 18) * M(18, 72)
      temp = temp + M(62, 22) * M(22, 72)
      temp = temp + M(62, 23) * M(23, 72)
      temp = temp + M(62, 25) * M(25, 72)
      temp = temp + M(62, 26) * M(26, 72)
      temp = temp + M(62, 30) * M(30, 72)
      temp = temp + M(62, 35) * M(35, 72)
      temp = temp + M(62, 40) * M(40, 72)
      temp = temp + M(62, 44) * M(44, 72)
      temp = temp + M(62, 48) * M(48, 72)
      temp = temp + M(62, 49) * M(49, 72)
      temp = temp + M(62, 50) * M(50, 72)
      temp = temp + M(62, 51) * M(51, 72)
      temp = temp + M(62, 52) * M(52, 72)
      temp = temp + M(62, 53) * M(53, 72)
      temp = temp + M(62, 54) * M(54, 72)
      temp = temp + M(62, 55) * M(55, 72)
      temp = temp + M(62, 56) * M(56, 72)
      temp = temp + M(62, 58) * M(58, 72)
      temp = temp + M(62, 59) * M(59, 72)
      temp = temp + M(62, 60) * M(60, 72)
      temp = temp + M(62, 61) * M(61, 72)
      M(62, 72) = ( M(62, 72) - temp ) / M(62, 62)

C     Lower part.
      temp = M(63, 16) * M(16, 63)
      temp = temp + M(63, 31) * M(31, 63)
      temp = temp + M(63, 32) * M(32, 63)
      temp = temp + M(63, 33) * M(33, 63)
      temp = temp + M(63, 36) * M(36, 63)
      temp = temp + M(63, 37) * M(37, 63)
      temp = temp + M(63, 38) * M(38, 63)
      temp = temp + M(63, 39) * M(39, 63)
      temp = temp + M(63, 40) * M(40, 63)
      temp = temp + M(63, 41) * M(41, 63)
      temp = temp + M(63, 42) * M(42, 63)
      temp = temp + M(63, 43) * M(43, 63)
      temp = temp + M(63, 44) * M(44, 63)
      temp = temp + M(63, 45) * M(45, 63)
      temp = temp + M(63, 46) * M(46, 63)
      temp = temp + M(63, 47) * M(47, 63)
      temp = temp + M(63, 48) * M(48, 63)
      temp = temp + M(63, 49) * M(49, 63)
      temp = temp + M(63, 50) * M(50, 63)
      temp = temp + M(63, 56) * M(56, 63)
      temp = temp + M(63, 58) * M(58, 63)
      temp = temp + M(63, 59) * M(59, 63)
      temp = temp + M(63, 60) * M(60, 63)
      temp = temp + M(63, 61) * M(61, 63)
      temp = temp + M(63, 62) * M(62, 63)
      M(63, 63) = M(63, 63) - temp
C     Lower part.
      temp = M(64, 53) * M(53, 63)
      temp = temp + M(64, 56) * M(56, 63)
      temp = temp + M(64, 58) * M(58, 63)
      temp = temp + M(64, 59) * M(59, 63)
      temp = temp + M(64, 60) * M(60, 63)
      temp = temp + M(64, 62) * M(62, 63)
      M(64, 63) = M(64, 63) - temp
C     Lower part.
      temp = M(65, 36) * M(36, 63)
      temp = temp + M(65, 37) * M(37, 63)
      temp = temp + M(65, 48) * M(48, 63)
      temp = temp + M(65, 49) * M(49, 63)
      temp = temp + M(65, 50) * M(50, 63)
      temp = temp + M(65, 53) * M(53, 63)
      temp = temp + M(65, 56) * M(56, 63)
      temp = temp + M(65, 58) * M(58, 63)
      temp = temp + M(65, 59) * M(59, 63)
      temp = temp + M(65, 60) * M(60, 63)
      temp = temp + M(65, 62) * M(62, 63)
      M(65, 63) = M(65, 63) - temp
C     Lower part.
      temp = M(66, 16) * M(16, 63)
      temp = temp + M(66, 24) * M(24, 63)
      temp = temp + M(66, 31) * M(31, 63)
      temp = temp + M(66, 32) * M(32, 63)
      temp = temp + M(66, 33) * M(33, 63)
      temp = temp + M(66, 36) * M(36, 63)
      temp = temp + M(66, 37) * M(37, 63)
      temp = temp + M(66, 38) * M(38, 63)
      temp = temp + M(66, 39) * M(39, 63)
      temp = temp + M(66, 40) * M(40, 63)
      temp = temp + M(66, 41) * M(41, 63)
      temp = temp + M(66, 42) * M(42, 63)
      temp = temp + M(66, 43) * M(43, 63)
      temp = temp + M(66, 44) * M(44, 63)
      temp = temp + M(66, 45) * M(45, 63)
      temp = temp + M(66, 46) * M(46, 63)
      temp = temp + M(66, 47) * M(47, 63)
      temp = temp + M(66, 48) * M(48, 63)
      temp = temp + M(66, 49) * M(49, 63)
      temp = temp + M(66, 50) * M(50, 63)
      temp = temp + M(66, 51) * M(51, 63)
      temp = temp + M(66, 56) * M(56, 63)
      temp = temp + M(66, 58) * M(58, 63)
      temp = temp + M(66, 59) * M(59, 63)
      temp = temp + M(66, 60) * M(60, 63)
      temp = temp + M(66, 62) * M(62, 63)
      M(66, 63) = M(66, 63) - temp
C     Lower part.
      temp = M(67, 31) * M(31, 63)
      temp = temp + M(67, 32) * M(32, 63)
      temp = temp + M(67, 33) * M(33, 63)
      temp = temp + M(67, 36) * M(36, 63)
      temp = temp + M(67, 37) * M(37, 63)
      temp = temp + M(67, 38) * M(38, 63)
      temp = temp + M(67, 39) * M(39, 63)
      temp = temp + M(67, 41) * M(41, 63)
      temp = temp + M(67, 42) * M(42, 63)
      temp = temp + M(67, 43) * M(43, 63)
      temp = temp + M(67, 45) * M(45, 63)
      temp = temp + M(67, 46) * M(46, 63)
      temp = temp + M(67, 47) * M(47, 63)
      temp = temp + M(67, 49) * M(49, 63)
      temp = temp + M(67, 50) * M(50, 63)
      temp = temp + M(67, 56) * M(56, 63)
      temp = temp + M(67, 58) * M(58, 63)
      temp = temp + M(67, 59) * M(59, 63)
      temp = temp + M(67, 60) * M(60, 63)
      temp = temp + M(67, 62) * M(62, 63)
      M(67, 63) = M(67, 63) - temp
C     Lower part.
      temp = M(68, 31) * M(31, 63)
      temp = temp + M(68, 32) * M(32, 63)
      temp = temp + M(68, 33) * M(33, 63)
      temp = temp + M(68, 36) * M(36, 63)
      temp = temp + M(68, 37) * M(37, 63)
      temp = temp + M(68, 38) * M(38, 63)
      temp = temp + M(68, 39) * M(39, 63)
      temp = temp + M(68, 40) * M(40, 63)
      temp = temp + M(68, 41) * M(41, 63)
      temp = temp + M(68, 42) * M(42, 63)
      temp = temp + M(68, 43) * M(43, 63)
      temp = temp + M(68, 44) * M(44, 63)
      temp = temp + M(68, 45) * M(45, 63)
      temp = temp + M(68, 46) * M(46, 63)
      temp = temp + M(68, 47) * M(47, 63)
      temp = temp + M(68, 48) * M(48, 63)
      temp = temp + M(68, 49) * M(49, 63)
      temp = temp + M(68, 50) * M(50, 63)
      temp = temp + M(68, 51) * M(51, 63)
      temp = temp + M(68, 54) * M(54, 63)
      temp = temp + M(68, 55) * M(55, 63)
      temp = temp + M(68, 56) * M(56, 63)
      temp = temp + M(68, 58) * M(58, 63)
      temp = temp + M(68, 59) * M(59, 63)
      temp = temp + M(68, 60) * M(60, 63)
      temp = temp + M(68, 61) * M(61, 63)
      temp = temp + M(68, 62) * M(62, 63)
      M(68, 63) = M(68, 63) - temp
C     Lower part.
      temp = M(69, 24) * M(24, 63)
      temp = temp + M(69, 31) * M(31, 63)
      temp = temp + M(69, 32) * M(32, 63)
      temp = temp + M(69, 33) * M(33, 63)
      temp = temp + M(69, 36) * M(36, 63)
      temp = temp + M(69, 37) * M(37, 63)
      temp = temp + M(69, 38) * M(38, 63)
      temp = temp + M(69, 39) * M(39, 63)
      temp = temp + M(69, 41) * M(41, 63)
      temp = temp + M(69, 42) * M(42, 63)
      temp = temp + M(69, 43) * M(43, 63)
      temp = temp + M(69, 45) * M(45, 63)
      temp = temp + M(69, 46) * M(46, 63)
      temp = temp + M(69, 47) * M(47, 63)
      temp = temp + M(69, 48) * M(48, 63)
      temp = temp + M(69, 49) * M(49, 63)
      temp = temp + M(69, 50) * M(50, 63)
      temp = temp + M(69, 54) * M(54, 63)
      temp = temp + M(69, 56) * M(56, 63)
      temp = temp + M(69, 58) * M(58, 63)
      temp = temp + M(69, 59) * M(59, 63)
      temp = temp + M(69, 60) * M(60, 63)
      temp = temp + M(69, 61) * M(61, 63)
      temp = temp + M(69, 62) * M(62, 63)
      M(69, 63) = M(69, 63) - temp
C     Lower part.
      temp = M(70, 31) * M(31, 63)
      temp = temp + M(70, 32) * M(32, 63)
      temp = temp + M(70, 36) * M(36, 63)
      temp = temp + M(70, 37) * M(37, 63)
      temp = temp + M(70, 39) * M(39, 63)
      temp = temp + M(70, 42) * M(42, 63)
      temp = temp + M(70, 43) * M(43, 63)
      temp = temp + M(70, 46) * M(46, 63)
      temp = temp + M(70, 47) * M(47, 63)
      temp = temp + M(70, 49) * M(49, 63)
      temp = temp + M(70, 50) * M(50, 63)
      temp = temp + M(70, 56) * M(56, 63)
      temp = temp + M(70, 62) * M(62, 63)
      M(70, 63) = M(70, 63) - temp
C     Lower part.
      temp = M(71, 16) * M(16, 63)
      temp = temp + M(71, 24) * M(24, 63)
      temp = temp + M(71, 31) * M(31, 63)
      temp = temp + M(71, 32) * M(32, 63)
      temp = temp + M(71, 33) * M(33, 63)
      temp = temp + M(71, 36) * M(36, 63)
      temp = temp + M(71, 37) * M(37, 63)
      temp = temp + M(71, 38) * M(38, 63)
      temp = temp + M(71, 39) * M(39, 63)
      temp = temp + M(71, 40) * M(40, 63)
      temp = temp + M(71, 41) * M(41, 63)
      temp = temp + M(71, 42) * M(42, 63)
      temp = temp + M(71, 43) * M(43, 63)
      temp = temp + M(71, 44) * M(44, 63)
      temp = temp + M(71, 45) * M(45, 63)
      temp = temp + M(71, 46) * M(46, 63)
      temp = temp + M(71, 47) * M(47, 63)
      temp = temp + M(71, 48) * M(48, 63)
      temp = temp + M(71, 49) * M(49, 63)
      temp = temp + M(71, 50) * M(50, 63)
      temp = temp + M(71, 51) * M(51, 63)
      temp = temp + M(71, 52) * M(52, 63)
      temp = temp + M(71, 53) * M(53, 63)
      temp = temp + M(71, 54) * M(54, 63)
      temp = temp + M(71, 56) * M(56, 63)
      temp = temp + M(71, 58) * M(58, 63)
      temp = temp + M(71, 59) * M(59, 63)
      temp = temp + M(71, 60) * M(60, 63)
      temp = temp + M(71, 61) * M(61, 63)
      temp = temp + M(71, 62) * M(62, 63)
      M(71, 63) = M(71, 63) - temp
C     Lower part.
      temp = M(72, 31) * M(31, 63)
      temp = temp + M(72, 32) * M(32, 63)
      temp = temp + M(72, 33) * M(33, 63)
      temp = temp + M(72, 36) * M(36, 63)
      temp = temp + M(72, 37) * M(37, 63)
      temp = temp + M(72, 38) * M(38, 63)
      temp = temp + M(72, 39) * M(39, 63)
      temp = temp + M(72, 41) * M(41, 63)
      temp = temp + M(72, 42) * M(42, 63)
      temp = temp + M(72, 43) * M(43, 63)
      temp = temp + M(72, 45) * M(45, 63)
      temp = temp + M(72, 46) * M(46, 63)
      temp = temp + M(72, 47) * M(47, 63)
      temp = temp + M(72, 48) * M(48, 63)
      temp = temp + M(72, 49) * M(49, 63)
      temp = temp + M(72, 50) * M(50, 63)
      temp = temp + M(72, 55) * M(55, 63)
      temp = temp + M(72, 56) * M(56, 63)
      temp = temp + M(72, 58) * M(58, 63)
      temp = temp + M(72, 59) * M(59, 63)
      temp = temp + M(72, 60) * M(60, 63)
      temp = temp + M(72, 61) * M(61, 63)
      temp = temp + M(72, 62) * M(62, 63)
      M(72, 63) = M(72, 63) - temp
C     Upper part.
      temp = M(63, 59) * M(59, 64)
      temp = temp + M(63, 60) * M(60, 64)
      temp = temp + M(63, 61) * M(61, 64)
      temp = temp + M(63, 62) * M(62, 64)
      M(63, 64) = ( M(63, 64) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 59) * M(59, 65)
      temp = temp + M(63, 60) * M(60, 65)
      temp = temp + M(63, 61) * M(61, 65)
      temp = temp + M(63, 62) * M(62, 65)
      M(63, 65) = ( M(63, 65) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 62) * M(62, 66)
      M(63, 66) = ( M(63, 66) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 31) * M(31, 67)
      temp = temp + M(63, 32) * M(32, 67)
      temp = temp + M(63, 33) * M(33, 67)
      temp = temp + M(63, 35) * M(35, 67)
      temp = temp + M(63, 36) * M(36, 67)
      temp = temp + M(63, 37) * M(37, 67)
      temp = temp + M(63, 38) * M(38, 67)
      temp = temp + M(63, 39) * M(39, 67)
      temp = temp + M(63, 40) * M(40, 67)
      temp = temp + M(63, 41) * M(41, 67)
      temp = temp + M(63, 42) * M(42, 67)
      temp = temp + M(63, 43) * M(43, 67)
      temp = temp + M(63, 44) * M(44, 67)
      temp = temp + M(63, 45) * M(45, 67)
      temp = temp + M(63, 46) * M(46, 67)
      temp = temp + M(63, 47) * M(47, 67)
      temp = temp + M(63, 48) * M(48, 67)
      temp = temp + M(63, 49) * M(49, 67)
      temp = temp + M(63, 50) * M(50, 67)
      temp = temp + M(63, 56) * M(56, 67)
      temp = temp + M(63, 58) * M(58, 67)
      temp = temp + M(63, 59) * M(59, 67)
      temp = temp + M(63, 60) * M(60, 67)
      temp = temp + M(63, 61) * M(61, 67)
      temp = temp + M(63, 62) * M(62, 67)
      M(63, 67) = ( M(63, 67) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 12) * M(12, 68)
      temp = temp + M(63, 19) * M(19, 68)
      temp = temp + M(63, 31) * M(31, 68)
      temp = temp + M(63, 32) * M(32, 68)
      temp = temp + M(63, 33) * M(33, 68)
      temp = temp + M(63, 35) * M(35, 68)
      temp = temp + M(63, 36) * M(36, 68)
      temp = temp + M(63, 37) * M(37, 68)
      temp = temp + M(63, 38) * M(38, 68)
      temp = temp + M(63, 39) * M(39, 68)
      temp = temp + M(63, 40) * M(40, 68)
      temp = temp + M(63, 41) * M(41, 68)
      temp = temp + M(63, 42) * M(42, 68)
      temp = temp + M(63, 43) * M(43, 68)
      temp = temp + M(63, 44) * M(44, 68)
      temp = temp + M(63, 45) * M(45, 68)
      temp = temp + M(63, 46) * M(46, 68)
      temp = temp + M(63, 47) * M(47, 68)
      temp = temp + M(63, 48) * M(48, 68)
      temp = temp + M(63, 49) * M(49, 68)
      temp = temp + M(63, 50) * M(50, 68)
      temp = temp + M(63, 56) * M(56, 68)
      temp = temp + M(63, 58) * M(58, 68)
      temp = temp + M(63, 59) * M(59, 68)
      temp = temp + M(63, 60) * M(60, 68)
      temp = temp + M(63, 61) * M(61, 68)
      temp = temp + M(63, 62) * M(62, 68)
      M(63, 68) = ( M(63, 68) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 28) * M(28, 69)
      temp = temp + M(63, 31) * M(31, 69)
      temp = temp + M(63, 32) * M(32, 69)
      temp = temp + M(63, 33) * M(33, 69)
      temp = temp + M(63, 36) * M(36, 69)
      temp = temp + M(63, 37) * M(37, 69)
      temp = temp + M(63, 38) * M(38, 69)
      temp = temp + M(63, 39) * M(39, 69)
      temp = temp + M(63, 40) * M(40, 69)
      temp = temp + M(63, 41) * M(41, 69)
      temp = temp + M(63, 42) * M(42, 69)
      temp = temp + M(63, 43) * M(43, 69)
      temp = temp + M(63, 44) * M(44, 69)
      temp = temp + M(63, 45) * M(45, 69)
      temp = temp + M(63, 46) * M(46, 69)
      temp = temp + M(63, 47) * M(47, 69)
      temp = temp + M(63, 48) * M(48, 69)
      temp = temp + M(63, 49) * M(49, 69)
      temp = temp + M(63, 50) * M(50, 69)
      temp = temp + M(63, 56) * M(56, 69)
      temp = temp + M(63, 58) * M(58, 69)
      temp = temp + M(63, 59) * M(59, 69)
      temp = temp + M(63, 60) * M(60, 69)
      temp = temp + M(63, 61) * M(61, 69)
      temp = temp + M(63, 62) * M(62, 69)
      M(63, 69) = ( M(63, 69) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 59) * M(59, 70)
      temp = temp + M(63, 60) * M(60, 70)
      temp = temp + M(63, 61) * M(61, 70)
      temp = temp + M(63, 62) * M(62, 70)
      M(63, 70) = ( M(63, 70) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 16) * M(16, 71)
      temp = temp + M(63, 28) * M(28, 71)
      temp = temp + M(63, 31) * M(31, 71)
      temp = temp + M(63, 32) * M(32, 71)
      temp = temp + M(63, 33) * M(33, 71)
      temp = temp + M(63, 36) * M(36, 71)
      temp = temp + M(63, 37) * M(37, 71)
      temp = temp + M(63, 38) * M(38, 71)
      temp = temp + M(63, 39) * M(39, 71)
      temp = temp + M(63, 40) * M(40, 71)
      temp = temp + M(63, 41) * M(41, 71)
      temp = temp + M(63, 42) * M(42, 71)
      temp = temp + M(63, 43) * M(43, 71)
      temp = temp + M(63, 44) * M(44, 71)
      temp = temp + M(63, 45) * M(45, 71)
      temp = temp + M(63, 46) * M(46, 71)
      temp = temp + M(63, 47) * M(47, 71)
      temp = temp + M(63, 48) * M(48, 71)
      temp = temp + M(63, 49) * M(49, 71)
      temp = temp + M(63, 50) * M(50, 71)
      temp = temp + M(63, 56) * M(56, 71)
      temp = temp + M(63, 58) * M(58, 71)
      temp = temp + M(63, 59) * M(59, 71)
      temp = temp + M(63, 60) * M(60, 71)
      temp = temp + M(63, 61) * M(61, 71)
      temp = temp + M(63, 62) * M(62, 71)
      M(63, 71) = ( M(63, 71) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 31) * M(31, 72)
      temp = temp + M(63, 32) * M(32, 72)
      temp = temp + M(63, 33) * M(33, 72)
      temp = temp + M(63, 35) * M(35, 72)
      temp = temp + M(63, 39) * M(39, 72)
      temp = temp + M(63, 40) * M(40, 72)
      temp = temp + M(63, 41) * M(41, 72)
      temp = temp + M(63, 44) * M(44, 72)
      temp = temp + M(63, 45) * M(45, 72)
      temp = temp + M(63, 46) * M(46, 72)
      temp = temp + M(63, 47) * M(47, 72)
      temp = temp + M(63, 48) * M(48, 72)
      temp = temp + M(63, 49) * M(49, 72)
      temp = temp + M(63, 50) * M(50, 72)
      temp = temp + M(63, 56) * M(56, 72)
      temp = temp + M(63, 58) * M(58, 72)
      temp = temp + M(63, 59) * M(59, 72)
      temp = temp + M(63, 60) * M(60, 72)
      temp = temp + M(63, 61) * M(61, 72)
      temp = temp + M(63, 62) * M(62, 72)
      M(63, 72) = ( M(63, 72) - temp ) / M(63, 63)

C     Lower part.
      temp = M(64, 53) * M(53, 64)
      temp = temp + M(64, 59) * M(59, 64)
      temp = temp + M(64, 60) * M(60, 64)
      temp = temp + M(64, 62) * M(62, 64)
      temp = temp + M(64, 63) * M(63, 64)
      M(64, 64) = M(64, 64) - temp
C     Lower part.
      temp = M(65, 53) * M(53, 64)
      temp = temp + M(65, 59) * M(59, 64)
      temp = temp + M(65, 60) * M(60, 64)
      temp = temp + M(65, 62) * M(62, 64)
      temp = temp + M(65, 63) * M(63, 64)
      M(65, 64) = M(65, 64) - temp
C     Lower part.
      temp = M(66, 51) * M(51, 64)
      temp = temp + M(66, 59) * M(59, 64)
      temp = temp + M(66, 60) * M(60, 64)
      temp = temp + M(66, 62) * M(62, 64)
      temp = temp + M(66, 63) * M(63, 64)
      M(66, 64) = M(66, 64) - temp
C     Lower part.
      temp = M(67, 59) * M(59, 64)
      temp = temp + M(67, 60) * M(60, 64)
      temp = temp + M(67, 62) * M(62, 64)
      temp = temp + M(67, 63) * M(63, 64)
      M(67, 64) = M(67, 64) - temp
C     Lower part.
      temp = M(68, 51) * M(51, 64)
      temp = temp + M(68, 54) * M(54, 64)
      temp = temp + M(68, 55) * M(55, 64)
      temp = temp + M(68, 59) * M(59, 64)
      temp = temp + M(68, 60) * M(60, 64)
      temp = temp + M(68, 61) * M(61, 64)
      temp = temp + M(68, 62) * M(62, 64)
      temp = temp + M(68, 63) * M(63, 64)
      M(68, 64) = M(68, 64) - temp
C     Lower part.
      temp = M(69, 54) * M(54, 64)
      temp = temp + M(69, 59) * M(59, 64)
      temp = temp + M(69, 60) * M(60, 64)
      temp = temp + M(69, 61) * M(61, 64)
      temp = temp + M(69, 62) * M(62, 64)
      temp = temp + M(69, 63) * M(63, 64)
      M(69, 64) = M(69, 64) - temp
C     Lower part.
      temp = M(70, 62) * M(62, 64)
      temp = temp + M(70, 63) * M(63, 64)
      M(70, 64) = M(70, 64) - temp
C     Lower part.
      temp = M(71, 51) * M(51, 64)
      temp = temp + M(71, 52) * M(52, 64)
      temp = temp + M(71, 53) * M(53, 64)
      temp = temp + M(71, 54) * M(54, 64)
      temp = temp + M(71, 59) * M(59, 64)
      temp = temp + M(71, 60) * M(60, 64)
      temp = temp + M(71, 61) * M(61, 64)
      temp = temp + M(71, 62) * M(62, 64)
      temp = temp + M(71, 63) * M(63, 64)
      M(71, 64) = M(71, 64) - temp
C     Lower part.
      temp = M(72, 55) * M(55, 64)
      temp = temp + M(72, 59) * M(59, 64)
      temp = temp + M(72, 60) * M(60, 64)
      temp = temp + M(72, 61) * M(61, 64)
      temp = temp + M(72, 62) * M(62, 64)
      temp = temp + M(72, 63) * M(63, 64)
      M(72, 64) = M(72, 64) - temp
C     Upper part.
      temp = M(64, 53) * M(53, 65)
      temp = temp + M(64, 59) * M(59, 65)
      temp = temp + M(64, 60) * M(60, 65)
      temp = temp + M(64, 62) * M(62, 65)
      temp = temp + M(64, 63) * M(63, 65)
      M(64, 65) = ( M(64, 65) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 62) * M(62, 66)
      temp = temp + M(64, 63) * M(63, 66)
      M(64, 66) = ( M(64, 66) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 53) * M(53, 67)
      temp = temp + M(64, 56) * M(56, 67)
      temp = temp + M(64, 58) * M(58, 67)
      temp = temp + M(64, 59) * M(59, 67)
      temp = temp + M(64, 60) * M(60, 67)
      temp = temp + M(64, 62) * M(62, 67)
      temp = temp + M(64, 63) * M(63, 67)
      M(64, 67) = ( M(64, 67) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 53) * M(53, 68)
      temp = temp + M(64, 56) * M(56, 68)
      temp = temp + M(64, 58) * M(58, 68)
      temp = temp + M(64, 59) * M(59, 68)
      temp = temp + M(64, 60) * M(60, 68)
      temp = temp + M(64, 62) * M(62, 68)
      temp = temp + M(64, 63) * M(63, 68)
      M(64, 68) = ( M(64, 68) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 53) * M(53, 69)
      temp = temp + M(64, 56) * M(56, 69)
      temp = temp + M(64, 58) * M(58, 69)
      temp = temp + M(64, 59) * M(59, 69)
      temp = temp + M(64, 60) * M(60, 69)
      temp = temp + M(64, 62) * M(62, 69)
      temp = temp + M(64, 63) * M(63, 69)
      M(64, 69) = ( M(64, 69) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 59) * M(59, 70)
      temp = temp + M(64, 60) * M(60, 70)
      temp = temp + M(64, 62) * M(62, 70)
      temp = temp + M(64, 63) * M(63, 70)
      M(64, 70) = ( M(64, 70) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 53) * M(53, 71)
      temp = temp + M(64, 56) * M(56, 71)
      temp = temp + M(64, 58) * M(58, 71)
      temp = temp + M(64, 59) * M(59, 71)
      temp = temp + M(64, 60) * M(60, 71)
      temp = temp + M(64, 62) * M(62, 71)
      temp = temp + M(64, 63) * M(63, 71)
      M(64, 71) = ( M(64, 71) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 53) * M(53, 72)
      temp = temp + M(64, 56) * M(56, 72)
      temp = temp + M(64, 58) * M(58, 72)
      temp = temp + M(64, 59) * M(59, 72)
      temp = temp + M(64, 60) * M(60, 72)
      temp = temp + M(64, 62) * M(62, 72)
      temp = temp + M(64, 63) * M(63, 72)
      M(64, 72) = ( M(64, 72) - temp ) / M(64, 64)

C     Lower part.
      temp = M(65, 53) * M(53, 65)
      temp = temp + M(65, 59) * M(59, 65)
      temp = temp + M(65, 60) * M(60, 65)
      temp = temp + M(65, 62) * M(62, 65)
      temp = temp + M(65, 63) * M(63, 65)
      temp = temp + M(65, 64) * M(64, 65)
      M(65, 65) = M(65, 65) - temp
C     Lower part.
      temp = M(66, 59) * M(59, 65)
      temp = temp + M(66, 60) * M(60, 65)
      temp = temp + M(66, 62) * M(62, 65)
      temp = temp + M(66, 63) * M(63, 65)
      temp = temp + M(66, 64) * M(64, 65)
      M(66, 65) = M(66, 65) - temp
C     Lower part.
      temp = M(67, 59) * M(59, 65)
      temp = temp + M(67, 60) * M(60, 65)
      temp = temp + M(67, 62) * M(62, 65)
      temp = temp + M(67, 63) * M(63, 65)
      temp = temp + M(67, 64) * M(64, 65)
      M(67, 65) = M(67, 65) - temp
C     Lower part.
      temp = M(68, 59) * M(59, 65)
      temp = temp + M(68, 60) * M(60, 65)
      temp = temp + M(68, 61) * M(61, 65)
      temp = temp + M(68, 62) * M(62, 65)
      temp = temp + M(68, 63) * M(63, 65)
      temp = temp + M(68, 64) * M(64, 65)
      M(68, 65) = M(68, 65) - temp
C     Lower part.
      temp = M(69, 59) * M(59, 65)
      temp = temp + M(69, 60) * M(60, 65)
      temp = temp + M(69, 61) * M(61, 65)
      temp = temp + M(69, 62) * M(62, 65)
      temp = temp + M(69, 63) * M(63, 65)
      temp = temp + M(69, 64) * M(64, 65)
      M(69, 65) = M(69, 65) - temp
C     Lower part.
      temp = M(70, 62) * M(62, 65)
      temp = temp + M(70, 63) * M(63, 65)
      temp = temp + M(70, 64) * M(64, 65)
      M(70, 65) = M(70, 65) - temp
C     Lower part.
      temp = M(71, 53) * M(53, 65)
      temp = temp + M(71, 59) * M(59, 65)
      temp = temp + M(71, 60) * M(60, 65)
      temp = temp + M(71, 61) * M(61, 65)
      temp = temp + M(71, 62) * M(62, 65)
      temp = temp + M(71, 63) * M(63, 65)
      temp = temp + M(71, 64) * M(64, 65)
      M(71, 65) = M(71, 65) - temp
C     Lower part.
      temp = M(72, 59) * M(59, 65)
      temp = temp + M(72, 60) * M(60, 65)
      temp = temp + M(72, 61) * M(61, 65)
      temp = temp + M(72, 62) * M(62, 65)
      temp = temp + M(72, 63) * M(63, 65)
      temp = temp + M(72, 64) * M(64, 65)
      M(72, 65) = M(72, 65) - temp
C     Upper part.
      temp = M(65, 62) * M(62, 66)
      temp = temp + M(65, 63) * M(63, 66)
      temp = temp + M(65, 64) * M(64, 66)
      M(65, 66) = ( M(65, 66) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 35) * M(35, 67)
      temp = temp + M(65, 36) * M(36, 67)
      temp = temp + M(65, 37) * M(37, 67)
      temp = temp + M(65, 48) * M(48, 67)
      temp = temp + M(65, 49) * M(49, 67)
      temp = temp + M(65, 50) * M(50, 67)
      temp = temp + M(65, 53) * M(53, 67)
      temp = temp + M(65, 56) * M(56, 67)
      temp = temp + M(65, 58) * M(58, 67)
      temp = temp + M(65, 59) * M(59, 67)
      temp = temp + M(65, 60) * M(60, 67)
      temp = temp + M(65, 62) * M(62, 67)
      temp = temp + M(65, 63) * M(63, 67)
      temp = temp + M(65, 64) * M(64, 67)
      M(65, 67) = ( M(65, 67) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 12) * M(12, 68)
      temp = temp + M(65, 19) * M(19, 68)
      temp = temp + M(65, 25) * M(25, 68)
      temp = temp + M(65, 26) * M(26, 68)
      temp = temp + M(65, 30) * M(30, 68)
      temp = temp + M(65, 35) * M(35, 68)
      temp = temp + M(65, 36) * M(36, 68)
      temp = temp + M(65, 37) * M(37, 68)
      temp = temp + M(65, 48) * M(48, 68)
      temp = temp + M(65, 49) * M(49, 68)
      temp = temp + M(65, 50) * M(50, 68)
      temp = temp + M(65, 53) * M(53, 68)
      temp = temp + M(65, 56) * M(56, 68)
      temp = temp + M(65, 58) * M(58, 68)
      temp = temp + M(65, 59) * M(59, 68)
      temp = temp + M(65, 60) * M(60, 68)
      temp = temp + M(65, 62) * M(62, 68)
      temp = temp + M(65, 63) * M(63, 68)
      temp = temp + M(65, 64) * M(64, 68)
      M(65, 68) = ( M(65, 68) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 26) * M(26, 69)
      temp = temp + M(65, 28) * M(28, 69)
      temp = temp + M(65, 36) * M(36, 69)
      temp = temp + M(65, 37) * M(37, 69)
      temp = temp + M(65, 48) * M(48, 69)
      temp = temp + M(65, 49) * M(49, 69)
      temp = temp + M(65, 50) * M(50, 69)
      temp = temp + M(65, 53) * M(53, 69)
      temp = temp + M(65, 56) * M(56, 69)
      temp = temp + M(65, 58) * M(58, 69)
      temp = temp + M(65, 59) * M(59, 69)
      temp = temp + M(65, 60) * M(60, 69)
      temp = temp + M(65, 62) * M(62, 69)
      temp = temp + M(65, 63) * M(63, 69)
      temp = temp + M(65, 64) * M(64, 69)
      M(65, 69) = ( M(65, 69) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 59) * M(59, 70)
      temp = temp + M(65, 60) * M(60, 70)
      temp = temp + M(65, 62) * M(62, 70)
      temp = temp + M(65, 63) * M(63, 70)
      temp = temp + M(65, 64) * M(64, 70)
      M(65, 70) = ( M(65, 70) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 28) * M(28, 71)
      temp = temp + M(65, 30) * M(30, 71)
      temp = temp + M(65, 36) * M(36, 71)
      temp = temp + M(65, 37) * M(37, 71)
      temp = temp + M(65, 48) * M(48, 71)
      temp = temp + M(65, 49) * M(49, 71)
      temp = temp + M(65, 50) * M(50, 71)
      temp = temp + M(65, 53) * M(53, 71)
      temp = temp + M(65, 56) * M(56, 71)
      temp = temp + M(65, 58) * M(58, 71)
      temp = temp + M(65, 59) * M(59, 71)
      temp = temp + M(65, 60) * M(60, 71)
      temp = temp + M(65, 62) * M(62, 71)
      temp = temp + M(65, 63) * M(63, 71)
      temp = temp + M(65, 64) * M(64, 71)
      M(65, 71) = ( M(65, 71) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 25) * M(25, 72)
      temp = temp + M(65, 26) * M(26, 72)
      temp = temp + M(65, 30) * M(30, 72)
      temp = temp + M(65, 35) * M(35, 72)
      temp = temp + M(65, 48) * M(48, 72)
      temp = temp + M(65, 49) * M(49, 72)
      temp = temp + M(65, 50) * M(50, 72)
      temp = temp + M(65, 53) * M(53, 72)
      temp = temp + M(65, 56) * M(56, 72)
      temp = temp + M(65, 58) * M(58, 72)
      temp = temp + M(65, 59) * M(59, 72)
      temp = temp + M(65, 60) * M(60, 72)
      temp = temp + M(65, 62) * M(62, 72)
      temp = temp + M(65, 63) * M(63, 72)
      temp = temp + M(65, 64) * M(64, 72)
      M(65, 72) = ( M(65, 72) - temp ) / M(65, 65)

C     Lower part.
      temp = M(66, 62) * M(62, 66)
      temp = temp + M(66, 63) * M(63, 66)
      temp = temp + M(66, 64) * M(64, 66)
      temp = temp + M(66, 65) * M(65, 66)
      M(66, 66) = M(66, 66) - temp
C     Lower part.
      temp = M(67, 62) * M(62, 66)
      temp = temp + M(67, 63) * M(63, 66)
      temp = temp + M(67, 64) * M(64, 66)
      temp = temp + M(67, 65) * M(65, 66)
      M(67, 66) = M(67, 66) - temp
C     Lower part.
      temp = M(68, 55) * M(55, 66)
      temp = temp + M(68, 62) * M(62, 66)
      temp = temp + M(68, 63) * M(63, 66)
      temp = temp + M(68, 64) * M(64, 66)
      temp = temp + M(68, 65) * M(65, 66)
      M(68, 66) = M(68, 66) - temp
C     Lower part.
      temp = M(69, 62) * M(62, 66)
      temp = temp + M(69, 63) * M(63, 66)
      temp = temp + M(69, 64) * M(64, 66)
      temp = temp + M(69, 65) * M(65, 66)
      M(69, 66) = M(69, 66) - temp
C     Lower part.
      temp = M(70, 62) * M(62, 66)
      temp = temp + M(70, 63) * M(63, 66)
      temp = temp + M(70, 64) * M(64, 66)
      temp = temp + M(70, 65) * M(65, 66)
      M(70, 66) = M(70, 66) - temp
C     Lower part.
      temp = M(71, 52) * M(52, 66)
      temp = temp + M(71, 62) * M(62, 66)
      temp = temp + M(71, 63) * M(63, 66)
      temp = temp + M(71, 64) * M(64, 66)
      temp = temp + M(71, 65) * M(65, 66)
      M(71, 66) = M(71, 66) - temp
C     Lower part.
      temp = M(72, 55) * M(55, 66)
      temp = temp + M(72, 62) * M(62, 66)
      temp = temp + M(72, 63) * M(63, 66)
      temp = temp + M(72, 64) * M(64, 66)
      temp = temp + M(72, 65) * M(65, 66)
      M(72, 66) = M(72, 66) - temp
C     Upper part.
      temp = M(66, 31) * M(31, 67)
      temp = temp + M(66, 32) * M(32, 67)
      temp = temp + M(66, 33) * M(33, 67)
      temp = temp + M(66, 35) * M(35, 67)
      temp = temp + M(66, 36) * M(36, 67)
      temp = temp + M(66, 37) * M(37, 67)
      temp = temp + M(66, 38) * M(38, 67)
      temp = temp + M(66, 39) * M(39, 67)
      temp = temp + M(66, 40) * M(40, 67)
      temp = temp + M(66, 41) * M(41, 67)
      temp = temp + M(66, 42) * M(42, 67)
      temp = temp + M(66, 43) * M(43, 67)
      temp = temp + M(66, 44) * M(44, 67)
      temp = temp + M(66, 45) * M(45, 67)
      temp = temp + M(66, 46) * M(46, 67)
      temp = temp + M(66, 47) * M(47, 67)
      temp = temp + M(66, 48) * M(48, 67)
      temp = temp + M(66, 49) * M(49, 67)
      temp = temp + M(66, 50) * M(50, 67)
      temp = temp + M(66, 51) * M(51, 67)
      temp = temp + M(66, 56) * M(56, 67)
      temp = temp + M(66, 58) * M(58, 67)
      temp = temp + M(66, 59) * M(59, 67)
      temp = temp + M(66, 60) * M(60, 67)
      temp = temp + M(66, 62) * M(62, 67)
      temp = temp + M(66, 63) * M(63, 67)
      temp = temp + M(66, 64) * M(64, 67)
      temp = temp + M(66, 65) * M(65, 67)
      M(66, 67) = ( M(66, 67) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 11) * M(11, 68)
      temp = temp + M(66, 12) * M(12, 68)
      temp = temp + M(66, 14) * M(14, 68)
      temp = temp + M(66, 19) * M(19, 68)
      temp = temp + M(66, 25) * M(25, 68)
      temp = temp + M(66, 26) * M(26, 68)
      temp = temp + M(66, 31) * M(31, 68)
      temp = temp + M(66, 32) * M(32, 68)
      temp = temp + M(66, 33) * M(33, 68)
      temp = temp + M(66, 35) * M(35, 68)
      temp = temp + M(66, 36) * M(36, 68)
      temp = temp + M(66, 37) * M(37, 68)
      temp = temp + M(66, 38) * M(38, 68)
      temp = temp + M(66, 39) * M(39, 68)
      temp = temp + M(66, 40) * M(40, 68)
      temp = temp + M(66, 41) * M(41, 68)
      temp = temp + M(66, 42) * M(42, 68)
      temp = temp + M(66, 43) * M(43, 68)
      temp = temp + M(66, 44) * M(44, 68)
      temp = temp + M(66, 45) * M(45, 68)
      temp = temp + M(66, 46) * M(46, 68)
      temp = temp + M(66, 47) * M(47, 68)
      temp = temp + M(66, 48) * M(48, 68)
      temp = temp + M(66, 49) * M(49, 68)
      temp = temp + M(66, 50) * M(50, 68)
      temp = temp + M(66, 51) * M(51, 68)
      temp = temp + M(66, 56) * M(56, 68)
      temp = temp + M(66, 58) * M(58, 68)
      temp = temp + M(66, 59) * M(59, 68)
      temp = temp + M(66, 60) * M(60, 68)
      temp = temp + M(66, 62) * M(62, 68)
      temp = temp + M(66, 63) * M(63, 68)
      temp = temp + M(66, 64) * M(64, 68)
      temp = temp + M(66, 65) * M(65, 68)
      M(66, 68) = ( M(66, 68) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 26) * M(26, 69)
      temp = temp + M(66, 28) * M(28, 69)
      temp = temp + M(66, 31) * M(31, 69)
      temp = temp + M(66, 32) * M(32, 69)
      temp = temp + M(66, 33) * M(33, 69)
      temp = temp + M(66, 36) * M(36, 69)
      temp = temp + M(66, 37) * M(37, 69)
      temp = temp + M(66, 38) * M(38, 69)
      temp = temp + M(66, 39) * M(39, 69)
      temp = temp + M(66, 40) * M(40, 69)
      temp = temp + M(66, 41) * M(41, 69)
      temp = temp + M(66, 42) * M(42, 69)
      temp = temp + M(66, 43) * M(43, 69)
      temp = temp + M(66, 44) * M(44, 69)
      temp = temp + M(66, 45) * M(45, 69)
      temp = temp + M(66, 46) * M(46, 69)
      temp = temp + M(66, 47) * M(47, 69)
      temp = temp + M(66, 48) * M(48, 69)
      temp = temp + M(66, 49) * M(49, 69)
      temp = temp + M(66, 50) * M(50, 69)
      temp = temp + M(66, 51) * M(51, 69)
      temp = temp + M(66, 56) * M(56, 69)
      temp = temp + M(66, 58) * M(58, 69)
      temp = temp + M(66, 59) * M(59, 69)
      temp = temp + M(66, 60) * M(60, 69)
      temp = temp + M(66, 62) * M(62, 69)
      temp = temp + M(66, 63) * M(63, 69)
      temp = temp + M(66, 64) * M(64, 69)
      temp = temp + M(66, 65) * M(65, 69)
      M(66, 69) = ( M(66, 69) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 59) * M(59, 70)
      temp = temp + M(66, 60) * M(60, 70)
      temp = temp + M(66, 62) * M(62, 70)
      temp = temp + M(66, 63) * M(63, 70)
      temp = temp + M(66, 64) * M(64, 70)
      temp = temp + M(66, 65) * M(65, 70)
      M(66, 70) = ( M(66, 70) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 16) * M(16, 71)
      temp = temp + M(66, 28) * M(28, 71)
      temp = temp + M(66, 31) * M(31, 71)
      temp = temp + M(66, 32) * M(32, 71)
      temp = temp + M(66, 33) * M(33, 71)
      temp = temp + M(66, 36) * M(36, 71)
      temp = temp + M(66, 37) * M(37, 71)
      temp = temp + M(66, 38) * M(38, 71)
      temp = temp + M(66, 39) * M(39, 71)
      temp = temp + M(66, 40) * M(40, 71)
      temp = temp + M(66, 41) * M(41, 71)
      temp = temp + M(66, 42) * M(42, 71)
      temp = temp + M(66, 43) * M(43, 71)
      temp = temp + M(66, 44) * M(44, 71)
      temp = temp + M(66, 45) * M(45, 71)
      temp = temp + M(66, 46) * M(46, 71)
      temp = temp + M(66, 47) * M(47, 71)
      temp = temp + M(66, 48) * M(48, 71)
      temp = temp + M(66, 49) * M(49, 71)
      temp = temp + M(66, 50) * M(50, 71)
      temp = temp + M(66, 51) * M(51, 71)
      temp = temp + M(66, 56) * M(56, 71)
      temp = temp + M(66, 58) * M(58, 71)
      temp = temp + M(66, 59) * M(59, 71)
      temp = temp + M(66, 60) * M(60, 71)
      temp = temp + M(66, 62) * M(62, 71)
      temp = temp + M(66, 63) * M(63, 71)
      temp = temp + M(66, 64) * M(64, 71)
      temp = temp + M(66, 65) * M(65, 71)
      M(66, 71) = ( M(66, 71) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 25) * M(25, 72)
      temp = temp + M(66, 26) * M(26, 72)
      temp = temp + M(66, 31) * M(31, 72)
      temp = temp + M(66, 32) * M(32, 72)
      temp = temp + M(66, 33) * M(33, 72)
      temp = temp + M(66, 35) * M(35, 72)
      temp = temp + M(66, 39) * M(39, 72)
      temp = temp + M(66, 40) * M(40, 72)
      temp = temp + M(66, 41) * M(41, 72)
      temp = temp + M(66, 44) * M(44, 72)
      temp = temp + M(66, 45) * M(45, 72)
      temp = temp + M(66, 46) * M(46, 72)
      temp = temp + M(66, 47) * M(47, 72)
      temp = temp + M(66, 48) * M(48, 72)
      temp = temp + M(66, 49) * M(49, 72)
      temp = temp + M(66, 50) * M(50, 72)
      temp = temp + M(66, 51) * M(51, 72)
      temp = temp + M(66, 56) * M(56, 72)
      temp = temp + M(66, 58) * M(58, 72)
      temp = temp + M(66, 59) * M(59, 72)
      temp = temp + M(66, 60) * M(60, 72)
      temp = temp + M(66, 62) * M(62, 72)
      temp = temp + M(66, 63) * M(63, 72)
      temp = temp + M(66, 64) * M(64, 72)
      temp = temp + M(66, 65) * M(65, 72)
      M(66, 72) = ( M(66, 72) - temp ) / M(66, 66)

C     Lower part.
      temp = M(67, 23) * M(23, 67)
      temp = temp + M(67, 31) * M(31, 67)
      temp = temp + M(67, 32) * M(32, 67)
      temp = temp + M(67, 33) * M(33, 67)
      temp = temp + M(67, 35) * M(35, 67)
      temp = temp + M(67, 36) * M(36, 67)
      temp = temp + M(67, 37) * M(37, 67)
      temp = temp + M(67, 38) * M(38, 67)
      temp = temp + M(67, 39) * M(39, 67)
      temp = temp + M(67, 41) * M(41, 67)
      temp = temp + M(67, 42) * M(42, 67)
      temp = temp + M(67, 43) * M(43, 67)
      temp = temp + M(67, 45) * M(45, 67)
      temp = temp + M(67, 46) * M(46, 67)
      temp = temp + M(67, 47) * M(47, 67)
      temp = temp + M(67, 49) * M(49, 67)
      temp = temp + M(67, 50) * M(50, 67)
      temp = temp + M(67, 56) * M(56, 67)
      temp = temp + M(67, 58) * M(58, 67)
      temp = temp + M(67, 59) * M(59, 67)
      temp = temp + M(67, 60) * M(60, 67)
      temp = temp + M(67, 62) * M(62, 67)
      temp = temp + M(67, 63) * M(63, 67)
      temp = temp + M(67, 64) * M(64, 67)
      temp = temp + M(67, 65) * M(65, 67)
      temp = temp + M(67, 66) * M(66, 67)
      M(67, 67) = M(67, 67) - temp
C     Lower part.
      temp = M(68, 31) * M(31, 67)
      temp = temp + M(68, 32) * M(32, 67)
      temp = temp + M(68, 33) * M(33, 67)
      temp = temp + M(68, 35) * M(35, 67)
      temp = temp + M(68, 36) * M(36, 67)
      temp = temp + M(68, 37) * M(37, 67)
      temp = temp + M(68, 38) * M(38, 67)
      temp = temp + M(68, 39) * M(39, 67)
      temp = temp + M(68, 40) * M(40, 67)
      temp = temp + M(68, 41) * M(41, 67)
      temp = temp + M(68, 42) * M(42, 67)
      temp = temp + M(68, 43) * M(43, 67)
      temp = temp + M(68, 44) * M(44, 67)
      temp = temp + M(68, 45) * M(45, 67)
      temp = temp + M(68, 46) * M(46, 67)
      temp = temp + M(68, 47) * M(47, 67)
      temp = temp + M(68, 48) * M(48, 67)
      temp = temp + M(68, 49) * M(49, 67)
      temp = temp + M(68, 50) * M(50, 67)
      temp = temp + M(68, 51) * M(51, 67)
      temp = temp + M(68, 54) * M(54, 67)
      temp = temp + M(68, 55) * M(55, 67)
      temp = temp + M(68, 56) * M(56, 67)
      temp = temp + M(68, 58) * M(58, 67)
      temp = temp + M(68, 59) * M(59, 67)
      temp = temp + M(68, 60) * M(60, 67)
      temp = temp + M(68, 61) * M(61, 67)
      temp = temp + M(68, 62) * M(62, 67)
      temp = temp + M(68, 63) * M(63, 67)
      temp = temp + M(68, 64) * M(64, 67)
      temp = temp + M(68, 65) * M(65, 67)
      temp = temp + M(68, 66) * M(66, 67)
      M(68, 67) = M(68, 67) - temp
C     Lower part.
      temp = M(69, 31) * M(31, 67)
      temp = temp + M(69, 32) * M(32, 67)
      temp = temp + M(69, 33) * M(33, 67)
      temp = temp + M(69, 35) * M(35, 67)
      temp = temp + M(69, 36) * M(36, 67)
      temp = temp + M(69, 37) * M(37, 67)
      temp = temp + M(69, 38) * M(38, 67)
      temp = temp + M(69, 39) * M(39, 67)
      temp = temp + M(69, 41) * M(41, 67)
      temp = temp + M(69, 42) * M(42, 67)
      temp = temp + M(69, 43) * M(43, 67)
      temp = temp + M(69, 45) * M(45, 67)
      temp = temp + M(69, 46) * M(46, 67)
      temp = temp + M(69, 47) * M(47, 67)
      temp = temp + M(69, 48) * M(48, 67)
      temp = temp + M(69, 49) * M(49, 67)
      temp = temp + M(69, 50) * M(50, 67)
      temp = temp + M(69, 54) * M(54, 67)
      temp = temp + M(69, 56) * M(56, 67)
      temp = temp + M(69, 58) * M(58, 67)
      temp = temp + M(69, 59) * M(59, 67)
      temp = temp + M(69, 60) * M(60, 67)
      temp = temp + M(69, 61) * M(61, 67)
      temp = temp + M(69, 62) * M(62, 67)
      temp = temp + M(69, 63) * M(63, 67)
      temp = temp + M(69, 64) * M(64, 67)
      temp = temp + M(69, 65) * M(65, 67)
      temp = temp + M(69, 66) * M(66, 67)
      M(69, 67) = M(69, 67) - temp
C     Lower part.
      temp = M(70, 31) * M(31, 67)
      temp = temp + M(70, 32) * M(32, 67)
      temp = temp + M(70, 36) * M(36, 67)
      temp = temp + M(70, 37) * M(37, 67)
      temp = temp + M(70, 39) * M(39, 67)
      temp = temp + M(70, 42) * M(42, 67)
      temp = temp + M(70, 43) * M(43, 67)
      temp = temp + M(70, 46) * M(46, 67)
      temp = temp + M(70, 47) * M(47, 67)
      temp = temp + M(70, 49) * M(49, 67)
      temp = temp + M(70, 50) * M(50, 67)
      temp = temp + M(70, 56) * M(56, 67)
      temp = temp + M(70, 62) * M(62, 67)
      temp = temp + M(70, 63) * M(63, 67)
      temp = temp + M(70, 64) * M(64, 67)
      temp = temp + M(70, 65) * M(65, 67)
      temp = temp + M(70, 66) * M(66, 67)
      M(70, 67) = M(70, 67) - temp
C     Lower part.
      temp = M(71, 31) * M(31, 67)
      temp = temp + M(71, 32) * M(32, 67)
      temp = temp + M(71, 33) * M(33, 67)
      temp = temp + M(71, 35) * M(35, 67)
      temp = temp + M(71, 36) * M(36, 67)
      temp = temp + M(71, 37) * M(37, 67)
      temp = temp + M(71, 38) * M(38, 67)
      temp = temp + M(71, 39) * M(39, 67)
      temp = temp + M(71, 40) * M(40, 67)
      temp = temp + M(71, 41) * M(41, 67)
      temp = temp + M(71, 42) * M(42, 67)
      temp = temp + M(71, 43) * M(43, 67)
      temp = temp + M(71, 44) * M(44, 67)
      temp = temp + M(71, 45) * M(45, 67)
      temp = temp + M(71, 46) * M(46, 67)
      temp = temp + M(71, 47) * M(47, 67)
      temp = temp + M(71, 48) * M(48, 67)
      temp = temp + M(71, 49) * M(49, 67)
      temp = temp + M(71, 50) * M(50, 67)
      temp = temp + M(71, 51) * M(51, 67)
      temp = temp + M(71, 52) * M(52, 67)
      temp = temp + M(71, 53) * M(53, 67)
      temp = temp + M(71, 54) * M(54, 67)
      temp = temp + M(71, 56) * M(56, 67)
      temp = temp + M(71, 58) * M(58, 67)
      temp = temp + M(71, 59) * M(59, 67)
      temp = temp + M(71, 60) * M(60, 67)
      temp = temp + M(71, 61) * M(61, 67)
      temp = temp + M(71, 62) * M(62, 67)
      temp = temp + M(71, 63) * M(63, 67)
      temp = temp + M(71, 64) * M(64, 67)
      temp = temp + M(71, 65) * M(65, 67)
      temp = temp + M(71, 66) * M(66, 67)
      M(71, 67) = M(71, 67) - temp
C     Lower part.
      temp = M(72, 23) * M(23, 67)
      temp = temp + M(72, 31) * M(31, 67)
      temp = temp + M(72, 32) * M(32, 67)
      temp = temp + M(72, 33) * M(33, 67)
      temp = temp + M(72, 35) * M(35, 67)
      temp = temp + M(72, 36) * M(36, 67)
      temp = temp + M(72, 37) * M(37, 67)
      temp = temp + M(72, 38) * M(38, 67)
      temp = temp + M(72, 39) * M(39, 67)
      temp = temp + M(72, 41) * M(41, 67)
      temp = temp + M(72, 42) * M(42, 67)
      temp = temp + M(72, 43) * M(43, 67)
      temp = temp + M(72, 45) * M(45, 67)
      temp = temp + M(72, 46) * M(46, 67)
      temp = temp + M(72, 47) * M(47, 67)
      temp = temp + M(72, 48) * M(48, 67)
      temp = temp + M(72, 49) * M(49, 67)
      temp = temp + M(72, 50) * M(50, 67)
      temp = temp + M(72, 55) * M(55, 67)
      temp = temp + M(72, 56) * M(56, 67)
      temp = temp + M(72, 58) * M(58, 67)
      temp = temp + M(72, 59) * M(59, 67)
      temp = temp + M(72, 60) * M(60, 67)
      temp = temp + M(72, 61) * M(61, 67)
      temp = temp + M(72, 62) * M(62, 67)
      temp = temp + M(72, 63) * M(63, 67)
      temp = temp + M(72, 64) * M(64, 67)
      temp = temp + M(72, 65) * M(65, 67)
      temp = temp + M(72, 66) * M(66, 67)
      M(72, 67) = M(72, 67) - temp
C     Upper part.
      temp = M(67, 30) * M(30, 68)
      temp = temp + M(67, 31) * M(31, 68)
      temp = temp + M(67, 32) * M(32, 68)
      temp = temp + M(67, 33) * M(33, 68)
      temp = temp + M(67, 35) * M(35, 68)
      temp = temp + M(67, 36) * M(36, 68)
      temp = temp + M(67, 37) * M(37, 68)
      temp = temp + M(67, 38) * M(38, 68)
      temp = temp + M(67, 39) * M(39, 68)
      temp = temp + M(67, 41) * M(41, 68)
      temp = temp + M(67, 42) * M(42, 68)
      temp = temp + M(67, 43) * M(43, 68)
      temp = temp + M(67, 45) * M(45, 68)
      temp = temp + M(67, 46) * M(46, 68)
      temp = temp + M(67, 47) * M(47, 68)
      temp = temp + M(67, 49) * M(49, 68)
      temp = temp + M(67, 50) * M(50, 68)
      temp = temp + M(67, 56) * M(56, 68)
      temp = temp + M(67, 58) * M(58, 68)
      temp = temp + M(67, 59) * M(59, 68)
      temp = temp + M(67, 60) * M(60, 68)
      temp = temp + M(67, 62) * M(62, 68)
      temp = temp + M(67, 63) * M(63, 68)
      temp = temp + M(67, 64) * M(64, 68)
      temp = temp + M(67, 65) * M(65, 68)
      temp = temp + M(67, 66) * M(66, 68)
      M(67, 68) = ( M(67, 68) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 31) * M(31, 69)
      temp = temp + M(67, 32) * M(32, 69)
      temp = temp + M(67, 33) * M(33, 69)
      temp = temp + M(67, 36) * M(36, 69)
      temp = temp + M(67, 37) * M(37, 69)
      temp = temp + M(67, 38) * M(38, 69)
      temp = temp + M(67, 39) * M(39, 69)
      temp = temp + M(67, 41) * M(41, 69)
      temp = temp + M(67, 42) * M(42, 69)
      temp = temp + M(67, 43) * M(43, 69)
      temp = temp + M(67, 45) * M(45, 69)
      temp = temp + M(67, 46) * M(46, 69)
      temp = temp + M(67, 47) * M(47, 69)
      temp = temp + M(67, 49) * M(49, 69)
      temp = temp + M(67, 50) * M(50, 69)
      temp = temp + M(67, 56) * M(56, 69)
      temp = temp + M(67, 58) * M(58, 69)
      temp = temp + M(67, 59) * M(59, 69)
      temp = temp + M(67, 60) * M(60, 69)
      temp = temp + M(67, 62) * M(62, 69)
      temp = temp + M(67, 63) * M(63, 69)
      temp = temp + M(67, 64) * M(64, 69)
      temp = temp + M(67, 65) * M(65, 69)
      temp = temp + M(67, 66) * M(66, 69)
      M(67, 69) = ( M(67, 69) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 59) * M(59, 70)
      temp = temp + M(67, 60) * M(60, 70)
      temp = temp + M(67, 62) * M(62, 70)
      temp = temp + M(67, 63) * M(63, 70)
      temp = temp + M(67, 64) * M(64, 70)
      temp = temp + M(67, 65) * M(65, 70)
      temp = temp + M(67, 66) * M(66, 70)
      M(67, 70) = ( M(67, 70) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 30) * M(30, 71)
      temp = temp + M(67, 31) * M(31, 71)
      temp = temp + M(67, 32) * M(32, 71)
      temp = temp + M(67, 33) * M(33, 71)
      temp = temp + M(67, 36) * M(36, 71)
      temp = temp + M(67, 37) * M(37, 71)
      temp = temp + M(67, 38) * M(38, 71)
      temp = temp + M(67, 39) * M(39, 71)
      temp = temp + M(67, 41) * M(41, 71)
      temp = temp + M(67, 42) * M(42, 71)
      temp = temp + M(67, 43) * M(43, 71)
      temp = temp + M(67, 45) * M(45, 71)
      temp = temp + M(67, 46) * M(46, 71)
      temp = temp + M(67, 47) * M(47, 71)
      temp = temp + M(67, 49) * M(49, 71)
      temp = temp + M(67, 50) * M(50, 71)
      temp = temp + M(67, 56) * M(56, 71)
      temp = temp + M(67, 58) * M(58, 71)
      temp = temp + M(67, 59) * M(59, 71)
      temp = temp + M(67, 60) * M(60, 71)
      temp = temp + M(67, 62) * M(62, 71)
      temp = temp + M(67, 63) * M(63, 71)
      temp = temp + M(67, 64) * M(64, 71)
      temp = temp + M(67, 65) * M(65, 71)
      temp = temp + M(67, 66) * M(66, 71)
      M(67, 71) = ( M(67, 71) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 23) * M(23, 72)
      temp = temp + M(67, 30) * M(30, 72)
      temp = temp + M(67, 31) * M(31, 72)
      temp = temp + M(67, 32) * M(32, 72)
      temp = temp + M(67, 33) * M(33, 72)
      temp = temp + M(67, 35) * M(35, 72)
      temp = temp + M(67, 39) * M(39, 72)
      temp = temp + M(67, 41) * M(41, 72)
      temp = temp + M(67, 45) * M(45, 72)
      temp = temp + M(67, 46) * M(46, 72)
      temp = temp + M(67, 47) * M(47, 72)
      temp = temp + M(67, 49) * M(49, 72)
      temp = temp + M(67, 50) * M(50, 72)
      temp = temp + M(67, 56) * M(56, 72)
      temp = temp + M(67, 58) * M(58, 72)
      temp = temp + M(67, 59) * M(59, 72)
      temp = temp + M(67, 60) * M(60, 72)
      temp = temp + M(67, 62) * M(62, 72)
      temp = temp + M(67, 63) * M(63, 72)
      temp = temp + M(67, 64) * M(64, 72)
      temp = temp + M(67, 65) * M(65, 72)
      temp = temp + M(67, 66) * M(66, 72)
      M(67, 72) = ( M(67, 72) - temp ) / M(67, 67)

C     Lower part.
      temp = M(68, 9) * M(9, 68)
      temp = temp + M(68, 11) * M(11, 68)
      temp = temp + M(68, 12) * M(12, 68)
      temp = temp + M(68, 13) * M(13, 68)
      temp = temp + M(68, 14) * M(14, 68)
      temp = temp + M(68, 19) * M(19, 68)
      temp = temp + M(68, 25) * M(25, 68)
      temp = temp + M(68, 26) * M(26, 68)
      temp = temp + M(68, 30) * M(30, 68)
      temp = temp + M(68, 31) * M(31, 68)
      temp = temp + M(68, 32) * M(32, 68)
      temp = temp + M(68, 33) * M(33, 68)
      temp = temp + M(68, 35) * M(35, 68)
      temp = temp + M(68, 36) * M(36, 68)
      temp = temp + M(68, 37) * M(37, 68)
      temp = temp + M(68, 38) * M(38, 68)
      temp = temp + M(68, 39) * M(39, 68)
      temp = temp + M(68, 40) * M(40, 68)
      temp = temp + M(68, 41) * M(41, 68)
      temp = temp + M(68, 42) * M(42, 68)
      temp = temp + M(68, 43) * M(43, 68)
      temp = temp + M(68, 44) * M(44, 68)
      temp = temp + M(68, 45) * M(45, 68)
      temp = temp + M(68, 46) * M(46, 68)
      temp = temp + M(68, 47) * M(47, 68)
      temp = temp + M(68, 48) * M(48, 68)
      temp = temp + M(68, 49) * M(49, 68)
      temp = temp + M(68, 50) * M(50, 68)
      temp = temp + M(68, 51) * M(51, 68)
      temp = temp + M(68, 54) * M(54, 68)
      temp = temp + M(68, 55) * M(55, 68)
      temp = temp + M(68, 56) * M(56, 68)
      temp = temp + M(68, 58) * M(58, 68)
      temp = temp + M(68, 59) * M(59, 68)
      temp = temp + M(68, 60) * M(60, 68)
      temp = temp + M(68, 61) * M(61, 68)
      temp = temp + M(68, 62) * M(62, 68)
      temp = temp + M(68, 63) * M(63, 68)
      temp = temp + M(68, 64) * M(64, 68)
      temp = temp + M(68, 65) * M(65, 68)
      temp = temp + M(68, 66) * M(66, 68)
      temp = temp + M(68, 67) * M(67, 68)
      M(68, 68) = M(68, 68) - temp
C     Lower part.
      temp = M(69, 12) * M(12, 68)
      temp = temp + M(69, 19) * M(19, 68)
      temp = temp + M(69, 25) * M(25, 68)
      temp = temp + M(69, 26) * M(26, 68)
      temp = temp + M(69, 31) * M(31, 68)
      temp = temp + M(69, 32) * M(32, 68)
      temp = temp + M(69, 33) * M(33, 68)
      temp = temp + M(69, 35) * M(35, 68)
      temp = temp + M(69, 36) * M(36, 68)
      temp = temp + M(69, 37) * M(37, 68)
      temp = temp + M(69, 38) * M(38, 68)
      temp = temp + M(69, 39) * M(39, 68)
      temp = temp + M(69, 41) * M(41, 68)
      temp = temp + M(69, 42) * M(42, 68)
      temp = temp + M(69, 43) * M(43, 68)
      temp = temp + M(69, 45) * M(45, 68)
      temp = temp + M(69, 46) * M(46, 68)
      temp = temp + M(69, 47) * M(47, 68)
      temp = temp + M(69, 48) * M(48, 68)
      temp = temp + M(69, 49) * M(49, 68)
      temp = temp + M(69, 50) * M(50, 68)
      temp = temp + M(69, 54) * M(54, 68)
      temp = temp + M(69, 56) * M(56, 68)
      temp = temp + M(69, 58) * M(58, 68)
      temp = temp + M(69, 59) * M(59, 68)
      temp = temp + M(69, 60) * M(60, 68)
      temp = temp + M(69, 61) * M(61, 68)
      temp = temp + M(69, 62) * M(62, 68)
      temp = temp + M(69, 63) * M(63, 68)
      temp = temp + M(69, 64) * M(64, 68)
      temp = temp + M(69, 65) * M(65, 68)
      temp = temp + M(69, 66) * M(66, 68)
      temp = temp + M(69, 67) * M(67, 68)
      M(69, 68) = M(69, 68) - temp
C     Lower part.
      temp = M(70, 25) * M(25, 68)
      temp = temp + M(70, 29) * M(29, 68)
      temp = temp + M(70, 30) * M(30, 68)
      temp = temp + M(70, 31) * M(31, 68)
      temp = temp + M(70, 32) * M(32, 68)
      temp = temp + M(70, 36) * M(36, 68)
      temp = temp + M(70, 37) * M(37, 68)
      temp = temp + M(70, 39) * M(39, 68)
      temp = temp + M(70, 42) * M(42, 68)
      temp = temp + M(70, 43) * M(43, 68)
      temp = temp + M(70, 46) * M(46, 68)
      temp = temp + M(70, 47) * M(47, 68)
      temp = temp + M(70, 49) * M(49, 68)
      temp = temp + M(70, 50) * M(50, 68)
      temp = temp + M(70, 56) * M(56, 68)
      temp = temp + M(70, 62) * M(62, 68)
      temp = temp + M(70, 63) * M(63, 68)
      temp = temp + M(70, 64) * M(64, 68)
      temp = temp + M(70, 65) * M(65, 68)
      temp = temp + M(70, 66) * M(66, 68)
      temp = temp + M(70, 67) * M(67, 68)
      M(70, 68) = M(70, 68) - temp
C     Lower part.
      temp = M(71, 11) * M(11, 68)
      temp = temp + M(71, 12) * M(12, 68)
      temp = temp + M(71, 13) * M(13, 68)
      temp = temp + M(71, 14) * M(14, 68)
      temp = temp + M(71, 19) * M(19, 68)
      temp = temp + M(71, 25) * M(25, 68)
      temp = temp + M(71, 27) * M(27, 68)
      temp = temp + M(71, 29) * M(29, 68)
      temp = temp + M(71, 30) * M(30, 68)
      temp = temp + M(71, 31) * M(31, 68)
      temp = temp + M(71, 32) * M(32, 68)
      temp = temp + M(71, 33) * M(33, 68)
      temp = temp + M(71, 35) * M(35, 68)
      temp = temp + M(71, 36) * M(36, 68)
      temp = temp + M(71, 37) * M(37, 68)
      temp = temp + M(71, 38) * M(38, 68)
      temp = temp + M(71, 39) * M(39, 68)
      temp = temp + M(71, 40) * M(40, 68)
      temp = temp + M(71, 41) * M(41, 68)
      temp = temp + M(71, 42) * M(42, 68)
      temp = temp + M(71, 43) * M(43, 68)
      temp = temp + M(71, 44) * M(44, 68)
      temp = temp + M(71, 45) * M(45, 68)
      temp = temp + M(71, 46) * M(46, 68)
      temp = temp + M(71, 47) * M(47, 68)
      temp = temp + M(71, 48) * M(48, 68)
      temp = temp + M(71, 49) * M(49, 68)
      temp = temp + M(71, 50) * M(50, 68)
      temp = temp + M(71, 51) * M(51, 68)
      temp = temp + M(71, 52) * M(52, 68)
      temp = temp + M(71, 53) * M(53, 68)
      temp = temp + M(71, 54) * M(54, 68)
      temp = temp + M(71, 56) * M(56, 68)
      temp = temp + M(71, 58) * M(58, 68)
      temp = temp + M(71, 59) * M(59, 68)
      temp = temp + M(71, 60) * M(60, 68)
      temp = temp + M(71, 61) * M(61, 68)
      temp = temp + M(71, 62) * M(62, 68)
      temp = temp + M(71, 63) * M(63, 68)
      temp = temp + M(71, 64) * M(64, 68)
      temp = temp + M(71, 65) * M(65, 68)
      temp = temp + M(71, 66) * M(66, 68)
      temp = temp + M(71, 67) * M(67, 68)
      M(71, 68) = M(71, 68) - temp
C     Lower part.
      temp = M(72, 9) * M(9, 68)
      temp = temp + M(72, 25) * M(25, 68)
      temp = temp + M(72, 26) * M(26, 68)
      temp = temp + M(72, 29) * M(29, 68)
      temp = temp + M(72, 30) * M(30, 68)
      temp = temp + M(72, 31) * M(31, 68)
      temp = temp + M(72, 32) * M(32, 68)
      temp = temp + M(72, 33) * M(33, 68)
      temp = temp + M(72, 35) * M(35, 68)
      temp = temp + M(72, 36) * M(36, 68)
      temp = temp + M(72, 37) * M(37, 68)
      temp = temp + M(72, 38) * M(38, 68)
      temp = temp + M(72, 39) * M(39, 68)
      temp = temp + M(72, 41) * M(41, 68)
      temp = temp + M(72, 42) * M(42, 68)
      temp = temp + M(72, 43) * M(43, 68)
      temp = temp + M(72, 45) * M(45, 68)
      temp = temp + M(72, 46) * M(46, 68)
      temp = temp + M(72, 47) * M(47, 68)
      temp = temp + M(72, 48) * M(48, 68)
      temp = temp + M(72, 49) * M(49, 68)
      temp = temp + M(72, 50) * M(50, 68)
      temp = temp + M(72, 55) * M(55, 68)
      temp = temp + M(72, 56) * M(56, 68)
      temp = temp + M(72, 58) * M(58, 68)
      temp = temp + M(72, 59) * M(59, 68)
      temp = temp + M(72, 60) * M(60, 68)
      temp = temp + M(72, 61) * M(61, 68)
      temp = temp + M(72, 62) * M(62, 68)
      temp = temp + M(72, 63) * M(63, 68)
      temp = temp + M(72, 64) * M(64, 68)
      temp = temp + M(72, 65) * M(65, 68)
      temp = temp + M(72, 66) * M(66, 68)
      temp = temp + M(72, 67) * M(67, 68)
      M(72, 68) = M(72, 68) - temp
C     Upper part.
      temp = M(68, 26) * M(26, 69)
      temp = temp + M(68, 31) * M(31, 69)
      temp = temp + M(68, 32) * M(32, 69)
      temp = temp + M(68, 33) * M(33, 69)
      temp = temp + M(68, 36) * M(36, 69)
      temp = temp + M(68, 37) * M(37, 69)
      temp = temp + M(68, 38) * M(38, 69)
      temp = temp + M(68, 39) * M(39, 69)
      temp = temp + M(68, 40) * M(40, 69)
      temp = temp + M(68, 41) * M(41, 69)
      temp = temp + M(68, 42) * M(42, 69)
      temp = temp + M(68, 43) * M(43, 69)
      temp = temp + M(68, 44) * M(44, 69)
      temp = temp + M(68, 45) * M(45, 69)
      temp = temp + M(68, 46) * M(46, 69)
      temp = temp + M(68, 47) * M(47, 69)
      temp = temp + M(68, 48) * M(48, 69)
      temp = temp + M(68, 49) * M(49, 69)
      temp = temp + M(68, 50) * M(50, 69)
      temp = temp + M(68, 51) * M(51, 69)
      temp = temp + M(68, 54) * M(54, 69)
      temp = temp + M(68, 55) * M(55, 69)
      temp = temp + M(68, 56) * M(56, 69)
      temp = temp + M(68, 58) * M(58, 69)
      temp = temp + M(68, 59) * M(59, 69)
      temp = temp + M(68, 60) * M(60, 69)
      temp = temp + M(68, 61) * M(61, 69)
      temp = temp + M(68, 62) * M(62, 69)
      temp = temp + M(68, 63) * M(63, 69)
      temp = temp + M(68, 64) * M(64, 69)
      temp = temp + M(68, 65) * M(65, 69)
      temp = temp + M(68, 66) * M(66, 69)
      temp = temp + M(68, 67) * M(67, 69)
      M(68, 69) = ( M(68, 69) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 59) * M(59, 70)
      temp = temp + M(68, 60) * M(60, 70)
      temp = temp + M(68, 61) * M(61, 70)
      temp = temp + M(68, 62) * M(62, 70)
      temp = temp + M(68, 63) * M(63, 70)
      temp = temp + M(68, 64) * M(64, 70)
      temp = temp + M(68, 65) * M(65, 70)
      temp = temp + M(68, 66) * M(66, 70)
      temp = temp + M(68, 67) * M(67, 70)
      M(68, 70) = ( M(68, 70) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 15) * M(15, 71)
      temp = temp + M(68, 30) * M(30, 71)
      temp = temp + M(68, 31) * M(31, 71)
      temp = temp + M(68, 32) * M(32, 71)
      temp = temp + M(68, 33) * M(33, 71)
      temp = temp + M(68, 36) * M(36, 71)
      temp = temp + M(68, 37) * M(37, 71)
      temp = temp + M(68, 38) * M(38, 71)
      temp = temp + M(68, 39) * M(39, 71)
      temp = temp + M(68, 40) * M(40, 71)
      temp = temp + M(68, 41) * M(41, 71)
      temp = temp + M(68, 42) * M(42, 71)
      temp = temp + M(68, 43) * M(43, 71)
      temp = temp + M(68, 44) * M(44, 71)
      temp = temp + M(68, 45) * M(45, 71)
      temp = temp + M(68, 46) * M(46, 71)
      temp = temp + M(68, 47) * M(47, 71)
      temp = temp + M(68, 48) * M(48, 71)
      temp = temp + M(68, 49) * M(49, 71)
      temp = temp + M(68, 50) * M(50, 71)
      temp = temp + M(68, 51) * M(51, 71)
      temp = temp + M(68, 54) * M(54, 71)
      temp = temp + M(68, 55) * M(55, 71)
      temp = temp + M(68, 56) * M(56, 71)
      temp = temp + M(68, 58) * M(58, 71)
      temp = temp + M(68, 59) * M(59, 71)
      temp = temp + M(68, 60) * M(60, 71)
      temp = temp + M(68, 61) * M(61, 71)
      temp = temp + M(68, 62) * M(62, 71)
      temp = temp + M(68, 63) * M(63, 71)
      temp = temp + M(68, 64) * M(64, 71)
      temp = temp + M(68, 65) * M(65, 71)
      temp = temp + M(68, 66) * M(66, 71)
      temp = temp + M(68, 67) * M(67, 71)
      M(68, 71) = ( M(68, 71) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 9) * M(9, 72)
      temp = temp + M(68, 15) * M(15, 72)
      temp = temp + M(68, 25) * M(25, 72)
      temp = temp + M(68, 26) * M(26, 72)
      temp = temp + M(68, 30) * M(30, 72)
      temp = temp + M(68, 31) * M(31, 72)
      temp = temp + M(68, 32) * M(32, 72)
      temp = temp + M(68, 33) * M(33, 72)
      temp = temp + M(68, 35) * M(35, 72)
      temp = temp + M(68, 39) * M(39, 72)
      temp = temp + M(68, 40) * M(40, 72)
      temp = temp + M(68, 41) * M(41, 72)
      temp = temp + M(68, 44) * M(44, 72)
      temp = temp + M(68, 45) * M(45, 72)
      temp = temp + M(68, 46) * M(46, 72)
      temp = temp + M(68, 47) * M(47, 72)
      temp = temp + M(68, 48) * M(48, 72)
      temp = temp + M(68, 49) * M(49, 72)
      temp = temp + M(68, 50) * M(50, 72)
      temp = temp + M(68, 51) * M(51, 72)
      temp = temp + M(68, 54) * M(54, 72)
      temp = temp + M(68, 55) * M(55, 72)
      temp = temp + M(68, 56) * M(56, 72)
      temp = temp + M(68, 58) * M(58, 72)
      temp = temp + M(68, 59) * M(59, 72)
      temp = temp + M(68, 60) * M(60, 72)
      temp = temp + M(68, 61) * M(61, 72)
      temp = temp + M(68, 62) * M(62, 72)
      temp = temp + M(68, 63) * M(63, 72)
      temp = temp + M(68, 64) * M(64, 72)
      temp = temp + M(68, 65) * M(65, 72)
      temp = temp + M(68, 66) * M(66, 72)
      temp = temp + M(68, 67) * M(67, 72)
      M(68, 72) = ( M(68, 72) - temp ) / M(68, 68)

C     Lower part.
      temp = M(69, 26) * M(26, 69)
      temp = temp + M(69, 28) * M(28, 69)
      temp = temp + M(69, 31) * M(31, 69)
      temp = temp + M(69, 32) * M(32, 69)
      temp = temp + M(69, 33) * M(33, 69)
      temp = temp + M(69, 36) * M(36, 69)
      temp = temp + M(69, 37) * M(37, 69)
      temp = temp + M(69, 38) * M(38, 69)
      temp = temp + M(69, 39) * M(39, 69)
      temp = temp + M(69, 41) * M(41, 69)
      temp = temp + M(69, 42) * M(42, 69)
      temp = temp + M(69, 43) * M(43, 69)
      temp = temp + M(69, 45) * M(45, 69)
      temp = temp + M(69, 46) * M(46, 69)
      temp = temp + M(69, 47) * M(47, 69)
      temp = temp + M(69, 48) * M(48, 69)
      temp = temp + M(69, 49) * M(49, 69)
      temp = temp + M(69, 50) * M(50, 69)
      temp = temp + M(69, 54) * M(54, 69)
      temp = temp + M(69, 56) * M(56, 69)
      temp = temp + M(69, 58) * M(58, 69)
      temp = temp + M(69, 59) * M(59, 69)
      temp = temp + M(69, 60) * M(60, 69)
      temp = temp + M(69, 61) * M(61, 69)
      temp = temp + M(69, 62) * M(62, 69)
      temp = temp + M(69, 63) * M(63, 69)
      temp = temp + M(69, 64) * M(64, 69)
      temp = temp + M(69, 65) * M(65, 69)
      temp = temp + M(69, 66) * M(66, 69)
      temp = temp + M(69, 67) * M(67, 69)
      temp = temp + M(69, 68) * M(68, 69)
      M(69, 69) = M(69, 69) - temp
C     Lower part.
      temp = M(70, 31) * M(31, 69)
      temp = temp + M(70, 32) * M(32, 69)
      temp = temp + M(70, 36) * M(36, 69)
      temp = temp + M(70, 37) * M(37, 69)
      temp = temp + M(70, 39) * M(39, 69)
      temp = temp + M(70, 42) * M(42, 69)
      temp = temp + M(70, 43) * M(43, 69)
      temp = temp + M(70, 46) * M(46, 69)
      temp = temp + M(70, 47) * M(47, 69)
      temp = temp + M(70, 49) * M(49, 69)
      temp = temp + M(70, 50) * M(50, 69)
      temp = temp + M(70, 56) * M(56, 69)
      temp = temp + M(70, 62) * M(62, 69)
      temp = temp + M(70, 63) * M(63, 69)
      temp = temp + M(70, 64) * M(64, 69)
      temp = temp + M(70, 65) * M(65, 69)
      temp = temp + M(70, 66) * M(66, 69)
      temp = temp + M(70, 67) * M(67, 69)
      temp = temp + M(70, 68) * M(68, 69)
      M(70, 69) = M(70, 69) - temp
C     Lower part.
      temp = M(71, 28) * M(28, 69)
      temp = temp + M(71, 31) * M(31, 69)
      temp = temp + M(71, 32) * M(32, 69)
      temp = temp + M(71, 33) * M(33, 69)
      temp = temp + M(71, 36) * M(36, 69)
      temp = temp + M(71, 37) * M(37, 69)
      temp = temp + M(71, 38) * M(38, 69)
      temp = temp + M(71, 39) * M(39, 69)
      temp = temp + M(71, 40) * M(40, 69)
      temp = temp + M(71, 41) * M(41, 69)
      temp = temp + M(71, 42) * M(42, 69)
      temp = temp + M(71, 43) * M(43, 69)
      temp = temp + M(71, 44) * M(44, 69)
      temp = temp + M(71, 45) * M(45, 69)
      temp = temp + M(71, 46) * M(46, 69)
      temp = temp + M(71, 47) * M(47, 69)
      temp = temp + M(71, 48) * M(48, 69)
      temp = temp + M(71, 49) * M(49, 69)
      temp = temp + M(71, 50) * M(50, 69)
      temp = temp + M(71, 51) * M(51, 69)
      temp = temp + M(71, 52) * M(52, 69)
      temp = temp + M(71, 53) * M(53, 69)
      temp = temp + M(71, 54) * M(54, 69)
      temp = temp + M(71, 56) * M(56, 69)
      temp = temp + M(71, 58) * M(58, 69)
      temp = temp + M(71, 59) * M(59, 69)
      temp = temp + M(71, 60) * M(60, 69)
      temp = temp + M(71, 61) * M(61, 69)
      temp = temp + M(71, 62) * M(62, 69)
      temp = temp + M(71, 63) * M(63, 69)
      temp = temp + M(71, 64) * M(64, 69)
      temp = temp + M(71, 65) * M(65, 69)
      temp = temp + M(71, 66) * M(66, 69)
      temp = temp + M(71, 67) * M(67, 69)
      temp = temp + M(71, 68) * M(68, 69)
      M(71, 69) = M(71, 69) - temp
C     Lower part.
      temp = M(72, 26) * M(26, 69)
      temp = temp + M(72, 31) * M(31, 69)
      temp = temp + M(72, 32) * M(32, 69)
      temp = temp + M(72, 33) * M(33, 69)
      temp = temp + M(72, 36) * M(36, 69)
      temp = temp + M(72, 37) * M(37, 69)
      temp = temp + M(72, 38) * M(38, 69)
      temp = temp + M(72, 39) * M(39, 69)
      temp = temp + M(72, 41) * M(41, 69)
      temp = temp + M(72, 42) * M(42, 69)
      temp = temp + M(72, 43) * M(43, 69)
      temp = temp + M(72, 45) * M(45, 69)
      temp = temp + M(72, 46) * M(46, 69)
      temp = temp + M(72, 47) * M(47, 69)
      temp = temp + M(72, 48) * M(48, 69)
      temp = temp + M(72, 49) * M(49, 69)
      temp = temp + M(72, 50) * M(50, 69)
      temp = temp + M(72, 55) * M(55, 69)
      temp = temp + M(72, 56) * M(56, 69)
      temp = temp + M(72, 58) * M(58, 69)
      temp = temp + M(72, 59) * M(59, 69)
      temp = temp + M(72, 60) * M(60, 69)
      temp = temp + M(72, 61) * M(61, 69)
      temp = temp + M(72, 62) * M(62, 69)
      temp = temp + M(72, 63) * M(63, 69)
      temp = temp + M(72, 64) * M(64, 69)
      temp = temp + M(72, 65) * M(65, 69)
      temp = temp + M(72, 66) * M(66, 69)
      temp = temp + M(72, 67) * M(67, 69)
      temp = temp + M(72, 68) * M(68, 69)
      M(72, 69) = M(72, 69) - temp
C     Upper part.
      temp = M(69, 59) * M(59, 70)
      temp = temp + M(69, 60) * M(60, 70)
      temp = temp + M(69, 61) * M(61, 70)
      temp = temp + M(69, 62) * M(62, 70)
      temp = temp + M(69, 63) * M(63, 70)
      temp = temp + M(69, 64) * M(64, 70)
      temp = temp + M(69, 65) * M(65, 70)
      temp = temp + M(69, 66) * M(66, 70)
      temp = temp + M(69, 67) * M(67, 70)
      temp = temp + M(69, 68) * M(68, 70)
      M(69, 70) = ( M(69, 70) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 28) * M(28, 71)
      temp = temp + M(69, 31) * M(31, 71)
      temp = temp + M(69, 32) * M(32, 71)
      temp = temp + M(69, 33) * M(33, 71)
      temp = temp + M(69, 36) * M(36, 71)
      temp = temp + M(69, 37) * M(37, 71)
      temp = temp + M(69, 38) * M(38, 71)
      temp = temp + M(69, 39) * M(39, 71)
      temp = temp + M(69, 41) * M(41, 71)
      temp = temp + M(69, 42) * M(42, 71)
      temp = temp + M(69, 43) * M(43, 71)
      temp = temp + M(69, 45) * M(45, 71)
      temp = temp + M(69, 46) * M(46, 71)
      temp = temp + M(69, 47) * M(47, 71)
      temp = temp + M(69, 48) * M(48, 71)
      temp = temp + M(69, 49) * M(49, 71)
      temp = temp + M(69, 50) * M(50, 71)
      temp = temp + M(69, 54) * M(54, 71)
      temp = temp + M(69, 56) * M(56, 71)
      temp = temp + M(69, 58) * M(58, 71)
      temp = temp + M(69, 59) * M(59, 71)
      temp = temp + M(69, 60) * M(60, 71)
      temp = temp + M(69, 61) * M(61, 71)
      temp = temp + M(69, 62) * M(62, 71)
      temp = temp + M(69, 63) * M(63, 71)
      temp = temp + M(69, 64) * M(64, 71)
      temp = temp + M(69, 65) * M(65, 71)
      temp = temp + M(69, 66) * M(66, 71)
      temp = temp + M(69, 67) * M(67, 71)
      temp = temp + M(69, 68) * M(68, 71)
      M(69, 71) = ( M(69, 71) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 25) * M(25, 72)
      temp = temp + M(69, 26) * M(26, 72)
      temp = temp + M(69, 31) * M(31, 72)
      temp = temp + M(69, 32) * M(32, 72)
      temp = temp + M(69, 33) * M(33, 72)
      temp = temp + M(69, 35) * M(35, 72)
      temp = temp + M(69, 39) * M(39, 72)
      temp = temp + M(69, 41) * M(41, 72)
      temp = temp + M(69, 45) * M(45, 72)
      temp = temp + M(69, 46) * M(46, 72)
      temp = temp + M(69, 47) * M(47, 72)
      temp = temp + M(69, 48) * M(48, 72)
      temp = temp + M(69, 49) * M(49, 72)
      temp = temp + M(69, 50) * M(50, 72)
      temp = temp + M(69, 54) * M(54, 72)
      temp = temp + M(69, 56) * M(56, 72)
      temp = temp + M(69, 58) * M(58, 72)
      temp = temp + M(69, 59) * M(59, 72)
      temp = temp + M(69, 60) * M(60, 72)
      temp = temp + M(69, 61) * M(61, 72)
      temp = temp + M(69, 62) * M(62, 72)
      temp = temp + M(69, 63) * M(63, 72)
      temp = temp + M(69, 64) * M(64, 72)
      temp = temp + M(69, 65) * M(65, 72)
      temp = temp + M(69, 66) * M(66, 72)
      temp = temp + M(69, 67) * M(67, 72)
      temp = temp + M(69, 68) * M(68, 72)
      M(69, 72) = ( M(69, 72) - temp ) / M(69, 69)

C     Lower part.
      temp = M(70, 62) * M(62, 70)
      temp = temp + M(70, 63) * M(63, 70)
      temp = temp + M(70, 64) * M(64, 70)
      temp = temp + M(70, 65) * M(65, 70)
      temp = temp + M(70, 66) * M(66, 70)
      temp = temp + M(70, 67) * M(67, 70)
      temp = temp + M(70, 68) * M(68, 70)
      temp = temp + M(70, 69) * M(69, 70)
      M(70, 70) = M(70, 70) - temp
C     Lower part.
      temp = M(71, 59) * M(59, 70)
      temp = temp + M(71, 60) * M(60, 70)
      temp = temp + M(71, 61) * M(61, 70)
      temp = temp + M(71, 62) * M(62, 70)
      temp = temp + M(71, 63) * M(63, 70)
      temp = temp + M(71, 64) * M(64, 70)
      temp = temp + M(71, 65) * M(65, 70)
      temp = temp + M(71, 66) * M(66, 70)
      temp = temp + M(71, 67) * M(67, 70)
      temp = temp + M(71, 68) * M(68, 70)
      temp = temp + M(71, 69) * M(69, 70)
      M(71, 70) = M(71, 70) - temp
C     Lower part.
      temp = M(72, 59) * M(59, 70)
      temp = temp + M(72, 60) * M(60, 70)
      temp = temp + M(72, 61) * M(61, 70)
      temp = temp + M(72, 62) * M(62, 70)
      temp = temp + M(72, 63) * M(63, 70)
      temp = temp + M(72, 64) * M(64, 70)
      temp = temp + M(72, 65) * M(65, 70)
      temp = temp + M(72, 66) * M(66, 70)
      temp = temp + M(72, 67) * M(67, 70)
      temp = temp + M(72, 68) * M(68, 70)
      temp = temp + M(72, 69) * M(69, 70)
      M(72, 70) = M(72, 70) - temp
C     Upper part.
      temp = M(70, 29) * M(29, 71)
      temp = temp + M(70, 30) * M(30, 71)
      temp = temp + M(70, 31) * M(31, 71)
      temp = temp + M(70, 32) * M(32, 71)
      temp = temp + M(70, 36) * M(36, 71)
      temp = temp + M(70, 37) * M(37, 71)
      temp = temp + M(70, 39) * M(39, 71)
      temp = temp + M(70, 42) * M(42, 71)
      temp = temp + M(70, 43) * M(43, 71)
      temp = temp + M(70, 46) * M(46, 71)
      temp = temp + M(70, 47) * M(47, 71)
      temp = temp + M(70, 49) * M(49, 71)
      temp = temp + M(70, 50) * M(50, 71)
      temp = temp + M(70, 56) * M(56, 71)
      temp = temp + M(70, 62) * M(62, 71)
      temp = temp + M(70, 63) * M(63, 71)
      temp = temp + M(70, 64) * M(64, 71)
      temp = temp + M(70, 65) * M(65, 71)
      temp = temp + M(70, 66) * M(66, 71)
      temp = temp + M(70, 67) * M(67, 71)
      temp = temp + M(70, 68) * M(68, 71)
      temp = temp + M(70, 69) * M(69, 71)
      M(70, 71) = ( M(70, 71) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 25) * M(25, 72)
      temp = temp + M(70, 29) * M(29, 72)
      temp = temp + M(70, 30) * M(30, 72)
      temp = temp + M(70, 31) * M(31, 72)
      temp = temp + M(70, 32) * M(32, 72)
      temp = temp + M(70, 39) * M(39, 72)
      temp = temp + M(70, 46) * M(46, 72)
      temp = temp + M(70, 47) * M(47, 72)
      temp = temp + M(70, 49) * M(49, 72)
      temp = temp + M(70, 50) * M(50, 72)
      temp = temp + M(70, 56) * M(56, 72)
      temp = temp + M(70, 62) * M(62, 72)
      temp = temp + M(70, 63) * M(63, 72)
      temp = temp + M(70, 64) * M(64, 72)
      temp = temp + M(70, 65) * M(65, 72)
      temp = temp + M(70, 66) * M(66, 72)
      temp = temp + M(70, 67) * M(67, 72)
      temp = temp + M(70, 68) * M(68, 72)
      temp = temp + M(70, 69) * M(69, 72)
      M(70, 72) = ( M(70, 72) - temp ) / M(70, 70)

C     Lower part.
      temp = M(71, 15) * M(15, 71)
      temp = temp + M(71, 16) * M(16, 71)
      temp = temp + M(71, 27) * M(27, 71)
      temp = temp + M(71, 28) * M(28, 71)
      temp = temp + M(71, 29) * M(29, 71)
      temp = temp + M(71, 30) * M(30, 71)
      temp = temp + M(71, 31) * M(31, 71)
      temp = temp + M(71, 32) * M(32, 71)
      temp = temp + M(71, 33) * M(33, 71)
      temp = temp + M(71, 36) * M(36, 71)
      temp = temp + M(71, 37) * M(37, 71)
      temp = temp + M(71, 38) * M(38, 71)
      temp = temp + M(71, 39) * M(39, 71)
      temp = temp + M(71, 40) * M(40, 71)
      temp = temp + M(71, 41) * M(41, 71)
      temp = temp + M(71, 42) * M(42, 71)
      temp = temp + M(71, 43) * M(43, 71)
      temp = temp + M(71, 44) * M(44, 71)
      temp = temp + M(71, 45) * M(45, 71)
      temp = temp + M(71, 46) * M(46, 71)
      temp = temp + M(71, 47) * M(47, 71)
      temp = temp + M(71, 48) * M(48, 71)
      temp = temp + M(71, 49) * M(49, 71)
      temp = temp + M(71, 50) * M(50, 71)
      temp = temp + M(71, 51) * M(51, 71)
      temp = temp + M(71, 52) * M(52, 71)
      temp = temp + M(71, 53) * M(53, 71)
      temp = temp + M(71, 54) * M(54, 71)
      temp = temp + M(71, 56) * M(56, 71)
      temp = temp + M(71, 58) * M(58, 71)
      temp = temp + M(71, 59) * M(59, 71)
      temp = temp + M(71, 60) * M(60, 71)
      temp = temp + M(71, 61) * M(61, 71)
      temp = temp + M(71, 62) * M(62, 71)
      temp = temp + M(71, 63) * M(63, 71)
      temp = temp + M(71, 64) * M(64, 71)
      temp = temp + M(71, 65) * M(65, 71)
      temp = temp + M(71, 66) * M(66, 71)
      temp = temp + M(71, 67) * M(67, 71)
      temp = temp + M(71, 68) * M(68, 71)
      temp = temp + M(71, 69) * M(69, 71)
      temp = temp + M(71, 70) * M(70, 71)
      M(71, 71) = M(71, 71) - temp
C     Lower part.
      temp = M(72, 15) * M(15, 71)
      temp = temp + M(72, 29) * M(29, 71)
      temp = temp + M(72, 30) * M(30, 71)
      temp = temp + M(72, 31) * M(31, 71)
      temp = temp + M(72, 32) * M(32, 71)
      temp = temp + M(72, 33) * M(33, 71)
      temp = temp + M(72, 36) * M(36, 71)
      temp = temp + M(72, 37) * M(37, 71)
      temp = temp + M(72, 38) * M(38, 71)
      temp = temp + M(72, 39) * M(39, 71)
      temp = temp + M(72, 41) * M(41, 71)
      temp = temp + M(72, 42) * M(42, 71)
      temp = temp + M(72, 43) * M(43, 71)
      temp = temp + M(72, 45) * M(45, 71)
      temp = temp + M(72, 46) * M(46, 71)
      temp = temp + M(72, 47) * M(47, 71)
      temp = temp + M(72, 48) * M(48, 71)
      temp = temp + M(72, 49) * M(49, 71)
      temp = temp + M(72, 50) * M(50, 71)
      temp = temp + M(72, 55) * M(55, 71)
      temp = temp + M(72, 56) * M(56, 71)
      temp = temp + M(72, 58) * M(58, 71)
      temp = temp + M(72, 59) * M(59, 71)
      temp = temp + M(72, 60) * M(60, 71)
      temp = temp + M(72, 61) * M(61, 71)
      temp = temp + M(72, 62) * M(62, 71)
      temp = temp + M(72, 63) * M(63, 71)
      temp = temp + M(72, 64) * M(64, 71)
      temp = temp + M(72, 65) * M(65, 71)
      temp = temp + M(72, 66) * M(66, 71)
      temp = temp + M(72, 67) * M(67, 71)
      temp = temp + M(72, 68) * M(68, 71)
      temp = temp + M(72, 69) * M(69, 71)
      temp = temp + M(72, 70) * M(70, 71)
      M(72, 71) = M(72, 71) - temp
C     Upper part.
      temp = M(71, 15) * M(15, 72)
      temp = temp + M(71, 17) * M(17, 72)
      temp = temp + M(71, 18) * M(18, 72)
      temp = temp + M(71, 22) * M(22, 72)
      temp = temp + M(71, 25) * M(25, 72)
      temp = temp + M(71, 29) * M(29, 72)
      temp = temp + M(71, 30) * M(30, 72)
      temp = temp + M(71, 31) * M(31, 72)
      temp = temp + M(71, 32) * M(32, 72)
      temp = temp + M(71, 33) * M(33, 72)
      temp = temp + M(71, 35) * M(35, 72)
      temp = temp + M(71, 39) * M(39, 72)
      temp = temp + M(71, 40) * M(40, 72)
      temp = temp + M(71, 41) * M(41, 72)
      temp = temp + M(71, 44) * M(44, 72)
      temp = temp + M(71, 45) * M(45, 72)
      temp = temp + M(71, 46) * M(46, 72)
      temp = temp + M(71, 47) * M(47, 72)
      temp = temp + M(71, 48) * M(48, 72)
      temp = temp + M(71, 49) * M(49, 72)
      temp = temp + M(71, 50) * M(50, 72)
      temp = temp + M(71, 51) * M(51, 72)
      temp = temp + M(71, 52) * M(52, 72)
      temp = temp + M(71, 53) * M(53, 72)
      temp = temp + M(71, 54) * M(54, 72)
      temp = temp + M(71, 56) * M(56, 72)
      temp = temp + M(71, 58) * M(58, 72)
      temp = temp + M(71, 59) * M(59, 72)
      temp = temp + M(71, 60) * M(60, 72)
      temp = temp + M(71, 61) * M(61, 72)
      temp = temp + M(71, 62) * M(62, 72)
      temp = temp + M(71, 63) * M(63, 72)
      temp = temp + M(71, 64) * M(64, 72)
      temp = temp + M(71, 65) * M(65, 72)
      temp = temp + M(71, 66) * M(66, 72)
      temp = temp + M(71, 67) * M(67, 72)
      temp = temp + M(71, 68) * M(68, 72)
      temp = temp + M(71, 69) * M(69, 72)
      temp = temp + M(71, 70) * M(70, 72)
      M(71, 72) = ( M(71, 72) - temp ) / M(71, 71)

C     Lower part.
      temp = M(72, 9) * M(9, 72)
      temp = temp + M(72, 15) * M(15, 72)
      temp = temp + M(72, 17) * M(17, 72)
      temp = temp + M(72, 18) * M(18, 72)
      temp = temp + M(72, 22) * M(22, 72)
      temp = temp + M(72, 23) * M(23, 72)
      temp = temp + M(72, 25) * M(25, 72)
      temp = temp + M(72, 26) * M(26, 72)
      temp = temp + M(72, 29) * M(29, 72)
      temp = temp + M(72, 30) * M(30, 72)
      temp = temp + M(72, 31) * M(31, 72)
      temp = temp + M(72, 32) * M(32, 72)
      temp = temp + M(72, 33) * M(33, 72)
      temp = temp + M(72, 35) * M(35, 72)
      temp = temp + M(72, 39) * M(39, 72)
      temp = temp + M(72, 41) * M(41, 72)
      temp = temp + M(72, 45) * M(45, 72)
      temp = temp + M(72, 46) * M(46, 72)
      temp = temp + M(72, 47) * M(47, 72)
      temp = temp + M(72, 48) * M(48, 72)
      temp = temp + M(72, 49) * M(49, 72)
      temp = temp + M(72, 50) * M(50, 72)
      temp = temp + M(72, 55) * M(55, 72)
      temp = temp + M(72, 56) * M(56, 72)
      temp = temp + M(72, 58) * M(58, 72)
      temp = temp + M(72, 59) * M(59, 72)
      temp = temp + M(72, 60) * M(60, 72)
      temp = temp + M(72, 61) * M(61, 72)
      temp = temp + M(72, 62) * M(62, 72)
      temp = temp + M(72, 63) * M(63, 72)
      temp = temp + M(72, 64) * M(64, 72)
      temp = temp + M(72, 65) * M(65, 72)
      temp = temp + M(72, 66) * M(66, 72)
      temp = temp + M(72, 67) * M(67, 72)
      temp = temp + M(72, 68) * M(68, 72)
      temp = temp + M(72, 69) * M(69, 72)
      temp = temp + M(72, 70) * M(70, 72)
      temp = temp + M(72, 71) * M(71, 72)
      M(72, 72) = M(72, 72) - temp


      END
