      subroutine jacdchemdc(y,rk,JacC)
      
C------------------------------------------------------------------------
C     
C     -- DESCRIPTION
C     
C     This routine computes the Jacobian matrix for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: RACM                
C     Species: _ciRACM             
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     -- OUTPUT VARIABLES
C     
C     JACC: Jacobian matrix.
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C     The matrix JACC could be stored in a low-dimensional vector.
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C     SPACK.
C     
C------------------------------------------------------------------------
      
      implicit none
      
C     -- INCLUDE FILES
C     PARACHEM: parameters for sizes of chemical arrays.
C     PARADOM: parameters for all forced fields.
      
      include 'PARACHEM.INC' 
      INCLUDE 'PARADOM.INC'  
      
      integer i,j
      double precision dw(nr,nesp),rk(nr),y(nesp),JacC(nesp,nesp)
      
      do j=1,nesp
         do i=1,nesp
            JacC(i,j)=0.d0
         enddo
      enddo
      
      call dratedc(rk,y,dw)
      
      JacC( 35, 72) = JacC( 35, 72) + dw(  1, 72)
      JacC( 67, 72) = JacC( 67, 72) + dw(  1, 72)
      JacC( 72, 72) = JacC( 72, 72) - dw(  1, 72)
      JacC(  7, 50) = JacC(  7, 50) + dw(  2, 50)
      JacC( 50, 50) = JacC( 50, 50) - dw(  2, 50)
      JacC( 35, 50) = JacC( 35, 50) + dw(  3, 50)
      JacC( 50, 50) = JacC( 50, 50) - dw(  3, 50)
      JacC( 23, 23) = JacC( 23, 23) - dw(  4, 23)
      JacC( 62, 23) = JacC( 62, 23) + dw(  4, 23)
      JacC( 67, 23) = JacC( 67, 23) + dw(  4, 23)
      JacC( 55, 55) = JacC( 55, 55) - dw(  5, 55)
      JacC( 62, 55) = JacC( 62, 55) + dw(  5, 55)
      JacC( 72, 55) = JacC( 72, 55) + dw(  5, 55)
      JacC( 15, 15) = JacC( 15, 15) - dw(  6, 15)
      JacC( 62, 15) = JacC( 62, 15)+ 0.3500000000000000D+00*dw(  6, 15)
      JacC( 68, 15) = JacC( 68, 15)+ 0.3500000000000000D+00*dw(  6, 15)
      JacC( 71, 15) = JacC( 71, 15)+ 0.6500000000000000D+00*dw(  6, 15)
      JacC( 72, 15) = JacC( 72, 15)+ 0.6500000000000000D+00*dw(  6, 15)
      JacC( 67, 68) = JacC( 67, 68) + dw(  7, 68)
      JacC( 68, 68) = JacC( 68, 68) - dw(  7, 68)
      JacC( 35, 68) = JacC( 35, 68) + dw(  8, 68)
      JacC( 68, 68) = JacC( 68, 68) - dw(  8, 68)
      JacC( 72, 68) = JacC( 72, 68) + dw(  8, 68)
      JacC( 27, 27) = JacC( 27, 27) - dw(  9, 27)
      JacC( 62, 27) = JacC( 62, 27)+ 0.2000000000000000D+01*dw(  9, 27)
      JacC( 52, 66) = JacC( 52, 66) + dw( 10, 66)
      JacC( 66, 66) = JacC( 66, 66) - dw( 10, 66)
      JacC( 52, 66) = JacC( 52, 66) + dw( 11, 66)
      JacC( 66, 66) = JacC( 66, 66) - dw( 11, 66)
      JacC( 71, 66) = JacC( 71, 66)+ 0.2000000000000000D+01*dw( 11, 66)
      JacC( 52, 61) = JacC( 52, 61) + dw( 12, 61)
      JacC( 61, 61) = JacC( 61, 61) - dw( 12, 61)
      JacC( 63, 61) = JacC( 63, 61) + dw( 12, 61)
      JacC( 71, 61) = JacC( 71, 61) + dw( 12, 61)
      JacC( 16, 16) = JacC( 16, 16) - dw( 13, 16)
      JacC( 62, 16) = JacC( 62, 16) + dw( 13, 16)
      JacC( 66, 16) = JacC( 66, 16) + dw( 13, 16)
      JacC( 71, 16) = JacC( 71, 16) + dw( 13, 16)
      JacC( 53, 53) = JacC( 53, 53) - dw( 14, 53)
      JacC( 61, 53) = JacC( 61, 53) + dw( 14, 53)
      JacC( 62, 53) = JacC( 62, 53) + dw( 14, 53)
      JacC( 71, 53) = JacC( 71, 53) + dw( 14, 53)
      JacC( 28, 28) = JacC( 28, 28) - dw( 15, 28)
      JacC( 62, 28) = JacC( 62, 28) + dw( 15, 28)
      JacC( 63, 28) = JacC( 63, 28) + dw( 15, 28)
      JacC( 59, 59) = JacC( 59, 59) - dw( 16, 59)
      JacC( 60, 59) = JacC( 60, 59) + dw( 16, 59)
      JacC( 69, 59) = JacC( 69, 59) + dw( 16, 59)
      JacC( 51, 51) = JacC( 51, 51) - dw( 17, 51)
      JacC( 52, 51) = JacC( 52, 51)+ 0.1870000000000000D+01*dw( 17, 51)
      JacC( 66, 51) = JacC( 66, 51)+ 0.1300000000000000D+00*dw( 17, 51)
      JacC( 51, 51) = JacC( 51, 51) - dw( 18, 51)
      JacC( 52, 51) = JacC( 52, 51)+ 0.1550000000000000D+01*dw( 18, 51)
      JacC( 66, 51) = JacC( 66, 51)+ 0.4500000000000000D+00*dw( 18, 51)
      JacC( 71, 51) = JacC( 71, 51)+ 0.8000000000000000D+00*dw( 18, 51)
      JacC( 52, 54) = JacC( 52, 54) + dw( 19, 54)
      JacC( 54, 54) = JacC( 54, 54) - dw( 19, 54)
      JacC( 69, 54) = JacC( 69, 54) + dw( 19, 54)
      JacC( 71, 54) = JacC( 71, 54) + dw( 19, 54)
      JacC( 48, 48) = JacC( 48, 48) - dw( 20, 48)
      JacC( 56, 48) = JacC( 56, 48) + dw( 20, 48)
      JacC( 71, 48) = JacC( 71, 48) + dw( 20, 48)
      JacC( 59, 70) = JacC( 59, 70)+ 0.8000000000000000D+00*dw( 21, 70)
      JacC( 61, 70) = JacC( 61, 70)+ 0.2000000000000000D+00*dw( 21, 70)
      JacC( 70, 70) = JacC( 70, 70) - dw( 21, 70)
      JacC( 71, 70) = JacC( 71, 70) + dw( 21, 70)
      JacC( 72, 70) = JacC( 72, 70) + dw( 21, 70)
      JacC( 49, 49) = JacC( 49, 49) - dw( 22, 49)
      JacC( 52, 49) = JacC( 52, 49) + dw( 22, 49)
      JacC( 66, 49) = JacC( 66, 49) + dw( 22, 49)
      JacC( 69, 49) = JacC( 69, 49) + dw( 22, 49)
      JacC( 71, 49) = JacC( 71, 49) + dw( 22, 49)
      JacC( 24, 24) = JacC( 24, 24) - dw( 23, 24)
      JacC( 66, 24) = JacC( 66, 24) + dw( 23, 24)
      JacC( 69, 24) = JacC( 69, 24) + dw( 23, 24)
      JacC( 71, 24) = JacC( 71, 24) + dw( 23, 24)
      JacC( 35, 35) = JacC( 35, 35) - dw( 24, 35)
      JacC( 50, 35) = JacC( 50, 35) + dw( 24, 35)
      JacC( 35, 35) = JacC( 35, 35) - dw( 25, 35)
      JacC( 35, 50) = JacC( 35, 50) - dw( 25, 50)
      JacC( 50, 35) = JacC( 50, 35) - dw( 25, 35)
      JacC( 50, 50) = JacC( 50, 50) - dw( 25, 50)
      JacC(  7,  7) = JacC(  7,  7) - dw( 26,  7)
      JacC( 35,  7) = JacC( 35,  7) + dw( 26,  7)
      JacC(  7,  7) = JacC(  7,  7) - dw( 27,  7)
      JacC( 35,  7) = JacC( 35,  7) + dw( 27,  7)
      JacC(  7,  7) = JacC(  7,  7) - dw( 28,  7)
      JacC( 62,  7) = JacC( 62,  7)+ 0.2000000000000000D+01*dw( 28,  7)
      JacC( 50, 50) = JacC( 50, 50) - dw( 29, 50)
      JacC( 50, 62) = JacC( 50, 62) - dw( 29, 62)
      JacC( 62, 50) = JacC( 62, 50) - dw( 29, 50)
      JacC( 62, 62) = JacC( 62, 62) - dw( 29, 62)
      JacC( 71, 50) = JacC( 71, 50) + dw( 29, 50)
      JacC( 71, 62) = JacC( 71, 62) + dw( 29, 62)
      JacC( 50, 50) = JacC( 50, 50) - dw( 30, 50)
      JacC( 50, 71) = JacC( 50, 71) - dw( 30, 71)
      JacC( 62, 50) = JacC( 62, 50) + dw( 30, 50)
      JacC( 62, 71) = JacC( 62, 71) + dw( 30, 71)
      JacC( 71, 50) = JacC( 71, 50) - dw( 30, 50)
      JacC( 71, 71) = JacC( 71, 71) - dw( 30, 71)
      JacC( 62, 62) = JacC( 62, 62) - dw( 31, 62)
      JacC( 62, 71) = JacC( 62, 71) - dw( 31, 71)
      JacC( 71, 62) = JacC( 71, 62) - dw( 31, 62)
      JacC( 71, 71) = JacC( 71, 71) - dw( 31, 71)
      JacC( 27, 27) = JacC( 27, 27) - dw( 32, 27)
      JacC( 27, 62) = JacC( 27, 62) - dw( 32, 62)
      JacC( 62, 27) = JacC( 62, 27) - dw( 32, 27)
      JacC( 62, 62) = JacC( 62, 62) - dw( 32, 62)
      JacC( 71, 27) = JacC( 71, 27) + dw( 32, 27)
      JacC( 71, 62) = JacC( 71, 62) + dw( 32, 62)
      JacC( 27, 71) = JacC( 27, 71) + dw( 33, 71)
      JacC( 27, 71) = JacC( 27, 71) + dw( 33, 71)
      JacC( 71, 71) = JacC( 71, 71)- 0.2000000000000000D+01*dw( 33, 71)
      JacC( 71, 71) = JacC( 71, 71)- 0.2000000000000000D+01*dw( 33, 71)
      JacC( 27, 71) = JacC( 27, 71) + dw( 34, 71)
      JacC( 27, 71) = JacC( 27, 71) + dw( 34, 71)
      JacC( 71, 71) = JacC( 71, 71)- 0.2000000000000000D+01*dw( 34, 71)
      JacC( 71, 71) = JacC( 71, 71)- 0.2000000000000000D+01*dw( 34, 71)
      JacC( 35, 35) = JacC( 35, 35) - dw( 35, 35)
      JacC( 35, 67) = JacC( 35, 67) - dw( 35, 67)
      JacC( 67, 35) = JacC( 67, 35) - dw( 35, 35)
      JacC( 67, 67) = JacC( 67, 67) - dw( 35, 67)
      JacC( 72, 35) = JacC( 72, 35) + dw( 35, 35)
      JacC( 72, 67) = JacC( 72, 67) + dw( 35, 67)
      JacC( 35, 35) = JacC( 35, 35) - dw( 36, 35)
      JacC( 35, 72) = JacC( 35, 72) - dw( 36, 72)
      JacC( 67, 35) = JacC( 67, 35) + dw( 36, 35)
      JacC( 67, 72) = JacC( 67, 72) + dw( 36, 72)
      JacC( 72, 35) = JacC( 72, 35) - dw( 36, 35)
      JacC( 72, 72) = JacC( 72, 72) - dw( 36, 72)
      JacC( 35, 35) = JacC( 35, 35) - dw( 37, 35)
      JacC( 35, 72) = JacC( 35, 72) - dw( 37, 72)
      JacC( 68, 35) = JacC( 68, 35) + dw( 37, 35)
      JacC( 68, 72) = JacC( 68, 72) + dw( 37, 72)
      JacC( 72, 35) = JacC( 72, 35) - dw( 37, 35)
      JacC( 72, 72) = JacC( 72, 72) - dw( 37, 72)
      JacC( 23, 62) = JacC( 23, 62) + dw( 38, 62)
      JacC( 23, 67) = JacC( 23, 67) + dw( 38, 67)
      JacC( 62, 62) = JacC( 62, 62) - dw( 38, 62)
      JacC( 62, 67) = JacC( 62, 67) - dw( 38, 67)
      JacC( 67, 62) = JacC( 67, 62) - dw( 38, 62)
      JacC( 67, 67) = JacC( 67, 67) - dw( 38, 67)
      JacC( 55, 62) = JacC( 55, 62) + dw( 39, 62)
      JacC( 55, 72) = JacC( 55, 72) + dw( 39, 72)
      JacC( 62, 62) = JacC( 62, 62) - dw( 39, 62)
      JacC( 62, 72) = JacC( 62, 72) - dw( 39, 72)
      JacC( 72, 62) = JacC( 72, 62) - dw( 39, 62)
      JacC( 72, 72) = JacC( 72, 72) - dw( 39, 72)
      JacC( 62, 62) = JacC( 62, 62) - dw( 40, 62)
      JacC( 62, 68) = JacC( 62, 68) - dw( 40, 68)
      JacC( 68, 62) = JacC( 68, 62) - dw( 40, 62)
      JacC( 68, 68) = JacC( 68, 68) - dw( 40, 68)
      JacC( 71, 62) = JacC( 71, 62) + dw( 40, 62)
      JacC( 71, 68) = JacC( 71, 68) + dw( 40, 68)
      JacC( 72, 62) = JacC( 72, 62) + dw( 40, 62)
      JacC( 72, 68) = JacC( 72, 68) + dw( 40, 68)
      JacC( 62, 71) = JacC( 62, 71) + dw( 41, 71)
      JacC( 62, 67) = JacC( 62, 67) + dw( 41, 67)
      JacC( 67, 71) = JacC( 67, 71) - dw( 41, 71)
      JacC( 67, 67) = JacC( 67, 67) - dw( 41, 67)
      JacC( 71, 71) = JacC( 71, 71) - dw( 41, 71)
      JacC( 71, 67) = JacC( 71, 67) - dw( 41, 67)
      JacC( 72, 71) = JacC( 72, 71) + dw( 41, 71)
      JacC( 72, 67) = JacC( 72, 67) + dw( 41, 67)
      JacC( 15, 71) = JacC( 15, 71) + dw( 42, 71)
      JacC( 15, 72) = JacC( 15, 72) + dw( 42, 72)
      JacC( 71, 71) = JacC( 71, 71) - dw( 42, 71)
      JacC( 71, 72) = JacC( 71, 72) - dw( 42, 72)
      JacC( 72, 71) = JacC( 72, 71) - dw( 42, 71)
      JacC( 72, 72) = JacC( 72, 72) - dw( 42, 72)
      JacC( 15, 15) = JacC( 15, 15) - dw( 43, 15)
      JacC( 71, 15) = JacC( 71, 15) + dw( 43, 15)
      JacC( 72, 15) = JacC( 72, 15) + dw( 43, 15)
      JacC( 55, 71) = JacC( 55, 71)+ 0.3000000000000000D+00*dw( 44, 71)
      JacC( 55, 68) = JacC( 55, 68)+ 0.3000000000000000D+00*dw( 44, 68)
      JacC( 62, 71) = JacC( 62, 71)+ 0.7000000000000000D+00*dw( 44, 71)
      JacC( 62, 68) = JacC( 62, 68)+ 0.7000000000000000D+00*dw( 44, 68)
      JacC( 68, 71) = JacC( 68, 71) - dw( 44, 71)
      JacC( 68, 68) = JacC( 68, 68) - dw( 44, 68)
      JacC( 71, 71) = JacC( 71, 71) - dw( 44, 71)
      JacC( 71, 68) = JacC( 71, 68) - dw( 44, 68)
      JacC( 72, 71) = JacC( 72, 71)+ 0.7000000000000000D+00*dw( 44, 71)
      JacC( 72, 68) = JacC( 72, 68)+ 0.7000000000000000D+00*dw( 44, 68)
      JacC( 23, 62) = JacC( 23, 62) - dw( 45, 62)
      JacC( 23, 23) = JacC( 23, 23) - dw( 45, 23)
      JacC( 62, 62) = JacC( 62, 62) - dw( 45, 62)
      JacC( 62, 23) = JacC( 62, 23) - dw( 45, 23)
      JacC( 72, 62) = JacC( 72, 62) + dw( 45, 62)
      JacC( 72, 23) = JacC( 72, 23) + dw( 45, 23)
      JacC( 55, 62) = JacC( 55, 62) - dw( 46, 62)
      JacC( 55, 55) = JacC( 55, 55) - dw( 46, 55)
      JacC( 62, 62) = JacC( 62, 62) - dw( 46, 62)
      JacC( 62, 55) = JacC( 62, 55) - dw( 46, 55)
      JacC( 68, 62) = JacC( 68, 62) + dw( 46, 62)
      JacC( 68, 55) = JacC( 68, 55) + dw( 46, 55)
      JacC( 15, 62) = JacC( 15, 62) - dw( 47, 62)
      JacC( 15, 15) = JacC( 15, 15) - dw( 47, 15)
      JacC( 62, 62) = JacC( 62, 62) - dw( 47, 62)
      JacC( 62, 15) = JacC( 62, 15) - dw( 47, 15)
      JacC( 72, 62) = JacC( 72, 62) + dw( 47, 62)
      JacC( 72, 15) = JacC( 72, 15) + dw( 47, 15)
      JacC( 50, 50) = JacC( 50, 50) - dw( 48, 50)
      JacC( 50, 67) = JacC( 50, 67) - dw( 48, 67)
      JacC( 67, 50) = JacC( 67, 50) - dw( 48, 50)
      JacC( 67, 67) = JacC( 67, 67) - dw( 48, 67)
      JacC( 72, 50) = JacC( 72, 50) + dw( 48, 50)
      JacC( 72, 67) = JacC( 72, 67) + dw( 48, 67)
      JacC( 50, 50) = JacC( 50, 50) - dw( 49, 50)
      JacC( 50, 72) = JacC( 50, 72) - dw( 49, 72)
      JacC( 68, 50) = JacC( 68, 50) + dw( 49, 50)
      JacC( 68, 72) = JacC( 68, 72) + dw( 49, 72)
      JacC( 72, 50) = JacC( 72, 50) - dw( 49, 50)
      JacC( 72, 72) = JacC( 72, 72) - dw( 49, 72)
      JacC( 67, 67) = JacC( 67, 67)- 0.2000000000000000D+01*dw( 50, 67)
      JacC( 67, 67) = JacC( 67, 67)- 0.2000000000000000D+01*dw( 50, 67)
      JacC( 72, 67) = JacC( 72, 67)+ 0.2000000000000000D+01*dw( 50, 67)
      JacC( 72, 67) = JacC( 72, 67)+ 0.2000000000000000D+01*dw( 50, 67)
      JacC( 67, 68) = JacC( 67, 68) - dw( 51, 68)
      JacC( 67, 67) = JacC( 67, 67) - dw( 51, 67)
      JacC( 68, 68) = JacC( 68, 68) - dw( 51, 68)
      JacC( 68, 67) = JacC( 68, 67) - dw( 51, 67)
      JacC( 72, 68) = JacC( 72, 68)+ 0.2000000000000000D+01*dw( 51, 68)
      JacC( 72, 67) = JacC( 72, 67)+ 0.2000000000000000D+01*dw( 51, 67)
      JacC( 67, 68) = JacC( 67, 68) + dw( 52, 68)
      JacC( 67, 72) = JacC( 67, 72) + dw( 52, 72)
      JacC( 68, 68) = JacC( 68, 68) - dw( 52, 68)
      JacC( 68, 72) = JacC( 68, 72) - dw( 52, 72)
      JacC(  9, 68) = JacC(  9, 68) + dw( 53, 68)
      JacC(  9, 72) = JacC(  9, 72) + dw( 53, 72)
      JacC( 68, 68) = JacC( 68, 68) - dw( 53, 68)
      JacC( 68, 72) = JacC( 68, 72) - dw( 53, 72)
      JacC( 72, 68) = JacC( 72, 68) - dw( 53, 68)
      JacC( 72, 72) = JacC( 72, 72) - dw( 53, 72)
      JacC(  9,  9) = JacC(  9,  9) - dw( 54,  9)
      JacC( 68,  9) = JacC( 68,  9) + dw( 54,  9)
      JacC( 72,  9) = JacC( 72,  9) + dw( 54,  9)
      JacC( 68, 68) = JacC( 68, 68)- 0.2000000000000000D+01*dw( 55, 68)
      JacC( 68, 68) = JacC( 68, 68)- 0.2000000000000000D+01*dw( 55, 68)
      JacC( 72, 68) = JacC( 72, 68)+ 0.2000000000000000D+01*dw( 55, 68)
      JacC( 72, 68) = JacC( 72, 68)+ 0.2000000000000000D+01*dw( 55, 68)
      JacC( 62, 62) = JacC( 62, 62) - dw( 56, 62)
      JacC( 71, 62) = JacC( 71, 62) + dw( 56, 62)
      JacC(  1, 62) = JacC(  1, 62) - dw( 57, 62)
      JacC(  1,  1) = JacC(  1,  1) - dw( 57,  1)
      JacC(  8, 62) = JacC(  8, 62) + dw( 57, 62)
      JacC(  8,  1) = JacC(  8,  1) + dw( 57,  1)
      JacC( 62, 62) = JacC( 62, 62) - dw( 57, 62)
      JacC( 62,  1) = JacC( 62,  1) - dw( 57,  1)
      JacC( 71, 62) = JacC( 71, 62) + dw( 57, 62)
      JacC( 71,  1) = JacC( 71,  1) + dw( 57,  1)
      JacC( 52, 52) = JacC( 52, 52) - dw( 58, 52)
      JacC( 52, 62) = JacC( 52, 62) - dw( 58, 62)
      JacC( 62, 52) = JacC( 62, 52) - dw( 58, 52)
      JacC( 62, 62) = JacC( 62, 62) - dw( 58, 62)
      JacC( 71, 52) = JacC( 71, 52) + dw( 58, 52)
      JacC( 71, 62) = JacC( 71, 62) + dw( 58, 62)
      JacC( 19, 19) = JacC( 19, 19) - dw( 59, 19)
      JacC( 19, 35) = JacC( 19, 35) - dw( 59, 35)
      JacC( 35, 19) = JacC( 35, 19) - dw( 59, 19)
      JacC( 35, 35) = JacC( 35, 35) - dw( 59, 35)
      JacC( 40, 19) = JacC( 40, 19)+ 0.8600000000000000D+00*dw( 59, 19)
      JacC( 40, 35) = JacC( 40, 35)+ 0.8600000000000000D+00*dw( 59, 35)
      JacC( 48, 19) = JacC( 48, 19)+ 0.1300000000000000D+00*dw( 59, 19)
      JacC( 48, 35) = JacC( 48, 35)+ 0.1300000000000000D+00*dw( 59, 35)
      JacC( 52, 19) = JacC( 52, 19)+ 0.1000000000000000D-01*dw( 59, 19)
      JacC( 52, 35) = JacC( 52, 35)+ 0.1000000000000000D-01*dw( 59, 35)
      JacC( 62, 19) = JacC( 62, 19)+ 0.2000000000000000D-01*dw( 59, 19)
      JacC( 62, 35) = JacC( 62, 35)+ 0.2000000000000000D-01*dw( 59, 35)
      JacC( 65, 19) = JacC( 65, 19)+ 0.1500000000000000D+00*dw( 59, 19)
      JacC( 65, 35) = JacC( 65, 35)+ 0.1500000000000000D+00*dw( 59, 35)
      JacC( 66, 19) = JacC( 66, 19)+ 0.5000000000000000D-01*dw( 59, 19)
      JacC( 66, 35) = JacC( 66, 35)+ 0.5000000000000000D-01*dw( 59, 35)
      JacC( 71, 19) = JacC( 71, 19)+ 0.2800000000000000D+00*dw( 59, 19)
      JacC( 71, 35) = JacC( 71, 35)+ 0.2800000000000000D+00*dw( 59, 35)
      JacC( 35, 49) = JacC( 35, 49) - dw( 60, 49)
      JacC( 35, 35) = JacC( 35, 35) - dw( 60, 35)
      JacC( 49, 49) = JacC( 49, 49) - dw( 60, 49)
      JacC( 49, 35) = JacC( 49, 35) - dw( 60, 35)
      JacC( 61, 49) = JacC( 61, 49) + dw( 60, 49)
      JacC( 61, 35) = JacC( 61, 35) + dw( 60, 35)
      JacC( 20, 20) = JacC( 20, 20) - dw( 61, 20)
      JacC( 20, 62) = JacC( 20, 62) - dw( 61, 62)
      JacC( 62, 20) = JacC( 62, 20) - dw( 61, 20)
      JacC( 62, 62) = JacC( 62, 62) - dw( 61, 62)
      JacC( 63, 20) = JacC( 63, 20) + dw( 61, 20)
      JacC( 63, 62) = JacC( 63, 62) + dw( 61, 62)
      JacC( 21, 21) = JacC( 21, 21) - dw( 62, 21)
      JacC( 21, 62) = JacC( 21, 62) - dw( 62, 62)
      JacC( 60, 21) = JacC( 60, 21) + dw( 62, 21)
      JacC( 60, 62) = JacC( 60, 62) + dw( 62, 62)
      JacC( 62, 21) = JacC( 62, 21) - dw( 62, 21)
      JacC( 62, 62) = JacC( 62, 62) - dw( 62, 62)
      JacC(  2,  2) = JacC(  2,  2) - dw( 63,  2)
      JacC(  2, 62) = JacC(  2, 62) - dw( 63, 62)
      JacC( 34,  2) = JacC( 34,  2)+ 0.3600000000000000D-01*dw( 63,  2)
      JacC( 34, 62) = JacC( 34, 62)+ 0.3600000000000000D-01*dw( 63, 62)
      JacC( 51,  2) = JacC( 51,  2)+ 0.3600000000000000D-01*dw( 63,  2)
      JacC( 51, 62) = JacC( 51, 62)+ 0.3600000000000000D-01*dw( 63, 62)
      JacC( 52,  2) = JacC( 52,  2)+ 0.3600000000000000D-01*dw( 63,  2)
      JacC( 52, 62) = JacC( 52, 62)+ 0.3600000000000000D-01*dw( 63, 62)
      JacC( 61,  2) = JacC( 61,  2)+ 0.3350000000000000D+00*dw( 63,  2)
      JacC( 61, 62) = JacC( 61, 62)+ 0.3350000000000000D+00*dw( 63, 62)
      JacC( 62,  2) = JacC( 62,  2)- 0.9640000000000000D+00*dw( 63,  2)
      JacC( 62, 62) = JacC( 62, 62)- 0.9640000000000000D+00*dw( 63, 62)
      JacC( 64,  2) = JacC( 64,  2)+ 0.5830000000000000D+00*dw( 63,  2)
      JacC( 64, 62) = JacC( 64, 62)+ 0.5830000000000000D+00*dw( 63, 62)
      JacC( 66,  2) = JacC( 66,  2)+ 0.1000000000000000D-01*dw( 63,  2)
      JacC( 66, 62) = JacC( 66, 62)+ 0.1000000000000000D-01*dw( 63, 62)
      JacC( 71,  2) = JacC( 71,  2)+ 0.3810000000000000D+00*dw( 63,  2)
      JacC( 71, 62) = JacC( 71, 62)+ 0.3810000000000000D+00*dw( 63, 62)
      JacC(  3,  3) = JacC(  3,  3) - dw( 64,  3)
      JacC(  3, 62) = JacC(  3, 62) - dw( 64, 62)
      JacC( 36,  3) = JacC( 36,  3)+ 0.7500000000000000D+00*dw( 64,  3)
      JacC( 36, 62) = JacC( 36, 62)+ 0.7500000000000000D+00*dw( 64, 62)
      JacC( 59,  3) = JacC( 59,  3)+ 0.2500000000000000D+00*dw( 64,  3)
      JacC( 59, 62) = JacC( 59, 62)+ 0.2500000000000000D+00*dw( 64, 62)
      JacC( 62,  3) = JacC( 62,  3) - dw( 64,  3)
      JacC( 62, 62) = JacC( 62, 62) - dw( 64, 62)
      JacC( 71,  3) = JacC( 71,  3)+ 0.2500000000000000D+00*dw( 64,  3)
      JacC( 71, 62) = JacC( 71, 62)+ 0.2500000000000000D+00*dw( 64, 62)
      JacC(  4,  4) = JacC(  4,  4) - dw( 65,  4)
      JacC(  4, 62) = JacC(  4, 62) - dw( 65, 62)
      JacC( 24,  4) = JacC( 24,  4)+ 0.2400000000000000D-01*dw( 65,  4)
      JacC( 24, 62) = JacC( 24, 62)+ 0.2400000000000000D-01*dw( 65, 62)
      JacC( 37,  4) = JacC( 37,  4)+ 0.9510000000000000D+00*dw( 65,  4)
      JacC( 37, 62) = JacC( 37, 62)+ 0.9510000000000000D+00*dw( 65, 62)
      JacC( 61,  4) = JacC( 61,  4)+ 0.2500000000000000D-01*dw( 65,  4)
      JacC( 61, 62) = JacC( 61, 62)+ 0.2500000000000000D-01*dw( 65, 62)
      JacC( 62,  4) = JacC( 62,  4) - dw( 65,  4)
      JacC( 62, 62) = JacC( 62, 62) - dw( 65, 62)
      JacC( 71,  4) = JacC( 71,  4)+ 0.4900000000000000D-01*dw( 65,  4)
      JacC( 71, 62) = JacC( 71, 62)+ 0.4900000000000000D-01*dw( 65, 62)
      JacC( 11, 11) = JacC( 11, 11) - dw( 66, 11)
      JacC( 11, 62) = JacC( 11, 62) - dw( 66, 62)
      JacC( 38, 11) = JacC( 38, 11) + dw( 66, 11)
      JacC( 38, 62) = JacC( 38, 62) + dw( 66, 62)
      JacC( 62, 11) = JacC( 62, 11) - dw( 66, 11)
      JacC( 62, 62) = JacC( 62, 62) - dw( 66, 62)
      JacC( 40, 40) = JacC( 40, 40) - dw( 67, 40)
      JacC( 40, 62) = JacC( 40, 62) - dw( 67, 62)
      JacC( 41, 40) = JacC( 41, 40) + dw( 67, 40)
      JacC( 41, 62) = JacC( 41, 62) + dw( 67, 62)
      JacC( 62, 40) = JacC( 62, 40) - dw( 67, 40)
      JacC( 62, 62) = JacC( 62, 62) - dw( 67, 62)
      JacC( 44, 44) = JacC( 44, 44) - dw( 68, 44)
      JacC( 44, 62) = JacC( 44, 62) - dw( 68, 62)
      JacC( 45, 44) = JacC( 45, 44) + dw( 68, 44)
      JacC( 45, 62) = JacC( 45, 62) + dw( 68, 62)
      JacC( 62, 44) = JacC( 62, 44) - dw( 68, 44)
      JacC( 62, 62) = JacC( 62, 62) - dw( 68, 62)
      JacC( 12, 12) = JacC( 12, 12) - dw( 69, 12)
      JacC( 12, 62) = JacC( 12, 62) - dw( 69, 62)
      JacC( 39, 12) = JacC( 39, 12) + dw( 69, 12)
      JacC( 39, 62) = JacC( 39, 62) + dw( 69, 62)
      JacC( 62, 12) = JacC( 62, 12) - dw( 69, 12)
      JacC( 62, 62) = JacC( 62, 62) - dw( 69, 62)
      JacC( 19, 19) = JacC( 19, 19) - dw( 70, 19)
      JacC( 19, 62) = JacC( 19, 62) - dw( 70, 62)
      JacC( 39, 19) = JacC( 39, 19) + dw( 70, 19)
      JacC( 39, 62) = JacC( 39, 62) + dw( 70, 62)
      JacC( 62, 19) = JacC( 62, 19) - dw( 70, 19)
      JacC( 62, 62) = JacC( 62, 62) - dw( 70, 62)
      JacC( 13, 13) = JacC( 13, 13) - dw( 71, 13)
      JacC( 13, 62) = JacC( 13, 62) - dw( 71, 62)
      JacC( 42, 13) = JacC( 42, 13) + dw( 71, 13)
      JacC( 42, 62) = JacC( 42, 62) + dw( 71, 62)
      JacC( 62, 13) = JacC( 62, 13) - dw( 71, 13)
      JacC( 62, 62) = JacC( 62, 62) - dw( 71, 62)
      JacC( 14, 14) = JacC( 14, 14) - dw( 72, 14)
      JacC( 14, 62) = JacC( 14, 62) - dw( 72, 62)
      JacC( 43, 14) = JacC( 43, 14) + dw( 72, 14)
      JacC( 43, 62) = JacC( 43, 62) + dw( 72, 62)
      JacC( 62, 14) = JacC( 62, 14) - dw( 72, 14)
      JacC( 62, 62) = JacC( 62, 62) - dw( 72, 62)
      JacC(  5,  5) = JacC(  5,  5) - dw( 73,  5)
      JacC(  5, 62) = JacC(  5, 62) - dw( 73, 62)
      JacC( 17,  5) = JacC( 17,  5)+ 0.9000000000000000D+00*dw( 73,  5)
      JacC( 17, 62) = JacC( 17, 62)+ 0.9000000000000000D+00*dw( 73, 62)
      JacC( 62,  5) = JacC( 62,  5) - dw( 73,  5)
      JacC( 62, 62) = JacC( 62, 62) - dw( 73, 62)
      JacC( 65,  5) = JacC( 65,  5)+ 0.1000000000000000D+00*dw( 73,  5)
      JacC( 65, 62) = JacC( 65, 62)+ 0.1000000000000000D+00*dw( 73, 62)
      JacC( 71,  5) = JacC( 71,  5)+ 0.1000000000000000D+00*dw( 73,  5)
      JacC( 71, 62) = JacC( 71, 62)+ 0.1000000000000000D+00*dw( 73, 62)
      JacC(  6,  6) = JacC(  6,  6) - dw( 74,  6)
      JacC(  6, 62) = JacC(  6, 62) - dw( 74, 62)
      JacC( 18,  6) = JacC( 18,  6)+ 0.9000000000000000D+00*dw( 74,  6)
      JacC( 18, 62) = JacC( 18, 62)+ 0.9000000000000000D+00*dw( 74, 62)
      JacC( 62,  6) = JacC( 62,  6) - dw( 74,  6)
      JacC( 62, 62) = JacC( 62, 62) - dw( 74, 62)
      JacC( 65,  6) = JacC( 65,  6)+ 0.1000000000000000D+00*dw( 74,  6)
      JacC( 65, 62) = JacC( 65, 62)+ 0.1000000000000000D+00*dw( 74, 62)
      JacC( 71,  6) = JacC( 71,  6)+ 0.1000000000000000D+00*dw( 74,  6)
      JacC( 71, 62) = JacC( 71, 62)+ 0.1000000000000000D+00*dw( 74, 62)
      JacC( 22, 30) = JacC( 22, 30)+ 0.8500000000000000D+00*dw( 75, 30)
      JacC( 22, 62) = JacC( 22, 62)+ 0.8500000000000000D+00*dw( 75, 62)
      JacC( 29, 30) = JacC( 29, 30)+ 0.1000000000000000D+00*dw( 75, 30)
      JacC( 29, 62) = JacC( 29, 62)+ 0.1000000000000000D+00*dw( 75, 62)
      JacC( 30, 30) = JacC( 30, 30) - dw( 75, 30)
      JacC( 30, 62) = JacC( 30, 62) - dw( 75, 62)
      JacC( 62, 30) = JacC( 62, 30) - dw( 75, 30)
      JacC( 62, 62) = JacC( 62, 62) - dw( 75, 62)
      JacC( 65, 30) = JacC( 65, 30)+ 0.5000000000000000D-01*dw( 75, 30)
      JacC( 65, 62) = JacC( 65, 62)+ 0.5000000000000000D-01*dw( 75, 62)
      JacC( 71, 30) = JacC( 71, 30)+ 0.5000000000000000D-01*dw( 75, 30)
      JacC( 71, 62) = JacC( 71, 62)+ 0.5000000000000000D-01*dw( 75, 62)
      JacC( 52, 66) = JacC( 52, 66) + dw( 76, 66)
      JacC( 52, 62) = JacC( 52, 62) + dw( 76, 62)
      JacC( 62, 66) = JacC( 62, 66) - dw( 76, 66)
      JacC( 62, 62) = JacC( 62, 62) - dw( 76, 62)
      JacC( 66, 66) = JacC( 66, 66) - dw( 76, 66)
      JacC( 66, 62) = JacC( 66, 62) - dw( 76, 62)
      JacC( 71, 66) = JacC( 71, 66) + dw( 76, 66)
      JacC( 71, 62) = JacC( 71, 62) + dw( 76, 62)
      JacC( 61, 61) = JacC( 61, 61) - dw( 77, 61)
      JacC( 61, 62) = JacC( 61, 62) - dw( 77, 62)
      JacC( 62, 61) = JacC( 62, 61) - dw( 77, 61)
      JacC( 62, 62) = JacC( 62, 62) - dw( 77, 62)
      JacC( 69, 61) = JacC( 69, 61) + dw( 77, 61)
      JacC( 69, 62) = JacC( 69, 62) + dw( 77, 62)
      JacC( 58, 59) = JacC( 58, 59) + dw( 78, 59)
      JacC( 58, 62) = JacC( 58, 62) + dw( 78, 62)
      JacC( 59, 59) = JacC( 59, 59) - dw( 78, 59)
      JacC( 59, 62) = JacC( 59, 62) - dw( 78, 62)
      JacC( 62, 59) = JacC( 62, 59) - dw( 78, 59)
      JacC( 62, 62) = JacC( 62, 62) - dw( 78, 62)
      JacC( 24, 24) = JacC( 24, 24) - dw( 79, 24)
      JacC( 24, 62) = JacC( 24, 62) - dw( 79, 62)
      JacC( 54, 24) = JacC( 54, 24) + dw( 79, 24)
      JacC( 54, 62) = JacC( 54, 62) + dw( 79, 62)
      JacC( 62, 24) = JacC( 62, 24) - dw( 79, 24)
      JacC( 62, 62) = JacC( 62, 62) - dw( 79, 62)
      JacC( 71, 24) = JacC( 71, 24) + dw( 79, 24)
      JacC( 71, 62) = JacC( 71, 62) + dw( 79, 62)
      JacC( 51, 51) = JacC( 51, 51) - dw( 80, 51)
      JacC( 51, 62) = JacC( 51, 62) - dw( 80, 62)
      JacC( 52, 51) = JacC( 52, 51)+ 0.2000000000000000D+01*dw( 80, 51)
      JacC( 52, 62) = JacC( 52, 62)+ 0.2000000000000000D+01*dw( 80, 62)
      JacC( 62, 51) = JacC( 62, 51) - dw( 80, 51)
      JacC( 62, 62) = JacC( 62, 62) - dw( 80, 62)
      JacC( 71, 51) = JacC( 71, 51) + dw( 80, 51)
      JacC( 71, 62) = JacC( 71, 62) + dw( 80, 62)
      JacC( 52, 54) = JacC( 52, 54) + dw( 81, 54)
      JacC( 52, 62) = JacC( 52, 62) + dw( 81, 62)
      JacC( 54, 54) = JacC( 54, 54) - dw( 81, 54)
      JacC( 54, 62) = JacC( 54, 62) - dw( 81, 62)
      JacC( 62, 54) = JacC( 62, 54) - dw( 81, 54)
      JacC( 62, 62) = JacC( 62, 62) - dw( 81, 62)
      JacC( 69, 54) = JacC( 69, 54) + dw( 81, 54)
      JacC( 69, 62) = JacC( 69, 62) + dw( 81, 62)
      JacC( 24, 49) = JacC( 24, 49)+ 0.4100000000000000D+00*dw( 82, 49)
      JacC( 24, 62) = JacC( 24, 62)+ 0.4100000000000000D+00*dw( 82, 62)
      JacC( 49, 49) = JacC( 49, 49) - dw( 82, 49)
      JacC( 49, 62) = JacC( 49, 62) - dw( 82, 62)
      JacC( 52, 49) = JacC( 52, 49)+ 0.4100000000000000D+00*dw( 82, 49)
      JacC( 52, 62) = JacC( 52, 62)+ 0.4100000000000000D+00*dw( 82, 62)
      JacC( 54, 49) = JacC( 54, 49)+ 0.8000000000000000D-01*dw( 82, 49)
      JacC( 54, 62) = JacC( 54, 62)+ 0.8000000000000000D-01*dw( 82, 62)
      JacC( 56, 49) = JacC( 56, 49)+ 0.5100000000000000D+00*dw( 82, 49)
      JacC( 56, 62) = JacC( 56, 62)+ 0.5100000000000000D+00*dw( 82, 62)
      JacC( 62, 49) = JacC( 62, 49) - dw( 82, 49)
      JacC( 62, 62) = JacC( 62, 62) - dw( 82, 62)
      JacC( 65, 49) = JacC( 65, 49)+ 0.4900000000000000D+00*dw( 82, 49)
      JacC( 65, 62) = JacC( 65, 62)+ 0.4900000000000000D+00*dw( 82, 62)
      JacC( 66, 49) = JacC( 66, 49)+ 0.8000000000000000D-01*dw( 82, 49)
      JacC( 66, 62) = JacC( 66, 62)+ 0.8000000000000000D-01*dw( 82, 62)
      JacC( 71, 49) = JacC( 71, 49)+ 0.4900000000000000D+00*dw( 82, 49)
      JacC( 71, 62) = JacC( 71, 62)+ 0.4900000000000000D+00*dw( 82, 62)
      JacC( 10, 62) = JacC( 10, 62)+ 0.3500000000000000D+00*dw( 83, 62)
      JacC( 10, 48) = JacC( 10, 48)+ 0.3500000000000000D+00*dw( 83, 48)
      JacC( 48, 62) = JacC( 48, 62) - dw( 83, 62)
      JacC( 48, 48) = JacC( 48, 48) - dw( 83, 48)
      JacC( 51, 62) = JacC( 51, 62)+ 0.1500000000000000D+00*dw( 83, 62)
      JacC( 51, 48) = JacC( 51, 48)+ 0.1500000000000000D+00*dw( 83, 48)
      JacC( 54, 62) = JacC( 54, 62)+ 0.1500000000000000D+00*dw( 83, 62)
      JacC( 54, 48) = JacC( 54, 48)+ 0.1500000000000000D+00*dw( 83, 48)
      JacC( 56, 62) = JacC( 56, 62)+ 0.5000000000000000D+00*dw( 83, 62)
      JacC( 56, 48) = JacC( 56, 48)+ 0.5000000000000000D+00*dw( 83, 48)
      JacC( 62, 62) = JacC( 62, 62) - dw( 83, 62)
      JacC( 62, 48) = JacC( 62, 48) - dw( 83, 48)
      JacC( 65, 62) = JacC( 65, 62)+ 0.5000000000000000D+00*dw( 83, 62)
      JacC( 65, 48) = JacC( 65, 48)+ 0.5000000000000000D+00*dw( 83, 48)
      JacC( 71, 62) = JacC( 71, 62)+ 0.5000000000000000D+00*dw( 83, 62)
      JacC( 71, 48) = JacC( 71, 48)+ 0.5000000000000000D+00*dw( 83, 48)
      JacC( 10, 62) = JacC( 10, 62) - dw( 84, 62)
      JacC( 10, 10) = JacC( 10, 10) - dw( 84, 10)
      JacC( 59, 62) = JacC( 59, 62)+ 0.1200000000000000D+00*dw( 84, 62)
      JacC( 59, 10) = JacC( 59, 10)+ 0.1200000000000000D+00*dw( 84, 10)
      JacC( 61, 62) = JacC( 61, 62)+ 0.8800000000000000D+00*dw( 84, 62)
      JacC( 61, 10) = JacC( 61, 10)+ 0.8800000000000000D+00*dw( 84, 10)
      JacC( 62, 62) = JacC( 62, 62) - dw( 84, 62)
      JacC( 62, 10) = JacC( 62, 10) - dw( 84, 10)
      JacC( 71, 62) = JacC( 71, 62) + dw( 84, 62)
      JacC( 71, 10) = JacC( 71, 10) + dw( 84, 10)
      JacC( 16, 16) = JacC( 16, 16) - dw( 85, 16)
      JacC( 16, 62) = JacC( 16, 62) - dw( 85, 62)
      JacC( 62, 16) = JacC( 62, 16)- 0.6500000000000000D+00*dw( 85, 16)
      JacC( 62, 62) = JacC( 62, 62)- 0.6500000000000000D+00*dw( 85, 62)
      JacC( 63, 16) = JacC( 63, 16)+ 0.6500000000000000D+00*dw( 85, 16)
      JacC( 63, 62) = JacC( 63, 62)+ 0.6500000000000000D+00*dw( 85, 62)
      JacC( 66, 16) = JacC( 66, 16)+ 0.3500000000000000D+00*dw( 85, 16)
      JacC( 66, 62) = JacC( 66, 62)+ 0.3500000000000000D+00*dw( 85, 62)
      JacC( 53, 53) = JacC( 53, 53) - dw( 86, 53)
      JacC( 53, 62) = JacC( 53, 62) - dw( 86, 62)
      JacC( 59, 53) = JacC( 59, 53)+ 0.4100000000000000D+00*dw( 86, 53)
      JacC( 59, 62) = JacC( 59, 62)+ 0.4100000000000000D+00*dw( 86, 62)
      JacC( 61, 53) = JacC( 61, 53)+ 0.8000000000000000D-01*dw( 86, 53)
      JacC( 61, 62) = JacC( 61, 62)+ 0.8000000000000000D-01*dw( 86, 62)
      JacC( 62, 53) = JacC( 62, 53)- 0.5100000000000000D+00*dw( 86, 53)
      JacC( 62, 62) = JacC( 62, 62)- 0.5100000000000000D+00*dw( 86, 62)
      JacC( 64, 53) = JacC( 64, 53)+ 0.4400000000000000D+00*dw( 86, 53)
      JacC( 64, 62) = JacC( 64, 62)+ 0.4400000000000000D+00*dw( 86, 62)
      JacC( 65, 53) = JacC( 65, 53)+ 0.7000000000000001D-01*dw( 86, 53)
      JacC( 65, 62) = JacC( 65, 62)+ 0.7000000000000001D-01*dw( 86, 62)
      JacC( 28, 28) = JacC( 28, 28) - dw( 87, 28)
      JacC( 28, 62) = JacC( 28, 62) - dw( 87, 62)
      JacC( 62, 28) = JacC( 62, 28) - dw( 87, 28)
      JacC( 62, 62) = JacC( 62, 62) - dw( 87, 62)
      JacC( 65, 28) = JacC( 65, 28)+ 0.3500000000000000D+00*dw( 87, 28)
      JacC( 65, 62) = JacC( 65, 62)+ 0.3500000000000000D+00*dw( 87, 62)
      JacC( 66, 28) = JacC( 66, 28)+ 0.3500000000000000D+00*dw( 87, 28)
      JacC( 66, 62) = JacC( 66, 62)+ 0.3500000000000000D+00*dw( 87, 62)
      JacC( 69, 28) = JacC( 69, 28)+ 0.6500000000000000D+00*dw( 87, 28)
      JacC( 69, 62) = JacC( 69, 62)+ 0.6500000000000000D+00*dw( 87, 62)
      JacC( 71, 28) = JacC( 71, 28)+ 0.3500000000000000D+00*dw( 87, 28)
      JacC( 71, 62) = JacC( 71, 62)+ 0.3500000000000000D+00*dw( 87, 62)
      JacC( 26, 26) = JacC( 26, 26) - dw( 88, 26)
      JacC( 26, 62) = JacC( 26, 62) - dw( 88, 62)
      JacC( 62, 26) = JacC( 62, 26) - dw( 88, 26)
      JacC( 62, 62) = JacC( 62, 62) - dw( 88, 62)
      JacC( 65, 26) = JacC( 65, 26) + dw( 88, 26)
      JacC( 65, 62) = JacC( 65, 62) + dw( 88, 62)
      JacC( 66, 26) = JacC( 66, 26) + dw( 88, 26)
      JacC( 66, 62) = JacC( 66, 62) + dw( 88, 62)
      JacC( 68, 26) = JacC( 68, 26) + dw( 88, 26)
      JacC( 68, 62) = JacC( 68, 62) + dw( 88, 62)
      JacC( 24, 25) = JacC( 24, 25)+ 0.6000000000000000D+00*dw( 89, 25)
      JacC( 24, 62) = JacC( 24, 62)+ 0.6000000000000000D+00*dw( 89, 62)
      JacC( 25, 25) = JacC( 25, 25) - dw( 89, 25)
      JacC( 25, 62) = JacC( 25, 62) - dw( 89, 62)
      JacC( 26, 25) = JacC( 26, 25)+ 0.4000000000000000D+00*dw( 89, 25)
      JacC( 26, 62) = JacC( 26, 62)+ 0.4000000000000000D+00*dw( 89, 62)
      JacC( 62, 25) = JacC( 62, 25) - dw( 89, 25)
      JacC( 62, 62) = JacC( 62, 62) - dw( 89, 62)
      JacC( 65, 25) = JacC( 65, 25) + dw( 89, 25)
      JacC( 65, 62) = JacC( 65, 62) + dw( 89, 62)
      JacC( 66, 25) = JacC( 66, 25)+ 0.4000000000000000D+00*dw( 89, 25)
      JacC( 66, 62) = JacC( 66, 62)+ 0.4000000000000000D+00*dw( 89, 62)
      JacC( 68, 25) = JacC( 68, 25)+ 0.6000000000000000D+00*dw( 89, 25)
      JacC( 68, 62) = JacC( 68, 62)+ 0.6000000000000000D+00*dw( 89, 62)
      JacC( 71, 25) = JacC( 71, 25)+ 0.4000000000000000D+00*dw( 89, 25)
      JacC( 71, 62) = JacC( 71, 62)+ 0.4000000000000000D+00*dw( 89, 62)
      JacC( 62, 70) = JacC( 62, 70) - dw( 90, 70)
      JacC( 62, 62) = JacC( 62, 62) - dw( 90, 62)
      JacC( 64, 70) = JacC( 64, 70) + dw( 90, 70)
      JacC( 64, 62) = JacC( 64, 62) + dw( 90, 62)
      JacC( 70, 70) = JacC( 70, 70) - dw( 90, 70)
      JacC( 70, 62) = JacC( 70, 62) - dw( 90, 62)
      JacC( 72, 70) = JacC( 72, 70) + dw( 90, 70)
      JacC( 72, 62) = JacC( 72, 62) + dw( 90, 62)
      JacC( 52, 66) = JacC( 52, 66) + dw( 91, 66)
      JacC( 52, 68) = JacC( 52, 68) + dw( 91, 68)
      JacC( 55, 66) = JacC( 55, 66) + dw( 91, 66)
      JacC( 55, 68) = JacC( 55, 68) + dw( 91, 68)
      JacC( 66, 66) = JacC( 66, 66) - dw( 91, 66)
      JacC( 66, 68) = JacC( 66, 68) - dw( 91, 68)
      JacC( 68, 66) = JacC( 68, 66) - dw( 91, 66)
      JacC( 68, 68) = JacC( 68, 68) - dw( 91, 68)
      JacC( 71, 66) = JacC( 71, 66) + dw( 91, 66)
      JacC( 71, 68) = JacC( 71, 68) + dw( 91, 68)
      JacC( 55, 61) = JacC( 55, 61) + dw( 92, 61)
      JacC( 55, 68) = JacC( 55, 68) + dw( 92, 68)
      JacC( 61, 61) = JacC( 61, 61) - dw( 92, 61)
      JacC( 61, 68) = JacC( 61, 68) - dw( 92, 68)
      JacC( 68, 61) = JacC( 68, 61) - dw( 92, 61)
      JacC( 68, 68) = JacC( 68, 68) - dw( 92, 68)
      JacC( 69, 61) = JacC( 69, 61) + dw( 92, 61)
      JacC( 69, 68) = JacC( 69, 68) + dw( 92, 68)
      JacC( 51, 51) = JacC( 51, 51) - dw( 93, 51)
      JacC( 51, 68) = JacC( 51, 68) - dw( 93, 68)
      JacC( 52, 51) = JacC( 52, 51)+ 0.2000000000000000D+01*dw( 93, 51)
      JacC( 52, 68) = JacC( 52, 68)+ 0.2000000000000000D+01*dw( 93, 68)
      JacC( 55, 51) = JacC( 55, 51) + dw( 93, 51)
      JacC( 55, 68) = JacC( 55, 68) + dw( 93, 68)
      JacC( 68, 51) = JacC( 68, 51) - dw( 93, 51)
      JacC( 68, 68) = JacC( 68, 68) - dw( 93, 68)
      JacC( 71, 51) = JacC( 71, 51) + dw( 93, 51)
      JacC( 71, 68) = JacC( 71, 68) + dw( 93, 68)
      JacC( 52, 54) = JacC( 52, 54) + dw( 94, 54)
      JacC( 52, 68) = JacC( 52, 68) + dw( 94, 68)
      JacC( 54, 54) = JacC( 54, 54) - dw( 94, 54)
      JacC( 54, 68) = JacC( 54, 68) - dw( 94, 68)
      JacC( 55, 54) = JacC( 55, 54) + dw( 94, 54)
      JacC( 55, 68) = JacC( 55, 68) + dw( 94, 68)
      JacC( 68, 54) = JacC( 68, 54) - dw( 94, 54)
      JacC( 68, 68) = JacC( 68, 68) - dw( 94, 68)
      JacC( 69, 54) = JacC( 69, 54) + dw( 94, 54)
      JacC( 69, 68) = JacC( 69, 68) + dw( 94, 68)
      JacC( 47, 49) = JacC( 47, 49)+ 0.8000000000000000D+00*dw( 95, 49)
      JacC( 47, 68) = JacC( 47, 68)+ 0.8000000000000000D+00*dw( 95, 68)
      JacC( 49, 49) = JacC( 49, 49) - dw( 95, 49)
      JacC( 49, 68) = JacC( 49, 68) - dw( 95, 68)
      JacC( 52, 49) = JacC( 52, 49)+ 0.8000000000000000D+00*dw( 95, 49)
      JacC( 52, 68) = JacC( 52, 68)+ 0.8000000000000000D+00*dw( 95, 68)
      JacC( 55, 49) = JacC( 55, 49)+ 0.2000000000000000D+00*dw( 95, 49)
      JacC( 55, 68) = JacC( 55, 68)+ 0.2000000000000000D+00*dw( 95, 68)
      JacC( 56, 49) = JacC( 56, 49)+ 0.2000000000000000D+00*dw( 95, 49)
      JacC( 56, 68) = JacC( 56, 68)+ 0.2000000000000000D+00*dw( 95, 68)
      JacC( 68, 49) = JacC( 68, 49) - dw( 95, 49)
      JacC( 68, 68) = JacC( 68, 68) - dw( 95, 68)
      JacC( 48, 48) = JacC( 48, 48) - dw( 96, 48)
      JacC( 48, 68) = JacC( 48, 68) - dw( 96, 68)
      JacC( 51, 48) = JacC( 51, 48)+ 0.2500000000000000D+00*dw( 96, 48)
      JacC( 51, 68) = JacC( 51, 68)+ 0.2500000000000000D+00*dw( 96, 68)
      JacC( 54, 48) = JacC( 54, 48)+ 0.2500000000000000D+00*dw( 96, 48)
      JacC( 54, 68) = JacC( 54, 68)+ 0.2500000000000000D+00*dw( 96, 68)
      JacC( 55, 48) = JacC( 55, 48)+ 0.5000000000000000D+00*dw( 96, 48)
      JacC( 55, 68) = JacC( 55, 68)+ 0.5000000000000000D+00*dw( 96, 68)
      JacC( 56, 48) = JacC( 56, 48)+ 0.5000000000000000D+00*dw( 96, 48)
      JacC( 56, 68) = JacC( 56, 68)+ 0.5000000000000000D+00*dw( 96, 68)
      JacC( 59, 48) = JacC( 59, 48)+ 0.3000000000000000D-01*dw( 96, 48)
      JacC( 59, 68) = JacC( 59, 68)+ 0.3000000000000000D-01*dw( 96, 68)
      JacC( 61, 48) = JacC( 61, 48)+ 0.2500000000000000D+00*dw( 96, 48)
      JacC( 61, 68) = JacC( 61, 68)+ 0.2500000000000000D+00*dw( 96, 68)
      JacC( 65, 48) = JacC( 65, 48)+ 0.5000000000000000D+00*dw( 96, 48)
      JacC( 65, 68) = JacC( 65, 68)+ 0.5000000000000000D+00*dw( 96, 68)
      JacC( 68, 48) = JacC( 68, 48) - dw( 96, 48)
      JacC( 68, 68) = JacC( 68, 68) - dw( 96, 68)
      JacC( 71, 48) = JacC( 71, 48)+ 0.5000000000000000D+00*dw( 96, 48)
      JacC( 71, 68) = JacC( 71, 68)+ 0.5000000000000000D+00*dw( 96, 68)
      JacC( 72, 48) = JacC( 72, 48)+ 0.5000000000000000D+00*dw( 96, 48)
      JacC( 72, 68) = JacC( 72, 68)+ 0.5000000000000000D+00*dw( 96, 68)
      JacC( 29, 30) = JacC( 29, 30) + dw( 97, 30)
      JacC( 29, 68) = JacC( 29, 68) + dw( 97, 68)
      JacC( 30, 30) = JacC( 30, 30) - dw( 97, 30)
      JacC( 30, 68) = JacC( 30, 68) - dw( 97, 68)
      JacC( 55, 30) = JacC( 55, 30) + dw( 97, 30)
      JacC( 55, 68) = JacC( 55, 68) + dw( 97, 68)
      JacC( 68, 30) = JacC( 68, 30) - dw( 97, 30)
      JacC( 68, 68) = JacC( 68, 68) - dw( 97, 68)
      JacC( 11, 11) = JacC( 11, 11) - dw( 98, 11)
      JacC( 11, 68) = JacC( 11, 68) - dw( 98, 68)
      JacC( 46, 11) = JacC( 46, 11)+ 0.2000000000000000D+00*dw( 98, 11)
      JacC( 46, 68) = JacC( 46, 68)+ 0.2000000000000000D+00*dw( 98, 68)
      JacC( 47, 11) = JacC( 47, 11)+ 0.8000000000000000D+00*dw( 98, 11)
      JacC( 47, 68) = JacC( 47, 68)+ 0.8000000000000000D+00*dw( 98, 68)
      JacC( 68, 11) = JacC( 68, 11) - dw( 98, 11)
      JacC( 68, 68) = JacC( 68, 68) - dw( 98, 68)
      JacC( 40, 40) = JacC( 40, 40) - dw( 99, 40)
      JacC( 40, 68) = JacC( 40, 68) - dw( 99, 68)
      JacC( 46, 40) = JacC( 46, 40)+ 0.5700000000000000D+00*dw( 99, 40)
      JacC( 46, 68) = JacC( 46, 68)+ 0.5700000000000000D+00*dw( 99, 68)
      JacC( 47, 40) = JacC( 47, 40)+ 0.4300000000000000D+00*dw( 99, 40)
      JacC( 47, 68) = JacC( 47, 68)+ 0.4300000000000000D+00*dw( 99, 68)
      JacC( 68, 40) = JacC( 68, 40) - dw( 99, 40)
      JacC( 68, 68) = JacC( 68, 68) - dw( 99, 68)
      JacC( 44, 44) = JacC( 44, 44) - dw(100, 44)
      JacC( 44, 68) = JacC( 44, 68) - dw(100, 68)
      JacC( 46, 44) = JacC( 46, 44)+ 0.8900000000000000D+00*dw(100, 44)
      JacC( 46, 68) = JacC( 46, 68)+ 0.8900000000000000D+00*dw(100, 68)
      JacC( 47, 44) = JacC( 47, 44)+ 0.1100000000000000D+00*dw(100, 44)
      JacC( 47, 68) = JacC( 47, 68)+ 0.1100000000000000D+00*dw(100, 68)
      JacC( 68, 44) = JacC( 68, 44) - dw(100, 44)
      JacC( 68, 68) = JacC( 68, 68) - dw(100, 68)
      JacC( 12, 12) = JacC( 12, 12) - dw(101, 12)
      JacC( 12, 68) = JacC( 12, 68) - dw(101, 68)
      JacC( 46, 12) = JacC( 46, 12)+ 0.1000000000000000D+00*dw(101, 12)
      JacC( 46, 68) = JacC( 46, 68)+ 0.1000000000000000D+00*dw(101, 68)
      JacC( 47, 12) = JacC( 47, 12)+ 0.9000000000000000D+00*dw(101, 12)
      JacC( 47, 68) = JacC( 47, 68)+ 0.9000000000000000D+00*dw(101, 68)
      JacC( 49, 12) = JacC( 49, 12)+ 0.9000000000000000D+00*dw(101, 12)
      JacC( 49, 68) = JacC( 49, 68)+ 0.9000000000000000D+00*dw(101, 68)
      JacC( 68, 12) = JacC( 68, 12) - dw(101, 12)
      JacC( 68, 68) = JacC( 68, 68) - dw(101, 68)
      JacC( 19, 19) = JacC( 19, 19) - dw(102, 19)
      JacC( 19, 68) = JacC( 19, 68) - dw(102, 68)
      JacC( 46, 19) = JacC( 46, 19)+ 0.1000000000000000D+00*dw(102, 19)
      JacC( 46, 68) = JacC( 46, 68)+ 0.1000000000000000D+00*dw(102, 68)
      JacC( 47, 19) = JacC( 47, 19)+ 0.9000000000000000D+00*dw(102, 19)
      JacC( 47, 68) = JacC( 47, 68)+ 0.9000000000000000D+00*dw(102, 68)
      JacC( 49, 19) = JacC( 49, 19)+ 0.9000000000000000D+00*dw(102, 19)
      JacC( 49, 68) = JacC( 49, 68)+ 0.9000000000000000D+00*dw(102, 68)
      JacC( 68, 19) = JacC( 68, 19) - dw(102, 19)
      JacC( 68, 68) = JacC( 68, 68) - dw(102, 68)
      JacC( 13, 13) = JacC( 13, 13) - dw(103, 13)
      JacC( 13, 68) = JacC( 13, 68) - dw(103, 68)
      JacC( 46, 13) = JacC( 46, 13)+ 0.9000000000000000D+00*dw(103, 13)
      JacC( 46, 68) = JacC( 46, 68)+ 0.9000000000000000D+00*dw(103, 68)
      JacC( 47, 13) = JacC( 47, 13)+ 0.1000000000000000D+00*dw(103, 13)
      JacC( 47, 68) = JacC( 47, 68)+ 0.1000000000000000D+00*dw(103, 68)
      JacC( 68, 13) = JacC( 68, 13) - dw(103, 13)
      JacC( 68, 68) = JacC( 68, 68) - dw(103, 68)
      JacC( 14, 14) = JacC( 14, 14) - dw(104, 14)
      JacC( 14, 68) = JacC( 14, 68) - dw(104, 68)
      JacC( 46, 14) = JacC( 46, 14)+ 0.8700000000000000D+00*dw(104, 14)
      JacC( 46, 68) = JacC( 46, 68)+ 0.8700000000000000D+00*dw(104, 68)
      JacC( 47, 14) = JacC( 47, 14)+ 0.1300000000000000D+00*dw(104, 14)
      JacC( 47, 68) = JacC( 47, 68)+ 0.1300000000000000D+00*dw(104, 68)
      JacC( 68, 14) = JacC( 68, 14) - dw(104, 14)
      JacC( 68, 68) = JacC( 68, 68) - dw(104, 68)
      JacC( 25, 25) = JacC( 25, 25) - dw(105, 25)
      JacC( 25, 68) = JacC( 25, 68) - dw(105, 68)
      JacC( 26, 25) = JacC( 26, 25)+ 0.4000000000000000D+00*dw(105, 25)
      JacC( 26, 68) = JacC( 26, 68)+ 0.4000000000000000D+00*dw(105, 68)
      JacC( 65, 25) = JacC( 65, 25) + dw(105, 25)
      JacC( 65, 68) = JacC( 65, 68) + dw(105, 68)
      JacC( 66, 25) = JacC( 66, 25)+ 0.4000000000000000D+00*dw(105, 25)
      JacC( 66, 68) = JacC( 66, 68)+ 0.4000000000000000D+00*dw(105, 68)
      JacC( 68, 25) = JacC( 68, 25)- 0.4000000000000000D+00*dw(105, 25)
      JacC( 68, 68) = JacC( 68, 68)- 0.4000000000000000D+00*dw(105, 68)
      JacC( 70, 25) = JacC( 70, 25)+ 0.6000000000000000D+00*dw(105, 25)
      JacC( 70, 68) = JacC( 70, 68)+ 0.6000000000000000D+00*dw(105, 68)
      JacC( 72, 25) = JacC( 72, 25)+ 0.4000000000000000D+00*dw(105, 25)
      JacC( 72, 68) = JacC( 72, 68)+ 0.4000000000000000D+00*dw(105, 68)
      JacC( 11, 11) = JacC( 11, 11) - dw(106, 11)
      JacC( 11, 50) = JacC( 11, 50) - dw(106, 50)
      JacC( 34, 11) = JacC( 34, 11)+ 0.3700000000000000D+00*dw(106, 11)
      JacC( 34, 50) = JacC( 34, 50)+ 0.3700000000000000D+00*dw(106, 50)
      JacC( 50, 11) = JacC( 50, 11) - dw(106, 11)
      JacC( 50, 50) = JacC( 50, 50) - dw(106, 50)
      JacC( 52, 11) = JacC( 52, 11)+ 0.4300000000000000D+00*dw(106, 11)
      JacC( 52, 50) = JacC( 52, 50)+ 0.4300000000000000D+00*dw(106, 50)
      JacC( 62, 11) = JacC( 62, 11)+ 0.1200000000000000D+00*dw(106, 11)
      JacC( 62, 50) = JacC( 62, 50)+ 0.1200000000000000D+00*dw(106, 50)
      JacC( 66, 11) = JacC( 66, 11) + dw(106, 11)
      JacC( 66, 50) = JacC( 66, 50) + dw(106, 50)
      JacC( 71, 11) = JacC( 71, 11)+ 0.2600000000000000D+00*dw(106, 11)
      JacC( 71, 50) = JacC( 71, 50)+ 0.2600000000000000D+00*dw(106, 50)
      JacC( 20, 40) = JacC( 20, 40)+ 0.6000000000000000D-01*dw(107, 40)
      JacC( 20, 50) = JacC( 20, 50)+ 0.6000000000000000D-01*dw(107, 50)
      JacC( 21, 40) = JacC( 21, 40)+ 0.3000000000000000D-01*dw(107, 40)
      JacC( 21, 50) = JacC( 21, 50)+ 0.3000000000000000D-01*dw(107, 50)
      JacC( 27, 40) = JacC( 27, 40)+ 0.6000000000000000D-02*dw(107, 40)
      JacC( 27, 50) = JacC( 27, 50)+ 0.6000000000000000D-02*dw(107, 50)
      JacC( 34, 40) = JacC( 34, 40)+ 0.1400000000000000D+00*dw(107, 40)
      JacC( 34, 50) = JacC( 34, 50)+ 0.1400000000000000D+00*dw(107, 50)
      JacC( 40, 40) = JacC( 40, 40) - dw(107, 40)
      JacC( 40, 50) = JacC( 40, 50) - dw(107, 50)
      JacC( 50, 40) = JacC( 50, 40) - dw(107, 40)
      JacC( 50, 50) = JacC( 50, 50) - dw(107, 50)
      JacC( 52, 40) = JacC( 52, 40)+ 0.3700000000000000D+00*dw(107, 40)
      JacC( 52, 50) = JacC( 52, 50)+ 0.3700000000000000D+00*dw(107, 50)
      JacC( 57, 40) = JacC( 57, 40)+ 0.1000000000000000D+00*dw(107, 40)
      JacC( 57, 50) = JacC( 57, 50)+ 0.1000000000000000D+00*dw(107, 50)
      JacC( 58, 40) = JacC( 58, 40)+ 0.3000000000000000D-01*dw(107, 40)
      JacC( 58, 50) = JacC( 58, 50)+ 0.3000000000000000D-01*dw(107, 50)
      JacC( 59, 40) = JacC( 59, 40)+ 0.3000000000000000D-01*dw(107, 40)
      JacC( 59, 50) = JacC( 59, 50)+ 0.3000000000000000D-01*dw(107, 50)
      JacC( 60, 40) = JacC( 60, 40)+ 0.1000000000000000D+00*dw(107, 40)
      JacC( 60, 50) = JacC( 60, 50)+ 0.1000000000000000D+00*dw(107, 50)
      JacC( 61, 40) = JacC( 61, 40)+ 0.4400000000000000D+00*dw(107, 40)
      JacC( 61, 50) = JacC( 61, 50)+ 0.4400000000000000D+00*dw(107, 50)
      JacC( 62, 40) = JacC( 62, 40)+ 0.4000000000000000D+00*dw(107, 40)
      JacC( 62, 50) = JacC( 62, 50)+ 0.4000000000000000D+00*dw(107, 50)
      JacC( 63, 40) = JacC( 63, 40)+ 0.1900000000000000D+00*dw(107, 40)
      JacC( 63, 50) = JacC( 63, 50)+ 0.1900000000000000D+00*dw(107, 50)
      JacC( 66, 40) = JacC( 66, 40)+ 0.6400000000000000D+00*dw(107, 40)
      JacC( 66, 50) = JacC( 66, 50)+ 0.6400000000000000D+00*dw(107, 50)
      JacC( 71, 40) = JacC( 71, 40)+ 0.2500000000000000D+00*dw(107, 40)
      JacC( 71, 50) = JacC( 71, 50)+ 0.2500000000000000D+00*dw(107, 50)
      JacC( 20, 44) = JacC( 20, 44)+ 0.7000000000000001D-01*dw(108, 44)
      JacC( 20, 50) = JacC( 20, 50)+ 0.7000000000000001D-01*dw(108, 50)
      JacC( 21, 44) = JacC( 21, 44)+ 0.6000000000000000D-01*dw(108, 44)
      JacC( 21, 50) = JacC( 21, 50)+ 0.6000000000000000D-01*dw(108, 50)
      JacC( 27, 44) = JacC( 27, 44)+ 0.1100000000000000D-01*dw(108, 44)
      JacC( 27, 50) = JacC( 27, 50)+ 0.1100000000000000D-01*dw(108, 50)
      JacC( 44, 44) = JacC( 44, 44) - dw(108, 44)
      JacC( 44, 50) = JacC( 44, 50) - dw(108, 50)
      JacC( 50, 44) = JacC( 50, 44) - dw(108, 44)
      JacC( 50, 50) = JacC( 50, 50) - dw(108, 50)
      JacC( 52, 44) = JacC( 52, 44)+ 0.3000000000000000D+00*dw(108, 44)
      JacC( 52, 50) = JacC( 52, 50)+ 0.3000000000000000D+00*dw(108, 50)
      JacC( 57, 44) = JacC( 57, 44)+ 0.1400000000000000D+00*dw(108, 44)
      JacC( 57, 50) = JacC( 57, 50)+ 0.1400000000000000D+00*dw(108, 50)
      JacC( 58, 44) = JacC( 58, 44)+ 0.1200000000000000D+00*dw(108, 44)
      JacC( 58, 50) = JacC( 58, 50)+ 0.1200000000000000D+00*dw(108, 50)
      JacC( 59, 44) = JacC( 59, 44)+ 0.1600000000000000D+00*dw(108, 44)
      JacC( 59, 50) = JacC( 59, 50)+ 0.1600000000000000D+00*dw(108, 50)
      JacC( 60, 44) = JacC( 60, 44)+ 0.1800000000000000D+00*dw(108, 44)
      JacC( 60, 50) = JacC( 60, 50)+ 0.1800000000000000D+00*dw(108, 50)
      JacC( 61, 44) = JacC( 61, 44)+ 0.9900000000000000D+00*dw(108, 44)
      JacC( 61, 50) = JacC( 61, 50)+ 0.9900000000000000D+00*dw(108, 50)
      JacC( 62, 44) = JacC( 62, 44)+ 0.6300000000000000D+00*dw(108, 44)
      JacC( 62, 50) = JacC( 62, 50)+ 0.6300000000000000D+00*dw(108, 50)
      JacC( 63, 44) = JacC( 63, 44)+ 0.2300000000000000D+00*dw(108, 44)
      JacC( 63, 50) = JacC( 63, 50)+ 0.2300000000000000D+00*dw(108, 50)
      JacC( 66, 44) = JacC( 66, 44)+ 0.2000000000000000D-01*dw(108, 44)
      JacC( 66, 50) = JacC( 66, 50)+ 0.2000000000000000D-01*dw(108, 50)
      JacC( 71, 44) = JacC( 71, 44)+ 0.2200000000000000D+00*dw(108, 44)
      JacC( 71, 50) = JacC( 71, 50)+ 0.2200000000000000D+00*dw(108, 50)
      JacC( 12, 12) = JacC( 12, 12) - dw(109, 12)
      JacC( 12, 50) = JacC( 12, 50) - dw(109, 50)
      JacC( 27, 12) = JacC( 27, 12)+ 0.1000000000000000D-02*dw(109, 12)
      JacC( 27, 50) = JacC( 27, 50)+ 0.1000000000000000D-02*dw(109, 50)
      JacC( 34, 12) = JacC( 34, 12)+ 0.1500000000000000D+00*dw(109, 12)
      JacC( 34, 50) = JacC( 34, 50)+ 0.1500000000000000D+00*dw(109, 50)
      JacC( 35, 12) = JacC( 35, 12)+ 0.9000000000000000D-01*dw(109, 12)
      JacC( 35, 50) = JacC( 35, 50)+ 0.9000000000000000D-01*dw(109, 50)
      JacC( 40, 12) = JacC( 40, 12)+ 0.3500000000000000D+00*dw(109, 12)
      JacC( 40, 50) = JacC( 40, 50)+ 0.3500000000000000D+00*dw(109, 50)
      JacC( 49, 12) = JacC( 49, 12)+ 0.3900000000000000D+00*dw(109, 12)
      JacC( 49, 50) = JacC( 49, 50)+ 0.3900000000000000D+00*dw(109, 50)
      JacC( 50, 12) = JacC( 50, 12) - dw(109, 12)
      JacC( 50, 50) = JacC( 50, 50) - dw(109, 50)
      JacC( 52, 12) = JacC( 52, 12)+ 0.3600000000000000D+00*dw(109, 12)
      JacC( 52, 50) = JacC( 52, 50)+ 0.3600000000000000D+00*dw(109, 50)
      JacC( 58, 12) = JacC( 58, 12)+ 0.2000000000000000D-01*dw(109, 12)
      JacC( 58, 50) = JacC( 58, 50)+ 0.2000000000000000D-01*dw(109, 50)
      JacC( 62, 12) = JacC( 62, 12)+ 0.2800000000000000D+00*dw(109, 12)
      JacC( 62, 50) = JacC( 62, 50)+ 0.2800000000000000D+00*dw(109, 50)
      JacC( 63, 12) = JacC( 63, 12)+ 0.3000000000000000D-01*dw(109, 12)
      JacC( 63, 50) = JacC( 63, 50)+ 0.3000000000000000D-01*dw(109, 50)
      JacC( 65, 12) = JacC( 65, 12)+ 0.1300000000000000D+00*dw(109, 12)
      JacC( 65, 50) = JacC( 65, 50)+ 0.1300000000000000D+00*dw(109, 50)
      JacC( 66, 12) = JacC( 66, 12)+ 0.9000000000000000D+00*dw(109, 12)
      JacC( 66, 50) = JacC( 66, 50)+ 0.9000000000000000D+00*dw(109, 50)
      JacC( 69, 12) = JacC( 69, 12)+ 0.1500000000000000D+00*dw(109, 12)
      JacC( 69, 50) = JacC( 69, 50)+ 0.1500000000000000D+00*dw(109, 50)
      JacC( 71, 12) = JacC( 71, 12)+ 0.3000000000000000D+00*dw(109, 12)
      JacC( 71, 50) = JacC( 71, 50)+ 0.3000000000000000D+00*dw(109, 50)
      JacC( 19, 19) = JacC( 19, 19) - dw(110, 19)
      JacC( 19, 50) = JacC( 19, 50) - dw(110, 50)
      JacC( 27, 19) = JacC( 27, 19)+ 0.1000000000000000D-02*dw(110, 19)
      JacC( 27, 50) = JacC( 27, 50)+ 0.1000000000000000D-02*dw(110, 50)
      JacC( 34, 19) = JacC( 34, 19)+ 0.1500000000000000D+00*dw(110, 19)
      JacC( 34, 50) = JacC( 34, 50)+ 0.1500000000000000D+00*dw(110, 50)
      JacC( 35, 19) = JacC( 35, 19)+ 0.9000000000000000D-01*dw(110, 19)
      JacC( 35, 50) = JacC( 35, 50)+ 0.9000000000000000D-01*dw(110, 50)
      JacC( 40, 19) = JacC( 40, 19)+ 0.3500000000000000D+00*dw(110, 19)
      JacC( 40, 50) = JacC( 40, 50)+ 0.3500000000000000D+00*dw(110, 50)
      JacC( 49, 19) = JacC( 49, 19)+ 0.3900000000000000D+00*dw(110, 19)
      JacC( 49, 50) = JacC( 49, 50)+ 0.3900000000000000D+00*dw(110, 50)
      JacC( 50, 19) = JacC( 50, 19) - dw(110, 19)
      JacC( 50, 50) = JacC( 50, 50) - dw(110, 50)
      JacC( 52, 19) = JacC( 52, 19)+ 0.3600000000000000D+00*dw(110, 19)
      JacC( 52, 50) = JacC( 52, 50)+ 0.3600000000000000D+00*dw(110, 50)
      JacC( 58, 19) = JacC( 58, 19)+ 0.2000000000000000D-01*dw(110, 19)
      JacC( 58, 50) = JacC( 58, 50)+ 0.2000000000000000D-01*dw(110, 50)
      JacC( 62, 19) = JacC( 62, 19)+ 0.2800000000000000D+00*dw(110, 19)
      JacC( 62, 50) = JacC( 62, 50)+ 0.2800000000000000D+00*dw(110, 50)
      JacC( 63, 19) = JacC( 63, 19)+ 0.3000000000000000D-01*dw(110, 19)
      JacC( 63, 50) = JacC( 63, 50)+ 0.3000000000000000D-01*dw(110, 50)
      JacC( 65, 19) = JacC( 65, 19)+ 0.1300000000000000D+00*dw(110, 19)
      JacC( 65, 50) = JacC( 65, 50)+ 0.1300000000000000D+00*dw(110, 50)
      JacC( 66, 19) = JacC( 66, 19)+ 0.9000000000000000D+00*dw(110, 19)
      JacC( 66, 50) = JacC( 66, 50)+ 0.9000000000000000D+00*dw(110, 50)
      JacC( 69, 19) = JacC( 69, 19)+ 0.1500000000000000D+00*dw(110, 19)
      JacC( 69, 50) = JacC( 69, 50)+ 0.1500000000000000D+00*dw(110, 50)
      JacC( 71, 19) = JacC( 71, 19)+ 0.3000000000000000D+00*dw(110, 19)
      JacC( 71, 50) = JacC( 71, 50)+ 0.3000000000000000D+00*dw(110, 50)
      JacC( 13, 13) = JacC( 13, 13) - dw(111, 13)
      JacC( 13, 50) = JacC( 13, 50) - dw(111, 50)
      JacC( 27, 13) = JacC( 27, 13)+ 0.2000000000000000D-01*dw(111, 13)
      JacC( 27, 50) = JacC( 27, 50)+ 0.2000000000000000D-01*dw(111, 50)
      JacC( 50, 13) = JacC( 50, 13) - dw(111, 13)
      JacC( 50, 50) = JacC( 50, 50) - dw(111, 50)
      JacC( 52, 13) = JacC( 52, 13)+ 0.1400000000000000D+00*dw(111, 13)
      JacC( 52, 50) = JacC( 52, 50)+ 0.1400000000000000D+00*dw(111, 50)
      JacC( 58, 13) = JacC( 58, 13)+ 0.4200000000000000D+00*dw(111, 13)
      JacC( 58, 50) = JacC( 58, 50)+ 0.4200000000000000D+00*dw(111, 50)
      JacC( 59, 13) = JacC( 59, 13)+ 0.5300000000000000D+00*dw(111, 13)
      JacC( 59, 50) = JacC( 59, 50)+ 0.5300000000000000D+00*dw(111, 50)
      JacC( 60, 13) = JacC( 60, 13)+ 0.2000000000000000D+00*dw(111, 13)
      JacC( 60, 50) = JacC( 60, 50)+ 0.2000000000000000D+00*dw(111, 50)
      JacC( 61, 13) = JacC( 61, 13)+ 0.6500000000000000D+00*dw(111, 13)
      JacC( 61, 50) = JacC( 61, 50)+ 0.6500000000000000D+00*dw(111, 50)
      JacC( 62, 13) = JacC( 62, 13)+ 0.8500000000000000D+00*dw(111, 13)
      JacC( 62, 50) = JacC( 62, 50)+ 0.8500000000000000D+00*dw(111, 50)
      JacC( 71, 13) = JacC( 71, 13)+ 0.1000000000000000D+00*dw(111, 13)
      JacC( 71, 50) = JacC( 71, 50)+ 0.1000000000000000D+00*dw(111, 50)
      JacC( 14, 14) = JacC( 14, 14) - dw(112, 14)
      JacC( 14, 50) = JacC( 14, 50) - dw(112, 50)
      JacC( 27, 14) = JacC( 27, 14)+ 0.2000000000000000D-01*dw(112, 14)
      JacC( 27, 50) = JacC( 27, 50)+ 0.2000000000000000D-01*dw(112, 50)
      JacC( 34, 14) = JacC( 34, 14)+ 0.1000000000000000D-01*dw(112, 14)
      JacC( 34, 50) = JacC( 34, 50)+ 0.1000000000000000D-01*dw(112, 50)
      JacC( 40, 14) = JacC( 40, 14)+ 0.4600000000000000D+00*dw(112, 14)
      JacC( 40, 50) = JacC( 40, 50)+ 0.4600000000000000D+00*dw(112, 50)
      JacC( 49, 14) = JacC( 49, 14)+ 0.7900000000000000D+00*dw(112, 14)
      JacC( 49, 50) = JacC( 49, 50)+ 0.7900000000000000D+00*dw(112, 50)
      JacC( 50, 14) = JacC( 50, 14) - dw(112, 14)
      JacC( 50, 50) = JacC( 50, 50) - dw(112, 50)
      JacC( 52, 14) = JacC( 52, 14)+ 0.1400000000000000D+00*dw(112, 14)
      JacC( 52, 50) = JacC( 52, 50)+ 0.1400000000000000D+00*dw(112, 50)
      JacC( 57, 14) = JacC( 57, 14)+ 0.7000000000000001D-01*dw(112, 14)
      JacC( 57, 50) = JacC( 57, 50)+ 0.7000000000000001D-01*dw(112, 50)
      JacC( 58, 14) = JacC( 58, 14)+ 0.4200000000000000D+00*dw(112, 14)
      JacC( 58, 50) = JacC( 58, 50)+ 0.4200000000000000D+00*dw(112, 50)
      JacC( 60, 14) = JacC( 60, 14)+ 0.1600000000000000D+00*dw(112, 14)
      JacC( 60, 50) = JacC( 60, 50)+ 0.1600000000000000D+00*dw(112, 50)
      JacC( 62, 14) = JacC( 62, 14)+ 0.8500000000000000D+00*dw(112, 14)
      JacC( 62, 50) = JacC( 62, 50)+ 0.8500000000000000D+00*dw(112, 50)
      JacC( 66, 14) = JacC( 66, 14)+ 0.4000000000000000D-01*dw(112, 14)
      JacC( 66, 50) = JacC( 66, 50)+ 0.4000000000000000D-01*dw(112, 50)
      JacC( 71, 14) = JacC( 71, 14)+ 0.1000000000000000D+00*dw(112, 14)
      JacC( 71, 50) = JacC( 71, 50)+ 0.1000000000000000D+00*dw(112, 50)
      JacC( 34, 49) = JacC( 34, 49)+ 0.2200000000000000D+00*dw(113, 49)
      JacC( 34, 50) = JacC( 34, 50)+ 0.2200000000000000D+00*dw(113, 50)
      JacC( 49, 49) = JacC( 49, 49) - dw(113, 49)
      JacC( 49, 50) = JacC( 49, 50) - dw(113, 50)
      JacC( 50, 49) = JacC( 50, 49) - dw(113, 49)
      JacC( 50, 50) = JacC( 50, 50) - dw(113, 50)
      JacC( 52, 49) = JacC( 52, 49)+ 0.5400000000000000D+00*dw(113, 49)
      JacC( 52, 50) = JacC( 52, 50)+ 0.5400000000000000D+00*dw(113, 50)
      JacC( 53, 49) = JacC( 53, 49)+ 0.1300000000000000D+00*dw(113, 49)
      JacC( 53, 50) = JacC( 53, 50)+ 0.1300000000000000D+00*dw(113, 50)
      JacC( 54, 49) = JacC( 54, 49)+ 0.6000000000000000D+00*dw(113, 49)
      JacC( 54, 50) = JacC( 54, 50)+ 0.6000000000000000D+00*dw(113, 50)
      JacC( 57, 49) = JacC( 57, 49)+ 0.1300000000000000D+00*dw(113, 49)
      JacC( 57, 50) = JacC( 57, 50)+ 0.1300000000000000D+00*dw(113, 50)
      JacC( 62, 49) = JacC( 62, 49)+ 0.7000000000000001D-01*dw(113, 49)
      JacC( 62, 50) = JacC( 62, 50)+ 0.7000000000000001D-01*dw(113, 50)
      JacC( 66, 49) = JacC( 66, 49)+ 0.4000000000000000D+00*dw(113, 49)
      JacC( 66, 50) = JacC( 66, 50)+ 0.4000000000000000D+00*dw(113, 50)
      JacC( 69, 49) = JacC( 69, 49)+ 0.1300000000000000D+00*dw(113, 49)
      JacC( 69, 50) = JacC( 69, 50)+ 0.1300000000000000D+00*dw(113, 50)
      JacC( 71, 49) = JacC( 71, 49)+ 0.2900000000000000D+00*dw(113, 49)
      JacC( 71, 50) = JacC( 71, 50)+ 0.2900000000000000D+00*dw(113, 50)
      JacC( 28, 48) = JacC( 28, 48)+ 0.1100000000000000D+00*dw(114, 48)
      JacC( 28, 50) = JacC( 28, 50)+ 0.1100000000000000D+00*dw(114, 50)
      JacC( 34, 48) = JacC( 34, 48)+ 0.1100000000000000D+00*dw(114, 48)
      JacC( 34, 50) = JacC( 34, 50)+ 0.1100000000000000D+00*dw(114, 50)
      JacC( 48, 48) = JacC( 48, 48) - dw(114, 48)
      JacC( 48, 50) = JacC( 48, 50) - dw(114, 50)
      JacC( 50, 48) = JacC( 50, 48) - dw(114, 48)
      JacC( 50, 50) = JacC( 50, 50) - dw(114, 50)
      JacC( 51, 48) = JacC( 51, 48)+ 0.5000000000000000D+00*dw(114, 48)
      JacC( 51, 50) = JacC( 51, 50)+ 0.5000000000000000D+00*dw(114, 50)
      JacC( 52, 48) = JacC( 52, 48)+ 0.6600000000000000D+00*dw(114, 48)
      JacC( 52, 50) = JacC( 52, 50)+ 0.6600000000000000D+00*dw(114, 50)
      JacC( 54, 48) = JacC( 54, 48)+ 0.6200000000000000D+00*dw(114, 48)
      JacC( 54, 50) = JacC( 54, 50)+ 0.6200000000000000D+00*dw(114, 50)
      JacC( 57, 48) = JacC( 57, 48)+ 0.2100000000000000D+00*dw(114, 48)
      JacC( 57, 50) = JacC( 57, 50)+ 0.2100000000000000D+00*dw(114, 50)
      JacC( 61, 48) = JacC( 61, 48)+ 0.1600000000000000D+00*dw(114, 48)
      JacC( 61, 50) = JacC( 61, 50)+ 0.1600000000000000D+00*dw(114, 50)
      JacC( 62, 48) = JacC( 62, 48)+ 0.2100000000000000D+00*dw(114, 48)
      JacC( 62, 50) = JacC( 62, 50)+ 0.2100000000000000D+00*dw(114, 50)
      JacC( 69, 48) = JacC( 69, 48)+ 0.2800000000000000D+00*dw(114, 48)
      JacC( 69, 50) = JacC( 69, 50)+ 0.2800000000000000D+00*dw(114, 50)
      JacC( 71, 48) = JacC( 71, 48)+ 0.2900000000000000D+00*dw(114, 48)
      JacC( 71, 50) = JacC( 71, 50)+ 0.2900000000000000D+00*dw(114, 50)
      JacC( 25, 25) = JacC( 25, 25) - dw(115, 25)
      JacC( 25, 50) = JacC( 25, 50) - dw(115, 50)
      JacC( 26, 25) = JacC( 26, 25)+ 0.3000000000000000D+00*dw(115, 25)
      JacC( 26, 50) = JacC( 26, 50)+ 0.3000000000000000D+00*dw(115, 50)
      JacC( 34, 25) = JacC( 34, 25)+ 0.1100000000000000D+00*dw(115, 25)
      JacC( 34, 50) = JacC( 34, 50)+ 0.1100000000000000D+00*dw(115, 50)
      JacC( 50, 25) = JacC( 50, 25) - dw(115, 25)
      JacC( 50, 50) = JacC( 50, 50) - dw(115, 50)
      JacC( 52, 25) = JacC( 52, 25)+ 0.1300000000000000D+00*dw(115, 25)
      JacC( 52, 50) = JacC( 52, 50)+ 0.1300000000000000D+00*dw(115, 50)
      JacC( 62, 25) = JacC( 62, 25)+ 0.3600000000000000D-01*dw(115, 25)
      JacC( 62, 50) = JacC( 62, 50)+ 0.3600000000000000D-01*dw(115, 50)
      JacC( 66, 25) = JacC( 66, 25)+ 0.7000000000000000D+00*dw(115, 25)
      JacC( 66, 50) = JacC( 66, 50)+ 0.7000000000000000D+00*dw(115, 50)
      JacC( 69, 25) = JacC( 69, 25)+ 0.7000000000000000D+00*dw(115, 25)
      JacC( 69, 50) = JacC( 69, 50)+ 0.7000000000000000D+00*dw(115, 50)
      JacC( 71, 25) = JacC( 71, 25)+ 0.8000000000000000D-01*dw(115, 25)
      JacC( 71, 50) = JacC( 71, 50)+ 0.8000000000000000D-01*dw(115, 50)
      JacC( 72, 25) = JacC( 72, 25)+ 0.7000000000000000D+00*dw(115, 25)
      JacC( 72, 50) = JacC( 72, 50)+ 0.7000000000000000D+00*dw(115, 50)
      JacC( 29, 29) = JacC( 29, 29) - dw(116, 29)
      JacC( 29, 72) = JacC( 29, 72) - dw(116, 72)
      JacC( 30, 29) = JacC( 30, 29)+ 0.1000000000000000D+00*dw(116, 29)
      JacC( 30, 72) = JacC( 30, 72)+ 0.1000000000000000D+00*dw(116, 72)
      JacC( 70, 29) = JacC( 70, 29) + dw(116, 29)
      JacC( 70, 72) = JacC( 70, 72) + dw(116, 72)
      JacC( 72, 29) = JacC( 72, 29) - dw(116, 29)
      JacC( 72, 72) = JacC( 72, 72) - dw(116, 72)
      JacC( 29, 29) = JacC( 29, 29) - dw(117, 29)
      JacC( 29, 71) = JacC( 29, 71) - dw(117, 71)
      JacC( 30, 29) = JacC( 30, 29) + dw(117, 29)
      JacC( 30, 71) = JacC( 30, 71) + dw(117, 71)
      JacC( 71, 29) = JacC( 71, 29) - dw(117, 29)
      JacC( 71, 71) = JacC( 71, 71) - dw(117, 71)
      JacC( 17, 17) = JacC( 17, 17) - dw(118, 17)
      JacC( 17, 72) = JacC( 17, 72) - dw(118, 72)
      JacC( 23, 17) = JacC( 23, 17) + dw(118, 17)
      JacC( 23, 72) = JacC( 23, 72) + dw(118, 72)
      JacC( 30, 17) = JacC( 30, 17) + dw(118, 17)
      JacC( 30, 72) = JacC( 30, 72) + dw(118, 72)
      JacC( 72, 17) = JacC( 72, 17) - dw(118, 17)
      JacC( 72, 72) = JacC( 72, 72) - dw(118, 72)
      JacC( 17, 17) = JacC( 17, 17) - dw(119, 17)
      JacC( 30, 17) = JacC( 30, 17)+ 0.2000000000000000D-01*dw(119, 17)
      JacC( 31, 17) = JacC( 31, 17)+ 0.9800000000000000D+00*dw(119, 17)
      JacC( 71, 17) = JacC( 71, 17)+ 0.2000000000000000D-01*dw(119, 17)
      JacC( 17, 17) = JacC( 17, 17) - dw(120, 17)
      JacC( 17, 50) = JacC( 17, 50) - dw(120, 50)
      JacC( 30, 17) = JacC( 30, 17) + dw(120, 17)
      JacC( 30, 50) = JacC( 30, 50) + dw(120, 50)
      JacC( 50, 17) = JacC( 50, 17) - dw(120, 17)
      JacC( 50, 50) = JacC( 50, 50) - dw(120, 50)
      JacC( 62, 17) = JacC( 62, 17) + dw(120, 17)
      JacC( 62, 50) = JacC( 62, 50) + dw(120, 50)
      JacC( 18, 18) = JacC( 18, 18) - dw(121, 18)
      JacC( 18, 72) = JacC( 18, 72) - dw(121, 72)
      JacC( 23, 18) = JacC( 23, 18) + dw(121, 18)
      JacC( 23, 72) = JacC( 23, 72) + dw(121, 72)
      JacC( 30, 18) = JacC( 30, 18) + dw(121, 18)
      JacC( 30, 72) = JacC( 30, 72) + dw(121, 72)
      JacC( 72, 18) = JacC( 72, 18) - dw(121, 18)
      JacC( 72, 72) = JacC( 72, 72) - dw(121, 72)
      JacC( 18, 18) = JacC( 18, 18) - dw(122, 18)
      JacC( 30, 18) = JacC( 30, 18)+ 0.2000000000000000D-01*dw(122, 18)
      JacC( 32, 18) = JacC( 32, 18)+ 0.9800000000000000D+00*dw(122, 18)
      JacC( 71, 18) = JacC( 71, 18)+ 0.2000000000000000D-01*dw(122, 18)
      JacC( 18, 18) = JacC( 18, 18) - dw(123, 18)
      JacC( 18, 50) = JacC( 18, 50) - dw(123, 50)
      JacC( 30, 18) = JacC( 30, 18) + dw(123, 18)
      JacC( 30, 50) = JacC( 30, 50) + dw(123, 50)
      JacC( 50, 18) = JacC( 50, 18) - dw(123, 18)
      JacC( 50, 50) = JacC( 50, 50) - dw(123, 50)
      JacC( 62, 18) = JacC( 62, 18) + dw(123, 18)
      JacC( 62, 50) = JacC( 62, 50) + dw(123, 50)
      JacC( 22, 22) = JacC( 22, 22) - dw(124, 22)
      JacC( 22, 72) = JacC( 22, 72) - dw(124, 72)
      JacC( 23, 22) = JacC( 23, 22) + dw(124, 22)
      JacC( 23, 72) = JacC( 23, 72) + dw(124, 72)
      JacC( 30, 22) = JacC( 30, 22) + dw(124, 22)
      JacC( 30, 72) = JacC( 30, 72) + dw(124, 72)
      JacC( 72, 22) = JacC( 72, 22) - dw(124, 22)
      JacC( 72, 72) = JacC( 72, 72) - dw(124, 72)
      JacC( 22, 22) = JacC( 22, 22) - dw(125, 22)
      JacC( 30, 22) = JacC( 30, 22)+ 0.2000000000000000D-01*dw(125, 22)
      JacC( 33, 22) = JacC( 33, 22)+ 0.9800000000000000D+00*dw(125, 22)
      JacC( 71, 22) = JacC( 71, 22)+ 0.2000000000000000D-01*dw(125, 22)
      JacC( 22, 22) = JacC( 22, 22) - dw(126, 22)
      JacC( 22, 50) = JacC( 22, 50) - dw(126, 50)
      JacC( 30, 22) = JacC( 30, 22) + dw(126, 22)
      JacC( 30, 50) = JacC( 30, 50) + dw(126, 50)
      JacC( 50, 22) = JacC( 50, 22) - dw(126, 22)
      JacC( 50, 50) = JacC( 50, 50) - dw(126, 50)
      JacC( 62, 22) = JacC( 62, 22) + dw(126, 22)
      JacC( 62, 50) = JacC( 62, 50) + dw(126, 50)
      JacC( 26, 69) = JacC( 26, 69) + dw(127, 69)
      JacC( 26, 72) = JacC( 26, 72) + dw(127, 72)
      JacC( 69, 69) = JacC( 69, 69) - dw(127, 69)
      JacC( 69, 72) = JacC( 69, 72) - dw(127, 72)
      JacC( 72, 69) = JacC( 72, 69) - dw(127, 69)
      JacC( 72, 72) = JacC( 72, 72) - dw(127, 72)
      JacC( 26, 26) = JacC( 26, 26) - dw(128, 26)
      JacC( 69, 26) = JacC( 69, 26) + dw(128, 26)
      JacC( 72, 26) = JacC( 72, 26) + dw(128, 26)
      JacC( 25, 56) = JacC( 25, 56) + dw(129, 56)
      JacC( 25, 72) = JacC( 25, 72) + dw(129, 72)
      JacC( 56, 56) = JacC( 56, 56) - dw(129, 56)
      JacC( 56, 72) = JacC( 56, 72) - dw(129, 72)
      JacC( 72, 56) = JacC( 72, 56) - dw(129, 56)
      JacC( 72, 72) = JacC( 72, 72) - dw(129, 72)
      JacC( 25, 25) = JacC( 25, 25) - dw(130, 25)
      JacC( 56, 25) = JacC( 56, 25) + dw(130, 25)
      JacC( 72, 25) = JacC( 72, 25) + dw(130, 25)
      JacC( 63, 63) = JacC( 63, 63) - dw(131, 63)
      JacC( 63, 67) = JacC( 63, 67) - dw(131, 67)
      JacC( 66, 63) = JacC( 66, 63) + dw(131, 63)
      JacC( 66, 67) = JacC( 66, 67) + dw(131, 67)
      JacC( 67, 63) = JacC( 67, 63) - dw(131, 63)
      JacC( 67, 67) = JacC( 67, 67) - dw(131, 67)
      JacC( 71, 63) = JacC( 71, 63) + dw(131, 63)
      JacC( 71, 67) = JacC( 71, 67) + dw(131, 67)
      JacC( 72, 63) = JacC( 72, 63) + dw(131, 63)
      JacC( 72, 67) = JacC( 72, 67) + dw(131, 67)
      JacC( 60, 60) = JacC( 60, 60) - dw(132, 60)
      JacC( 60, 67) = JacC( 60, 67) - dw(132, 67)
      JacC( 61, 60) = JacC( 61, 60) + dw(132, 60)
      JacC( 61, 67) = JacC( 61, 67) + dw(132, 67)
      JacC( 67, 60) = JacC( 67, 60) - dw(132, 60)
      JacC( 67, 67) = JacC( 67, 67) - dw(132, 67)
      JacC( 71, 60) = JacC( 71, 60) + dw(132, 60)
      JacC( 71, 67) = JacC( 71, 67) + dw(132, 67)
      JacC( 72, 60) = JacC( 72, 60) + dw(132, 60)
      JacC( 72, 67) = JacC( 72, 67) + dw(132, 67)
      JacC( 51, 64) = JacC( 51, 64)+ 0.6300000000000000D-01*dw(133, 64)
      JacC( 51, 67) = JacC( 51, 67)+ 0.6300000000000000D-01*dw(133, 67)
      JacC( 59, 64) = JacC( 59, 64)+ 0.6230000000000000D+00*dw(133, 64)
      JacC( 59, 67) = JacC( 59, 67)+ 0.6230000000000000D+00*dw(133, 67)
      JacC( 60, 64) = JacC( 60, 64)+ 0.4800000000000000D-01*dw(133, 64)
      JacC( 60, 67) = JacC( 60, 67)+ 0.4800000000000000D-01*dw(133, 67)
      JacC( 61, 64) = JacC( 61, 64)+ 0.2330000000000000D+00*dw(133, 64)
      JacC( 61, 67) = JacC( 61, 67)+ 0.2330000000000000D+00*dw(133, 67)
      JacC( 63, 64) = JacC( 63, 64)+ 0.1500000000000000D+00*dw(133, 64)
      JacC( 63, 67) = JacC( 63, 67)+ 0.1500000000000000D+00*dw(133, 67)
      JacC( 64, 64) = JacC( 64, 64) - dw(133, 64)
      JacC( 64, 67) = JacC( 64, 67) - dw(133, 67)
      JacC( 65, 64) = JacC( 65, 64)+ 0.4800000000000000D-01*dw(133, 64)
      JacC( 65, 67) = JacC( 65, 67)+ 0.4800000000000000D-01*dw(133, 67)
      JacC( 66, 64) = JacC( 66, 64)+ 0.4700000000000000D-01*dw(133, 64)
      JacC( 66, 67) = JacC( 66, 67)+ 0.4700000000000000D-01*dw(133, 67)
      JacC( 67, 64) = JacC( 67, 64) - dw(133, 64)
      JacC( 67, 67) = JacC( 67, 67) - dw(133, 67)
      JacC( 70, 64) = JacC( 70, 64)+ 0.5900000000000000D-01*dw(133, 64)
      JacC( 70, 67) = JacC( 70, 67)+ 0.5900000000000000D-01*dw(133, 67)
      JacC( 71, 64) = JacC( 71, 64)+ 0.7420000000000000D+00*dw(133, 64)
      JacC( 71, 67) = JacC( 71, 67)+ 0.7420000000000000D+00*dw(133, 67)
      JacC( 72, 64) = JacC( 72, 64)+ 0.9409999999999999D+00*dw(133, 64)
      JacC( 72, 67) = JacC( 72, 67)+ 0.9409999999999999D+00*dw(133, 67)
      JacC( 36, 36) = JacC( 36, 36) - dw(134, 36)
      JacC( 36, 67) = JacC( 36, 67) - dw(134, 67)
      JacC( 59, 36) = JacC( 59, 36)+ 0.7220000000000000D+00*dw(134, 36)
      JacC( 59, 67) = JacC( 59, 67)+ 0.7220000000000000D+00*dw(134, 67)
      JacC( 60, 36) = JacC( 60, 36)+ 0.2450000000000000D+00*dw(134, 36)
      JacC( 60, 67) = JacC( 60, 67)+ 0.2450000000000000D+00*dw(134, 67)
      JacC( 61, 36) = JacC( 61, 36)+ 0.2110000000000000D+00*dw(134, 36)
      JacC( 61, 67) = JacC( 61, 67)+ 0.2110000000000000D+00*dw(134, 67)
      JacC( 63, 36) = JacC( 63, 36)+ 0.3100000000000000D-01*dw(134, 36)
      JacC( 63, 67) = JacC( 63, 67)+ 0.3100000000000000D-01*dw(134, 67)
      JacC( 65, 36) = JacC( 65, 36)+ 0.3340000000000000D+00*dw(134, 36)
      JacC( 65, 67) = JacC( 65, 67)+ 0.3340000000000000D+00*dw(134, 67)
      JacC( 66, 36) = JacC( 66, 36)+ 0.2100000000000000D-01*dw(134, 36)
      JacC( 66, 67) = JacC( 66, 67)+ 0.2100000000000000D-01*dw(134, 67)
      JacC( 67, 36) = JacC( 67, 36) - dw(134, 36)
      JacC( 67, 67) = JacC( 67, 67) - dw(134, 67)
      JacC( 70, 36) = JacC( 70, 36)+ 0.1240000000000000D+00*dw(134, 36)
      JacC( 70, 67) = JacC( 70, 67)+ 0.1240000000000000D+00*dw(134, 67)
      JacC( 71, 36) = JacC( 71, 36)+ 0.5990000000000000D+00*dw(134, 36)
      JacC( 71, 67) = JacC( 71, 67)+ 0.5990000000000000D+00*dw(134, 67)
      JacC( 72, 36) = JacC( 72, 36)+ 0.8760000000000000D+00*dw(134, 36)
      JacC( 72, 67) = JacC( 72, 67)+ 0.8760000000000000D+00*dw(134, 67)
      JacC( 37, 37) = JacC( 37, 37) - dw(135, 37)
      JacC( 37, 67) = JacC( 37, 67) - dw(135, 67)
      JacC( 59, 37) = JacC( 59, 37)+ 0.6420000000000000D+00*dw(135, 37)
      JacC( 59, 67) = JacC( 59, 67)+ 0.6420000000000000D+00*dw(135, 67)
      JacC( 60, 37) = JacC( 60, 37)+ 0.1330000000000000D+00*dw(135, 37)
      JacC( 60, 67) = JacC( 60, 67)+ 0.1330000000000000D+00*dw(135, 67)
      JacC( 61, 37) = JacC( 61, 37)+ 0.1500000000000000D+00*dw(135, 37)
      JacC( 61, 67) = JacC( 61, 67)+ 0.1500000000000000D+00*dw(135, 67)
      JacC( 65, 37) = JacC( 65, 37)+ 0.4160000000000000D+00*dw(135, 37)
      JacC( 65, 67) = JacC( 65, 67)+ 0.4160000000000000D+00*dw(135, 67)
      JacC( 67, 37) = JacC( 67, 37) - dw(135, 37)
      JacC( 67, 67) = JacC( 67, 67) - dw(135, 67)
      JacC( 70, 37) = JacC( 70, 37)+ 0.2610000000000000D+00*dw(135, 37)
      JacC( 70, 67) = JacC( 70, 67)+ 0.2610000000000000D+00*dw(135, 67)
      JacC( 71, 37) = JacC( 71, 37)+ 0.6060000000000000D+00*dw(135, 37)
      JacC( 71, 67) = JacC( 71, 67)+ 0.6060000000000000D+00*dw(135, 67)
      JacC( 72, 37) = JacC( 72, 37)+ 0.7390000000000000D+00*dw(135, 37)
      JacC( 72, 67) = JacC( 72, 67)+ 0.7390000000000000D+00*dw(135, 67)
      JacC( 38, 38) = JacC( 38, 38) - dw(136, 38)
      JacC( 38, 67) = JacC( 38, 67) - dw(136, 67)
      JacC( 61, 38) = JacC( 61, 38)+ 0.2000000000000000D+00*dw(136, 38)
      JacC( 61, 67) = JacC( 61, 67)+ 0.2000000000000000D+00*dw(136, 67)
      JacC( 66, 38) = JacC( 66, 38)+ 0.1600000000000000D+01*dw(136, 38)
      JacC( 66, 67) = JacC( 66, 67)+ 0.1600000000000000D+01*dw(136, 67)
      JacC( 67, 38) = JacC( 67, 38) - dw(136, 38)
      JacC( 67, 67) = JacC( 67, 67) - dw(136, 67)
      JacC( 71, 38) = JacC( 71, 38) + dw(136, 38)
      JacC( 71, 67) = JacC( 71, 67) + dw(136, 67)
      JacC( 72, 38) = JacC( 72, 38) + dw(136, 38)
      JacC( 72, 67) = JacC( 72, 67) + dw(136, 67)
      JacC( 41, 41) = JacC( 41, 41) - dw(137, 41)
      JacC( 41, 67) = JacC( 41, 67) - dw(137, 67)
      JacC( 59, 41) = JacC( 59, 41)+ 0.6000000000000000D-01*dw(137, 41)
      JacC( 59, 67) = JacC( 59, 67)+ 0.6000000000000000D-01*dw(137, 67)
      JacC( 61, 41) = JacC( 61, 41)+ 0.9399999999999999D+00*dw(137, 41)
      JacC( 61, 67) = JacC( 61, 67)+ 0.9399999999999999D+00*dw(137, 67)
      JacC( 66, 41) = JacC( 66, 41) + dw(137, 41)
      JacC( 66, 67) = JacC( 66, 67) + dw(137, 67)
      JacC( 67, 41) = JacC( 67, 41) - dw(137, 41)
      JacC( 67, 67) = JacC( 67, 67) - dw(137, 67)
      JacC( 71, 41) = JacC( 71, 41) + dw(137, 41)
      JacC( 71, 67) = JacC( 71, 67) + dw(137, 67)
      JacC( 72, 41) = JacC( 72, 41) + dw(137, 41)
      JacC( 72, 67) = JacC( 72, 67) + dw(137, 67)
      JacC( 45, 45) = JacC( 45, 45) - dw(138, 45)
      JacC( 45, 67) = JacC( 45, 67) - dw(138, 67)
      JacC( 59, 45) = JacC( 59, 45)+ 0.2900000000000000D+00*dw(138, 45)
      JacC( 59, 67) = JacC( 59, 67)+ 0.2900000000000000D+00*dw(138, 67)
      JacC( 61, 45) = JacC( 61, 45)+ 0.1710000000000000D+01*dw(138, 45)
      JacC( 61, 67) = JacC( 61, 67)+ 0.1710000000000000D+01*dw(138, 67)
      JacC( 67, 45) = JacC( 67, 45) - dw(138, 45)
      JacC( 67, 67) = JacC( 67, 67) - dw(138, 67)
      JacC( 71, 45) = JacC( 71, 45) + dw(138, 45)
      JacC( 71, 67) = JacC( 71, 67) + dw(138, 67)
      JacC( 72, 45) = JacC( 72, 45) + dw(138, 45)
      JacC( 72, 67) = JacC( 72, 67) + dw(138, 67)
      JacC( 39, 39) = JacC( 39, 39) - dw(139, 39)
      JacC( 39, 67) = JacC( 39, 67) - dw(139, 67)
      JacC( 40, 39) = JacC( 40, 39)+ 0.3540000000000000D+00*dw(139, 39)
      JacC( 40, 67) = JacC( 40, 67)+ 0.3540000000000000D+00*dw(139, 67)
      JacC( 49, 39) = JacC( 49, 39)+ 0.4460000000000000D+00*dw(139, 39)
      JacC( 49, 67) = JacC( 49, 67)+ 0.4460000000000000D+00*dw(139, 67)
      JacC( 66, 39) = JacC( 66, 39)+ 0.6060000000000000D+00*dw(139, 39)
      JacC( 66, 67) = JacC( 66, 67)+ 0.6060000000000000D+00*dw(139, 67)
      JacC( 67, 39) = JacC( 67, 39) - dw(139, 39)
      JacC( 67, 67) = JacC( 67, 67) - dw(139, 67)
      JacC( 70, 39) = JacC( 70, 39)+ 0.1530000000000000D+00*dw(139, 39)
      JacC( 70, 67) = JacC( 70, 67)+ 0.1530000000000000D+00*dw(139, 67)
      JacC( 71, 39) = JacC( 71, 39)+ 0.8470000000000000D+00*dw(139, 39)
      JacC( 71, 67) = JacC( 71, 67)+ 0.8470000000000000D+00*dw(139, 67)
      JacC( 72, 39) = JacC( 72, 39)+ 0.8470000000000000D+00*dw(139, 39)
      JacC( 72, 67) = JacC( 72, 67)+ 0.8470000000000000D+00*dw(139, 67)
      JacC( 42, 42) = JacC( 42, 42) - dw(140, 42)
      JacC( 42, 67) = JacC( 42, 67) - dw(140, 67)
      JacC( 59, 42) = JacC( 59, 42)+ 0.8000000000000000D+00*dw(140, 42)
      JacC( 59, 67) = JacC( 59, 67)+ 0.8000000000000000D+00*dw(140, 67)
      JacC( 61, 42) = JacC( 61, 42)+ 0.8000000000000000D+00*dw(140, 42)
      JacC( 61, 67) = JacC( 61, 67)+ 0.8000000000000000D+00*dw(140, 67)
      JacC( 67, 42) = JacC( 67, 42) - dw(140, 42)
      JacC( 67, 67) = JacC( 67, 67) - dw(140, 67)
      JacC( 70, 42) = JacC( 70, 42)+ 0.2000000000000000D+00*dw(140, 42)
      JacC( 70, 67) = JacC( 70, 67)+ 0.2000000000000000D+00*dw(140, 67)
      JacC( 71, 42) = JacC( 71, 42)+ 0.8000000000000000D+00*dw(140, 42)
      JacC( 71, 67) = JacC( 71, 67)+ 0.8000000000000000D+00*dw(140, 67)
      JacC( 72, 42) = JacC( 72, 42)+ 0.8000000000000000D+00*dw(140, 42)
      JacC( 72, 67) = JacC( 72, 67)+ 0.8000000000000000D+00*dw(140, 67)
      JacC( 43, 43) = JacC( 43, 43) - dw(141, 43)
      JacC( 43, 67) = JacC( 43, 67) - dw(141, 67)
      JacC( 44, 43) = JacC( 44, 43)+ 0.2500000000000000D+00*dw(141, 43)
      JacC( 44, 67) = JacC( 44, 67)+ 0.2500000000000000D+00*dw(141, 67)
      JacC( 49, 43) = JacC( 49, 43)+ 0.4000000000000000D+00*dw(141, 43)
      JacC( 49, 67) = JacC( 49, 67)+ 0.4000000000000000D+00*dw(141, 67)
      JacC( 66, 43) = JacC( 66, 43)+ 0.2500000000000000D+00*dw(141, 43)
      JacC( 66, 67) = JacC( 66, 67)+ 0.2500000000000000D+00*dw(141, 67)
      JacC( 67, 43) = JacC( 67, 43) - dw(141, 43)
      JacC( 67, 67) = JacC( 67, 67) - dw(141, 67)
      JacC( 70, 43) = JacC( 70, 43)+ 0.3500000000000000D+00*dw(141, 43)
      JacC( 70, 67) = JacC( 70, 67)+ 0.3500000000000000D+00*dw(141, 67)
      JacC( 71, 43) = JacC( 71, 43)+ 0.6500000000000000D+00*dw(141, 43)
      JacC( 71, 67) = JacC( 71, 67)+ 0.6500000000000000D+00*dw(141, 67)
      JacC( 72, 43) = JacC( 72, 43)+ 0.6500000000000000D+00*dw(141, 43)
      JacC( 72, 67) = JacC( 72, 67)+ 0.6500000000000000D+00*dw(141, 67)
      JacC( 31, 31) = JacC( 31, 31) - dw(142, 31)
      JacC( 31, 67) = JacC( 31, 67) - dw(142, 67)
      JacC( 48, 31) = JacC( 48, 31)+ 0.5000000000000000D+00*dw(142, 31)
      JacC( 48, 67) = JacC( 48, 67)+ 0.5000000000000000D+00*dw(142, 67)
      JacC( 51, 31) = JacC( 51, 31)+ 0.1200000000000000D+01*dw(142, 31)
      JacC( 51, 67) = JacC( 51, 67)+ 0.1200000000000000D+01*dw(142, 67)
      JacC( 54, 31) = JacC( 54, 31)+ 0.6500000000000000D+00*dw(142, 31)
      JacC( 54, 67) = JacC( 54, 67)+ 0.6500000000000000D+00*dw(142, 67)
      JacC( 67, 31) = JacC( 67, 31) - dw(142, 31)
      JacC( 67, 67) = JacC( 67, 67) - dw(142, 67)
      JacC( 70, 31) = JacC( 70, 31)+ 0.5000000000000000D-01*dw(142, 31)
      JacC( 70, 67) = JacC( 70, 67)+ 0.5000000000000000D-01*dw(142, 67)
      JacC( 71, 31) = JacC( 71, 31)+ 0.9500000000000000D+00*dw(142, 31)
      JacC( 71, 67) = JacC( 71, 67)+ 0.9500000000000000D+00*dw(142, 67)
      JacC( 72, 31) = JacC( 72, 31)+ 0.9500000000000000D+00*dw(142, 31)
      JacC( 72, 67) = JacC( 72, 67)+ 0.9500000000000000D+00*dw(142, 67)
      JacC( 32, 32) = JacC( 32, 32) - dw(143, 32)
      JacC( 32, 67) = JacC( 32, 67) - dw(143, 67)
      JacC( 48, 32) = JacC( 48, 32)+ 0.9500000000000000D+00*dw(143, 32)
      JacC( 48, 67) = JacC( 48, 67)+ 0.9500000000000000D+00*dw(143, 67)
      JacC( 51, 32) = JacC( 51, 32)+ 0.3500000000000000D+00*dw(143, 32)
      JacC( 51, 67) = JacC( 51, 67)+ 0.3500000000000000D+00*dw(143, 67)
      JacC( 54, 32) = JacC( 54, 32)+ 0.6000000000000000D+00*dw(143, 32)
      JacC( 54, 67) = JacC( 54, 67)+ 0.6000000000000000D+00*dw(143, 67)
      JacC( 67, 32) = JacC( 67, 32) - dw(143, 32)
      JacC( 67, 67) = JacC( 67, 67) - dw(143, 67)
      JacC( 70, 32) = JacC( 70, 32)+ 0.5000000000000000D-01*dw(143, 32)
      JacC( 70, 67) = JacC( 70, 67)+ 0.5000000000000000D-01*dw(143, 67)
      JacC( 71, 32) = JacC( 71, 32)+ 0.9500000000000000D+00*dw(143, 32)
      JacC( 71, 67) = JacC( 71, 67)+ 0.9500000000000000D+00*dw(143, 67)
      JacC( 72, 32) = JacC( 72, 32)+ 0.9500000000000000D+00*dw(143, 32)
      JacC( 72, 67) = JacC( 72, 67)+ 0.9500000000000000D+00*dw(143, 67)
      JacC( 33, 33) = JacC( 33, 33) - dw(144, 33)
      JacC( 33, 67) = JacC( 33, 67) - dw(144, 67)
      JacC( 51, 33) = JacC( 51, 33) + dw(144, 33)
      JacC( 51, 67) = JacC( 51, 67) + dw(144, 67)
      JacC( 54, 33) = JacC( 54, 33) + dw(144, 33)
      JacC( 54, 67) = JacC( 54, 67) + dw(144, 67)
      JacC( 67, 33) = JacC( 67, 33) - dw(144, 33)
      JacC( 67, 67) = JacC( 67, 67) - dw(144, 67)
      JacC( 71, 33) = JacC( 71, 33) + dw(144, 33)
      JacC( 71, 67) = JacC( 71, 67) + dw(144, 67)
      JacC( 72, 33) = JacC( 72, 33) + dw(144, 33)
      JacC( 72, 67) = JacC( 72, 67) + dw(144, 67)
      JacC( 63, 69) = JacC( 63, 69) + dw(145, 69)
      JacC( 63, 67) = JacC( 63, 67) + dw(145, 67)
      JacC( 67, 69) = JacC( 67, 69) - dw(145, 69)
      JacC( 67, 67) = JacC( 67, 67) - dw(145, 67)
      JacC( 69, 69) = JacC( 69, 69) - dw(145, 69)
      JacC( 69, 67) = JacC( 69, 67) - dw(145, 67)
      JacC( 72, 69) = JacC( 72, 69) + dw(145, 69)
      JacC( 72, 67) = JacC( 72, 67) + dw(145, 67)
      JacC( 56, 56) = JacC( 56, 56) - dw(146, 56)
      JacC( 56, 67) = JacC( 56, 67) - dw(146, 67)
      JacC( 66, 56) = JacC( 66, 56) + dw(146, 56)
      JacC( 66, 67) = JacC( 66, 67) + dw(146, 67)
      JacC( 67, 56) = JacC( 67, 56) - dw(146, 56)
      JacC( 67, 67) = JacC( 67, 67) - dw(146, 67)
      JacC( 69, 56) = JacC( 69, 56) + dw(146, 56)
      JacC( 69, 67) = JacC( 69, 67) + dw(146, 67)
      JacC( 72, 56) = JacC( 72, 56) + dw(146, 56)
      JacC( 72, 67) = JacC( 72, 67) + dw(146, 67)
      JacC( 54, 58) = JacC( 54, 58)+ 0.5400000000000000D+00*dw(147, 58)
      JacC( 54, 67) = JacC( 54, 67)+ 0.5400000000000000D+00*dw(147, 67)
      JacC( 58, 58) = JacC( 58, 58) - dw(147, 58)
      JacC( 58, 67) = JacC( 58, 67) - dw(147, 67)
      JacC( 61, 58) = JacC( 61, 58)+ 0.4600000000000000D+00*dw(147, 58)
      JacC( 61, 67) = JacC( 61, 67)+ 0.4600000000000000D+00*dw(147, 67)
      JacC( 65, 58) = JacC( 65, 58)+ 0.1600000000000000D+00*dw(147, 58)
      JacC( 65, 67) = JacC( 65, 67)+ 0.1600000000000000D+00*dw(147, 67)
      JacC( 67, 58) = JacC( 67, 58) - dw(147, 58)
      JacC( 67, 67) = JacC( 67, 67) - dw(147, 67)
      JacC( 69, 58) = JacC( 69, 58)+ 0.2300000000000000D+00*dw(147, 58)
      JacC( 69, 67) = JacC( 69, 67)+ 0.2300000000000000D+00*dw(147, 67)
      JacC( 71, 58) = JacC( 71, 58)+ 0.7700000000000000D+00*dw(147, 58)
      JacC( 71, 67) = JacC( 71, 67)+ 0.7700000000000000D+00*dw(147, 67)
      JacC( 72, 58) = JacC( 72, 58) + dw(147, 58)
      JacC( 72, 67) = JacC( 72, 67) + dw(147, 67)
      JacC( 47, 47) = JacC( 47, 47) - dw(148, 47)
      JacC( 47, 67) = JacC( 47, 67) - dw(148, 67)
      JacC( 67, 47) = JacC( 67, 47) - dw(148, 47)
      JacC( 67, 67) = JacC( 67, 67) - dw(148, 67)
      JacC( 70, 47) = JacC( 70, 47) + dw(148, 47)
      JacC( 70, 67) = JacC( 70, 67) + dw(148, 67)
      JacC( 71, 47) = JacC( 71, 47) + dw(148, 47)
      JacC( 71, 67) = JacC( 71, 67) + dw(148, 67)
      JacC( 72, 47) = JacC( 72, 47) + dw(148, 47)
      JacC( 72, 67) = JacC( 72, 67) + dw(148, 67)
      JacC( 46, 46) = JacC( 46, 46) - dw(149, 46)
      JacC( 46, 67) = JacC( 46, 67) - dw(149, 67)
      JacC( 59, 46) = JacC( 59, 46)+ 0.4640000000000000D+00*dw(149, 46)
      JacC( 59, 67) = JacC( 59, 67)+ 0.4640000000000000D+00*dw(149, 67)
      JacC( 61, 46) = JacC( 61, 46)+ 0.1240000000000000D+01*dw(149, 46)
      JacC( 61, 67) = JacC( 61, 67)+ 0.1240000000000000D+01*dw(149, 67)
      JacC( 66, 46) = JacC( 66, 46)+ 0.2870000000000000D+00*dw(149, 46)
      JacC( 66, 67) = JacC( 66, 67)+ 0.2870000000000000D+00*dw(149, 67)
      JacC( 67, 46) = JacC( 67, 46) - dw(149, 46)
      JacC( 67, 67) = JacC( 67, 67) - dw(149, 67)
      JacC( 72, 46) = JacC( 72, 46)+ 0.2000000000000000D+01*dw(149, 46)
      JacC( 72, 67) = JacC( 72, 67)+ 0.2000000000000000D+01*dw(149, 67)
      JacC( 16, 63) = JacC( 16, 63) + dw(150, 63)
      JacC( 16, 71) = JacC( 16, 71) + dw(150, 71)
      JacC( 63, 63) = JacC( 63, 63) - dw(150, 63)
      JacC( 63, 71) = JacC( 63, 71) - dw(150, 71)
      JacC( 71, 63) = JacC( 71, 63) - dw(150, 63)
      JacC( 71, 71) = JacC( 71, 71) - dw(150, 71)
      JacC( 53, 60) = JacC( 53, 60) + dw(151, 60)
      JacC( 53, 71) = JacC( 53, 71) + dw(151, 71)
      JacC( 60, 60) = JacC( 60, 60) - dw(151, 60)
      JacC( 60, 71) = JacC( 60, 71) - dw(151, 71)
      JacC( 71, 60) = JacC( 71, 60) - dw(151, 60)
      JacC( 71, 71) = JacC( 71, 71) - dw(151, 71)
      JacC( 53, 64) = JacC( 53, 64) + dw(152, 64)
      JacC( 53, 71) = JacC( 53, 71) + dw(152, 71)
      JacC( 64, 64) = JacC( 64, 64) - dw(152, 64)
      JacC( 64, 71) = JacC( 64, 71) - dw(152, 71)
      JacC( 71, 64) = JacC( 71, 64) - dw(152, 64)
      JacC( 71, 71) = JacC( 71, 71) - dw(152, 71)
      JacC( 36, 36) = JacC( 36, 36) - dw(153, 36)
      JacC( 36, 71) = JacC( 36, 71) - dw(153, 71)
      JacC( 53, 36) = JacC( 53, 36) + dw(153, 36)
      JacC( 53, 71) = JacC( 53, 71) + dw(153, 71)
      JacC( 71, 36) = JacC( 71, 36) - dw(153, 36)
      JacC( 71, 71) = JacC( 71, 71) - dw(153, 71)
      JacC( 37, 37) = JacC( 37, 37) - dw(154, 37)
      JacC( 37, 71) = JacC( 37, 71) - dw(154, 71)
      JacC( 53, 37) = JacC( 53, 37) + dw(154, 37)
      JacC( 53, 71) = JacC( 53, 71) + dw(154, 71)
      JacC( 71, 37) = JacC( 71, 37) - dw(154, 37)
      JacC( 71, 71) = JacC( 71, 71) - dw(154, 71)
      JacC( 38, 38) = JacC( 38, 38) - dw(155, 38)
      JacC( 38, 71) = JacC( 38, 71) - dw(155, 71)
      JacC( 53, 38) = JacC( 53, 38) + dw(155, 38)
      JacC( 53, 71) = JacC( 53, 71) + dw(155, 71)
      JacC( 71, 38) = JacC( 71, 38) - dw(155, 38)
      JacC( 71, 71) = JacC( 71, 71) - dw(155, 71)
      JacC( 41, 41) = JacC( 41, 41) - dw(156, 41)
      JacC( 41, 71) = JacC( 41, 71) - dw(156, 71)
      JacC( 53, 41) = JacC( 53, 41) + dw(156, 41)
      JacC( 53, 71) = JacC( 53, 71) + dw(156, 71)
      JacC( 71, 41) = JacC( 71, 41) - dw(156, 41)
      JacC( 71, 71) = JacC( 71, 71) - dw(156, 71)
      JacC( 45, 45) = JacC( 45, 45) - dw(157, 45)
      JacC( 45, 71) = JacC( 45, 71) - dw(157, 71)
      JacC( 53, 45) = JacC( 53, 45) + dw(157, 45)
      JacC( 53, 71) = JacC( 53, 71) + dw(157, 71)
      JacC( 71, 45) = JacC( 71, 45) - dw(157, 45)
      JacC( 71, 71) = JacC( 71, 71) - dw(157, 71)
      JacC( 39, 39) = JacC( 39, 39) - dw(158, 39)
      JacC( 39, 71) = JacC( 39, 71) - dw(158, 71)
      JacC( 53, 39) = JacC( 53, 39) + dw(158, 39)
      JacC( 53, 71) = JacC( 53, 71) + dw(158, 71)
      JacC( 71, 39) = JacC( 71, 39) - dw(158, 39)
      JacC( 71, 71) = JacC( 71, 71) - dw(158, 71)
      JacC( 42, 42) = JacC( 42, 42) - dw(159, 42)
      JacC( 42, 71) = JacC( 42, 71) - dw(159, 71)
      JacC( 53, 42) = JacC( 53, 42) + dw(159, 42)
      JacC( 53, 71) = JacC( 53, 71) + dw(159, 71)
      JacC( 71, 42) = JacC( 71, 42) - dw(159, 42)
      JacC( 71, 71) = JacC( 71, 71) - dw(159, 71)
      JacC( 43, 43) = JacC( 43, 43) - dw(160, 43)
      JacC( 43, 71) = JacC( 43, 71) - dw(160, 71)
      JacC( 53, 43) = JacC( 53, 43) + dw(160, 43)
      JacC( 53, 71) = JacC( 53, 71) + dw(160, 71)
      JacC( 71, 43) = JacC( 71, 43) - dw(160, 43)
      JacC( 71, 71) = JacC( 71, 71) - dw(160, 71)
      JacC( 31, 31) = JacC( 31, 31) - dw(161, 31)
      JacC( 31, 71) = JacC( 31, 71) - dw(161, 71)
      JacC( 53, 31) = JacC( 53, 31) + dw(161, 31)
      JacC( 53, 71) = JacC( 53, 71) + dw(161, 71)
      JacC( 71, 31) = JacC( 71, 31) - dw(161, 31)
      JacC( 71, 71) = JacC( 71, 71) - dw(161, 71)
      JacC( 32, 32) = JacC( 32, 32) - dw(162, 32)
      JacC( 32, 71) = JacC( 32, 71) - dw(162, 71)
      JacC( 53, 32) = JacC( 53, 32) + dw(162, 32)
      JacC( 53, 71) = JacC( 53, 71) + dw(162, 71)
      JacC( 71, 32) = JacC( 71, 32) - dw(162, 32)
      JacC( 71, 71) = JacC( 71, 71) - dw(162, 71)
      JacC( 33, 33) = JacC( 33, 33) - dw(163, 33)
      JacC( 33, 71) = JacC( 33, 71) - dw(163, 71)
      JacC( 53, 33) = JacC( 53, 33) + dw(163, 33)
      JacC( 53, 71) = JacC( 53, 71) + dw(163, 71)
      JacC( 71, 33) = JacC( 71, 33) - dw(163, 33)
      JacC( 71, 71) = JacC( 71, 71) - dw(163, 71)
      JacC( 28, 69) = JacC( 28, 69) + dw(164, 69)
      JacC( 28, 71) = JacC( 28, 71) + dw(164, 71)
      JacC( 69, 69) = JacC( 69, 69) - dw(164, 69)
      JacC( 69, 71) = JacC( 69, 71) - dw(164, 71)
      JacC( 71, 69) = JacC( 71, 69) - dw(164, 69)
      JacC( 71, 71) = JacC( 71, 71) - dw(164, 71)
      JacC( 50, 69) = JacC( 50, 69) + dw(165, 69)
      JacC( 50, 71) = JacC( 50, 71) + dw(165, 71)
      JacC( 57, 69) = JacC( 57, 69) + dw(165, 69)
      JacC( 57, 71) = JacC( 57, 71) + dw(165, 71)
      JacC( 69, 69) = JacC( 69, 69) - dw(165, 69)
      JacC( 69, 71) = JacC( 69, 71) - dw(165, 71)
      JacC( 71, 69) = JacC( 71, 69) - dw(165, 69)
      JacC( 71, 71) = JacC( 71, 71) - dw(165, 71)
      JacC( 53, 56) = JacC( 53, 56) + dw(166, 56)
      JacC( 53, 71) = JacC( 53, 71) + dw(166, 71)
      JacC( 56, 56) = JacC( 56, 56) - dw(166, 56)
      JacC( 56, 71) = JacC( 56, 71) - dw(166, 71)
      JacC( 71, 56) = JacC( 71, 56) - dw(166, 56)
      JacC( 71, 71) = JacC( 71, 71) - dw(166, 71)
      JacC( 50, 56) = JacC( 50, 56) + dw(167, 56)
      JacC( 50, 71) = JacC( 50, 71) + dw(167, 71)
      JacC( 56, 56) = JacC( 56, 56) - dw(167, 56)
      JacC( 56, 71) = JacC( 56, 71) - dw(167, 71)
      JacC( 57, 56) = JacC( 57, 56) + dw(167, 56)
      JacC( 57, 71) = JacC( 57, 71) + dw(167, 71)
      JacC( 71, 56) = JacC( 71, 56) - dw(167, 56)
      JacC( 71, 71) = JacC( 71, 71) - dw(167, 71)
      JacC( 53, 58) = JacC( 53, 58) + dw(168, 58)
      JacC( 53, 71) = JacC( 53, 71) + dw(168, 71)
      JacC( 58, 58) = JacC( 58, 58) - dw(168, 58)
      JacC( 58, 71) = JacC( 58, 71) - dw(168, 71)
      JacC( 71, 58) = JacC( 71, 58) - dw(168, 58)
      JacC( 71, 71) = JacC( 71, 71) - dw(168, 71)
      JacC( 47, 47) = JacC( 47, 47) - dw(169, 47)
      JacC( 47, 71) = JacC( 47, 71) - dw(169, 71)
      JacC( 70, 47) = JacC( 70, 47) + dw(169, 47)
      JacC( 70, 71) = JacC( 70, 71) + dw(169, 71)
      JacC( 71, 47) = JacC( 71, 47) - dw(169, 47)
      JacC( 71, 71) = JacC( 71, 71) - dw(169, 71)
      JacC( 46, 46) = JacC( 46, 46) - dw(170, 46)
      JacC( 46, 71) = JacC( 46, 71) - dw(170, 71)
      JacC( 70, 46) = JacC( 70, 46) + dw(170, 46)
      JacC( 70, 71) = JacC( 70, 71) + dw(170, 71)
      JacC( 71, 46) = JacC( 71, 46) - dw(170, 46)
      JacC( 71, 71) = JacC( 71, 71) - dw(170, 71)
      JacC( 63, 63) = JacC( 63, 63)- 0.2000000000000000D+01*dw(171, 63)
      JacC( 63, 63) = JacC( 63, 63)- 0.2000000000000000D+01*dw(171, 63)
      JacC( 66, 63) = JacC( 66, 63)+ 0.1330000000000000D+01*dw(171, 63)
      JacC( 66, 63) = JacC( 66, 63)+ 0.1330000000000000D+01*dw(171, 63)
      JacC( 71, 63) = JacC( 71, 63)+ 0.6600000000000000D+00*dw(171, 63)
      JacC( 71, 63) = JacC( 71, 63)+ 0.6600000000000000D+00*dw(171, 63)
      JacC( 60, 60) = JacC( 60, 60) - dw(172, 60)
      JacC( 60, 63) = JacC( 60, 63) - dw(172, 63)
      JacC( 61, 60) = JacC( 61, 60)+ 0.7500000000000000D+00*dw(172, 60)
      JacC( 61, 63) = JacC( 61, 63)+ 0.7500000000000000D+00*dw(172, 63)
      JacC( 63, 60) = JacC( 63, 60) - dw(172, 60)
      JacC( 63, 63) = JacC( 63, 63) - dw(172, 63)
      JacC( 66, 60) = JacC( 66, 60)+ 0.7500000000000000D+00*dw(172, 60)
      JacC( 66, 63) = JacC( 66, 63)+ 0.7500000000000000D+00*dw(172, 63)
      JacC( 71, 60) = JacC( 71, 60) + dw(172, 60)
      JacC( 71, 63) = JacC( 71, 63) + dw(172, 63)
      JacC( 51, 64) = JacC( 51, 64)+ 0.1190000000000000D+00*dw(173, 64)
      JacC( 51, 63) = JacC( 51, 63)+ 0.1190000000000000D+00*dw(173, 63)
      JacC( 54, 64) = JacC( 54, 64)+ 0.5000000000000000D-02*dw(173, 64)
      JacC( 54, 63) = JacC( 54, 63)+ 0.5000000000000000D-02*dw(173, 63)
      JacC( 59, 64) = JacC( 59, 64)+ 0.1800000000000000D-01*dw(173, 64)
      JacC( 59, 63) = JacC( 59, 63)+ 0.1800000000000000D-01*dw(173, 63)
      JacC( 61, 64) = JacC( 61, 64)+ 0.5800000000000000D+00*dw(173, 64)
      JacC( 61, 63) = JacC( 61, 63)+ 0.5800000000000000D+00*dw(173, 63)
      JacC( 63, 64) = JacC( 63, 64)- 0.9930000000000000D+00*dw(173, 64)
      JacC( 63, 63) = JacC( 63, 63)- 0.9930000000000000D+00*dw(173, 63)
      JacC( 64, 64) = JacC( 64, 64) - dw(173, 64)
      JacC( 64, 63) = JacC( 64, 63) - dw(173, 63)
      JacC( 65, 64) = JacC( 65, 64)+ 0.8500000000000001D-01*dw(173, 64)
      JacC( 65, 63) = JacC( 65, 63)+ 0.8500000000000001D-01*dw(173, 63)
      JacC( 66, 64) = JacC( 66, 64)+ 0.8100000000000001D+00*dw(173, 64)
      JacC( 66, 63) = JacC( 66, 63)+ 0.8100000000000001D+00*dw(173, 63)
      JacC( 71, 64) = JacC( 71, 64)+ 0.9920000000000000D+00*dw(173, 64)
      JacC( 71, 63) = JacC( 71, 63)+ 0.9920000000000000D+00*dw(173, 63)
      JacC( 36, 36) = JacC( 36, 36) - dw(174, 36)
      JacC( 36, 63) = JacC( 36, 63) - dw(174, 63)
      JacC( 59, 36) = JacC( 59, 36)+ 0.2400000000000000D+00*dw(174, 36)
      JacC( 59, 63) = JacC( 59, 63)+ 0.2400000000000000D+00*dw(174, 63)
      JacC( 60, 36) = JacC( 60, 36)+ 0.1400000000000000D-01*dw(174, 36)
      JacC( 60, 63) = JacC( 60, 63)+ 0.1400000000000000D-01*dw(174, 63)
      JacC( 61, 36) = JacC( 61, 36)+ 0.5230000000000000D+00*dw(174, 36)
      JacC( 61, 63) = JacC( 61, 63)+ 0.5230000000000000D+00*dw(174, 63)
      JacC( 63, 36) = JacC( 63, 36)- 0.9510000000000000D+00*dw(174, 36)
      JacC( 63, 63) = JacC( 63, 63)- 0.9510000000000000D+00*dw(174, 63)
      JacC( 65, 36) = JacC( 65, 36)+ 0.2450000000000000D+00*dw(174, 36)
      JacC( 65, 63) = JacC( 65, 63)+ 0.2450000000000000D+00*dw(174, 63)
      JacC( 66, 36) = JacC( 66, 36)+ 0.8290000000000000D+00*dw(174, 36)
      JacC( 66, 63) = JacC( 66, 63)+ 0.8290000000000000D+00*dw(174, 63)
      JacC( 71, 36) = JacC( 71, 36)+ 0.9460000000000000D+00*dw(174, 36)
      JacC( 71, 63) = JacC( 71, 63)+ 0.9460000000000000D+00*dw(174, 63)
      JacC( 37, 37) = JacC( 37, 37) - dw(175, 37)
      JacC( 37, 63) = JacC( 37, 63) - dw(175, 63)
      JacC( 59, 37) = JacC( 59, 37)+ 0.4190000000000000D+00*dw(175, 37)
      JacC( 59, 63) = JacC( 59, 63)+ 0.4190000000000000D+00*dw(175, 63)
      JacC( 60, 37) = JacC( 60, 37)+ 0.1300000000000000D-01*dw(175, 37)
      JacC( 60, 63) = JacC( 60, 63)+ 0.1300000000000000D-01*dw(175, 63)
      JacC( 61, 37) = JacC( 61, 37)+ 0.4110000000000000D+00*dw(175, 37)
      JacC( 61, 63) = JacC( 61, 63)+ 0.4110000000000000D+00*dw(175, 63)
      JacC( 63, 37) = JacC( 63, 37) - dw(175, 37)
      JacC( 63, 63) = JacC( 63, 63) - dw(175, 63)
      JacC( 65, 37) = JacC( 65, 37)+ 0.3220000000000000D+00*dw(175, 37)
      JacC( 65, 63) = JacC( 65, 63)+ 0.3220000000000000D+00*dw(175, 63)
      JacC( 66, 37) = JacC( 66, 37)+ 0.7530000000000000D+00*dw(175, 37)
      JacC( 66, 63) = JacC( 66, 63)+ 0.7530000000000000D+00*dw(175, 63)
      JacC( 71, 37) = JacC( 71, 37)+ 0.9930000000000000D+00*dw(175, 37)
      JacC( 71, 63) = JacC( 71, 63)+ 0.9930000000000000D+00*dw(175, 63)
      JacC( 38, 38) = JacC( 38, 38) - dw(176, 38)
      JacC( 38, 63) = JacC( 38, 63) - dw(176, 63)
      JacC( 61, 38) = JacC( 61, 38)+ 0.3500000000000000D+00*dw(176, 38)
      JacC( 61, 63) = JacC( 61, 63)+ 0.3500000000000000D+00*dw(176, 63)
      JacC( 63, 38) = JacC( 63, 38) - dw(176, 38)
      JacC( 63, 63) = JacC( 63, 63) - dw(176, 63)
      JacC( 66, 38) = JacC( 66, 38)+ 0.1550000000000000D+01*dw(176, 38)
      JacC( 66, 63) = JacC( 66, 63)+ 0.1550000000000000D+01*dw(176, 63)
      JacC( 71, 38) = JacC( 71, 38) + dw(176, 38)
      JacC( 71, 63) = JacC( 71, 63) + dw(176, 63)
      JacC( 41, 41) = JacC( 41, 41) - dw(177, 41)
      JacC( 41, 63) = JacC( 41, 63) - dw(177, 63)
      JacC( 59, 41) = JacC( 59, 41)+ 0.8100000000000000D-01*dw(177, 41)
      JacC( 59, 63) = JacC( 59, 63)+ 0.8100000000000000D-01*dw(177, 63)
      JacC( 61, 41) = JacC( 61, 41)+ 0.6690000000000000D+00*dw(177, 41)
      JacC( 61, 63) = JacC( 61, 63)+ 0.6690000000000000D+00*dw(177, 63)
      JacC( 63, 41) = JacC( 63, 41) - dw(177, 41)
      JacC( 63, 63) = JacC( 63, 63) - dw(177, 63)
      JacC( 66, 41) = JacC( 66, 41)+ 0.1250000000000000D+01*dw(177, 41)
      JacC( 66, 63) = JacC( 66, 63)+ 0.1250000000000000D+01*dw(177, 63)
      JacC( 71, 41) = JacC( 71, 41) + dw(177, 41)
      JacC( 71, 63) = JacC( 71, 63) + dw(177, 63)
      JacC( 45, 45) = JacC( 45, 45) - dw(178, 45)
      JacC( 45, 63) = JacC( 45, 63) - dw(178, 63)
      JacC( 59, 45) = JacC( 59, 45)+ 0.3130000000000000D+00*dw(178, 45)
      JacC( 59, 63) = JacC( 59, 63)+ 0.3130000000000000D+00*dw(178, 63)
      JacC( 61, 45) = JacC( 61, 45)+ 0.9320000000000001D+00*dw(178, 45)
      JacC( 61, 63) = JacC( 61, 63)+ 0.9320000000000001D+00*dw(178, 63)
      JacC( 63, 45) = JacC( 63, 45) - dw(178, 45)
      JacC( 63, 63) = JacC( 63, 63) - dw(178, 63)
      JacC( 66, 45) = JacC( 66, 45)+ 0.7550000000000000D+00*dw(178, 45)
      JacC( 66, 63) = JacC( 66, 63)+ 0.7550000000000000D+00*dw(178, 63)
      JacC( 71, 45) = JacC( 71, 45) + dw(178, 45)
      JacC( 71, 63) = JacC( 71, 63) + dw(178, 63)
      JacC( 39, 39) = JacC( 39, 39) - dw(179, 39)
      JacC( 39, 63) = JacC( 39, 63) - dw(179, 63)
      JacC( 40, 39) = JacC( 40, 39)+ 0.3700000000000000D+00*dw(179, 39)
      JacC( 40, 63) = JacC( 40, 63)+ 0.3700000000000000D+00*dw(179, 63)
      JacC( 44, 39) = JacC( 44, 39)+ 0.8000000000000000D-01*dw(179, 39)
      JacC( 44, 63) = JacC( 44, 63)+ 0.8000000000000000D-01*dw(179, 63)
      JacC( 49, 39) = JacC( 49, 39)+ 0.5500000000000000D+00*dw(179, 39)
      JacC( 49, 63) = JacC( 49, 63)+ 0.5500000000000000D+00*dw(179, 63)
      JacC( 63, 39) = JacC( 63, 39) - dw(179, 39)
      JacC( 63, 63) = JacC( 63, 63) - dw(179, 63)
      JacC( 66, 39) = JacC( 66, 39)+ 0.1090000000000000D+01*dw(179, 39)
      JacC( 66, 63) = JacC( 66, 63)+ 0.1090000000000000D+01*dw(179, 63)
      JacC( 71, 39) = JacC( 71, 39) + dw(179, 39)
      JacC( 71, 63) = JacC( 71, 63) + dw(179, 63)
      JacC( 42, 42) = JacC( 42, 42) - dw(180, 42)
      JacC( 42, 63) = JacC( 42, 63) - dw(180, 63)
      JacC( 59, 42) = JacC( 59, 42) + dw(180, 42)
      JacC( 59, 63) = JacC( 59, 63) + dw(180, 63)
      JacC( 61, 42) = JacC( 61, 42) + dw(180, 42)
      JacC( 61, 63) = JacC( 61, 63) + dw(180, 63)
      JacC( 63, 42) = JacC( 63, 42) - dw(180, 42)
      JacC( 63, 63) = JacC( 63, 63) - dw(180, 63)
      JacC( 66, 42) = JacC( 66, 42) + dw(180, 42)
      JacC( 66, 63) = JacC( 66, 63) + dw(180, 63)
      JacC( 71, 42) = JacC( 71, 42)+ 0.2000000000000000D+01*dw(180, 42)
      JacC( 71, 63) = JacC( 71, 63)+ 0.2000000000000000D+01*dw(180, 63)
      JacC( 43, 43) = JacC( 43, 43) - dw(181, 43)
      JacC( 43, 63) = JacC( 43, 63) - dw(181, 63)
      JacC( 44, 43) = JacC( 44, 43)+ 0.4000000000000000D+00*dw(181, 43)
      JacC( 44, 63) = JacC( 44, 63)+ 0.4000000000000000D+00*dw(181, 63)
      JacC( 49, 43) = JacC( 49, 43)+ 0.6000000000000000D+00*dw(181, 43)
      JacC( 49, 63) = JacC( 49, 63)+ 0.6000000000000000D+00*dw(181, 63)
      JacC( 63, 43) = JacC( 63, 43) - dw(181, 43)
      JacC( 63, 63) = JacC( 63, 63) - dw(181, 63)
      JacC( 66, 43) = JacC( 66, 43)+ 0.1400000000000000D+01*dw(181, 43)
      JacC( 66, 63) = JacC( 66, 63)+ 0.1400000000000000D+01*dw(181, 63)
      JacC( 71, 43) = JacC( 71, 43)+ 0.2000000000000000D+01*dw(181, 43)
      JacC( 71, 63) = JacC( 71, 63)+ 0.2000000000000000D+01*dw(181, 63)
      JacC( 31, 31) = JacC( 31, 31) - dw(182, 31)
      JacC( 31, 63) = JacC( 31, 63) - dw(182, 63)
      JacC( 48, 31) = JacC( 48, 31) + dw(182, 31)
      JacC( 48, 63) = JacC( 48, 63) + dw(182, 63)
      JacC( 51, 31) = JacC( 51, 31)+ 0.6500000000000000D+00*dw(182, 31)
      JacC( 51, 63) = JacC( 51, 63)+ 0.6500000000000000D+00*dw(182, 63)
      JacC( 54, 31) = JacC( 54, 31)+ 0.3500000000000000D+00*dw(182, 31)
      JacC( 54, 63) = JacC( 54, 63)+ 0.3500000000000000D+00*dw(182, 63)
      JacC( 63, 31) = JacC( 63, 31) - dw(182, 31)
      JacC( 63, 63) = JacC( 63, 63) - dw(182, 63)
      JacC( 66, 31) = JacC( 66, 31) + dw(182, 31)
      JacC( 66, 63) = JacC( 66, 63) + dw(182, 63)
      JacC( 71, 31) = JacC( 71, 31) + dw(182, 31)
      JacC( 71, 63) = JacC( 71, 63) + dw(182, 63)
      JacC( 32, 32) = JacC( 32, 32) - dw(183, 32)
      JacC( 32, 63) = JacC( 32, 63) - dw(183, 63)
      JacC( 48, 32) = JacC( 48, 32) + dw(183, 32)
      JacC( 48, 63) = JacC( 48, 63) + dw(183, 63)
      JacC( 51, 32) = JacC( 51, 32)+ 0.3700000000000000D+00*dw(183, 32)
      JacC( 51, 63) = JacC( 51, 63)+ 0.3700000000000000D+00*dw(183, 63)
      JacC( 54, 32) = JacC( 54, 32)+ 0.6300000000000000D+00*dw(183, 32)
      JacC( 54, 63) = JacC( 54, 63)+ 0.6300000000000000D+00*dw(183, 63)
      JacC( 63, 32) = JacC( 63, 32) - dw(183, 32)
      JacC( 63, 63) = JacC( 63, 63) - dw(183, 63)
      JacC( 66, 32) = JacC( 66, 32) + dw(183, 32)
      JacC( 66, 63) = JacC( 66, 63) + dw(183, 63)
      JacC( 71, 32) = JacC( 71, 32) + dw(183, 32)
      JacC( 71, 63) = JacC( 71, 63) + dw(183, 63)
      JacC( 33, 33) = JacC( 33, 33) - dw(184, 33)
      JacC( 33, 63) = JacC( 33, 63) - dw(184, 63)
      JacC( 51, 33) = JacC( 51, 33) + dw(184, 33)
      JacC( 51, 63) = JacC( 51, 63) + dw(184, 63)
      JacC( 54, 33) = JacC( 54, 33) + dw(184, 33)
      JacC( 54, 63) = JacC( 54, 63) + dw(184, 63)
      JacC( 63, 33) = JacC( 63, 33) - dw(184, 33)
      JacC( 63, 63) = JacC( 63, 63) - dw(184, 63)
      JacC( 66, 33) = JacC( 66, 33) + dw(184, 33)
      JacC( 66, 63) = JacC( 66, 63) + dw(184, 63)
      JacC( 71, 33) = JacC( 71, 33)+ 0.2000000000000000D+01*dw(184, 33)
      JacC( 71, 63) = JacC( 71, 63)+ 0.2000000000000000D+01*dw(184, 63)
      JacC( 66, 69) = JacC( 66, 69) + dw(185, 69)
      JacC( 66, 63) = JacC( 66, 63) + dw(185, 63)
      JacC( 69, 69) = JacC( 69, 69) - dw(185, 69)
      JacC( 69, 63) = JacC( 69, 63) - dw(185, 63)
      JacC( 71, 69) = JacC( 71, 69) + dw(185, 69)
      JacC( 71, 63) = JacC( 71, 63) + dw(185, 63)
      JacC( 57, 69) = JacC( 57, 69) + dw(186, 69)
      JacC( 57, 63) = JacC( 57, 63) + dw(186, 63)
      JacC( 63, 69) = JacC( 63, 69) - dw(186, 69)
      JacC( 63, 63) = JacC( 63, 63) - dw(186, 63)
      JacC( 66, 69) = JacC( 66, 69) + dw(186, 69)
      JacC( 66, 63) = JacC( 66, 63) + dw(186, 63)
      JacC( 69, 69) = JacC( 69, 69) - dw(186, 69)
      JacC( 69, 63) = JacC( 69, 63) - dw(186, 63)
      JacC( 56, 56) = JacC( 56, 56) - dw(187, 56)
      JacC( 56, 63) = JacC( 56, 63) - dw(187, 63)
      JacC( 63, 56) = JacC( 63, 56) - dw(187, 56)
      JacC( 63, 63) = JacC( 63, 63) - dw(187, 63)
      JacC( 66, 56) = JacC( 66, 56)+ 0.2000000000000000D+01*dw(187, 56)
      JacC( 66, 63) = JacC( 66, 63)+ 0.2000000000000000D+01*dw(187, 63)
      JacC( 69, 56) = JacC( 69, 56) + dw(187, 56)
      JacC( 69, 63) = JacC( 69, 63) + dw(187, 63)
      JacC( 71, 56) = JacC( 71, 56) + dw(187, 56)
      JacC( 71, 63) = JacC( 71, 63) + dw(187, 63)
      JacC( 56, 56) = JacC( 56, 56) - dw(188, 56)
      JacC( 56, 63) = JacC( 56, 63) - dw(188, 63)
      JacC( 57, 56) = JacC( 57, 56) + dw(188, 56)
      JacC( 57, 63) = JacC( 57, 63) + dw(188, 63)
      JacC( 63, 56) = JacC( 63, 56) - dw(188, 56)
      JacC( 63, 63) = JacC( 63, 63) - dw(188, 63)
      JacC( 66, 56) = JacC( 66, 56) + dw(188, 56)
      JacC( 66, 63) = JacC( 66, 63) + dw(188, 63)
      JacC( 24, 58) = JacC( 24, 58)+ 0.3000000000000000D+00*dw(189, 58)
      JacC( 24, 63) = JacC( 24, 63)+ 0.3000000000000000D+00*dw(189, 63)
      JacC( 54, 58) = JacC( 54, 58)+ 0.4000000000000000D+00*dw(189, 58)
      JacC( 54, 63) = JacC( 54, 63)+ 0.4000000000000000D+00*dw(189, 63)
      JacC( 58, 58) = JacC( 58, 58) - dw(189, 58)
      JacC( 58, 63) = JacC( 58, 63) - dw(189, 63)
      JacC( 61, 58) = JacC( 61, 58)+ 0.3000000000000000D+00*dw(189, 58)
      JacC( 61, 63) = JacC( 61, 63)+ 0.3000000000000000D+00*dw(189, 63)
      JacC( 63, 58) = JacC( 63, 58) - dw(189, 58)
      JacC( 63, 63) = JacC( 63, 63) - dw(189, 63)
      JacC( 65, 58) = JacC( 65, 58)+ 0.8000000000000000D-01*dw(189, 58)
      JacC( 65, 63) = JacC( 65, 63)+ 0.8000000000000000D-01*dw(189, 63)
      JacC( 66, 58) = JacC( 66, 58)+ 0.7500000000000000D+00*dw(189, 58)
      JacC( 66, 63) = JacC( 66, 63)+ 0.7500000000000000D+00*dw(189, 63)
      JacC( 69, 58) = JacC( 69, 58)+ 0.1200000000000000D+00*dw(189, 58)
      JacC( 69, 63) = JacC( 69, 63)+ 0.1200000000000000D+00*dw(189, 63)
      JacC( 71, 58) = JacC( 71, 58)+ 0.8800000000000000D+00*dw(189, 58)
      JacC( 71, 63) = JacC( 71, 63)+ 0.8800000000000000D+00*dw(189, 63)
      JacC( 47, 47) = JacC( 47, 47) - dw(190, 47)
      JacC( 47, 63) = JacC( 47, 63) - dw(190, 63)
      JacC( 63, 47) = JacC( 63, 47) - dw(190, 47)
      JacC( 63, 63) = JacC( 63, 63) - dw(190, 63)
      JacC( 66, 47) = JacC( 66, 47)+ 0.7500000000000000D+00*dw(190, 47)
      JacC( 66, 63) = JacC( 66, 63)+ 0.7500000000000000D+00*dw(190, 63)
      JacC( 70, 47) = JacC( 70, 47) + dw(190, 47)
      JacC( 70, 63) = JacC( 70, 63) + dw(190, 63)
      JacC( 71, 47) = JacC( 71, 47) + dw(190, 47)
      JacC( 71, 63) = JacC( 71, 63) + dw(190, 63)
      JacC( 46, 46) = JacC( 46, 46) - dw(191, 46)
      JacC( 46, 63) = JacC( 46, 63) - dw(191, 63)
      JacC( 59, 46) = JacC( 59, 46)+ 0.1490000000000000D+00*dw(191, 46)
      JacC( 59, 63) = JacC( 59, 63)+ 0.1490000000000000D+00*dw(191, 63)
      JacC( 61, 46) = JacC( 61, 46)+ 0.6400000000000000D+00*dw(191, 46)
      JacC( 61, 63) = JacC( 61, 63)+ 0.6400000000000000D+00*dw(191, 63)
      JacC( 63, 46) = JacC( 63, 46) - dw(191, 46)
      JacC( 63, 63) = JacC( 63, 63) - dw(191, 63)
      JacC( 66, 46) = JacC( 66, 46)+ 0.9600000000000000D+00*dw(191, 46)
      JacC( 66, 63) = JacC( 66, 63)+ 0.9600000000000000D+00*dw(191, 63)
      JacC( 70, 46) = JacC( 70, 46)+ 0.5000000000000000D+00*dw(191, 46)
      JacC( 70, 63) = JacC( 70, 63)+ 0.5000000000000000D+00*dw(191, 63)
      JacC( 71, 46) = JacC( 71, 46)+ 0.5000000000000000D+00*dw(191, 46)
      JacC( 71, 63) = JacC( 71, 63)+ 0.5000000000000000D+00*dw(191, 63)
      JacC( 72, 46) = JacC( 72, 46)+ 0.5000000000000000D+00*dw(191, 46)
      JacC( 72, 63) = JacC( 72, 63)+ 0.5000000000000000D+00*dw(191, 63)
      JacC( 57, 60) = JacC( 57, 60)+ 0.5000000000000000D+00*dw(192, 60)
      JacC( 57, 69) = JacC( 57, 69)+ 0.5000000000000000D+00*dw(192, 69)
      JacC( 60, 60) = JacC( 60, 60) - dw(192, 60)
      JacC( 60, 69) = JacC( 60, 69) - dw(192, 69)
      JacC( 61, 60) = JacC( 61, 60) + dw(192, 60)
      JacC( 61, 69) = JacC( 61, 69) + dw(192, 69)
      JacC( 63, 60) = JacC( 63, 60)+ 0.5000000000000000D+00*dw(192, 60)
      JacC( 63, 69) = JacC( 63, 69)+ 0.5000000000000000D+00*dw(192, 69)
      JacC( 69, 60) = JacC( 69, 60) - dw(192, 60)
      JacC( 69, 69) = JacC( 69, 69) - dw(192, 69)
      JacC( 71, 60) = JacC( 71, 60)+ 0.5000000000000000D+00*dw(192, 60)
      JacC( 71, 69) = JacC( 71, 69)+ 0.5000000000000000D+00*dw(192, 69)
      JacC( 51, 64) = JacC( 51, 64)+ 0.1000000000000000D+00*dw(193, 64)
      JacC( 51, 69) = JacC( 51, 69)+ 0.1000000000000000D+00*dw(193, 69)
      JacC( 54, 64) = JacC( 54, 64)+ 0.4000000000000000D-02*dw(193, 64)
      JacC( 54, 69) = JacC( 54, 69)+ 0.4000000000000000D-02*dw(193, 69)
      JacC( 57, 64) = JacC( 57, 64)+ 0.4990000000000000D+00*dw(193, 64)
      JacC( 57, 69) = JacC( 57, 69)+ 0.4990000000000000D+00*dw(193, 69)
      JacC( 59, 64) = JacC( 59, 64)+ 0.1270000000000000D+00*dw(193, 64)
      JacC( 59, 69) = JacC( 59, 69)+ 0.1270000000000000D+00*dw(193, 69)
      JacC( 60, 64) = JacC( 60, 64)+ 0.6000000000000000D-02*dw(193, 64)
      JacC( 60, 69) = JacC( 60, 69)+ 0.6000000000000000D-02*dw(193, 69)
      JacC( 61, 64) = JacC( 61, 64)+ 0.7240000000000000D+00*dw(193, 64)
      JacC( 61, 69) = JacC( 61, 69)+ 0.7240000000000000D+00*dw(193, 69)
      JacC( 63, 64) = JacC( 63, 64)+ 0.5080000000000000D+00*dw(193, 64)
      JacC( 63, 69) = JacC( 63, 69)+ 0.5080000000000000D+00*dw(193, 69)
      JacC( 64, 64) = JacC( 64, 64) - dw(193, 64)
      JacC( 64, 69) = JacC( 64, 69) - dw(193, 69)
      JacC( 65, 64) = JacC( 65, 64)+ 0.7099999999999999D-01*dw(193, 64)
      JacC( 65, 69) = JacC( 65, 69)+ 0.7099999999999999D-01*dw(193, 69)
      JacC( 66, 64) = JacC( 66, 64)+ 0.9100000000000000D-01*dw(193, 64)
      JacC( 66, 69) = JacC( 66, 69)+ 0.9100000000000000D-01*dw(193, 69)
      JacC( 69, 64) = JacC( 69, 64) - dw(193, 64)
      JacC( 69, 69) = JacC( 69, 69) - dw(193, 69)
      JacC( 71, 64) = JacC( 71, 64)+ 0.4880000000000000D+00*dw(193, 64)
      JacC( 71, 69) = JacC( 71, 69)+ 0.4880000000000000D+00*dw(193, 69)
      JacC( 36, 36) = JacC( 36, 36) - dw(194, 36)
      JacC( 36, 69) = JacC( 36, 69) - dw(194, 69)
      JacC( 57, 36) = JacC( 57, 36)+ 0.4950000000000000D+00*dw(194, 36)
      JacC( 57, 69) = JacC( 57, 69)+ 0.4950000000000000D+00*dw(194, 69)
      JacC( 59, 36) = JacC( 59, 36)+ 0.3300000000000000D+00*dw(194, 36)
      JacC( 59, 69) = JacC( 59, 69)+ 0.3300000000000000D+00*dw(194, 69)
      JacC( 60, 36) = JacC( 60, 36)+ 0.1800000000000000D-01*dw(194, 36)
      JacC( 60, 69) = JacC( 60, 69)+ 0.1800000000000000D-01*dw(194, 69)
      JacC( 61, 36) = JacC( 61, 36)+ 0.6770000000000000D+00*dw(194, 36)
      JacC( 61, 69) = JacC( 61, 69)+ 0.6770000000000000D+00*dw(194, 69)
      JacC( 63, 36) = JacC( 63, 36)+ 0.5540000000000000D+00*dw(194, 36)
      JacC( 63, 69) = JacC( 63, 69)+ 0.5540000000000000D+00*dw(194, 69)
      JacC( 65, 36) = JacC( 65, 36)+ 0.2370000000000000D+00*dw(194, 36)
      JacC( 65, 69) = JacC( 65, 69)+ 0.2370000000000000D+00*dw(194, 69)
      JacC( 66, 36) = JacC( 66, 36)+ 0.7600000000000000D-01*dw(194, 36)
      JacC( 66, 69) = JacC( 66, 69)+ 0.7600000000000000D-01*dw(194, 69)
      JacC( 69, 36) = JacC( 69, 36) - dw(194, 36)
      JacC( 69, 69) = JacC( 69, 69) - dw(194, 69)
      JacC( 71, 36) = JacC( 71, 36)+ 0.4380000000000000D+00*dw(194, 36)
      JacC( 71, 69) = JacC( 71, 69)+ 0.4380000000000000D+00*dw(194, 69)
      JacC( 37, 37) = JacC( 37, 37) - dw(195, 37)
      JacC( 37, 69) = JacC( 37, 69) - dw(195, 69)
      JacC( 57, 37) = JacC( 57, 37)+ 0.4950000000000000D+00*dw(195, 37)
      JacC( 57, 69) = JacC( 57, 69)+ 0.4950000000000000D+00*dw(195, 69)
      JacC( 59, 37) = JacC( 59, 37)+ 0.5810000000000000D+00*dw(195, 37)
      JacC( 59, 69) = JacC( 59, 69)+ 0.5810000000000000D+00*dw(195, 69)
      JacC( 60, 37) = JacC( 60, 37)+ 0.1500000000000000D-01*dw(195, 37)
      JacC( 60, 69) = JacC( 60, 69)+ 0.1500000000000000D-01*dw(195, 69)
      JacC( 61, 37) = JacC( 61, 37)+ 0.4970000000000000D+00*dw(195, 37)
      JacC( 61, 69) = JacC( 61, 69)+ 0.4970000000000000D+00*dw(195, 69)
      JacC( 63, 37) = JacC( 63, 37)+ 0.5070000000000000D+00*dw(195, 37)
      JacC( 63, 69) = JacC( 63, 69)+ 0.5070000000000000D+00*dw(195, 69)
      JacC( 65, 37) = JacC( 65, 37)+ 0.3180000000000000D+00*dw(195, 37)
      JacC( 65, 69) = JacC( 65, 69)+ 0.3180000000000000D+00*dw(195, 69)
      JacC( 69, 37) = JacC( 69, 37) - dw(195, 37)
      JacC( 69, 69) = JacC( 69, 69) - dw(195, 69)
      JacC( 71, 37) = JacC( 71, 37)+ 0.4890000000000000D+00*dw(195, 37)
      JacC( 71, 69) = JacC( 71, 69)+ 0.4890000000000000D+00*dw(195, 69)
      JacC( 38, 38) = JacC( 38, 38) - dw(196, 38)
      JacC( 38, 69) = JacC( 38, 69) - dw(196, 69)
      JacC( 57, 38) = JacC( 57, 38)+ 0.5000000000000000D+00*dw(196, 38)
      JacC( 57, 69) = JacC( 57, 69)+ 0.5000000000000000D+00*dw(196, 69)
      JacC( 61, 38) = JacC( 61, 38)+ 0.6000000000000000D+00*dw(196, 38)
      JacC( 61, 69) = JacC( 61, 69)+ 0.6000000000000000D+00*dw(196, 69)
      JacC( 63, 38) = JacC( 63, 38)+ 0.5000000000000000D+00*dw(196, 38)
      JacC( 63, 69) = JacC( 63, 69)+ 0.5000000000000000D+00*dw(196, 69)
      JacC( 66, 38) = JacC( 66, 38)+ 0.8000000000000000D+00*dw(196, 38)
      JacC( 66, 69) = JacC( 66, 69)+ 0.8000000000000000D+00*dw(196, 69)
      JacC( 69, 38) = JacC( 69, 38) - dw(196, 38)
      JacC( 69, 69) = JacC( 69, 69) - dw(196, 69)
      JacC( 71, 38) = JacC( 71, 38)+ 0.5000000000000000D+00*dw(196, 38)
      JacC( 71, 69) = JacC( 71, 69)+ 0.5000000000000000D+00*dw(196, 69)
      JacC( 41, 41) = JacC( 41, 41) - dw(197, 41)
      JacC( 41, 69) = JacC( 41, 69) - dw(197, 69)
      JacC( 57, 41) = JacC( 57, 41)+ 0.4990000000000000D+00*dw(197, 41)
      JacC( 57, 69) = JacC( 57, 69)+ 0.4990000000000000D+00*dw(197, 69)
      JacC( 59, 41) = JacC( 59, 41)+ 0.1410000000000000D+00*dw(197, 41)
      JacC( 59, 69) = JacC( 59, 69)+ 0.1410000000000000D+00*dw(197, 69)
      JacC( 61, 41) = JacC( 61, 41)+ 0.8590000000000000D+00*dw(197, 41)
      JacC( 61, 69) = JacC( 61, 69)+ 0.8590000000000000D+00*dw(197, 69)
      JacC( 63, 41) = JacC( 63, 41)+ 0.5010000000000000D+00*dw(197, 41)
      JacC( 63, 69) = JacC( 63, 69)+ 0.5010000000000000D+00*dw(197, 69)
      JacC( 66, 41) = JacC( 66, 41)+ 0.5010000000000000D+00*dw(197, 41)
      JacC( 66, 69) = JacC( 66, 69)+ 0.5010000000000000D+00*dw(197, 69)
      JacC( 69, 41) = JacC( 69, 41) - dw(197, 41)
      JacC( 69, 69) = JacC( 69, 69) - dw(197, 69)
      JacC( 71, 41) = JacC( 71, 41)+ 0.5010000000000000D+00*dw(197, 41)
      JacC( 71, 69) = JacC( 71, 69)+ 0.5010000000000000D+00*dw(197, 69)
      JacC( 45, 45) = JacC( 45, 45) - dw(198, 45)
      JacC( 45, 69) = JacC( 45, 69) - dw(198, 69)
      JacC( 57, 45) = JacC( 57, 45)+ 0.4900000000000000D+00*dw(198, 45)
      JacC( 57, 69) = JacC( 57, 69)+ 0.4900000000000000D+00*dw(198, 69)
      JacC( 59, 45) = JacC( 59, 45)+ 0.5690000000000000D+00*dw(198, 45)
      JacC( 59, 69) = JacC( 59, 69)+ 0.5690000000000000D+00*dw(198, 69)
      JacC( 61, 45) = JacC( 61, 45)+ 0.9409999999999999D+00*dw(198, 45)
      JacC( 61, 69) = JacC( 61, 69)+ 0.9409999999999999D+00*dw(198, 69)
      JacC( 63, 45) = JacC( 63, 45)+ 0.5100000000000000D+00*dw(198, 45)
      JacC( 63, 69) = JacC( 63, 69)+ 0.5100000000000000D+00*dw(198, 69)
      JacC( 69, 45) = JacC( 69, 45) - dw(198, 45)
      JacC( 69, 69) = JacC( 69, 69) - dw(198, 69)
      JacC( 71, 45) = JacC( 71, 45)+ 0.5100000000000000D+00*dw(198, 45)
      JacC( 71, 69) = JacC( 71, 69)+ 0.5100000000000000D+00*dw(198, 69)
      JacC( 39, 39) = JacC( 39, 39) - dw(199, 39)
      JacC( 39, 69) = JacC( 39, 69) - dw(199, 69)
      JacC( 40, 39) = JacC( 40, 39)+ 0.2290000000000000D+00*dw(199, 39)
      JacC( 40, 69) = JacC( 40, 69)+ 0.2290000000000000D+00*dw(199, 69)
      JacC( 49, 39) = JacC( 49, 39)+ 0.7710000000000000D+00*dw(199, 39)
      JacC( 49, 69) = JacC( 49, 69)+ 0.7710000000000000D+00*dw(199, 69)
      JacC( 57, 39) = JacC( 57, 39)+ 0.4940000000000000D+00*dw(199, 39)
      JacC( 57, 69) = JacC( 57, 69)+ 0.4940000000000000D+00*dw(199, 69)
      JacC( 63, 39) = JacC( 63, 39)+ 0.5060000000000000D+00*dw(199, 39)
      JacC( 63, 69) = JacC( 63, 69)+ 0.5060000000000000D+00*dw(199, 69)
      JacC( 66, 39) = JacC( 66, 39)+ 0.3400000000000000D+00*dw(199, 39)
      JacC( 66, 69) = JacC( 66, 69)+ 0.3400000000000000D+00*dw(199, 69)
      JacC( 69, 39) = JacC( 69, 39) - dw(199, 39)
      JacC( 69, 69) = JacC( 69, 69) - dw(199, 69)
      JacC( 71, 39) = JacC( 71, 39)+ 0.5060000000000000D+00*dw(199, 39)
      JacC( 71, 69) = JacC( 71, 69)+ 0.5060000000000000D+00*dw(199, 69)
      JacC( 42, 42) = JacC( 42, 42) - dw(200, 42)
      JacC( 42, 69) = JacC( 42, 69) - dw(200, 69)
      JacC( 59, 42) = JacC( 59, 42) + dw(200, 42)
      JacC( 59, 69) = JacC( 59, 69) + dw(200, 69)
      JacC( 61, 42) = JacC( 61, 42) + dw(200, 42)
      JacC( 61, 69) = JacC( 61, 69) + dw(200, 69)
      JacC( 63, 42) = JacC( 63, 42) + dw(200, 42)
      JacC( 63, 69) = JacC( 63, 69) + dw(200, 69)
      JacC( 69, 42) = JacC( 69, 42) - dw(200, 42)
      JacC( 69, 69) = JacC( 69, 69) - dw(200, 69)
      JacC( 71, 42) = JacC( 71, 42) + dw(200, 42)
      JacC( 71, 69) = JacC( 71, 69) + dw(200, 69)
      JacC( 43, 43) = JacC( 43, 43) - dw(201, 43)
      JacC( 43, 69) = JacC( 43, 69) - dw(201, 69)
      JacC( 44, 43) = JacC( 44, 43)+ 0.4000000000000000D+00*dw(201, 43)
      JacC( 44, 69) = JacC( 44, 69)+ 0.4000000000000000D+00*dw(201, 69)
      JacC( 49, 43) = JacC( 49, 43)+ 0.6000000000000000D+00*dw(201, 43)
      JacC( 49, 69) = JacC( 49, 69)+ 0.6000000000000000D+00*dw(201, 69)
      JacC( 63, 43) = JacC( 63, 43) + dw(201, 43)
      JacC( 63, 69) = JacC( 63, 69) + dw(201, 69)
      JacC( 66, 43) = JacC( 66, 43)+ 0.4000000000000000D+00*dw(201, 43)
      JacC( 66, 69) = JacC( 66, 69)+ 0.4000000000000000D+00*dw(201, 69)
      JacC( 69, 43) = JacC( 69, 43) - dw(201, 43)
      JacC( 69, 69) = JacC( 69, 69) - dw(201, 69)
      JacC( 71, 43) = JacC( 71, 43) + dw(201, 43)
      JacC( 71, 69) = JacC( 71, 69) + dw(201, 69)
      JacC( 31, 31) = JacC( 31, 31) - dw(202, 31)
      JacC( 31, 69) = JacC( 31, 69) - dw(202, 69)
      JacC( 48, 31) = JacC( 48, 31) + dw(202, 31)
      JacC( 48, 69) = JacC( 48, 69) + dw(202, 69)
      JacC( 51, 31) = JacC( 51, 31)+ 0.6500000000000000D+00*dw(202, 31)
      JacC( 51, 69) = JacC( 51, 69)+ 0.6500000000000000D+00*dw(202, 69)
      JacC( 54, 31) = JacC( 54, 31)+ 0.3500000000000000D+00*dw(202, 31)
      JacC( 54, 69) = JacC( 54, 69)+ 0.3500000000000000D+00*dw(202, 69)
      JacC( 63, 31) = JacC( 63, 31) + dw(202, 31)
      JacC( 63, 69) = JacC( 63, 69) + dw(202, 69)
      JacC( 69, 31) = JacC( 69, 31) - dw(202, 31)
      JacC( 69, 69) = JacC( 69, 69) - dw(202, 69)
      JacC( 71, 31) = JacC( 71, 31) + dw(202, 31)
      JacC( 71, 69) = JacC( 71, 69) + dw(202, 69)
      JacC( 32, 32) = JacC( 32, 32) - dw(203, 32)
      JacC( 32, 69) = JacC( 32, 69) - dw(203, 69)
      JacC( 48, 32) = JacC( 48, 32) + dw(203, 32)
      JacC( 48, 69) = JacC( 48, 69) + dw(203, 69)
      JacC( 51, 32) = JacC( 51, 32)+ 0.3700000000000000D+00*dw(203, 32)
      JacC( 51, 69) = JacC( 51, 69)+ 0.3700000000000000D+00*dw(203, 69)
      JacC( 54, 32) = JacC( 54, 32)+ 0.6300000000000000D+00*dw(203, 32)
      JacC( 54, 69) = JacC( 54, 69)+ 0.6300000000000000D+00*dw(203, 69)
      JacC( 63, 32) = JacC( 63, 32) + dw(203, 32)
      JacC( 63, 69) = JacC( 63, 69) + dw(203, 69)
      JacC( 69, 32) = JacC( 69, 32) - dw(203, 32)
      JacC( 69, 69) = JacC( 69, 69) - dw(203, 69)
      JacC( 71, 32) = JacC( 71, 32) + dw(203, 32)
      JacC( 71, 69) = JacC( 71, 69) + dw(203, 69)
      JacC( 33, 33) = JacC( 33, 33) - dw(204, 33)
      JacC( 33, 69) = JacC( 33, 69) - dw(204, 69)
      JacC( 51, 33) = JacC( 51, 33) + dw(204, 33)
      JacC( 51, 69) = JacC( 51, 69) + dw(204, 69)
      JacC( 54, 33) = JacC( 54, 33) + dw(204, 33)
      JacC( 54, 69) = JacC( 54, 69) + dw(204, 69)
      JacC( 63, 33) = JacC( 63, 33) + dw(204, 33)
      JacC( 63, 69) = JacC( 63, 69) + dw(204, 69)
      JacC( 69, 33) = JacC( 69, 33) - dw(204, 33)
      JacC( 69, 69) = JacC( 69, 69) - dw(204, 69)
      JacC( 71, 33) = JacC( 71, 33) + dw(204, 33)
      JacC( 71, 69) = JacC( 71, 69) + dw(204, 69)
      JacC( 63, 69) = JacC( 63, 69)+ 0.2000000000000000D+01*dw(205, 69)
      JacC( 63, 69) = JacC( 63, 69)+ 0.2000000000000000D+01*dw(205, 69)
      JacC( 69, 69) = JacC( 69, 69)- 0.2000000000000000D+01*dw(205, 69)
      JacC( 69, 69) = JacC( 69, 69)- 0.2000000000000000D+01*dw(205, 69)
      JacC( 56, 56) = JacC( 56, 56) - dw(206, 56)
      JacC( 56, 69) = JacC( 56, 69) - dw(206, 69)
      JacC( 63, 56) = JacC( 63, 56) + dw(206, 56)
      JacC( 63, 69) = JacC( 63, 69) + dw(206, 69)
      JacC( 66, 56) = JacC( 66, 56) + dw(206, 56)
      JacC( 66, 69) = JacC( 66, 69) + dw(206, 69)
      JacC( 54, 58) = JacC( 54, 58)+ 0.5400000000000000D+00*dw(207, 58)
      JacC( 54, 69) = JacC( 54, 69)+ 0.5400000000000000D+00*dw(207, 69)
      JacC( 57, 58) = JacC( 57, 58)+ 0.5000000000000000D+00*dw(207, 58)
      JacC( 57, 69) = JacC( 57, 69)+ 0.5000000000000000D+00*dw(207, 69)
      JacC( 58, 58) = JacC( 58, 58) - dw(207, 58)
      JacC( 58, 69) = JacC( 58, 69) - dw(207, 69)
      JacC( 59, 58) = JacC( 59, 58)+ 0.1100000000000000D+00*dw(207, 58)
      JacC( 59, 69) = JacC( 59, 69)+ 0.1100000000000000D+00*dw(207, 69)
      JacC( 61, 58) = JacC( 61, 58)+ 0.3500000000000000D+00*dw(207, 58)
      JacC( 61, 69) = JacC( 61, 69)+ 0.3500000000000000D+00*dw(207, 69)
      JacC( 63, 58) = JacC( 63, 58)+ 0.5000000000000000D+00*dw(207, 58)
      JacC( 63, 69) = JacC( 63, 69)+ 0.5000000000000000D+00*dw(207, 69)
      JacC( 65, 58) = JacC( 65, 58)+ 0.8000000000000000D-01*dw(207, 58)
      JacC( 65, 69) = JacC( 65, 69)+ 0.8000000000000000D-01*dw(207, 69)
      JacC( 69, 58) = JacC( 69, 58)- 0.8800000000000000D+00*dw(207, 58)
      JacC( 69, 69) = JacC( 69, 69)- 0.8800000000000000D+00*dw(207, 69)
      JacC( 71, 58) = JacC( 71, 58)+ 0.3800000000000000D+00*dw(207, 58)
      JacC( 71, 69) = JacC( 71, 69)+ 0.3800000000000000D+00*dw(207, 69)
      JacC( 47, 47) = JacC( 47, 47) - dw(208, 47)
      JacC( 47, 69) = JacC( 47, 69) - dw(208, 69)
      JacC( 57, 47) = JacC( 57, 47)+ 0.5000000000000000D+00*dw(208, 47)
      JacC( 57, 69) = JacC( 57, 69)+ 0.5000000000000000D+00*dw(208, 69)
      JacC( 63, 47) = JacC( 63, 47)+ 0.5000000000000000D+00*dw(208, 47)
      JacC( 63, 69) = JacC( 63, 69)+ 0.5000000000000000D+00*dw(208, 69)
      JacC( 69, 47) = JacC( 69, 47) - dw(208, 47)
      JacC( 69, 69) = JacC( 69, 69) - dw(208, 69)
      JacC( 70, 47) = JacC( 70, 47) + dw(208, 47)
      JacC( 70, 69) = JacC( 70, 69) + dw(208, 69)
      JacC( 71, 47) = JacC( 71, 47)+ 0.5000000000000000D+00*dw(208, 47)
      JacC( 71, 69) = JacC( 71, 69)+ 0.5000000000000000D+00*dw(208, 69)
      JacC( 46, 46) = JacC( 46, 46) - dw(209, 46)
      JacC( 46, 69) = JacC( 46, 69) - dw(209, 69)
      JacC( 57, 46) = JacC( 57, 46)+ 0.4840000000000000D+00*dw(209, 46)
      JacC( 57, 69) = JacC( 57, 69)+ 0.4840000000000000D+00*dw(209, 69)
      JacC( 59, 46) = JacC( 59, 46)+ 0.1670000000000000D+00*dw(209, 46)
      JacC( 59, 69) = JacC( 59, 69)+ 0.1670000000000000D+00*dw(209, 69)
      JacC( 61, 46) = JacC( 61, 46)+ 0.6500000000000000D+00*dw(209, 46)
      JacC( 61, 69) = JacC( 61, 69)+ 0.6500000000000000D+00*dw(209, 69)
      JacC( 63, 46) = JacC( 63, 46)+ 0.5160000000000000D+00*dw(209, 46)
      JacC( 63, 69) = JacC( 63, 69)+ 0.5160000000000000D+00*dw(209, 69)
      JacC( 66, 46) = JacC( 66, 46)+ 0.2070000000000000D+00*dw(209, 46)
      JacC( 66, 69) = JacC( 66, 69)+ 0.2070000000000000D+00*dw(209, 69)
      JacC( 69, 46) = JacC( 69, 46) - dw(209, 46)
      JacC( 69, 69) = JacC( 69, 69) - dw(209, 69)
      JacC( 70, 46) = JacC( 70, 46)+ 0.4840000000000000D+00*dw(209, 46)
      JacC( 70, 69) = JacC( 70, 69)+ 0.4840000000000000D+00*dw(209, 69)
      JacC( 72, 46) = JacC( 72, 46)+ 0.5160000000000000D+00*dw(209, 46)
      JacC( 72, 69) = JacC( 72, 69)+ 0.5160000000000000D+00*dw(209, 69)
      JacC( 47, 47) = JacC( 47, 47)- 0.2000000000000000D+01*dw(210, 47)
      JacC( 47, 47) = JacC( 47, 47)- 0.2000000000000000D+01*dw(210, 47)
      JacC( 70, 47) = JacC( 70, 47)+ 0.2000000000000000D+01*dw(210, 47)
      JacC( 70, 47) = JacC( 70, 47)+ 0.2000000000000000D+01*dw(210, 47)
      JacC( 71, 47) = JacC( 71, 47) + dw(210, 47)
      JacC( 71, 47) = JacC( 71, 47) + dw(210, 47)
      JacC( 46, 47) = JacC( 46, 47) - dw(211, 47)
      JacC( 46, 46) = JacC( 46, 46) - dw(211, 46)
      JacC( 47, 47) = JacC( 47, 47) - dw(211, 47)
      JacC( 47, 46) = JacC( 47, 46) - dw(211, 46)
      JacC( 59, 47) = JacC( 59, 47)+ 0.1490000000000000D+00*dw(211, 47)
      JacC( 59, 46) = JacC( 59, 46)+ 0.1490000000000000D+00*dw(211, 46)
      JacC( 61, 47) = JacC( 61, 47)+ 0.6400000000000000D+00*dw(211, 47)
      JacC( 61, 46) = JacC( 61, 46)+ 0.6400000000000000D+00*dw(211, 46)
      JacC( 66, 47) = JacC( 66, 47)+ 0.2020000000000000D+00*dw(211, 47)
      JacC( 66, 46) = JacC( 66, 46)+ 0.2020000000000000D+00*dw(211, 46)
      JacC( 70, 47) = JacC( 70, 47)+ 0.1500000000000000D+01*dw(211, 47)
      JacC( 70, 46) = JacC( 70, 46)+ 0.1500000000000000D+01*dw(211, 46)
      JacC( 71, 47) = JacC( 71, 47)+ 0.5000000000000000D+00*dw(211, 47)
      JacC( 71, 46) = JacC( 71, 46)+ 0.5000000000000000D+00*dw(211, 46)
      JacC( 72, 47) = JacC( 72, 47)+ 0.5000000000000000D+00*dw(211, 47)
      JacC( 72, 46) = JacC( 72, 46)+ 0.5000000000000000D+00*dw(211, 46)
      JacC( 46, 46) = JacC( 46, 46)- 0.2000000000000000D+01*dw(212, 46)
      JacC( 46, 46) = JacC( 46, 46)- 0.2000000000000000D+01*dw(212, 46)
      JacC( 59, 46) = JacC( 59, 46)+ 0.2850000000000000D+00*dw(212, 46)
      JacC( 59, 46) = JacC( 59, 46)+ 0.2850000000000000D+00*dw(212, 46)
      JacC( 61, 46) = JacC( 61, 46)+ 0.1210000000000000D+01*dw(212, 46)
      JacC( 61, 46) = JacC( 61, 46)+ 0.1210000000000000D+01*dw(212, 46)
      JacC( 66, 46) = JacC( 66, 46)+ 0.5040000000000000D+00*dw(212, 46)
      JacC( 66, 46) = JacC( 66, 46)+ 0.5040000000000000D+00*dw(212, 46)
      JacC( 70, 46) = JacC( 70, 46) + dw(212, 46)
      JacC( 70, 46) = JacC( 70, 46) + dw(212, 46)
      JacC( 72, 46) = JacC( 72, 46) + dw(212, 46)
      JacC( 72, 46) = JacC( 72, 46) + dw(212, 46)
      JacC( 63, 63) = JacC( 63, 63) - dw(213, 63)
      JacC( 63, 68) = JacC( 63, 68) - dw(213, 68)
      JacC( 66, 63) = JacC( 66, 63) + dw(213, 63)
      JacC( 66, 68) = JacC( 66, 68) + dw(213, 68)
      JacC( 68, 63) = JacC( 68, 63) - dw(213, 63)
      JacC( 68, 68) = JacC( 68, 68) - dw(213, 68)
      JacC( 71, 63) = JacC( 71, 63) + dw(213, 63)
      JacC( 71, 68) = JacC( 71, 68) + dw(213, 68)
      JacC( 72, 63) = JacC( 72, 63) + dw(213, 63)
      JacC( 72, 68) = JacC( 72, 68) + dw(213, 68)
      JacC( 60, 60) = JacC( 60, 60) - dw(214, 60)
      JacC( 60, 68) = JacC( 60, 68) - dw(214, 68)
      JacC( 61, 60) = JacC( 61, 60) + dw(214, 60)
      JacC( 61, 68) = JacC( 61, 68) + dw(214, 68)
      JacC( 68, 60) = JacC( 68, 60) - dw(214, 60)
      JacC( 68, 68) = JacC( 68, 68) - dw(214, 68)
      JacC( 71, 60) = JacC( 71, 60) + dw(214, 60)
      JacC( 71, 68) = JacC( 71, 68) + dw(214, 68)
      JacC( 72, 60) = JacC( 72, 60) + dw(214, 60)
      JacC( 72, 68) = JacC( 72, 68) + dw(214, 68)
      JacC( 51, 64) = JacC( 51, 64)+ 0.6300000000000000D-01*dw(215, 64)
      JacC( 51, 68) = JacC( 51, 68)+ 0.6300000000000000D-01*dw(215, 68)
      JacC( 59, 64) = JacC( 59, 64)+ 0.6700000000000000D+00*dw(215, 64)
      JacC( 59, 68) = JacC( 59, 68)+ 0.6700000000000000D+00*dw(215, 68)
      JacC( 60, 64) = JacC( 60, 64)+ 0.5300000000000000D-01*dw(215, 64)
      JacC( 60, 68) = JacC( 60, 68)+ 0.5300000000000000D-01*dw(215, 68)
      JacC( 61, 64) = JacC( 61, 64)+ 0.2430000000000000D+00*dw(215, 64)
      JacC( 61, 68) = JacC( 61, 68)+ 0.2430000000000000D+00*dw(215, 68)
      JacC( 63, 64) = JacC( 63, 64)+ 0.1550000000000000D+00*dw(215, 64)
      JacC( 63, 68) = JacC( 63, 68)+ 0.1550000000000000D+00*dw(215, 68)
      JacC( 64, 64) = JacC( 64, 64) - dw(215, 64)
      JacC( 64, 68) = JacC( 64, 68) - dw(215, 68)
      JacC( 65, 64) = JacC( 65, 64)+ 0.5100000000000000D-01*dw(215, 64)
      JacC( 65, 68) = JacC( 65, 68)+ 0.5100000000000000D-01*dw(215, 68)
      JacC( 66, 64) = JacC( 66, 64)+ 0.4800000000000000D-01*dw(215, 64)
      JacC( 66, 68) = JacC( 66, 68)+ 0.4800000000000000D-01*dw(215, 68)
      JacC( 68, 64) = JacC( 68, 64) - dw(215, 64)
      JacC( 68, 68) = JacC( 68, 68) - dw(215, 68)
      JacC( 71, 64) = JacC( 71, 64)+ 0.7920000000000000D+00*dw(215, 64)
      JacC( 71, 68) = JacC( 71, 68)+ 0.7920000000000000D+00*dw(215, 68)
      JacC( 72, 64) = JacC( 72, 64) + dw(215, 64)
      JacC( 72, 68) = JacC( 72, 68) + dw(215, 68)
      JacC( 36, 36) = JacC( 36, 36) - dw(216, 36)
      JacC( 36, 68) = JacC( 36, 68) - dw(216, 68)
      JacC( 59, 36) = JacC( 59, 36)+ 0.8280000000000000D+00*dw(216, 36)
      JacC( 59, 68) = JacC( 59, 68)+ 0.8280000000000000D+00*dw(216, 68)
      JacC( 60, 36) = JacC( 60, 36)+ 0.2620000000000000D+00*dw(216, 36)
      JacC( 60, 68) = JacC( 60, 68)+ 0.2620000000000000D+00*dw(216, 68)
      JacC( 61, 36) = JacC( 61, 36)+ 0.2390000000000000D+00*dw(216, 36)
      JacC( 61, 68) = JacC( 61, 68)+ 0.2390000000000000D+00*dw(216, 68)
      JacC( 63, 36) = JacC( 63, 36)+ 0.4000000000000000D-01*dw(216, 36)
      JacC( 63, 68) = JacC( 63, 68)+ 0.4000000000000000D-01*dw(216, 68)
      JacC( 65, 36) = JacC( 65, 36)+ 0.3910000000000000D+00*dw(216, 36)
      JacC( 65, 68) = JacC( 65, 68)+ 0.3910000000000000D+00*dw(216, 68)
      JacC( 66, 36) = JacC( 66, 36)+ 0.2100000000000000D-01*dw(216, 36)
      JacC( 66, 68) = JacC( 66, 68)+ 0.2100000000000000D-01*dw(216, 68)
      JacC( 68, 36) = JacC( 68, 36) - dw(216, 36)
      JacC( 68, 68) = JacC( 68, 68) - dw(216, 68)
      JacC( 71, 36) = JacC( 71, 36)+ 0.6990000000000000D+00*dw(216, 36)
      JacC( 71, 68) = JacC( 71, 68)+ 0.6990000000000000D+00*dw(216, 68)
      JacC( 72, 36) = JacC( 72, 36) + dw(216, 36)
      JacC( 72, 68) = JacC( 72, 68) + dw(216, 68)
      JacC( 37, 37) = JacC( 37, 37) - dw(217, 37)
      JacC( 37, 68) = JacC( 37, 68) - dw(217, 68)
      JacC( 59, 37) = JacC( 59, 37)+ 0.8800000000000000D+00*dw(217, 37)
      JacC( 59, 68) = JacC( 59, 68)+ 0.8800000000000000D+00*dw(217, 68)
      JacC( 60, 37) = JacC( 60, 37)+ 0.1550000000000000D+00*dw(217, 37)
      JacC( 60, 68) = JacC( 60, 68)+ 0.1550000000000000D+00*dw(217, 68)
      JacC( 61, 37) = JacC( 61, 37)+ 0.1870000000000000D+00*dw(217, 37)
      JacC( 61, 68) = JacC( 61, 68)+ 0.1870000000000000D+00*dw(217, 68)
      JacC( 65, 37) = JacC( 65, 37)+ 0.5870000000000000D+00*dw(217, 37)
      JacC( 65, 68) = JacC( 65, 68)+ 0.5870000000000000D+00*dw(217, 68)
      JacC( 68, 37) = JacC( 68, 37) - dw(217, 37)
      JacC( 68, 68) = JacC( 68, 68) - dw(217, 68)
      JacC( 71, 37) = JacC( 71, 37)+ 0.8450000000000000D+00*dw(217, 37)
      JacC( 71, 68) = JacC( 71, 68)+ 0.8450000000000000D+00*dw(217, 68)
      JacC( 72, 37) = JacC( 72, 37) + dw(217, 37)
      JacC( 72, 68) = JacC( 72, 68) + dw(217, 68)
      JacC( 38, 38) = JacC( 38, 38) - dw(218, 38)
      JacC( 38, 68) = JacC( 38, 68) - dw(218, 68)
      JacC( 61, 38) = JacC( 61, 38)+ 0.2000000000000000D+00*dw(218, 38)
      JacC( 61, 68) = JacC( 61, 68)+ 0.2000000000000000D+00*dw(218, 68)
      JacC( 66, 38) = JacC( 66, 38)+ 0.1600000000000000D+01*dw(218, 38)
      JacC( 66, 68) = JacC( 66, 68)+ 0.1600000000000000D+01*dw(218, 68)
      JacC( 68, 38) = JacC( 68, 38) - dw(218, 38)
      JacC( 68, 68) = JacC( 68, 68) - dw(218, 68)
      JacC( 71, 38) = JacC( 71, 38) + dw(218, 38)
      JacC( 71, 68) = JacC( 71, 68) + dw(218, 68)
      JacC( 72, 38) = JacC( 72, 38) + dw(218, 38)
      JacC( 72, 68) = JacC( 72, 68) + dw(218, 68)
      JacC( 41, 41) = JacC( 41, 41) - dw(219, 41)
      JacC( 41, 68) = JacC( 41, 68) - dw(219, 68)
      JacC( 59, 41) = JacC( 59, 41)+ 0.6000000000000000D-01*dw(219, 41)
      JacC( 59, 68) = JacC( 59, 68)+ 0.6000000000000000D-01*dw(219, 68)
      JacC( 61, 41) = JacC( 61, 41)+ 0.9399999999999999D+00*dw(219, 41)
      JacC( 61, 68) = JacC( 61, 68)+ 0.9399999999999999D+00*dw(219, 68)
      JacC( 66, 41) = JacC( 66, 41) + dw(219, 41)
      JacC( 66, 68) = JacC( 66, 68) + dw(219, 68)
      JacC( 68, 41) = JacC( 68, 41) - dw(219, 41)
      JacC( 68, 68) = JacC( 68, 68) - dw(219, 68)
      JacC( 71, 41) = JacC( 71, 41) + dw(219, 41)
      JacC( 71, 68) = JacC( 71, 68) + dw(219, 68)
      JacC( 72, 41) = JacC( 72, 41) + dw(219, 41)
      JacC( 72, 68) = JacC( 72, 68) + dw(219, 68)
      JacC( 45, 45) = JacC( 45, 45) - dw(220, 45)
      JacC( 45, 68) = JacC( 45, 68) - dw(220, 68)
      JacC( 59, 45) = JacC( 59, 45)+ 0.2900000000000000D+00*dw(220, 45)
      JacC( 59, 68) = JacC( 59, 68)+ 0.2900000000000000D+00*dw(220, 68)
      JacC( 61, 45) = JacC( 61, 45)+ 0.1710000000000000D+01*dw(220, 45)
      JacC( 61, 68) = JacC( 61, 68)+ 0.1710000000000000D+01*dw(220, 68)
      JacC( 68, 45) = JacC( 68, 45) - dw(220, 45)
      JacC( 68, 68) = JacC( 68, 68) - dw(220, 68)
      JacC( 71, 45) = JacC( 71, 45) + dw(220, 45)
      JacC( 71, 68) = JacC( 71, 68) + dw(220, 68)
      JacC( 72, 45) = JacC( 72, 45) + dw(220, 45)
      JacC( 72, 68) = JacC( 72, 68) + dw(220, 68)
      JacC( 39, 39) = JacC( 39, 39) - dw(221, 39)
      JacC( 39, 68) = JacC( 39, 68) - dw(221, 68)
      JacC( 40, 39) = JacC( 40, 39)+ 0.4000000000000000D+00*dw(221, 39)
      JacC( 40, 68) = JacC( 40, 68)+ 0.4000000000000000D+00*dw(221, 68)
      JacC( 49, 39) = JacC( 49, 39)+ 0.6000000000000000D+00*dw(221, 39)
      JacC( 49, 68) = JacC( 49, 68)+ 0.6000000000000000D+00*dw(221, 68)
      JacC( 66, 39) = JacC( 66, 39)+ 0.6860000000000001D+00*dw(221, 39)
      JacC( 66, 68) = JacC( 66, 68)+ 0.6860000000000001D+00*dw(221, 68)
      JacC( 68, 39) = JacC( 68, 39) - dw(221, 39)
      JacC( 68, 68) = JacC( 68, 68) - dw(221, 68)
      JacC( 71, 39) = JacC( 71, 39) + dw(221, 39)
      JacC( 71, 68) = JacC( 71, 68) + dw(221, 68)
      JacC( 72, 39) = JacC( 72, 39) + dw(221, 39)
      JacC( 72, 68) = JacC( 72, 68) + dw(221, 68)
      JacC( 42, 42) = JacC( 42, 42) - dw(222, 42)
      JacC( 42, 68) = JacC( 42, 68) - dw(222, 68)
      JacC( 59, 42) = JacC( 59, 42) + dw(222, 42)
      JacC( 59, 68) = JacC( 59, 68) + dw(222, 68)
      JacC( 61, 42) = JacC( 61, 42) + dw(222, 42)
      JacC( 61, 68) = JacC( 61, 68) + dw(222, 68)
      JacC( 68, 42) = JacC( 68, 42) - dw(222, 42)
      JacC( 68, 68) = JacC( 68, 68) - dw(222, 68)
      JacC( 71, 42) = JacC( 71, 42) + dw(222, 42)
      JacC( 71, 68) = JacC( 71, 68) + dw(222, 68)
      JacC( 72, 42) = JacC( 72, 42) + dw(222, 42)
      JacC( 72, 68) = JacC( 72, 68) + dw(222, 68)
      JacC( 43, 43) = JacC( 43, 43) - dw(223, 43)
      JacC( 43, 68) = JacC( 43, 68) - dw(223, 68)
      JacC( 44, 43) = JacC( 44, 43)+ 0.4000000000000000D+00*dw(223, 43)
      JacC( 44, 68) = JacC( 44, 68)+ 0.4000000000000000D+00*dw(223, 68)
      JacC( 49, 43) = JacC( 49, 43)+ 0.6000000000000000D+00*dw(223, 43)
      JacC( 49, 68) = JacC( 49, 68)+ 0.6000000000000000D+00*dw(223, 68)
      JacC( 66, 43) = JacC( 66, 43)+ 0.4000000000000000D+00*dw(223, 43)
      JacC( 66, 68) = JacC( 66, 68)+ 0.4000000000000000D+00*dw(223, 68)
      JacC( 68, 43) = JacC( 68, 43) - dw(223, 43)
      JacC( 68, 68) = JacC( 68, 68) - dw(223, 68)
      JacC( 71, 43) = JacC( 71, 43) + dw(223, 43)
      JacC( 71, 68) = JacC( 71, 68) + dw(223, 68)
      JacC( 72, 43) = JacC( 72, 43) + dw(223, 43)
      JacC( 72, 68) = JacC( 72, 68) + dw(223, 68)
      JacC( 31, 31) = JacC( 31, 31) - dw(224, 31)
      JacC( 31, 68) = JacC( 31, 68) - dw(224, 68)
      JacC( 48, 31) = JacC( 48, 31)+ 0.5000000000000000D+00*dw(224, 31)
      JacC( 48, 68) = JacC( 48, 68)+ 0.5000000000000000D+00*dw(224, 68)
      JacC( 51, 31) = JacC( 51, 31)+ 0.1300000000000000D+01*dw(224, 31)
      JacC( 51, 68) = JacC( 51, 68)+ 0.1300000000000000D+01*dw(224, 68)
      JacC( 54, 31) = JacC( 54, 31)+ 0.7000000000000000D+00*dw(224, 31)
      JacC( 54, 68) = JacC( 54, 68)+ 0.7000000000000000D+00*dw(224, 68)
      JacC( 68, 31) = JacC( 68, 31) - dw(224, 31)
      JacC( 68, 68) = JacC( 68, 68) - dw(224, 68)
      JacC( 71, 31) = JacC( 71, 31) + dw(224, 31)
      JacC( 71, 68) = JacC( 71, 68) + dw(224, 68)
      JacC( 72, 31) = JacC( 72, 31) + dw(224, 31)
      JacC( 72, 68) = JacC( 72, 68) + dw(224, 68)
      JacC( 32, 32) = JacC( 32, 32) - dw(225, 32)
      JacC( 32, 68) = JacC( 32, 68) - dw(225, 68)
      JacC( 48, 32) = JacC( 48, 32) + dw(225, 32)
      JacC( 48, 68) = JacC( 48, 68) + dw(225, 68)
      JacC( 51, 32) = JacC( 51, 32)+ 0.7400000000000000D+00*dw(225, 32)
      JacC( 51, 68) = JacC( 51, 68)+ 0.7400000000000000D+00*dw(225, 68)
      JacC( 54, 32) = JacC( 54, 32)+ 0.1260000000000000D+01*dw(225, 32)
      JacC( 54, 68) = JacC( 54, 68)+ 0.1260000000000000D+01*dw(225, 68)
      JacC( 68, 32) = JacC( 68, 32) - dw(225, 32)
      JacC( 68, 68) = JacC( 68, 68) - dw(225, 68)
      JacC( 71, 32) = JacC( 71, 32) + dw(225, 32)
      JacC( 71, 68) = JacC( 71, 68) + dw(225, 68)
      JacC( 72, 32) = JacC( 72, 32) + dw(225, 32)
      JacC( 72, 68) = JacC( 72, 68) + dw(225, 68)
      JacC( 33, 33) = JacC( 33, 33) - dw(226, 33)
      JacC( 33, 68) = JacC( 33, 68) - dw(226, 68)
      JacC( 51, 33) = JacC( 51, 33) + dw(226, 33)
      JacC( 51, 68) = JacC( 51, 68) + dw(226, 68)
      JacC( 54, 33) = JacC( 54, 33) + dw(226, 33)
      JacC( 54, 68) = JacC( 54, 68) + dw(226, 68)
      JacC( 68, 33) = JacC( 68, 33) - dw(226, 33)
      JacC( 68, 68) = JacC( 68, 68) - dw(226, 68)
      JacC( 71, 33) = JacC( 71, 33) + dw(226, 33)
      JacC( 71, 68) = JacC( 71, 68) + dw(226, 68)
      JacC( 72, 33) = JacC( 72, 33) + dw(226, 33)
      JacC( 72, 68) = JacC( 72, 68) + dw(226, 68)
      JacC( 63, 69) = JacC( 63, 69) + dw(227, 69)
      JacC( 63, 68) = JacC( 63, 68) + dw(227, 68)
      JacC( 68, 69) = JacC( 68, 69) - dw(227, 69)
      JacC( 68, 68) = JacC( 68, 68) - dw(227, 68)
      JacC( 69, 69) = JacC( 69, 69) - dw(227, 69)
      JacC( 69, 68) = JacC( 69, 68) - dw(227, 68)
      JacC( 72, 69) = JacC( 72, 69) + dw(227, 69)
      JacC( 72, 68) = JacC( 72, 68) + dw(227, 68)
      JacC( 56, 56) = JacC( 56, 56) - dw(228, 56)
      JacC( 56, 68) = JacC( 56, 68) - dw(228, 68)
      JacC( 66, 56) = JacC( 66, 56) + dw(228, 56)
      JacC( 66, 68) = JacC( 66, 68) + dw(228, 68)
      JacC( 68, 56) = JacC( 68, 56) - dw(228, 56)
      JacC( 68, 68) = JacC( 68, 68) - dw(228, 68)
      JacC( 69, 56) = JacC( 69, 56) + dw(228, 56)
      JacC( 69, 68) = JacC( 69, 68) + dw(228, 68)
      JacC( 72, 56) = JacC( 72, 56) + dw(228, 56)
      JacC( 72, 68) = JacC( 72, 68) + dw(228, 68)
      JacC( 54, 58) = JacC( 54, 58)+ 0.5400000000000000D+00*dw(229, 58)
      JacC( 54, 68) = JacC( 54, 68)+ 0.5400000000000000D+00*dw(229, 68)
      JacC( 58, 58) = JacC( 58, 58) - dw(229, 58)
      JacC( 58, 68) = JacC( 58, 68) - dw(229, 68)
      JacC( 61, 58) = JacC( 61, 58)+ 0.4600000000000000D+00*dw(229, 58)
      JacC( 61, 68) = JacC( 61, 68)+ 0.4600000000000000D+00*dw(229, 68)
      JacC( 65, 58) = JacC( 65, 58)+ 0.1600000000000000D+00*dw(229, 58)
      JacC( 65, 68) = JacC( 65, 68)+ 0.1600000000000000D+00*dw(229, 68)
      JacC( 68, 58) = JacC( 68, 58) - dw(229, 58)
      JacC( 68, 68) = JacC( 68, 68) - dw(229, 68)
      JacC( 69, 58) = JacC( 69, 58)+ 0.2300000000000000D+00*dw(229, 58)
      JacC( 69, 68) = JacC( 69, 68)+ 0.2300000000000000D+00*dw(229, 68)
      JacC( 71, 58) = JacC( 71, 58)+ 0.7700000000000000D+00*dw(229, 58)
      JacC( 71, 68) = JacC( 71, 68)+ 0.7700000000000000D+00*dw(229, 68)
      JacC( 72, 58) = JacC( 72, 58) + dw(229, 58)
      JacC( 72, 68) = JacC( 72, 68) + dw(229, 68)
      JacC( 47, 47) = JacC( 47, 47) - dw(230, 47)
      JacC( 47, 68) = JacC( 47, 68) - dw(230, 68)
      JacC( 68, 47) = JacC( 68, 47) - dw(230, 47)
      JacC( 68, 68) = JacC( 68, 68) - dw(230, 68)
      JacC( 70, 47) = JacC( 70, 47) + dw(230, 47)
      JacC( 70, 68) = JacC( 70, 68) + dw(230, 68)
      JacC( 71, 47) = JacC( 71, 47) + dw(230, 47)
      JacC( 71, 68) = JacC( 71, 68) + dw(230, 68)
      JacC( 72, 47) = JacC( 72, 47) + dw(230, 47)
      JacC( 72, 68) = JacC( 72, 68) + dw(230, 68)
      JacC( 46, 46) = JacC( 46, 46) - dw(231, 46)
      JacC( 46, 68) = JacC( 46, 68) - dw(231, 68)
      JacC( 59, 46) = JacC( 59, 46)+ 0.4690000000000000D+00*dw(231, 46)
      JacC( 59, 68) = JacC( 59, 68)+ 0.4690000000000000D+00*dw(231, 68)
      JacC( 61, 46) = JacC( 61, 46)+ 0.1240000000000000D+01*dw(231, 46)
      JacC( 61, 68) = JacC( 61, 68)+ 0.1240000000000000D+01*dw(231, 68)
      JacC( 66, 46) = JacC( 66, 46)+ 0.2800000000000000D+00*dw(231, 46)
      JacC( 66, 68) = JacC( 66, 68)+ 0.2800000000000000D+00*dw(231, 68)
      JacC( 68, 46) = JacC( 68, 46) - dw(231, 46)
      JacC( 68, 68) = JacC( 68, 68) - dw(231, 68)
      JacC( 72, 46) = JacC( 72, 46)+ 0.2000000000000000D+01*dw(231, 46)
      JacC( 72, 68) = JacC( 72, 68)+ 0.2000000000000000D+01*dw(231, 68)
      JacC( 53, 65) = JacC( 53, 65) + dw(232, 65)
      JacC( 53, 71) = JacC( 53, 71) + dw(232, 71)
      JacC( 65, 65) = JacC( 65, 65) - dw(232, 65)
      JacC( 65, 71) = JacC( 65, 71) - dw(232, 71)
      JacC( 71, 65) = JacC( 71, 65) - dw(232, 65)
      JacC( 71, 71) = JacC( 71, 71) - dw(232, 71)
      JacC( 63, 65) = JacC( 63, 65) - dw(233, 65)
      JacC( 63, 63) = JacC( 63, 63) - dw(233, 63)
      JacC( 65, 65) = JacC( 65, 65) - dw(233, 65)
      JacC( 65, 63) = JacC( 65, 63) - dw(233, 63)
      JacC( 66, 65) = JacC( 66, 65) + dw(233, 65)
      JacC( 66, 63) = JacC( 66, 63) + dw(233, 63)
      JacC( 71, 65) = JacC( 71, 65) + dw(233, 65)
      JacC( 71, 63) = JacC( 71, 63) + dw(233, 63)
      JacC( 63, 65) = JacC( 63, 65) + dw(234, 65)
      JacC( 63, 69) = JacC( 63, 69) + dw(234, 69)
      JacC( 65, 65) = JacC( 65, 65) - dw(234, 65)
      JacC( 65, 69) = JacC( 65, 69) - dw(234, 69)
      JacC( 69, 65) = JacC( 69, 65) - dw(234, 65)
      JacC( 69, 69) = JacC( 69, 69) - dw(234, 69)
      JacC( 65, 65) = JacC( 65, 65)- 0.2000000000000000D+01*dw(235, 65)
      JacC( 65, 65) = JacC( 65, 65)- 0.2000000000000000D+01*dw(235, 65)
      JacC( 65, 65) = JacC( 65, 65) - dw(236, 65)
      JacC( 65, 67) = JacC( 65, 67) - dw(236, 67)
      JacC( 67, 65) = JacC( 67, 65) - dw(236, 65)
      JacC( 67, 67) = JacC( 67, 67) - dw(236, 67)
      JacC( 72, 65) = JacC( 72, 65) + dw(236, 65)
      JacC( 72, 67) = JacC( 72, 67) + dw(236, 67)
      JacC( 65, 65) = JacC( 65, 65) - dw(237, 65)
      JacC( 65, 68) = JacC( 65, 68) - dw(237, 68)
      JacC( 68, 65) = JacC( 68, 65) - dw(237, 65)
      JacC( 68, 68) = JacC( 68, 68) - dw(237, 68)
      JacC( 72, 65) = JacC( 72, 65) + dw(237, 65)
      JacC( 72, 68) = JacC( 72, 68) + dw(237, 68)
      
      RETURN
      END
      
